DatasetService

Struct DatasetService 

pub struct DatasetService { /* private fields */ }
Implements a client for the BigQuery API.

Example

async fn sample(
) -> anyhow::Result<()> {
    let client = DatasetService::builder().build().await?;
    let response = client.get_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

DatasetService provides methods for managing BigQuery datasets.

Configuration

To configure DatasetService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

DatasetService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap DatasetService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl DatasetService

pub fn builder() -> ClientBuilder

Returns a builder for DatasetService.

let client = DatasetService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: DatasetService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn get_dataset(&self) -> GetDataset

Returns the dataset specified by datasetID.

IAM Permissions

Requires the bigquery.datasets.get permission on the dataset.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let response = client.get_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn insert_dataset(&self) -> InsertDataset

Creates a new empty dataset.

IAM Permissions

Requires the bigquery.datasets.create permission on the project.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let response = client.insert_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn patch_dataset(&self) -> PatchDataset

Updates information in an existing dataset. The update method replaces the entire dataset resource, whereas the patch method only replaces fields that are provided in the submitted dataset resource. This method supports RFC5789 patch semantics.

IAM Permissions

Requires the following IAM permission(s) to use this method:

  • bigquery.datasets.update on the dataset.
  • bigquery.datasets.get on the dataset.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let response = client.patch_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_dataset(&self) -> UpdateDataset

Updates information in an existing dataset. The update method replaces the entire dataset resource, whereas the patch method only replaces fields that are provided in the submitted dataset resource.

IAM Permissions

Requires the bigquery.datasets.update permission on the dataset.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let response = client.update_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_dataset(&self) -> DeleteDataset

Deletes the dataset specified by the datasetId value. Before you can delete a dataset, you must delete all its tables, either manually or by specifying deleteContents. Immediately after deletion, you can create another dataset with the same name.

IAM Permissions

Requires the bigquery.datasets.delete permission on the dataset.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    client.delete_dataset()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn list_datasets(&self) -> ListDatasets

Lists all datasets in the specified project to which the user has been granted the READER dataset role.

IAM Permissions

Requires no specific IAM permission(s) to use this method. Results are filtered to only include datasets on which the caller has the bigquery.datasets.get permission.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let mut list = client.list_datasets()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn undelete_dataset(&self) -> UndeleteDataset

Undeletes a dataset which is within time travel window based on datasetId. If a time is specified, the dataset version deleted at that time is undeleted, else the last live version is undeleted.

IAM Permissions

Requires the following IAM permission(s) to use this method:

  • bigquery.datasets.create on the project.
  • bigquery.datasets.get on the dataset.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &DatasetService
) -> Result<()> {
    let response = client.undelete_dataset()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}