ModelService

Struct ModelService 

pub struct ModelService { /* private fields */ }
Implements a client for the BigQuery API.

Example

async fn sample(
) -> anyhow::Result<()> {
    let client = ModelService::builder().build().await?;
    let response = client.get_model()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

Model Service for BigQuery ML

Configuration

To configure ModelService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

ModelService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap ModelService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl ModelService

pub fn builder() -> ClientBuilder

Returns a builder for ModelService.

let client = ModelService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: ModelService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn get_model(&self) -> GetModel

Gets the specified model resource by model ID.

IAM Permissions

Requires the bigquery.models.getMetadata permission on the model.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &ModelService
) -> Result<()> {
    let response = client.get_model()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_models(&self) -> ListModels

Lists all models in the specified dataset. Requires the READER dataset role. After retrieving the list of models, you can get information about a particular model by calling the models.get method.

IAM Permissions

Requires the bigquery.models.list permission on the dataset.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &ModelService
) -> Result<()> {
    let mut list = client.list_models()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn patch_model(&self) -> PatchModel

Patch specific fields in the specified model.

IAM Permissions

Requires the bigquery.models.updateMetadata permission on the model.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &ModelService
) -> Result<()> {
    let response = client.patch_model()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_model(&self) -> DeleteModel

Deletes the model specified by modelId from the dataset.

IAM Permissions

Requires the bigquery.models.delete permission on the model.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &ModelService
) -> Result<()> {
    client.delete_model()
        /* set fields */
        .send().await?;
    Ok(())
}