pub struct ProjectService { /* private fields */ }Expand description
Implements a client for the BigQuery API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = ProjectService::builder().build().await?;
let response = client.get_service_account()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
This service provides access to BigQuery functionality related to projects.
Configuration
To configure ProjectService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://bigquery.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ProjectService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ProjectService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ProjectService
impl ProjectService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ProjectService.
let client = ProjectService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ProjectService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ProjectService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_service_account(&self) -> GetServiceAccount
pub fn get_service_account(&self) -> GetServiceAccount
RPC to get the service account for a project used for interactions with
Google Cloud KMS. Requires the bigquery.jobs.create permission on the
project resource. This permission is required to authorize the retrieval
of the project’s service identity for technical management tasks like
encryption configuration.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &ProjectService
) -> Result<()> {
let response = client.get_service_account()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for ProjectService
impl Clone for ProjectService
Sourcefn clone(&self) -> ProjectService
fn clone(&self) -> ProjectService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for ProjectService
impl !UnwindSafe for ProjectService
impl Freeze for ProjectService
impl Send for ProjectService
impl Sync for ProjectService
impl Unpin for ProjectService
impl UnsafeUnpin for ProjectService