RoutineService

Struct RoutineService 

pub struct RoutineService { /* private fields */ }
Implements a client for the BigQuery API.

Example

async fn sample(
) -> anyhow::Result<()> {
    let client = RoutineService::builder().build().await?;
    let response = client.get_routine()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

RoutineService provides management access to BigQuery routines.

Configuration

To configure RoutineService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

RoutineService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap RoutineService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl RoutineService

pub fn builder() -> ClientBuilder

Returns a builder for RoutineService.

let client = RoutineService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: RoutineService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn get_routine(&self) -> GetRoutine

Gets the specified routine resource by routine ID.

IAM Permissions

Requires the bigquery.routines.get permission on the routine.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &RoutineService
) -> Result<()> {
    let response = client.get_routine()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn insert_routine(&self) -> InsertRoutine

Creates a new routine in the dataset.

IAM Permissions

Requires the bigquery.routines.create permission on the dataset.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &RoutineService
) -> Result<()> {
    let response = client.insert_routine()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_routine(&self) -> UpdateRoutine

Updates information in an existing routine. The update method replaces the entire Routine resource.

IAM Permissions

Requires the bigquery.routines.update permission on the routine.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &RoutineService
) -> Result<()> {
    let response = client.update_routine()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_routine(&self) -> DeleteRoutine

Deletes the routine specified by routineId from the dataset.

IAM Permissions

Requires the bigquery.routines.delete permission on the routine.

Example
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &RoutineService
) -> Result<()> {
    client.delete_routine()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn list_routines(&self) -> ListRoutines

Lists all routines in the specified dataset. Requires the READER dataset role.

IAM Permissions

Requires the bigquery.routines.list permission on the dataset.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_v2::Result;
async fn sample(
   client: &RoutineService
) -> Result<()> {
    let mut list = client.list_routines()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}