pub struct RowAccessPolicyService { /* private fields */ }Expand description
Implements a client for the BigQuery API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = RowAccessPolicyService::builder().build().await?;
let response = client.get_row_access_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Service for interacting with row access policies.
Configuration
To configure RowAccessPolicyService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://bigquery.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RowAccessPolicyService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RowAccessPolicyService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RowAccessPolicyService
impl RowAccessPolicyService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RowAccessPolicyService.
let client = RowAccessPolicyService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RowAccessPolicyService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RowAccessPolicyService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_row_access_policies(&self) -> ListRowAccessPolicies
pub fn list_row_access_policies(&self) -> ListRowAccessPolicies
Lists all row access policies on the specified table.
IAM Permissions
Requires the bigquery.rowAccessPolicies.list permission on the table.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
let mut list = client.list_row_access_policies()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_row_access_policy(&self) -> GetRowAccessPolicy
pub fn get_row_access_policy(&self) -> GetRowAccessPolicy
Gets the specified row access policy by policy ID.
IAM Permissions
Requires the bigquery.rowAccessPolicies.get permission on the table.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
let response = client.get_row_access_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_row_access_policy(&self) -> CreateRowAccessPolicy
pub fn create_row_access_policy(&self) -> CreateRowAccessPolicy
Creates a row access policy.
IAM Permissions
Requires the following IAM permission(s) on the table:
bigquery.rowAccessPolicies.createbigquery.rowAccessPolicies.setIamPolicybigquery.tables.getData
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
let response = client.create_row_access_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_row_access_policy(&self) -> UpdateRowAccessPolicy
pub fn update_row_access_policy(&self) -> UpdateRowAccessPolicy
Updates a row access policy.
IAM Permissions
Requires the following IAM permission(s) on the table:
bigquery.rowAccessPolicies.updatebigquery.rowAccessPolicies.setIamPolicybigquery.tables.getData
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
let response = client.update_row_access_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_row_access_policy(&self) -> DeleteRowAccessPolicy
pub fn delete_row_access_policy(&self) -> DeleteRowAccessPolicy
Deletes a row access policy.
IAM Permissions
Requires the following IAM permission(s) on the table:
bigquery.rowAccessPolicies.deletebigquery.rowAccessPolicies.setIamPolicy
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
client.delete_row_access_policy()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn batch_delete_row_access_policies(&self) -> BatchDeleteRowAccessPolicies
pub fn batch_delete_row_access_policies(&self) -> BatchDeleteRowAccessPolicies
Deletes provided row access policies.
IAM Permissions
Requires the following IAM permission(s) on the table:
bigquery.rowAccessPolicies.deletebigquery.rowAccessPolicies.setIamPolicy
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &RowAccessPolicyService
) -> Result<()> {
client.batch_delete_row_access_policies()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for RowAccessPolicyService
impl Clone for RowAccessPolicyService
Sourcefn clone(&self) -> RowAccessPolicyService
fn clone(&self) -> RowAccessPolicyService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for RowAccessPolicyService
impl !UnwindSafe for RowAccessPolicyService
impl Freeze for RowAccessPolicyService
impl Send for RowAccessPolicyService
impl Sync for RowAccessPolicyService
impl Unpin for RowAccessPolicyService
impl UnsafeUnpin for RowAccessPolicyService