#[non_exhaustive]pub enum PicosTimestampPrecision {
Unspecified,
TimestampPrecisionMicros,
TimestampPrecisionNanos,
TimestampPrecisionPicos,
UnknownValue(UnknownValue),
}Expand description
The precision of the timestamp value in the Avro message. This precision
will only be applied to the column(s) with the TIMESTAMP_PICOS type.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified timestamp precision. The default precision is microseconds.
TimestampPrecisionMicros
Timestamp values returned in the results will be truncated to microsecond level precision. The value will be encoded as Arrow TIMESTAMP type in a 64 bit integer.
TimestampPrecisionNanos
Timestamp values returned in the results will be truncated to nanosecond level precision. The value will be encoded as Arrow TIMESTAMP type in a 64 bit integer.
TimestampPrecisionPicos
Timestamp values returned in the results will contain full precision picosecond value. The value will be encoded as a string which conforms to ISO 8601 format.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PicosTimestampPrecision::value or PicosTimestampPrecision::name.
Implementations