#[non_exhaustive]pub enum Code {
Unspecified,
NoReservation,
InsufficientReservation,
UnsupportedSqlText,
InputTooLarge,
OtherReason,
TableExcluded,
UnknownValue(UnknownValue),
}Expand description
Indicates the high-level reason for no/partial acceleration
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
BiEngineReason not specified.
NoReservation
No reservation available for BI Engine acceleration.
InsufficientReservation
Not enough memory available for BI Engine acceleration.
UnsupportedSqlText
This particular SQL text is not supported for acceleration by BI Engine.
InputTooLarge
Input too large for acceleration by BI Engine.
OtherReason
Catch-all code for all other cases for partial or disabled acceleration.
TableExcluded
One or more tables were not eligible for BI Engine acceleration.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Code::value or Code::name.
Implementations