#[non_exhaustive]pub enum BiEngineMode {
AccelerationModeUnspecified,
Disabled,
Partial,
Full,
UnknownValue(UnknownValue),
}Expand description
Indicates the type of BI Engine acceleration.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccelerationModeUnspecified
BiEngineMode type not specified.
Disabled
BI Engine disabled the acceleration. bi_engine_reasons specifies a more detailed reason.
Partial
Part of the query was accelerated using BI Engine. See bi_engine_reasons for why parts of the query were not accelerated.
Full
All of the query was accelerated using BI Engine.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using BiEngineMode::value or BiEngineMode::name.
Implementations