#[non_exhaustive]pub enum TimestampOutputFormat {
Unspecified,
Float64,
Int64,
Iso8601String,
UnknownValue(UnknownValue),
}Expand description
The API output format for a timestamp.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Corresponds to default API output behavior, which is FLOAT64.
Float64
Timestamp is output as float64 seconds since Unix epoch.
Int64
Timestamp is output as int64 microseconds since Unix epoch.
Iso8601String
Timestamp is output as ISO 8601 String (“YYYY-MM-DDTHH:MM:SS.FFFFFFFFFFFFZ”).
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TimestampOutputFormat::value or TimestampOutputFormat::name.
Implementations