#[non_exhaustive]pub enum DecimalTargetType {
Unspecified,
Numeric,
Bignumeric,
String,
UnknownValue(UnknownValue),
}Expand description
The data types that could be used as a target type when converting decimal values.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Invalid type.
Numeric
Decimal values could be converted to NUMERIC type.
Bignumeric
Decimal values could be converted to BIGNUMERIC type.
String
Decimal values could be converted to STRING type.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DecimalTargetType::value or DecimalTargetType::name.
Implementations