#[non_exhaustive]pub enum FileSetSpecType {
FileSystemMatch,
NewLineDelimitedManifest,
UnknownValue(UnknownValue),
}Expand description
This enum defines how to interpret source URIs for load jobs and external tables.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FileSystemMatch
This option expands source URIs by listing files from the object store. It is the default behavior if FileSetSpecType is not set.
NewLineDelimitedManifest
This option indicates that the provided URIs are newline-delimited manifest files, with one URI per line. Wildcard URIs are not supported.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using FileSetSpecType::value or FileSetSpecType::name.
Implementations