#[non_exhaustive]pub enum JsonExtension {
Unspecified,
Geojson,
UnknownValue(UnknownValue),
}Expand description
Used to indicate that a JSON variant, rather than normal JSON, is being used as the source_format. This should only be used in combination with the JSON source format.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default if provided value is not one included in the enum, or the value is not specified. The source format is parsed without any modification.
Geojson
Use GeoJSON variant of JSON. See https://tools.ietf.org/html/rfc7946.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using JsonExtension::value or JsonExtension::name.
Implementations