#[non_exhaustive]pub enum ManagedTableType {
Unspecified,
Native,
Biglake,
UnknownValue(UnknownValue),
}Expand description
The classification of managed table types that can be created.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
No managed table type specified.
Native
The managed table is a native BigQuery table.
Biglake
The managed table is a BigLake table for Apache Iceberg in BigQuery.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ManagedTableType::value or ManagedTableType::name.
Implementations