#[non_exhaustive]pub enum MetadataCacheMode {
Unspecified,
Automatic,
Manual,
UnknownValue(UnknownValue),
}Expand description
MetadataCacheMode identifies if the table should use metadata caching for files from external source (eg Google Cloud Storage).
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified metadata cache mode.
Automatic
Set this mode to trigger automatic background refresh of metadata cache from the external source. Queries will use the latest available cache version within the table’s maxStaleness interval.
Manual
Set this mode to enable triggering manual refresh of the metadata cache from external source. Queries will use the latest manually triggered cache version within the table’s maxStaleness interval.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MetadataCacheMode::value or MetadataCacheMode::name.
Implementations