#[non_exhaustive]pub enum DatasetView {
Unspecified,
Metadata,
Acl,
Full,
UnknownValue(UnknownValue),
}Expand description
DatasetView specifies which dataset information is returned.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. Default to the FULL view.
Metadata
View metadata information for the dataset, such as friendlyName, description, labels, etc.
Acl
View ACL information for the dataset, which defines dataset access for one or more entities.
Full
View both dataset metadata and ACL information.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DatasetView::value or DatasetView::name.
Implementations