TableMetadataView

Enum TableMetadataView 

#[non_exhaustive]
pub enum TableMetadataView { Unspecified, Basic, StorageStats, Full, UnknownValue(UnknownValue), }
TableMetadataView specifies which table information is returned.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

The default value. Default to the STORAGE_STATS view.



Basic

Includes basic table information including schema and partitioning specification. This view does not include storage statistics such as numRows or numBytes. This view is significantly more efficient and should be used to support high query rates.



StorageStats

Includes all information in the BASIC view as well as storage statistics (numBytes, numLongTermBytes, numRows and lastModifiedTime).



Full

Includes all table information, including storage statistics. It returns same information as STORAGE_STATS view, but may contain additional information in the future.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using TableMetadataView::value or TableMetadataView::name.

Implementations

Source

impl TableMetadataView

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.