Code

#[non_exhaustive]
pub enum Code {
Show 23 variants Unspecified, IndexConfigNotAvailable, PendingIndexCreation, BaseTableTruncated, IndexConfigModified, TimeTravelQuery, NoPruningPower, UnindexedSearchFields, UnsupportedSearchPattern, OptimizedWithMaterializedView, SecuredByDataMasking, MismatchedTextAnalyzer, BaseTableTooSmall, BaseTableTooLarge, EstimatedPerformanceGainTooLow, ColumnMetadataIndexNotUsed, NotSupportedInStandardEdition, IndexSuppressedByFunctionOption, QueryCacheHit, StaleIndex, InternalError, OtherReason, UnknownValue(UnknownValue),
}
Indicates the high-level reason for the scenario when no search index was used.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Code not specified.



IndexConfigNotAvailable

Indicates the search index configuration has not been created.



PendingIndexCreation

Indicates the search index creation has not been completed.



BaseTableTruncated

Indicates the base table has been truncated (rows have been removed from table with TRUNCATE TABLE statement) since the last time the search index was refreshed.



IndexConfigModified

Indicates the search index configuration has been changed since the last time the search index was refreshed.



TimeTravelQuery

Indicates the search query accesses data at a timestamp before the last time the search index was refreshed.



NoPruningPower

Indicates the usage of search index will not contribute to any pruning improvement for the search function, e.g. when the search predicate is in a disjunction with other non-search predicates.



UnindexedSearchFields

Indicates the search index does not cover all fields in the search function.



UnsupportedSearchPattern

Indicates the search index does not support the given search query pattern.



OptimizedWithMaterializedView

Indicates the query has been optimized by using a materialized view.



SecuredByDataMasking

Indicates the query has been secured by data masking, and thus search indexes are not applicable.



MismatchedTextAnalyzer

Indicates that the search index and the search function call do not have the same text analyzer.



BaseTableTooSmall

Indicates the base table is too small (below a certain threshold). The index does not provide noticeable search performance gains when the base table is too small.



BaseTableTooLarge

Indicates that the total size of indexed base tables in your organization exceeds your region’s limit and the index is not used in the query. To index larger base tables, you can use your own reservation for index-management jobs.



EstimatedPerformanceGainTooLow

Indicates that the estimated performance gain from using the search index is too low for the given search query.



ColumnMetadataIndexNotUsed

Indicates that the column metadata index (which the search index depends on) is not used. User can refer to the column metadata index usage for more details on why it was not used.



NotSupportedInStandardEdition

Indicates that search indexes can not be used for search query with STANDARD edition.



IndexSuppressedByFunctionOption

Indicates that an option in the search function that cannot make use of the index has been selected.



QueryCacheHit

Indicates that the query was cached, and thus the search index was not used.



StaleIndex

The index cannot be used in the search query because it is stale.



InternalError

Indicates an internal error that causes the search index to be unused.



OtherReason

Indicates that the reason search indexes cannot be used in the query is not covered by any of the other IndexUnusedReason options.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using Code::value or Code::name.

Implementations

Source

impl Code

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.