#[non_exhaustive]pub struct ModelExtractOptions {
pub trial_id: Option<Int64Value>,
/* private fields */
}Expand description
Options related to model extraction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trial_id: Option<Int64Value>The 1-based ID of the trial to be exported from a hyperparameter tuning model. If not specified, the trial with id = Model.defaultTrialId is exported. This field is ignored for models not trained with hyperparameter tuning.
Implementations
Sourceimpl ModelExtractOptions
impl ModelExtractOptions
Sourcepub fn set_trial_id<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_trial_id<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_trial_id<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_trial_id<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,