#[non_exhaustive]pub enum ColumnNameCharacterMap {
Unspecified,
Strict,
V1,
V2,
UnknownValue(UnknownValue),
}Expand description
Indicates the character map used for column names.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified column name character map.
Strict
Support flexible column name and reject invalid column names.
V1
Support alphanumeric + underscore characters and names must start with a letter or underscore. Invalid column names will be normalized.
V2
Support flexible column name. Invalid column names will be normalized.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ColumnNameCharacterMap::value or ColumnNameCharacterMap::name.
Implementations