#[non_exhaustive]pub enum SourceColumnMatch {
Unspecified,
Position,
Name,
UnknownValue(UnknownValue),
}Expand description
Indicates the strategy used to match loaded columns to the schema.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Uses sensible defaults based on how the schema is provided. If autodetect is used, then columns are matched by name. Otherwise, columns are matched by position. This is done to keep the behavior backward-compatible.
Position
Matches by position. This assumes that the columns are ordered the same way as the schema.
Name
Matches by name. This reads the header row as column names and reorders columns to match the field names in the schema.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SourceColumnMatch::value or SourceColumnMatch::name.
Implementations