#[non_exhaustive]pub enum Code {
Unspecified,
Requested,
LongRunning,
LargeResults,
Other,
UnknownValue(UnknownValue),
}Expand description
Indicates the high level reason why a job was created.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Reason is not specified.
Requested
Job creation was requested.
LongRunning
The query request ran beyond a system defined timeout specified by the timeoutMs field in the QueryRequest. As a result it was considered a long running operation for which a job was created.
LargeResults
The results from the query cannot fit in the response.
Other
BigQuery has determined that the query needs to be executed as a Job.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Code::value or Code::name.
Implementations