#[non_exhaustive]pub enum LinkState {
Unspecified,
Linked,
Unlinked,
UnknownValue(UnknownValue),
}Expand description
Specifies whether Linked Dataset is currently in a linked state or not.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. Default to the LINKED state.
Linked
Normal Linked Dataset state. Data is queryable via the Linked Dataset.
Unlinked
Data publisher or owner has unlinked this Linked Dataset. It means you can no longer query or see the data in the Linked Dataset.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LinkState::value or LinkState::name.
Implementations