RejectedReason

Enum RejectedReason 

#[non_exhaustive]
pub enum RejectedReason {
Show 13 variants Unspecified, NoData, Cost, BaseTableTruncated, BaseTableDataChange, BaseTablePartitionExpirationChange, BaseTableExpiredPartition, BaseTableIncompatibleMetadataChange, TimeZone, OutOfTimeTravelWindow, BaseTableFineGrainedSecurityPolicy, BaseTableTooStale, UnknownValue(UnknownValue),
}
Reason why a materialized view was not chosen for a query. For more information, see Understand why materialized views were rejected.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Default unspecified value.



NoData

View has no cached data because it has not refreshed yet.



Cost

The estimated cost of the view is more expensive than another view or the base table.

Note: The estimate cost might not match the billed cost.



BaseTableTruncated

View has no cached data because a base table is truncated.



BaseTableDataChange

View is invalidated because of a data change in one or more base tables. It could be any recent change if the maxStaleness option is not set for the view, or otherwise any change outside of the staleness window.



BaseTablePartitionExpirationChange

View is invalidated because a base table’s partition expiration has changed.



BaseTableExpiredPartition

View is invalidated because a base table’s partition has expired.



BaseTableIncompatibleMetadataChange

View is invalidated because a base table has an incompatible metadata change.



TimeZone

View is invalidated because it was refreshed with a time zone other than that of the current job.



OutOfTimeTravelWindow

View is outside the time travel window.



BaseTableFineGrainedSecurityPolicy

View is inaccessible to the user because of a fine-grained security policy on one of its base tables.



BaseTableTooStale

One of the view’s base tables is too stale. For example, the cached metadata of a BigLake external table needs to be updated.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using RejectedReason::value or RejectedReason::name.

Implementations

Source

impl RejectedReason

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.