#[non_exhaustive]pub enum DataSplitMethod {
Unspecified,
Random,
Custom,
Sequential,
NoSplit,
AutoSplit,
UnknownValue(UnknownValue),
}Expand description
Indicates the method to split input data into multiple tables.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Default value.
Random
Splits data randomly.
Custom
Splits data with the user provided tags.
Sequential
Splits data sequentially.
NoSplit
Data split will be skipped.
AutoSplit
Splits data automatically: Uses NO_SPLIT if the data size is small. Otherwise uses RANDOM.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DataSplitMethod::value or DataSplitMethod::name.
Implementations