#[non_exhaustive]pub struct AggregateClassificationMetrics {
pub precision: Option<DoubleValue>,
pub recall: Option<DoubleValue>,
pub accuracy: Option<DoubleValue>,
pub threshold: Option<DoubleValue>,
pub f1_score: Option<DoubleValue>,
pub log_loss: Option<DoubleValue>,
pub roc_auc: Option<DoubleValue>,
/* private fields */
}Expand description
Aggregate metrics for classification/classifier models. For multi-class models, the metrics are either macro-averaged or micro-averaged. When macro-averaged, the metrics are calculated for each label and then an unweighted average is taken of those values. When micro-averaged, the metric is calculated globally by counting the total number of correctly predicted rows.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.precision: Option<DoubleValue>Precision is the fraction of actual positive predictions that had positive actual labels. For multiclass this is a macro-averaged metric treating each class as a binary classifier.
recall: Option<DoubleValue>Recall is the fraction of actual positive labels that were given a positive prediction. For multiclass this is a macro-averaged metric.
accuracy: Option<DoubleValue>Accuracy is the fraction of predictions given the correct label. For multiclass this is a micro-averaged metric.
threshold: Option<DoubleValue>Threshold at which the metrics are computed. For binary classification models this is the positive class threshold. For multi-class classification models this is the confidence threshold.
f1_score: Option<DoubleValue>The F1 score is an average of recall and precision. For multiclass this is a macro-averaged metric.
log_loss: Option<DoubleValue>Logarithmic Loss. For multiclass this is a macro-averaged metric.
roc_auc: Option<DoubleValue>Area Under a ROC Curve. For multiclass this is a macro-averaged metric.
Implementations
Sourceimpl AggregateClassificationMetrics
impl AggregateClassificationMetrics
Sourcepub fn set_precision<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_precision<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_precision<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_precision<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_recall<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_recall<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_recall<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_recall<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_accuracy<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_accuracy<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_accuracy<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_accuracy<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_threshold<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_threshold<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_threshold<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_threshold<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_f1_score<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_f1_score<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_f1_score<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_f1_score<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_log_loss<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_log_loss<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_log_loss<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_log_loss<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_roc_auc<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_roc_auc<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sourcepub fn set_or_clear_roc_auc<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_roc_auc<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,