#[non_exhaustive]pub enum JobCreationMode {
Unspecified,
JobCreationRequired,
JobCreationOptional,
UnknownValue(UnknownValue),
}Expand description
Job Creation Mode provides different options on job creation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
If unspecified JOB_CREATION_REQUIRED is the default.
JobCreationRequired
Default. Job creation is always required.
JobCreationOptional
Job creation is optional. Returning immediate results is prioritized. BigQuery will automatically determine if a Job needs to be created. The conditions under which BigQuery can decide to not create a Job are subject to change. If Job creation is required, JOB_CREATION_REQUIRED mode should be used, which is the default.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using JobCreationMode::value or JobCreationMode::name.
Implementations