#[non_exhaustive]pub enum QueryResultsFormat {
Unspecified,
StructEncoding,
Arrow,
UnknownValue(UnknownValue),
}Expand description
The format of the query results.
This feature is not yet available.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
If unspecified it will default to struct QueryResponse.rows
(STRUCT_ENCODING)
StructEncoding
Default encoding of results as struct in QueryResponse.rows
Arrow
Arrow is a standard open source column-based message format. See https://arrow.apache.org/ for more details.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using QueryResultsFormat::value or QueryResultsFormat::name.
Implementations