Module query_response

Module query_response 

Defines additional types related to QueryResponse.

Enums

Results
Row data is returned in format when query_results_format has been specified with value other than default STRUCT_ENCODING.
ResultsSchema
The schema if query_results_format has been specified with value other than default STRUCT_ENCODING.