#[non_exhaustive]pub enum RemoteService {
Endpoint(String),
RemoteServiceType(RemoteServiceType),
}Expand description
Remote services are services outside of BigQuery used by remote models for predictions. A remote service is backed by either an arbitrary endpoint or a selected remote service type, but not both.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Endpoint(String)
Output only. The endpoint for remote model.
RemoteServiceType(RemoteServiceType)
Output only. The remote service type for remote model.