#[non_exhaustive]pub enum ArgumentKind {
Unspecified,
FixedType,
AnyType,
FixedTable,
AnyTable,
UnknownValue(UnknownValue),
}Expand description
Represents the kind of a given argument.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
FixedType
The argument is a variable with fully specified type, which can be a struct or an array, but not a table.
AnyType
The argument is any type, including struct or array, but not a table.
FixedTable
The argument is a table with fully specified column names and types.
AnyTable
The argument is any table type.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ArgumentKind::value or ArgumentKind::name.
Implementations