#[non_exhaustive]pub enum DeterminismLevel {
Unspecified,
Deterministic,
NotDeterministic,
UnknownValue(UnknownValue),
}Expand description
JavaScript UDF determinism levels.
If all JavaScript UDFs are DETERMINISTIC, the query result is potentially cacheable (see below). If any JavaScript UDF is NOT_DETERMINISTIC, the query result is not cacheable.
Even if a JavaScript UDF is deterministic, many other factors can prevent usage of cached query results. Example factors include but not limited to: DDL/DML, non-deterministic SQL function calls, update of referenced tables/views/UDFs or imported JavaScript libraries.
SQL UDFs cannot have determinism specified. Their determinism is automatically determined.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The determinism of the UDF is unspecified.
Deterministic
The UDF is deterministic, meaning that 2 function calls with the same inputs always produce the same result, even across 2 query runs.
NotDeterministic
The UDF is not deterministic.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DeterminismLevel::value or DeterminismLevel::name.
Implementations