RemoteFunctionOptions

Struct RemoteFunctionOptions 

#[non_exhaustive]
pub struct RemoteFunctionOptions { pub endpoint: String, pub connection: String, pub user_defined_context: HashMap<String, String>, pub max_batching_rows: i64, /* private fields */ }
Options for a remote user-defined function.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
endpoint: String

Endpoint of the user-provided remote service, e.g. <https://us-east1-my_gcf_project.cloudfunctions.net/remote_add>

connection: String

Fully qualified name of the user-provided connection object which holds the authentication information to send requests to the remote service. Format: "projects/{projectId}/locations/{locationId}/connections/{connectionId}"

user_defined_context: HashMap<String, String>

User-defined context as a set of key/value pairs, which will be sent as function invocation context together with batched arguments in the requests to the remote service. The total number of bytes of keys and values must be less than 8KB.

max_batching_rows: i64

Max number of rows in each batch sent to the remote service. If absent or if 0, BigQuery dynamically decides the number of rows in a batch.

Implementations

Source

impl RemoteFunctionOptions

pub fn new() -> Self

Creates a new default instance.

pub fn set_endpoint<T: Into<String>>(self, v: T) -> Self

Sets the value of endpoint.

Example
let x = RemoteFunctionOptions::new().set_endpoint("example");
pub fn set_connection<T: Into<String>>(self, v: T) -> Self

Sets the value of connection.

Example
let x = RemoteFunctionOptions::new().set_connection("example");
pub fn set_user_defined_context<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of user_defined_context.

Example
let x = RemoteFunctionOptions::new().set_user_defined_context([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self

Sets the value of max_batching_rows.

Example
let x = RemoteFunctionOptions::new().set_max_batching_rows(42);