ScriptStackFrame

Struct ScriptStackFrame 

#[non_exhaustive]
pub struct ScriptStackFrame { pub start_line: i32, pub start_column: i32, pub end_line: i32, pub end_column: i32, pub procedure_id: String, pub text: String, /* private fields */ }
Represents the location of the statement/expression being evaluated. Line and column numbers are defined as follows:

  • Line and column numbers start with one. That is, line 1 column 1 denotes the start of the script.
  • When inside a stored procedure, all line/column numbers are relative to the procedure body, not the script in which the procedure was defined.
  • Start/end positions exclude leading/trailing comments and whitespace. The end position always ends with a “;”, when present.
  • Multi-byte Unicode characters are treated as just one column.
  • If the original script (or procedure definition) contains TAB characters, a tab “snaps” the indentation forward to the nearest multiple of 8 characters, plus 1. For example, a TAB on column 1, 2, 3, 4, 5, 6 , or 8 will advance the next character to column 9. A TAB on column 9, 10, 11, 12, 13, 14, 15, or 16 will advance the next character to column 17.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
start_line: i32

Output only. One-based start line.

start_column: i32

Output only. One-based start column.

end_line: i32

Output only. One-based end line.

end_column: i32

Output only. One-based end column.

procedure_id: String

Output only. Name of the active procedure, empty if in a top-level script.

text: String

Output only. Text of the current statement/expression.

Implementations

Source

impl ScriptStackFrame

pub fn new() -> Self

Creates a new default instance.

pub fn set_start_line<T: Into<i32>>(self, v: T) -> Self

Sets the value of start_line.

Example
let x = ScriptStackFrame::new().set_start_line(42);
pub fn set_start_column<T: Into<i32>>(self, v: T) -> Self

Sets the value of start_column.

Example
let x = ScriptStackFrame::new().set_start_column(42);
pub fn set_end_line<T: Into<i32>>(self, v: T) -> Self

Sets the value of end_line.

Example
let x = ScriptStackFrame::new().set_end_line(42);
pub fn set_end_column<T: Into<i32>>(self, v: T) -> Self

Sets the value of end_column.

Example
let x = ScriptStackFrame::new().set_end_column(42);
pub fn set_procedure_id<T: Into<String>>(self, v: T) -> Self

Sets the value of procedure_id.

Example
let x = ScriptStackFrame::new().set_procedure_id("example");
pub fn set_text<T: Into<String>>(self, v: T) -> Self

Sets the value of text.

Example
let x = ScriptStackFrame::new().set_text("example");