AggregationThresholdPolicy

Struct AggregationThresholdPolicy 

#[non_exhaustive]
pub struct AggregationThresholdPolicy { pub threshold: Option<i64>, pub privacy_unit_columns: Vec<String>, /* private fields */ }
Represents privacy policy associated with “aggregation threshold” method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
threshold: Option<i64>

Optional. The threshold for the “aggregation threshold” policy.

privacy_unit_columns: Vec<String>

Optional. The privacy unit column(s) associated with this policy. For now, only one column per data source object (table, view) is allowed as a privacy unit column. Representing as a repeated field in metadata for extensibility to multiple columns in future. Duplicates and Repeated struct fields are not allowed. For nested fields, use dot notation (“outer.inner”)

Implementations

Source

impl AggregationThresholdPolicy

pub fn new() -> Self

Creates a new default instance.

pub fn set_threshold<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of threshold.

Example
let x = AggregationThresholdPolicy::new().set_threshold(42);
pub fn set_or_clear_threshold<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of threshold.

Example
let x = AggregationThresholdPolicy::new().set_or_clear_threshold(Some(42));
let x = AggregationThresholdPolicy::new().set_or_clear_threshold(None::<i32>);
pub fn set_privacy_unit_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of privacy_unit_columns.

Example
let x = AggregationThresholdPolicy::new().set_privacy_unit_columns(["a", "b", "c"]);