#[non_exhaustive]pub struct BatchDeleteRowAccessPoliciesRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub policy_ids: Vec<String>,
pub force: Option<bool>,
/* private fields */
}Expand description
Request message for the BatchDeleteRowAccessPoliciesRequest method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the table to delete the row access policies.
dataset_id: StringRequired. Dataset ID of the table to delete the row access policies.
table_id: StringRequired. Table ID of the table to delete the row access policies.
policy_ids: Vec<String>Required. Policy IDs of the row access policies.
force: Option<bool>If set to true, it deletes the row access policy even if it’s the last row access policy on the table and the deletion will widen the access rather narrowing it.
Implementations
Sourceimpl BatchDeleteRowAccessPoliciesRequest
impl BatchDeleteRowAccessPoliciesRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = BatchDeleteRowAccessPoliciesRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = BatchDeleteRowAccessPoliciesRequest::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_policy_ids<T, V>(self, v: T) -> Self
pub fn set_policy_ids<T, V>(self, v: T) -> Self
Sets the value of policy_ids.
Example
ⓘ
let x = BatchDeleteRowAccessPoliciesRequest::new().set_policy_ids(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for BatchDeleteRowAccessPoliciesRequest
impl Clone for BatchDeleteRowAccessPoliciesRequest
Sourcefn clone(&self) -> BatchDeleteRowAccessPoliciesRequest
fn clone(&self) -> BatchDeleteRowAccessPoliciesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BatchDeleteRowAccessPoliciesRequest
impl Default for BatchDeleteRowAccessPoliciesRequest
Sourcefn default() -> BatchDeleteRowAccessPoliciesRequest
fn default() -> BatchDeleteRowAccessPoliciesRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for BatchDeleteRowAccessPoliciesRequest