BiEngineStatistics

Struct BiEngineStatistics 

#[non_exhaustive]
pub struct BiEngineStatistics { pub bi_engine_mode: BiEngineMode, pub acceleration_mode: BiEngineAccelerationMode, pub bi_engine_reasons: Vec<BiEngineReason>, /* private fields */ }
Statistics for a BI Engine specific query. Populated as part of JobStatistics2

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bi_engine_mode: BiEngineMode

Output only. Specifies which mode of BI Engine acceleration was performed (if any).

acceleration_mode: BiEngineAccelerationMode

Output only. Specifies which mode of BI Engine acceleration was performed (if any).

bi_engine_reasons: Vec<BiEngineReason>

In case of DISABLED or PARTIAL bi_engine_mode, these contain the explanatory reasons as to why BI Engine could not accelerate. In case the full query was accelerated, this field is not populated.

Implementations

Source

impl BiEngineStatistics

pub fn new() -> Self

Creates a new default instance.

pub fn set_bi_engine_mode<T: Into<BiEngineMode>>(self, v: T) -> Self

Sets the value of bi_engine_mode.

Example
use google_cloud_bigquery_v2::model::bi_engine_statistics::BiEngineMode;
let x0 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Disabled);
let x1 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Partial);
let x2 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Full);
pub fn set_acceleration_mode<T: Into<BiEngineAccelerationMode>>( self, v: T, ) -> Self

Sets the value of acceleration_mode.

Example
use google_cloud_bigquery_v2::model::bi_engine_statistics::BiEngineAccelerationMode;
let x0 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::BiEngineDisabled);
let x1 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::PartialInput);
let x2 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::FullInput);
pub fn set_bi_engine_reasons<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<BiEngineReason>,

Sets the value of bi_engine_reasons.

Example
use google_cloud_bigquery_v2::model::BiEngineReason;
let x = BiEngineStatistics::new()
    .set_bi_engine_reasons([
        BiEngineReason::default()/* use setters */,
        BiEngineReason::default()/* use (different) setters */,
    ]);