#[non_exhaustive]pub struct BigLakeConfiguration {
pub connection_id: String,
pub storage_uri: String,
pub file_format: FileFormat,
pub table_format: TableFormat,
/* private fields */
}Expand description
Configuration for BigQuery tables for Apache Iceberg (formerly BigLake managed tables.)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_id: StringOptional. The connection specifying the credentials to be used to read and
write to external storage, such as Cloud Storage. The connection_id can
have the form {project}.{location}.{connection_id} or
`projects/{project}/locations/{location}/connections/{connection_id}“.
storage_uri: StringOptional. The fully qualified location prefix of the external folder where
table data is stored. The ‘*’ wildcard character is not allowed. The URI
should be in the format gs://bucket/path_to_table/
file_format: FileFormatOptional. The file format the table data is stored in.
table_format: TableFormatOptional. The table format the metadata only snapshots are stored in.
Implementations
Sourceimpl BigLakeConfiguration
impl BigLakeConfiguration
Sourcepub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
pub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
Sets the value of connection_id.
Example
let x = BigLakeConfiguration::new().set_connection_id("example");Sourcepub fn set_storage_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_storage_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of storage_uri.
Example
let x = BigLakeConfiguration::new().set_storage_uri("example");Sourcepub fn set_file_format<T: Into<FileFormat>>(self, v: T) -> Self
pub fn set_file_format<T: Into<FileFormat>>(self, v: T) -> Self
Sets the value of file_format.
Example
use google_cloud_bigquery_v2::model::big_lake_configuration::FileFormat;
let x0 = BigLakeConfiguration::new().set_file_format(FileFormat::Parquet);Sourcepub fn set_table_format<T: Into<TableFormat>>(self, v: T) -> Self
pub fn set_table_format<T: Into<TableFormat>>(self, v: T) -> Self
Sets the value of table_format.
Example
use google_cloud_bigquery_v2::model::big_lake_configuration::TableFormat;
let x0 = BigLakeConfiguration::new().set_table_format(TableFormat::Iceberg);Trait Implementations
Sourceimpl Clone for BigLakeConfiguration
impl Clone for BigLakeConfiguration
Sourcefn clone(&self) -> BigLakeConfiguration
fn clone(&self) -> BigLakeConfiguration
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BigLakeConfiguration
impl Debug for BigLakeConfiguration
Sourceimpl Default for BigLakeConfiguration
impl Default for BigLakeConfiguration
Sourcefn default() -> BigLakeConfiguration
fn default() -> BigLakeConfiguration
Sourceimpl Message for BigLakeConfiguration
impl Message for BigLakeConfiguration
Sourceimpl PartialEq for BigLakeConfiguration
impl PartialEq for BigLakeConfiguration
impl StructuralPartialEq for BigLakeConfiguration