BigtableColumn

Struct BigtableColumn 

#[non_exhaustive]
pub struct BigtableColumn { pub qualifier_encoded: Option<BytesValue>, pub qualifier_string: Option<StringValue>, pub field_name: String, pub type: String, pub encoding: String, pub only_read_latest: Option<BoolValue>, pub proto_config: Option<BigtableProtoConfig>, /* private fields */ }
Information related to a Bigtable column.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
qualifier_encoded: Option<BytesValue>

[Required] Qualifier of the column. Columns in the parent column family that has this exact qualifier are exposed as <family field name>.<column field name> field. If the qualifier is valid UTF-8 string, it can be specified in the qualifier_string field. Otherwise, a base-64 encoded value must be set to qualifier_encoded. The column field name is the same as the column qualifier. However, if the qualifier is not a valid BigQuery field identifier i.e. does not match [a-zA-Z][a-zA-Z0-9_]*, a valid identifier must be provided as field_name.

qualifier_string: Option<StringValue>

Qualifier string.

field_name: String

Optional. If the qualifier is not a valid BigQuery field identifier i.e. does not match [a-zA-Z][a-zA-Z0-9_]*, a valid identifier must be provided as the column field name and is used as field name in queries.

type: String

Optional. The type to convert the value in cells of this column. The values are expected to be encoded using HBase Bytes.toBytes function when using the BINARY encoding value. Following BigQuery types are allowed (case-sensitive):

  • BYTES
  • STRING
  • INTEGER
  • FLOAT
  • BOOLEAN
  • JSON

Default type is BYTES. ‘type’ can also be set at the column family level. However, the setting at this level takes precedence if ‘type’ is set at both levels.

encoding: String

Optional. The encoding of the values when the type is not STRING. Acceptable encoding values are: TEXT - indicates values are alphanumeric text strings. BINARY - indicates values are encoded using HBase Bytes.toBytes family of functions. PROTO_BINARY - indicates values are encoded using serialized proto messages. This can only be used in combination with JSON type. ‘encoding’ can also be set at the column family level. However, the setting at this level takes precedence if ‘encoding’ is set at both levels.

only_read_latest: Option<BoolValue>

Optional. If this is set, only the latest version of value in this column are exposed. ‘onlyReadLatest’ can also be set at the column family level. However, the setting at this level takes precedence if ‘onlyReadLatest’ is set at both levels.

proto_config: Option<BigtableProtoConfig>

Optional. Protobuf-specific configurations, only takes effect when the encoding is PROTO_BINARY.

Implementations

Source

impl BigtableColumn

pub fn new() -> Self

Creates a new default instance.

pub fn set_qualifier_encoded<T>(self, v: T) -> Self
where T: Into<BytesValue>,

Sets the value of qualifier_encoded.

Example
use wkt::BytesValue;
let x = BigtableColumn::new().set_qualifier_encoded(BytesValue::default()/* use setters */);
pub fn set_or_clear_qualifier_encoded<T>(self, v: Option<T>) -> Self
where T: Into<BytesValue>,

Sets or clears the value of qualifier_encoded.

Example
use wkt::BytesValue;
let x = BigtableColumn::new().set_or_clear_qualifier_encoded(Some(BytesValue::default()/* use setters */));
let x = BigtableColumn::new().set_or_clear_qualifier_encoded(None::<BytesValue>);
pub fn set_qualifier_string<T>(self, v: T) -> Self
where T: Into<StringValue>,

Sets the value of qualifier_string.

Example
use wkt::StringValue;
let x = BigtableColumn::new().set_qualifier_string(StringValue::default()/* use setters */);
pub fn set_or_clear_qualifier_string<T>(self, v: Option<T>) -> Self
where T: Into<StringValue>,

Sets or clears the value of qualifier_string.

Example
use wkt::StringValue;
let x = BigtableColumn::new().set_or_clear_qualifier_string(Some(StringValue::default()/* use setters */));
let x = BigtableColumn::new().set_or_clear_qualifier_string(None::<StringValue>);
pub fn set_field_name<T: Into<String>>(self, v: T) -> Self

Sets the value of field_name.

Example
let x = BigtableColumn::new().set_field_name("example");
pub fn set_type<T: Into<String>>(self, v: T) -> Self

Sets the value of r#type.

Example
let x = BigtableColumn::new().set_type("example");
pub fn set_encoding<T: Into<String>>(self, v: T) -> Self

Sets the value of encoding.

Example
let x = BigtableColumn::new().set_encoding("example");
pub fn set_only_read_latest<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of only_read_latest.

Example
use wkt::BoolValue;
let x = BigtableColumn::new().set_only_read_latest(BoolValue::default()/* use setters */);
pub fn set_or_clear_only_read_latest<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of only_read_latest.

Example
use wkt::BoolValue;
let x = BigtableColumn::new().set_or_clear_only_read_latest(Some(BoolValue::default()/* use setters */));
let x = BigtableColumn::new().set_or_clear_only_read_latest(None::<BoolValue>);
pub fn set_proto_config<T>(self, v: T) -> Self

Sets the value of proto_config.

Example
use google_cloud_bigquery_v2::model::BigtableProtoConfig;
let x = BigtableColumn::new().set_proto_config(BigtableProtoConfig::default()/* use setters */);
pub fn set_or_clear_proto_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of proto_config.

Example
use google_cloud_bigquery_v2::model::BigtableProtoConfig;
let x = BigtableColumn::new().set_or_clear_proto_config(Some(BigtableProtoConfig::default()/* use setters */));
let x = BigtableColumn::new().set_or_clear_proto_config(None::<BigtableProtoConfig>);