#[non_exhaustive]pub struct BigtableProtoConfig {
pub schema_bundle_id: String,
pub proto_message_name: String,
/* private fields */
}Expand description
Information related to a Bigtable protobuf column.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_bundle_id: StringOptional. The ID of the Bigtable SchemaBundle resource associated with this
protobuf. The ID should be referred to within the parent table, e.g.,
foo rather than
projects/{project}/instances/{instance}/tables/{table}/schemaBundles/foo.
See more details on Bigtable
SchemaBundles.
proto_message_name: StringOptional. The fully qualified proto message name of the protobuf. In the format of “foo.bar.Message”.
Implementations
Sourceimpl BigtableProtoConfig
impl BigtableProtoConfig
Sourcepub fn set_schema_bundle_id<T: Into<String>>(self, v: T) -> Self
pub fn set_schema_bundle_id<T: Into<String>>(self, v: T) -> Self
Sets the value of schema_bundle_id.
Example
ⓘ
let x = BigtableProtoConfig::new().set_schema_bundle_id("example");Sourcepub fn set_proto_message_name<T: Into<String>>(self, v: T) -> Self
pub fn set_proto_message_name<T: Into<String>>(self, v: T) -> Self
Sets the value of proto_message_name.
Example
ⓘ
let x = BigtableProtoConfig::new().set_proto_message_name("example");Trait Implementations
Sourceimpl Clone for BigtableProtoConfig
impl Clone for BigtableProtoConfig
Sourcefn clone(&self) -> BigtableProtoConfig
fn clone(&self) -> BigtableProtoConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BigtableProtoConfig
impl Debug for BigtableProtoConfig
Sourceimpl Default for BigtableProtoConfig
impl Default for BigtableProtoConfig
Sourcefn default() -> BigtableProtoConfig
fn default() -> BigtableProtoConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for BigtableProtoConfig
impl Message for BigtableProtoConfig
Sourceimpl PartialEq for BigtableProtoConfig
impl PartialEq for BigtableProtoConfig
impl StructuralPartialEq for BigtableProtoConfig