#[non_exhaustive]pub struct CloneDefinition {
pub base_table_reference: Option<TableReference>,
pub clone_time: Option<Timestamp>,
/* private fields */
}Expand description
Information about base table and clone time of a table clone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.base_table_reference: Option<TableReference>Required. Reference describing the ID of the table that was cloned.
clone_time: Option<Timestamp>Required. The time at which the base table was cloned. This value is reported in the JSON response using RFC3339 format.
Implementations
Sourceimpl CloneDefinition
impl CloneDefinition
Sourcepub fn set_base_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_base_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of base_table_reference.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = CloneDefinition::new().set_base_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_base_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_base_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of base_table_reference.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = CloneDefinition::new().set_or_clear_base_table_reference(Some(TableReference::default()/* use setters */));
let x = CloneDefinition::new().set_or_clear_base_table_reference(None::<TableReference>);Sourcepub fn set_clone_time<T>(self, v: T) -> Self
pub fn set_clone_time<T>(self, v: T) -> Self
Sets the value of clone_time.
Example
ⓘ
use wkt::Timestamp;
let x = CloneDefinition::new().set_clone_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_clone_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_clone_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of clone_time.
Example
ⓘ
use wkt::Timestamp;
let x = CloneDefinition::new().set_or_clear_clone_time(Some(Timestamp::default()/* use setters */));
let x = CloneDefinition::new().set_or_clear_clone_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for CloneDefinition
impl Clone for CloneDefinition
Sourcefn clone(&self) -> CloneDefinition
fn clone(&self) -> CloneDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloneDefinition
impl Debug for CloneDefinition
Sourceimpl Default for CloneDefinition
impl Default for CloneDefinition
Sourcefn default() -> CloneDefinition
fn default() -> CloneDefinition
Returns the “default value” for a type. Read more
Sourceimpl Message for CloneDefinition
impl Message for CloneDefinition
Sourceimpl PartialEq for CloneDefinition
impl PartialEq for CloneDefinition
impl StructuralPartialEq for CloneDefinition