#[non_exhaustive]pub struct ColumnReference {
pub referencing_column: String,
pub referenced_column: String,
/* private fields */
}Expand description
The pair of the foreign key column and primary key column.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.referencing_column: StringRequired. The column that composes the foreign key.
referenced_column: StringRequired. The column in the primary key that are referenced by the referencing_column.
Implementations
Sourceimpl ColumnReference
impl ColumnReference
Sourcepub fn set_referencing_column<T: Into<String>>(self, v: T) -> Self
pub fn set_referencing_column<T: Into<String>>(self, v: T) -> Self
Sets the value of referencing_column.
Example
ⓘ
let x = ColumnReference::new().set_referencing_column("example");Sourcepub fn set_referenced_column<T: Into<String>>(self, v: T) -> Self
pub fn set_referenced_column<T: Into<String>>(self, v: T) -> Self
Sets the value of referenced_column.
Example
ⓘ
let x = ColumnReference::new().set_referenced_column("example");Trait Implementations
Sourceimpl Clone for ColumnReference
impl Clone for ColumnReference
Sourcefn clone(&self) -> ColumnReference
fn clone(&self) -> ColumnReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColumnReference
impl Debug for ColumnReference
Sourceimpl Default for ColumnReference
impl Default for ColumnReference
Sourcefn default() -> ColumnReference
fn default() -> ColumnReference
Returns the “default value” for a type. Read more
Sourceimpl Message for ColumnReference
impl Message for ColumnReference
Sourceimpl PartialEq for ColumnReference
impl PartialEq for ColumnReference
impl StructuralPartialEq for ColumnReference