ConnectionProperty

Struct ConnectionProperty 

#[non_exhaustive]
pub struct ConnectionProperty { pub key: String, pub value: String, /* private fields */ }
A connection-level property to customize query behavior. Under JDBC, these correspond directly to connection properties passed to the DriverManager. Under ODBC, these correspond to properties in the connection string.

Currently supported connection properties:

  • dataset_project_id: represents the default project for datasets that are used in the query. Setting the system variable @@dataset_project_id achieves the same behavior. For more information about system variables, see: https://cloud.google.com/bigquery/docs/reference/system-variables

  • time_zone: represents the default timezone used to run the query.

  • session_id: associates the query with a given session.

  • query_label: associates the query with a given job label. If set, all subsequent queries in a script or session will have this label. For the format in which a you can specify a query label, see labels in the JobConfiguration resource type: https://cloud.google.com/bigquery/docs/reference/rest/v2/Job#jobconfiguration

  • service_account: indicates the service account to use to run a continuous query. If set, the query job uses the service account to access Google Cloud resources. Service account access is bounded by the IAM permissions that you have granted to the service account.

Additional properties are allowed, but ignored. Specifying multiple connection properties with the same key returns an error.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
key: String

The key of the property to set.

value: String

The value of the property to set.

Implementations

Source

impl ConnectionProperty

pub fn new() -> Self

Creates a new default instance.

pub fn set_key<T: Into<String>>(self, v: T) -> Self

Sets the value of key.

Example
let x = ConnectionProperty::new().set_key("example");
pub fn set_value<T: Into<String>>(self, v: T) -> Self

Sets the value of value.

Example
let x = ConnectionProperty::new().set_value("example");