#[non_exhaustive]pub struct DataPolicyOption {
pub name: Option<String>,
/* private fields */
}Expand description
Data policy option. For more information, see Mask data by applying data policies to a column.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Data policy resource name in the form of projects/project_id/locations/location_id/dataPolicies/data_policy_id.
Implementations
Sourceimpl DataPolicyOption
impl DataPolicyOption