#[non_exhaustive]pub struct Dataset {Show 31 fields
pub kind: String,
pub etag: String,
pub id: String,
pub self_link: String,
pub dataset_reference: Option<DatasetReference>,
pub friendly_name: Option<StringValue>,
pub description: Option<StringValue>,
pub default_table_expiration_ms: Option<Int64Value>,
pub default_partition_expiration_ms: Option<Int64Value>,
pub labels: HashMap<String, String>,
pub access: Vec<Access>,
pub creation_time: i64,
pub last_modified_time: i64,
pub location: String,
pub default_encryption_configuration: Option<EncryptionConfiguration>,
pub satisfies_pzs: Option<BoolValue>,
pub satisfies_pzi: Option<BoolValue>,
pub type: String,
pub catalog_source: Option<String>,
pub linked_dataset_source: Option<LinkedDatasetSource>,
pub linked_dataset_metadata: Option<LinkedDatasetMetadata>,
pub external_dataset_reference: Option<ExternalDatasetReference>,
pub external_catalog_dataset_options: Option<ExternalCatalogDatasetOptions>,
pub is_case_insensitive: Option<BoolValue>,
pub default_collation: Option<StringValue>,
pub default_rounding_mode: RoundingMode,
pub max_time_travel_hours: Option<Int64Value>,
pub tags: Vec<GcpTag>,
pub storage_billing_model: StorageBillingModel,
pub restrictions: Option<RestrictionConfig>,
pub resource_tags: HashMap<String, String>,
/* private fields */
}Expand description
Represents a BigQuery dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringOutput only. The resource type.
etag: StringOutput only. A hash of the resource.
id: StringOutput only. The fully-qualified unique name of the dataset in the format projectId:datasetId. The dataset name without the project name is given in the datasetId field. When creating a new dataset, leave this field blank, and instead specify the datasetId field.
self_link: StringOutput only. A URL that can be used to access the resource again. You can use this URL in Get or Update requests to the resource.
dataset_reference: Option<DatasetReference>Required. A reference that identifies the dataset.
friendly_name: Option<StringValue>Optional. A descriptive name for the dataset.
description: Option<StringValue>Optional. A user-friendly description of the dataset.
default_table_expiration_ms: Option<Int64Value>Optional. The default lifetime of all tables in the dataset, in milliseconds. The minimum lifetime value is 3600000 milliseconds (one hour). To clear an existing default expiration with a PATCH request, set to 0. Once this property is set, all newly-created tables in the dataset will have an expirationTime property set to the creation time plus the value in this property, and changing the value will only affect new tables, not existing ones. When the expirationTime for a given table is reached, that table will be deleted automatically. If a table’s expirationTime is modified or removed before the table expires, or if you provide an explicit expirationTime when creating a table, that value takes precedence over the default expiration time indicated by this property.
default_partition_expiration_ms: Option<Int64Value>This default partition expiration, expressed in milliseconds.
When new time-partitioned tables are created in a dataset where this
property is set, the table will inherit this value, propagated as the
TimePartitioning.expirationMs property on the new table. If you set
TimePartitioning.expirationMs explicitly when creating a table,
the defaultPartitionExpirationMs of the containing dataset is ignored.
When creating a partitioned table, if defaultPartitionExpirationMs
is set, the defaultTableExpirationMs value is ignored and the table
will not be inherit a table expiration deadline.
labels: HashMap<String, String>The labels associated with this dataset. You can use these to organize and group your datasets. You can set this property when inserting or updating a dataset. See Creating and Updating Dataset Labels for more information.
access: Vec<Access>Optional. An array of objects that define dataset access for one or more entities. You can set this property when inserting or updating a dataset in order to control who is allowed to access the data. If unspecified at dataset creation time, BigQuery adds default dataset access for the following entities: access.specialGroup: projectReaders; access.role: READER; access.specialGroup: projectWriters; access.role: WRITER; access.specialGroup: projectOwners; access.role: OWNER; access.userByEmail: [dataset creator email]; access.role: OWNER; If you patch a dataset, then this field is overwritten by the patched dataset’s access field. To add entities, you must supply the entire existing access array in addition to any new entities that you want to add.
creation_time: i64Output only. The time when this dataset was created, in milliseconds since the epoch.
last_modified_time: i64Output only. The date when this dataset was last modified, in milliseconds since the epoch.
location: StringThe geographic location where the dataset should reside. See https://cloud.google.com/bigquery/docs/locations for supported locations.
default_encryption_configuration: Option<EncryptionConfiguration>The default encryption key for all tables in the dataset. After this property is set, the encryption key of all newly-created tables in the dataset is set to this value unless the table creation request or query explicitly overrides the key.
satisfies_pzs: Option<BoolValue>Output only. Reserved for future use.
satisfies_pzi: Option<BoolValue>Output only. Reserved for future use.
type: StringOutput only. Same as type in ListFormatDataset.
The type of the dataset, one of:
- DEFAULT - only accessible by owner and authorized accounts,
- PUBLIC - accessible by everyone,
- LINKED - linked dataset,
- EXTERNAL - dataset with definition in external metadata catalog,
- BIGLAKE_ICEBERG - a Biglake dataset accessible through the Iceberg API,
- BIGLAKE_HIVE - a Biglake dataset accessible through the Hive API.
catalog_source: Option<String>Output only. The origin of the dataset, one of:
- (Unset) - Native BigQuery Dataset
- BIGLAKE - Dataset is backed by a namespace stored natively in Biglake
linked_dataset_source: Option<LinkedDatasetSource>Optional. The source dataset reference when the dataset is of type LINKED. For all other dataset types it is not set. This field cannot be updated once it is set. Any attempt to update this field using Update and Patch API Operations will be ignored.
linked_dataset_metadata: Option<LinkedDatasetMetadata>Output only. Metadata about the LinkedDataset. Filled out when the dataset type is LINKED.
external_dataset_reference: Option<ExternalDatasetReference>Optional. Reference to a read-only external dataset defined in data catalogs outside of BigQuery. Filled out when the dataset type is EXTERNAL.
external_catalog_dataset_options: Option<ExternalCatalogDatasetOptions>Optional. Options defining open source compatible datasets living in the BigQuery catalog. Contains metadata of open source database, schema or namespace represented by the current dataset.
is_case_insensitive: Option<BoolValue>Optional. TRUE if the dataset and its table names are case-insensitive, otherwise FALSE. By default, this is FALSE, which means the dataset and its table names are case-sensitive. This field does not affect routine references.
default_collation: Option<StringValue>Optional. Defines the default collation specification of future tables created in the dataset. If a table is created in this dataset without table-level default collation, then the table inherits the dataset default collation, which is applied to the string fields that do not have explicit collation specified. A change to this field affects only tables created afterwards, and does not alter the existing tables. The following values are supported:
- ‘und:ci’: undetermined locale, case insensitive.
- ‘’: empty string. Default to case-sensitive behavior.
default_rounding_mode: RoundingModeOptional. Defines the default rounding mode specification of new tables created within this dataset. During table creation, if this field is specified, the table within this dataset will inherit the default rounding mode of the dataset. Setting the default rounding mode on a table overrides this option. Existing tables in the dataset are unaffected. If columns are defined during that table creation, they will immediately inherit the table’s default rounding mode, unless otherwise specified.
max_time_travel_hours: Option<Int64Value>Optional. Defines the time travel window in hours. The value can be from 48 to 168 hours (2 to 7 days). The default value is 168 hours if this is not set.
Output only. Tags for the dataset. To provide tags as inputs, use the
resourceTags field.
storage_billing_model: StorageBillingModelOptional. Updates storage_billing_model for the dataset.
restrictions: Option<RestrictionConfig>Optional. Output only. Restriction config for all tables and dataset. If set, restrict certain accesses on the dataset and all its tables based on the config. See Data egress for more details.
Optional. The tags attached to this dataset. Tag keys are globally unique. Tag key is expected to be in the namespaced format, for example “123456789012/environment” where 123456789012 is the ID of the parent organization or project resource for this tag key. Tag value is expected to be the short name, for example “Production”. See Tag definitions for more details.
Implementations
Sourceimpl Dataset
impl Dataset
Sourcepub fn set_self_link<T: Into<String>>(self, v: T) -> Self
pub fn set_self_link<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sets the value of dataset_reference.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = Dataset::new().set_dataset_reference(DatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sets or clears the value of dataset_reference.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = Dataset::new().set_or_clear_dataset_reference(Some(DatasetReference::default()/* use setters */));
let x = Dataset::new().set_or_clear_dataset_reference(None::<DatasetReference>);Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = Dataset::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = Dataset::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of description.
Example
use wkt::StringValue;
let x = Dataset::new().set_description(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of description.
Example
use wkt::StringValue;
let x = Dataset::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_description(None::<StringValue>);Sourcepub fn set_default_table_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_default_table_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of default_table_expiration_ms.
Example
use wkt::Int64Value;
let x = Dataset::new().set_default_table_expiration_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_default_table_expiration_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_default_table_expiration_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of default_table_expiration_ms.
Example
use wkt::Int64Value;
let x = Dataset::new().set_or_clear_default_table_expiration_ms(Some(Int64Value::default()/* use setters */));
let x = Dataset::new().set_or_clear_default_table_expiration_ms(None::<Int64Value>);Sourcepub fn set_default_partition_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_default_partition_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of default_partition_expiration_ms.
Example
use wkt::Int64Value;
let x = Dataset::new().set_default_partition_expiration_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_default_partition_expiration_ms<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_default_partition_expiration_ms<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of default_partition_expiration_ms.
Example
use wkt::Int64Value;
let x = Dataset::new().set_or_clear_default_partition_expiration_ms(Some(Int64Value::default()/* use setters */));
let x = Dataset::new().set_or_clear_default_partition_expiration_ms(None::<Int64Value>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_access<T, V>(self, v: T) -> Self
pub fn set_access<T, V>(self, v: T) -> Self
Sourcepub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_last_modified_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_last_modified_time<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_default_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_default_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets the value of default_encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Dataset::new().set_default_encryption_configuration(EncryptionConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_default_encryption_configuration<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_or_clear_default_encryption_configuration<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets or clears the value of default_encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Dataset::new().set_or_clear_default_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = Dataset::new().set_or_clear_default_encryption_configuration(None::<EncryptionConfiguration>);Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sets the value of satisfies_pzs.
Example
use wkt::BoolValue;
let x = Dataset::new().set_satisfies_pzs(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
use wkt::BoolValue;
let x = Dataset::new().set_or_clear_satisfies_pzs(Some(BoolValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_satisfies_pzs(None::<BoolValue>);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sets the value of satisfies_pzi.
Example
use wkt::BoolValue;
let x = Dataset::new().set_satisfies_pzi(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
use wkt::BoolValue;
let x = Dataset::new().set_or_clear_satisfies_pzi(Some(BoolValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_satisfies_pzi(None::<BoolValue>);Sourcepub fn set_catalog_source<T>(self, v: T) -> Self
pub fn set_catalog_source<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_catalog_source<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_catalog_source<T>(self, v: Option<T>) -> Self
Sets or clears the value of catalog_source.
Example
let x = Dataset::new().set_or_clear_catalog_source(Some("example"));
let x = Dataset::new().set_or_clear_catalog_source(None::<String>);Sourcepub fn set_linked_dataset_source<T>(self, v: T) -> Selfwhere
T: Into<LinkedDatasetSource>,
pub fn set_linked_dataset_source<T>(self, v: T) -> Selfwhere
T: Into<LinkedDatasetSource>,
Sets the value of linked_dataset_source.
Example
use google_cloud_bigquery_v2::model::LinkedDatasetSource;
let x = Dataset::new().set_linked_dataset_source(LinkedDatasetSource::default()/* use setters */);Sourcepub fn set_or_clear_linked_dataset_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<LinkedDatasetSource>,
pub fn set_or_clear_linked_dataset_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<LinkedDatasetSource>,
Sets or clears the value of linked_dataset_source.
Example
use google_cloud_bigquery_v2::model::LinkedDatasetSource;
let x = Dataset::new().set_or_clear_linked_dataset_source(Some(LinkedDatasetSource::default()/* use setters */));
let x = Dataset::new().set_or_clear_linked_dataset_source(None::<LinkedDatasetSource>);Sourcepub fn set_linked_dataset_metadata<T>(self, v: T) -> Selfwhere
T: Into<LinkedDatasetMetadata>,
pub fn set_linked_dataset_metadata<T>(self, v: T) -> Selfwhere
T: Into<LinkedDatasetMetadata>,
Sets the value of linked_dataset_metadata.
Example
use google_cloud_bigquery_v2::model::LinkedDatasetMetadata;
let x = Dataset::new().set_linked_dataset_metadata(LinkedDatasetMetadata::default()/* use setters */);Sourcepub fn set_or_clear_linked_dataset_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<LinkedDatasetMetadata>,
pub fn set_or_clear_linked_dataset_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<LinkedDatasetMetadata>,
Sets or clears the value of linked_dataset_metadata.
Example
use google_cloud_bigquery_v2::model::LinkedDatasetMetadata;
let x = Dataset::new().set_or_clear_linked_dataset_metadata(Some(LinkedDatasetMetadata::default()/* use setters */));
let x = Dataset::new().set_or_clear_linked_dataset_metadata(None::<LinkedDatasetMetadata>);Sourcepub fn set_external_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<ExternalDatasetReference>,
pub fn set_external_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<ExternalDatasetReference>,
Sets the value of external_dataset_reference.
Example
use google_cloud_bigquery_v2::model::ExternalDatasetReference;
let x = Dataset::new().set_external_dataset_reference(ExternalDatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_external_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDatasetReference>,
pub fn set_or_clear_external_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDatasetReference>,
Sets or clears the value of external_dataset_reference.
Example
use google_cloud_bigquery_v2::model::ExternalDatasetReference;
let x = Dataset::new().set_or_clear_external_dataset_reference(Some(ExternalDatasetReference::default()/* use setters */));
let x = Dataset::new().set_or_clear_external_dataset_reference(None::<ExternalDatasetReference>);Sourcepub fn set_external_catalog_dataset_options<T>(self, v: T) -> Selfwhere
T: Into<ExternalCatalogDatasetOptions>,
pub fn set_external_catalog_dataset_options<T>(self, v: T) -> Selfwhere
T: Into<ExternalCatalogDatasetOptions>,
Sets the value of external_catalog_dataset_options.
Example
use google_cloud_bigquery_v2::model::ExternalCatalogDatasetOptions;
let x = Dataset::new().set_external_catalog_dataset_options(ExternalCatalogDatasetOptions::default()/* use setters */);Sourcepub fn set_or_clear_external_catalog_dataset_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExternalCatalogDatasetOptions>,
pub fn set_or_clear_external_catalog_dataset_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExternalCatalogDatasetOptions>,
Sets or clears the value of external_catalog_dataset_options.
Example
use google_cloud_bigquery_v2::model::ExternalCatalogDatasetOptions;
let x = Dataset::new().set_or_clear_external_catalog_dataset_options(Some(ExternalCatalogDatasetOptions::default()/* use setters */));
let x = Dataset::new().set_or_clear_external_catalog_dataset_options(None::<ExternalCatalogDatasetOptions>);Sourcepub fn set_is_case_insensitive<T>(self, v: T) -> Self
pub fn set_is_case_insensitive<T>(self, v: T) -> Self
Sets the value of is_case_insensitive.
Example
use wkt::BoolValue;
let x = Dataset::new().set_is_case_insensitive(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_is_case_insensitive<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_is_case_insensitive<T>(self, v: Option<T>) -> Self
Sets or clears the value of is_case_insensitive.
Example
use wkt::BoolValue;
let x = Dataset::new().set_or_clear_is_case_insensitive(Some(BoolValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_is_case_insensitive(None::<BoolValue>);Sourcepub fn set_default_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_default_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of default_collation.
Example
use wkt::StringValue;
let x = Dataset::new().set_default_collation(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_default_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_default_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of default_collation.
Example
use wkt::StringValue;
let x = Dataset::new().set_or_clear_default_collation(Some(StringValue::default()/* use setters */));
let x = Dataset::new().set_or_clear_default_collation(None::<StringValue>);Sourcepub fn set_default_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
pub fn set_default_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
Sets the value of default_rounding_mode.
Example
use google_cloud_bigquery_v2::model::table_field_schema::RoundingMode;
let x0 = Dataset::new().set_default_rounding_mode(RoundingMode::RoundHalfAwayFromZero);
let x1 = Dataset::new().set_default_rounding_mode(RoundingMode::RoundHalfEven);Sourcepub fn set_max_time_travel_hours<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_max_time_travel_hours<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of max_time_travel_hours.
Example
use wkt::Int64Value;
let x = Dataset::new().set_max_time_travel_hours(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_max_time_travel_hours<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_max_time_travel_hours<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of max_time_travel_hours.
Example
use wkt::Int64Value;
let x = Dataset::new().set_or_clear_max_time_travel_hours(Some(Int64Value::default()/* use setters */));
let x = Dataset::new().set_or_clear_max_time_travel_hours(None::<Int64Value>);👎Deprecated
Sourcepub fn set_storage_billing_model<T: Into<StorageBillingModel>>(
self,
v: T,
) -> Self
pub fn set_storage_billing_model<T: Into<StorageBillingModel>>( self, v: T, ) -> Self
Sets the value of storage_billing_model.
Example
use google_cloud_bigquery_v2::model::dataset::StorageBillingModel;
let x0 = Dataset::new().set_storage_billing_model(StorageBillingModel::Logical);
let x1 = Dataset::new().set_storage_billing_model(StorageBillingModel::Physical);Sourcepub fn set_restrictions<T>(self, v: T) -> Selfwhere
T: Into<RestrictionConfig>,
pub fn set_restrictions<T>(self, v: T) -> Selfwhere
T: Into<RestrictionConfig>,
Sets the value of restrictions.
Example
use google_cloud_bigquery_v2::model::RestrictionConfig;
let x = Dataset::new().set_restrictions(RestrictionConfig::default()/* use setters */);Sourcepub fn set_or_clear_restrictions<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictionConfig>,
pub fn set_or_clear_restrictions<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictionConfig>,
Sets or clears the value of restrictions.
Example
use google_cloud_bigquery_v2::model::RestrictionConfig;
let x = Dataset::new().set_or_clear_restrictions(Some(RestrictionConfig::default()/* use setters */));
let x = Dataset::new().set_or_clear_restrictions(None::<RestrictionConfig>);Sets the value of resource_tags.
Example
let x = Dataset::new().set_resource_tags([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
impl StructuralPartialEq for Dataset