DatasetAccessEntry

Struct DatasetAccessEntry 

#[non_exhaustive]
pub struct DatasetAccessEntry { pub dataset: Option<DatasetReference>, pub target_types: Vec<TargetType>, /* private fields */ }
Grants all resources of particular types in a particular dataset read access to the current dataset.

Similar to how individually authorized views work, updates to any resource granted through its dataset (including creation of new resources) requires read permission to referenced resources, plus write permission to the authorizing dataset.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
dataset: Option<DatasetReference>

The dataset this entry applies to

target_types: Vec<TargetType>

Which resources in the dataset this entry applies to. Currently, only views are supported, but additional target types may be added in the future.

Implementations

Source

impl DatasetAccessEntry

pub fn new() -> Self

Creates a new default instance.

pub fn set_dataset<T>(self, v: T) -> Self

Sets the value of dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = DatasetAccessEntry::new().set_dataset(DatasetReference::default()/* use setters */);
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Self

Sets or clears the value of dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = DatasetAccessEntry::new().set_or_clear_dataset(Some(DatasetReference::default()/* use setters */));
let x = DatasetAccessEntry::new().set_or_clear_dataset(None::<DatasetReference>);
pub fn set_target_types<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TargetType>,

Sets the value of target_types.

Example
use google_cloud_bigquery_v2::model::dataset_access_entry::TargetType;
let x = DatasetAccessEntry::new().set_target_types([
    TargetType::Views,
    TargetType::Routines,
]);