#[non_exhaustive]pub struct DatasetList {
pub kind: String,
pub etag: String,
pub next_page_token: String,
pub datasets: Vec<ListFormatDataset>,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response format for a page of results when listing datasets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringOutput only. The resource type. This property always returns the value “bigquery#datasetList”
etag: StringOutput only. A hash value of the results page. You can use this property to determine if the page has changed since the last request.
next_page_token: StringA token that can be used to request the next results page. This property is omitted on the final results page.
datasets: Vec<ListFormatDataset>An array of the dataset resources in the project. Each resource contains basic information. For full information about a particular dataset resource, use the Datasets: get method. This property is omitted when there are no datasets in the project.
unreachable: Vec<String>A list of skipped locations that were unreachable. For more information about BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations. Example: “europe-west5”
Implementations
Sourceimpl DatasetList
impl DatasetList
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = DatasetList::new().set_next_page_token("example");Sourcepub fn set_datasets<T, V>(self, v: T) -> Self
pub fn set_datasets<T, V>(self, v: T) -> Self
Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
let x = DatasetList::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DatasetList
impl Clone for DatasetList
Sourcefn clone(&self) -> DatasetList
fn clone(&self) -> DatasetList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DatasetList
impl Debug for DatasetList
Sourceimpl Default for DatasetList
impl Default for DatasetList
Sourcefn default() -> DatasetList
fn default() -> DatasetList
Sourceimpl Message for DatasetList
impl Message for DatasetList
Sourceimpl PartialEq for DatasetList
impl PartialEq for DatasetList
impl StructuralPartialEq for DatasetList