DeleteDatasetRequest

Struct DeleteDatasetRequest 

#[non_exhaustive]
pub struct DeleteDatasetRequest { pub project_id: String, pub dataset_id: String, pub delete_contents: bool, /* private fields */ }
Request format for deleting a dataset.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
project_id: String

Required. Project ID of the dataset being deleted

dataset_id: String

Required. Dataset ID of dataset being deleted

delete_contents: bool

If True, delete all the tables in the dataset. If False and the dataset contains tables, the request will fail. Default is False

Implementations

Source

impl DeleteDatasetRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of project_id.

Example
let x = DeleteDatasetRequest::new().set_project_id("example");
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self

Sets the value of dataset_id.

Example
let x = DeleteDatasetRequest::new().set_dataset_id("example");
pub fn set_delete_contents<T: Into<bool>>(self, v: T) -> Self

Sets the value of delete_contents.

Example
let x = DeleteDatasetRequest::new().set_delete_contents(true);