#[non_exhaustive]pub struct DeleteJobRequest {
pub project_id: String,
pub job_id: String,
pub location: String,
/* private fields */
}Expand description
Describes the format of a jobs deletion request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the job for which metadata is to be deleted.
job_id: StringRequired. Job ID of the job for which metadata is to be deleted. If this is a parent job which has child jobs, the metadata from all child jobs will be deleted as well. Direct deletion of the metadata of child jobs is not allowed.
location: StringThe geographic location of the job. Required.
For more information, see how to specify locations.
Implementations
Sourceimpl DeleteJobRequest
impl DeleteJobRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_job_id<T: Into<String>>(self, v: T) -> Self