DestinationTableProperties

Struct DestinationTableProperties 

#[non_exhaustive]
pub struct DestinationTableProperties { pub friendly_name: Option<StringValue>, pub description: Option<StringValue>, pub labels: HashMap<String, String>, /* private fields */ }
Properties for the destination table.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
friendly_name: Option<StringValue>

Optional. Friendly name for the destination table. If the table already exists, it should be same as the existing friendly name.

description: Option<StringValue>

Optional. The description for the destination table. This will only be used if the destination table is newly created. If the table already exists and a value different than the current description is provided, the job will fail.

labels: HashMap<String, String>

Optional. The labels associated with this table. You can use these to organize and group your tables. This will only be used if the destination table is newly created. If the table already exists and labels are different than the current labels are provided, the job will fail.

Implementations

Source

impl DestinationTableProperties

pub fn new() -> Self

Creates a new default instance.

pub fn set_friendly_name<T>(self, v: T) -> Self
where T: Into<StringValue>,

Sets the value of friendly_name.

Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_friendly_name(StringValue::default()/* use setters */);
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Self
where T: Into<StringValue>,

Sets or clears the value of friendly_name.

Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = DestinationTableProperties::new().set_or_clear_friendly_name(None::<StringValue>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<StringValue>,

Sets the value of description.

Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_description(StringValue::default()/* use setters */);
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<StringValue>,

Sets or clears the value of description.

Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = DestinationTableProperties::new().set_or_clear_description(None::<StringValue>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DestinationTableProperties::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);