DifferentialPrivacyPolicy

Struct DifferentialPrivacyPolicy 

#[non_exhaustive]
pub struct DifferentialPrivacyPolicy { pub max_epsilon_per_query: Option<f64>, pub delta_per_query: Option<f64>, pub max_groups_contributed: Option<i64>, pub privacy_unit_column: Option<String>, pub epsilon_budget: Option<f64>, pub delta_budget: Option<f64>, pub epsilon_budget_remaining: Option<f64>, pub delta_budget_remaining: Option<f64>, /* private fields */ }
Represents privacy policy associated with “differential privacy” method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_epsilon_per_query: Option<f64>

Optional. The maximum epsilon value that a query can consume. If the subscriber specifies epsilon as a parameter in a SELECT query, it must be less than or equal to this value. The epsilon parameter controls the amount of noise that is added to the groups — a higher epsilon means less noise.

delta_per_query: Option<f64>

Optional. The delta value that is used per query. Delta represents the probability that any row will fail to be epsilon differentially private. Indicates the risk associated with exposing aggregate rows in the result of a query.

max_groups_contributed: Option<i64>

Optional. The maximum groups contributed value that is used per query. Represents the maximum number of groups to which each protected entity can contribute. Changing this value does not improve or worsen privacy. The best value for accuracy and utility depends on the query and data.

privacy_unit_column: Option<String>

Optional. The privacy unit column associated with this policy. Differential privacy policies can only have one privacy unit column per data source object (table, view).

epsilon_budget: Option<f64>

Optional. The total epsilon budget for all queries against the privacy-protected view. Each subscriber query against this view charges the amount of epsilon they request in their query. If there is sufficient budget, then the subscriber query attempts to complete. It might still fail due to other reasons, in which case the charge is refunded. If there is insufficient budget the query is rejected. There might be multiple charge attempts if a single query references multiple views. In this case there must be sufficient budget for all charges or the query is rejected and charges are refunded in best effort. The budget does not have a refresh policy and can only be updated via ALTER VIEW or circumvented by creating a new view that can be queried with a fresh budget.

delta_budget: Option<f64>

Optional. The total delta budget for all queries against the privacy-protected view. Each subscriber query against this view charges the amount of delta that is pre-defined by the contributor through the privacy policy delta_per_query field. If there is sufficient budget, then the subscriber query attempts to complete. It might still fail due to other reasons, in which case the charge is refunded. If there is insufficient budget the query is rejected. There might be multiple charge attempts if a single query references multiple views. In this case there must be sufficient budget for all charges or the query is rejected and charges are refunded in best effort. The budget does not have a refresh policy and can only be updated via ALTER VIEW or circumvented by creating a new view that can be queried with a fresh budget.

epsilon_budget_remaining: Option<f64>

Output only. The epsilon budget remaining. If budget is exhausted, no more queries are allowed. Note that the budget for queries that are in progress is deducted before the query executes. If the query fails or is cancelled then the budget is refunded. In this case the amount of budget remaining can increase.

delta_budget_remaining: Option<f64>

Output only. The delta budget remaining. If budget is exhausted, no more queries are allowed. Note that the budget for queries that are in progress is deducted before the query executes. If the query fails or is cancelled then the budget is refunded. In this case the amount of budget remaining can increase.

Implementations

Source

impl DifferentialPrivacyPolicy

pub fn new() -> Self

Creates a new default instance.

pub fn set_max_epsilon_per_query<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of max_epsilon_per_query.

Example
let x = DifferentialPrivacyPolicy::new().set_max_epsilon_per_query(42.0);
pub fn set_or_clear_max_epsilon_per_query<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of max_epsilon_per_query.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_max_epsilon_per_query(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_max_epsilon_per_query(None::<f32>);
pub fn set_delta_per_query<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of delta_per_query.

Example
let x = DifferentialPrivacyPolicy::new().set_delta_per_query(42.0);
pub fn set_or_clear_delta_per_query<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of delta_per_query.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_per_query(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_per_query(None::<f32>);
pub fn set_max_groups_contributed<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of max_groups_contributed.

Example
let x = DifferentialPrivacyPolicy::new().set_max_groups_contributed(42);
pub fn set_or_clear_max_groups_contributed<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of max_groups_contributed.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_max_groups_contributed(Some(42));
let x = DifferentialPrivacyPolicy::new().set_or_clear_max_groups_contributed(None::<i32>);
pub fn set_privacy_unit_column<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of privacy_unit_column.

Example
let x = DifferentialPrivacyPolicy::new().set_privacy_unit_column("example");
pub fn set_or_clear_privacy_unit_column<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of privacy_unit_column.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_privacy_unit_column(Some("example"));
let x = DifferentialPrivacyPolicy::new().set_or_clear_privacy_unit_column(None::<String>);
pub fn set_epsilon_budget<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of epsilon_budget.

Example
let x = DifferentialPrivacyPolicy::new().set_epsilon_budget(42.0);
pub fn set_or_clear_epsilon_budget<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of epsilon_budget.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_epsilon_budget(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_epsilon_budget(None::<f32>);
pub fn set_delta_budget<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of delta_budget.

Example
let x = DifferentialPrivacyPolicy::new().set_delta_budget(42.0);
pub fn set_or_clear_delta_budget<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of delta_budget.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_budget(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_budget(None::<f32>);
pub fn set_epsilon_budget_remaining<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of epsilon_budget_remaining.

Example
let x = DifferentialPrivacyPolicy::new().set_epsilon_budget_remaining(42.0);
pub fn set_or_clear_epsilon_budget_remaining<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of epsilon_budget_remaining.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_epsilon_budget_remaining(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_epsilon_budget_remaining(None::<f32>);
pub fn set_delta_budget_remaining<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of delta_budget_remaining.

Example
let x = DifferentialPrivacyPolicy::new().set_delta_budget_remaining(42.0);
pub fn set_or_clear_delta_budget_remaining<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of delta_budget_remaining.

Example
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_budget_remaining(Some(42.0));
let x = DifferentialPrivacyPolicy::new().set_or_clear_delta_budget_remaining(None::<f32>);