EncryptionConfiguration

Struct EncryptionConfiguration 

#[non_exhaustive]
pub struct EncryptionConfiguration { pub kms_key_name: Option<StringValue>, /* private fields */ }
Configuration for Cloud KMS encryption settings.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kms_key_name: Option<StringValue>

Optional. Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table. The BigQuery Service Account associated with your project requires access to this encryption key.

Implementations

Source

impl EncryptionConfiguration

pub fn new() -> Self

Creates a new default instance.

pub fn set_kms_key_name<T>(self, v: T) -> Self
where T: Into<StringValue>,

Sets the value of kms_key_name.

Example
use wkt::StringValue;
let x = EncryptionConfiguration::new().set_kms_key_name(StringValue::default()/* use setters */);
pub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
where T: Into<StringValue>,

Sets or clears the value of kms_key_name.

Example
use wkt::StringValue;
let x = EncryptionConfiguration::new().set_or_clear_kms_key_name(Some(StringValue::default()/* use setters */));
let x = EncryptionConfiguration::new().set_or_clear_kms_key_name(None::<StringValue>);