ExplainQueryStage

Struct ExplainQueryStage 

#[non_exhaustive]
pub struct ExplainQueryStage {
Show 31 fields pub name: String, pub id: Option<Int64Value>, pub start_ms: i64, pub end_ms: i64, pub input_stages: Vec<i64>, pub wait_ratio_avg: Option<DoubleValue>, pub wait_ms_avg: Option<Int64Value>, pub wait_ratio_max: Option<DoubleValue>, pub wait_ms_max: Option<Int64Value>, pub read_ratio_avg: Option<DoubleValue>, pub read_ms_avg: Option<Int64Value>, pub read_ratio_max: Option<DoubleValue>, pub read_ms_max: Option<Int64Value>, pub compute_ratio_avg: Option<DoubleValue>, pub compute_ms_avg: Option<Int64Value>, pub compute_ratio_max: Option<DoubleValue>, pub compute_ms_max: Option<Int64Value>, pub write_ratio_avg: Option<DoubleValue>, pub write_ms_avg: Option<Int64Value>, pub write_ratio_max: Option<DoubleValue>, pub write_ms_max: Option<Int64Value>, pub shuffle_output_bytes: Option<Int64Value>, pub shuffle_output_bytes_spilled: Option<Int64Value>, pub records_read: Option<Int64Value>, pub records_written: Option<Int64Value>, pub parallel_inputs: Option<Int64Value>, pub completed_parallel_inputs: Option<Int64Value>, pub status: String, pub steps: Vec<ExplainQueryStep>, pub slot_ms: Option<Int64Value>, pub compute_mode: ComputeMode, /* private fields */
}
A single stage of query execution.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Human-readable name for the stage.

id: Option<Int64Value>

Unique ID for the stage within the plan.

start_ms: i64

Stage start time represented as milliseconds since the epoch.

end_ms: i64

Stage end time represented as milliseconds since the epoch.

input_stages: Vec<i64>

IDs for stages that are inputs to this stage.

wait_ratio_avg: Option<DoubleValue>

Relative amount of time the average shard spent waiting to be scheduled.

wait_ms_avg: Option<Int64Value>

Milliseconds the average shard spent waiting to be scheduled.

wait_ratio_max: Option<DoubleValue>

Relative amount of time the slowest shard spent waiting to be scheduled.

wait_ms_max: Option<Int64Value>

Milliseconds the slowest shard spent waiting to be scheduled.

read_ratio_avg: Option<DoubleValue>

Relative amount of time the average shard spent reading input.

read_ms_avg: Option<Int64Value>

Milliseconds the average shard spent reading input.

read_ratio_max: Option<DoubleValue>

Relative amount of time the slowest shard spent reading input.

read_ms_max: Option<Int64Value>

Milliseconds the slowest shard spent reading input.

compute_ratio_avg: Option<DoubleValue>

Relative amount of time the average shard spent on CPU-bound tasks.

compute_ms_avg: Option<Int64Value>

Milliseconds the average shard spent on CPU-bound tasks.

compute_ratio_max: Option<DoubleValue>

Relative amount of time the slowest shard spent on CPU-bound tasks.

compute_ms_max: Option<Int64Value>

Milliseconds the slowest shard spent on CPU-bound tasks.

write_ratio_avg: Option<DoubleValue>

Relative amount of time the average shard spent on writing output.

write_ms_avg: Option<Int64Value>

Milliseconds the average shard spent on writing output.

write_ratio_max: Option<DoubleValue>

Relative amount of time the slowest shard spent on writing output.

write_ms_max: Option<Int64Value>

Milliseconds the slowest shard spent on writing output.

shuffle_output_bytes: Option<Int64Value>

Total number of bytes written to shuffle.

shuffle_output_bytes_spilled: Option<Int64Value>

Total number of bytes written to shuffle and spilled to disk.

records_read: Option<Int64Value>

Number of records read into the stage.

records_written: Option<Int64Value>

Number of records written by the stage.

parallel_inputs: Option<Int64Value>

Number of parallel input segments to be processed

completed_parallel_inputs: Option<Int64Value>

Number of parallel input segments completed.

status: String

Current status for this stage.

steps: Vec<ExplainQueryStep>

List of operations within the stage in dependency order (approximately chronological).

slot_ms: Option<Int64Value>

Slot-milliseconds used by the stage.

compute_mode: ComputeMode

Output only. Compute mode for this stage.

Implementations

Source

impl ExplainQueryStage

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = ExplainQueryStage::new().set_name("example");
pub fn set_id<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of id.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_id(Int64Value::default()/* use setters */);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of id.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_id(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_id(None::<Int64Value>);
pub fn set_start_ms<T: Into<i64>>(self, v: T) -> Self

Sets the value of start_ms.

Example
let x = ExplainQueryStage::new().set_start_ms(42);
pub fn set_end_ms<T: Into<i64>>(self, v: T) -> Self

Sets the value of end_ms.

Example
let x = ExplainQueryStage::new().set_end_ms(42);
pub fn set_input_stages<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<i64>,

Sets the value of input_stages.

Example
let x = ExplainQueryStage::new().set_input_stages([1, 2, 3]);
pub fn set_wait_ratio_avg<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of wait_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_wait_ratio_avg(DoubleValue::default()/* use setters */);
pub fn set_or_clear_wait_ratio_avg<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of wait_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_avg(None::<DoubleValue>);
pub fn set_wait_ms_avg<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of wait_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_wait_ms_avg(Int64Value::default()/* use setters */);
pub fn set_or_clear_wait_ms_avg<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of wait_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_wait_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ms_avg(None::<Int64Value>);
pub fn set_wait_ratio_max<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of wait_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_wait_ratio_max(DoubleValue::default()/* use setters */);
pub fn set_or_clear_wait_ratio_max<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of wait_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_max(None::<DoubleValue>);
pub fn set_wait_ms_max<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of wait_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_wait_ms_max(Int64Value::default()/* use setters */);
pub fn set_or_clear_wait_ms_max<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of wait_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_wait_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ms_max(None::<Int64Value>);
pub fn set_read_ratio_avg<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of read_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_read_ratio_avg(DoubleValue::default()/* use setters */);
pub fn set_or_clear_read_ratio_avg<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of read_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_read_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ratio_avg(None::<DoubleValue>);
pub fn set_read_ms_avg<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of read_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_read_ms_avg(Int64Value::default()/* use setters */);
pub fn set_or_clear_read_ms_avg<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of read_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_read_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ms_avg(None::<Int64Value>);
pub fn set_read_ratio_max<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of read_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_read_ratio_max(DoubleValue::default()/* use setters */);
pub fn set_or_clear_read_ratio_max<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of read_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_read_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ratio_max(None::<DoubleValue>);
pub fn set_read_ms_max<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of read_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_read_ms_max(Int64Value::default()/* use setters */);
pub fn set_or_clear_read_ms_max<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of read_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_read_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ms_max(None::<Int64Value>);
pub fn set_compute_ratio_avg<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of compute_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_compute_ratio_avg(DoubleValue::default()/* use setters */);
pub fn set_or_clear_compute_ratio_avg<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of compute_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_avg(None::<DoubleValue>);
pub fn set_compute_ms_avg<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of compute_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_compute_ms_avg(Int64Value::default()/* use setters */);
pub fn set_or_clear_compute_ms_avg<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of compute_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_compute_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ms_avg(None::<Int64Value>);
pub fn set_compute_ratio_max<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of compute_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_compute_ratio_max(DoubleValue::default()/* use setters */);
pub fn set_or_clear_compute_ratio_max<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of compute_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_max(None::<DoubleValue>);
pub fn set_compute_ms_max<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of compute_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_compute_ms_max(Int64Value::default()/* use setters */);
pub fn set_or_clear_compute_ms_max<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of compute_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_compute_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ms_max(None::<Int64Value>);
pub fn set_write_ratio_avg<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of write_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_write_ratio_avg(DoubleValue::default()/* use setters */);
pub fn set_or_clear_write_ratio_avg<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of write_ratio_avg.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_write_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ratio_avg(None::<DoubleValue>);
pub fn set_write_ms_avg<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of write_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_write_ms_avg(Int64Value::default()/* use setters */);
pub fn set_or_clear_write_ms_avg<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of write_ms_avg.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_write_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ms_avg(None::<Int64Value>);
pub fn set_write_ratio_max<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of write_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_write_ratio_max(DoubleValue::default()/* use setters */);
pub fn set_or_clear_write_ratio_max<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of write_ratio_max.

Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_write_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ratio_max(None::<DoubleValue>);
pub fn set_write_ms_max<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of write_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_write_ms_max(Int64Value::default()/* use setters */);
pub fn set_or_clear_write_ms_max<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of write_ms_max.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_write_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ms_max(None::<Int64Value>);
pub fn set_shuffle_output_bytes<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of shuffle_output_bytes.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_shuffle_output_bytes(Int64Value::default()/* use setters */);
pub fn set_or_clear_shuffle_output_bytes<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of shuffle_output_bytes.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes(None::<Int64Value>);
pub fn set_shuffle_output_bytes_spilled<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of shuffle_output_bytes_spilled.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_shuffle_output_bytes_spilled(Int64Value::default()/* use setters */);
pub fn set_or_clear_shuffle_output_bytes_spilled<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of shuffle_output_bytes_spilled.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes_spilled(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes_spilled(None::<Int64Value>);
pub fn set_records_read<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of records_read.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_records_read(Int64Value::default()/* use setters */);
pub fn set_or_clear_records_read<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of records_read.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_records_read(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_records_read(None::<Int64Value>);
pub fn set_records_written<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of records_written.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_records_written(Int64Value::default()/* use setters */);
pub fn set_or_clear_records_written<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of records_written.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_records_written(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_records_written(None::<Int64Value>);
pub fn set_parallel_inputs<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of parallel_inputs.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_parallel_inputs(Int64Value::default()/* use setters */);
pub fn set_or_clear_parallel_inputs<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of parallel_inputs.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_parallel_inputs(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_parallel_inputs(None::<Int64Value>);
pub fn set_completed_parallel_inputs<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of completed_parallel_inputs.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_completed_parallel_inputs(Int64Value::default()/* use setters */);
pub fn set_or_clear_completed_parallel_inputs<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of completed_parallel_inputs.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_completed_parallel_inputs(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_completed_parallel_inputs(None::<Int64Value>);
pub fn set_status<T: Into<String>>(self, v: T) -> Self

Sets the value of status.

Example
let x = ExplainQueryStage::new().set_status("example");
pub fn set_steps<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ExplainQueryStep>,

Sets the value of steps.

Example
use google_cloud_bigquery_v2::model::ExplainQueryStep;
let x = ExplainQueryStage::new()
    .set_steps([
        ExplainQueryStep::default()/* use setters */,
        ExplainQueryStep::default()/* use (different) setters */,
    ]);
pub fn set_slot_ms<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of slot_ms.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_slot_ms(Int64Value::default()/* use setters */);
pub fn set_or_clear_slot_ms<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of slot_ms.

Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_slot_ms(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_slot_ms(None::<Int64Value>);
pub fn set_compute_mode<T: Into<ComputeMode>>(self, v: T) -> Self

Sets the value of compute_mode.

Example
use google_cloud_bigquery_v2::model::explain_query_stage::ComputeMode;
let x0 = ExplainQueryStage::new().set_compute_mode(ComputeMode::Bigquery);
let x1 = ExplainQueryStage::new().set_compute_mode(ComputeMode::BiEngine);