#[non_exhaustive]pub struct ExportDataStatistics {
pub file_count: Option<Int64Value>,
pub row_count: Option<Int64Value>,
/* private fields */
}Expand description
Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_count: Option<Int64Value>Number of destination files generated in case of EXPORT DATA statement only.
row_count: Option<Int64Value>[Alpha] Number of destination rows generated in case of EXPORT DATA statement only.
Implementations
Sourceimpl ExportDataStatistics
impl ExportDataStatistics
Sourcepub fn set_file_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_file_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of file_count.
Example
ⓘ
use wkt::Int64Value;
let x = ExportDataStatistics::new().set_file_count(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_file_count<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_file_count<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of file_count.
Example
ⓘ
use wkt::Int64Value;
let x = ExportDataStatistics::new().set_or_clear_file_count(Some(Int64Value::default()/* use setters */));
let x = ExportDataStatistics::new().set_or_clear_file_count(None::<Int64Value>);Sourcepub fn set_row_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_row_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_row_count<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_row_count<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,