#[non_exhaustive]pub struct ExternalCatalogDatasetOptions {
pub parameters: HashMap<String, String>,
pub default_storage_location_uri: String,
/* private fields */
}Expand description
Options defining open source compatible datasets living in the BigQuery catalog. Contains metadata of open source database, schema, or namespace represented by the current dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameters: HashMap<String, String>Optional. A map of key value pairs defining the parameters and properties of the open source schema. Maximum size of 2MiB.
default_storage_location_uri: StringOptional. The storage location URI for all tables in the dataset. Equivalent to hive metastore’s database locationUri. Maximum length of 1024 characters.
Implementations
Sourceimpl ExternalCatalogDatasetOptions
impl ExternalCatalogDatasetOptions
Sourcepub fn set_parameters<T, K, V>(self, v: T) -> Self
pub fn set_parameters<T, K, V>(self, v: T) -> Self
Sets the value of parameters.
Example
ⓘ
let x = ExternalCatalogDatasetOptions::new().set_parameters([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_default_storage_location_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_default_storage_location_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of default_storage_location_uri.
Example
ⓘ
let x = ExternalCatalogDatasetOptions::new().set_default_storage_location_uri("example");Trait Implementations
Sourceimpl Clone for ExternalCatalogDatasetOptions
impl Clone for ExternalCatalogDatasetOptions
Sourcefn clone(&self) -> ExternalCatalogDatasetOptions
fn clone(&self) -> ExternalCatalogDatasetOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExternalCatalogDatasetOptions
impl Default for ExternalCatalogDatasetOptions
Sourcefn default() -> ExternalCatalogDatasetOptions
fn default() -> ExternalCatalogDatasetOptions
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ExternalCatalogDatasetOptions