#[non_exhaustive]pub struct ExternalDataConfiguration {Show 27 fields
pub source_uris: Vec<String>,
pub file_set_spec_type: FileSetSpecType,
pub schema: Option<TableSchema>,
pub source_format: String,
pub max_bad_records: Option<Int32Value>,
pub autodetect: Option<BoolValue>,
pub ignore_unknown_values: Option<BoolValue>,
pub compression: String,
pub csv_options: Option<CsvOptions>,
pub json_options: Option<JsonOptions>,
pub bigtable_options: Option<BigtableOptions>,
pub google_sheets_options: Option<GoogleSheetsOptions>,
pub hive_partitioning_options: Option<HivePartitioningOptions>,
pub connection_id: String,
pub decimal_target_types: Vec<DecimalTargetType>,
pub avro_options: Option<AvroOptions>,
pub json_extension: JsonExtension,
pub parquet_options: Option<ParquetOptions>,
pub object_metadata: Option<ObjectMetadata>,
pub reference_file_schema_uri: Option<StringValue>,
pub metadata_cache_mode: MetadataCacheMode,
pub time_zone: Option<String>,
pub date_format: Option<String>,
pub datetime_format: Option<String>,
pub time_format: Option<String>,
pub timestamp_format: Option<String>,
pub timestamp_target_precision: Vec<i32>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_uris: Vec<String>[Required] The fully-qualified URIs that point to your data in Google Cloud. For Google Cloud Storage URIs: Each URI can contain one ‘’ wildcard character and it must come after the ‘bucket’ name. Size limits related to load jobs apply to external data sources. For Google Cloud Bigtable URIs: Exactly one URI can be specified and it has be a fully specified and valid HTTPS URL for a Google Cloud Bigtable table. For Google Cloud Datastore backups, exactly one URI can be specified. Also, the ‘’ wildcard character is not allowed.
file_set_spec_type: FileSetSpecTypeOptional. Specifies how source URIs are interpreted for constructing the file set to load. By default source URIs are expanded against the underlying storage. Other options include specifying manifest files. Only applicable to object storage systems.
schema: Option<TableSchema>Optional. The schema for the data. Schema is required for CSV and JSON formats if autodetect is not on. Schema is disallowed for Google Cloud Bigtable, Cloud Datastore backups, Avro, ORC and Parquet formats.
source_format: String[Required] The data format. For CSV files, specify “CSV”. For Google sheets, specify “GOOGLE_SHEETS”. For newline-delimited JSON, specify “NEWLINE_DELIMITED_JSON”. For Avro files, specify “AVRO”. For Google Cloud Datastore backups, specify “DATASTORE_BACKUP”. For Apache Iceberg tables, specify “ICEBERG”. For ORC files, specify “ORC”. For Parquet files, specify “PARQUET”. [Beta] For Google Cloud Bigtable, specify “BIGTABLE”.
max_bad_records: Option<Int32Value>Optional. The maximum number of bad records that BigQuery can ignore when reading data. If the number of bad records exceeds this value, an invalid error is returned in the job result. The default value is 0, which requires that all records are valid. This setting is ignored for Google Cloud Bigtable, Google Cloud Datastore backups, Avro, ORC and Parquet formats.
autodetect: Option<BoolValue>Try to detect schema and format options automatically. Any option specified explicitly will be honored.
ignore_unknown_values: Option<BoolValue>Optional. Indicates if BigQuery should allow extra values that are not represented in the table schema. If true, the extra values are ignored. If false, records with extra columns are treated as bad records, and if there are too many bad records, an invalid error is returned in the job result. The default value is false. The sourceFormat property determines what BigQuery treats as an extra value: CSV: Trailing columns JSON: Named values that don’t match any column names Google Cloud Bigtable: This setting is ignored. Google Cloud Datastore backups: This setting is ignored. Avro: This setting is ignored. ORC: This setting is ignored. Parquet: This setting is ignored.
compression: StringOptional. The compression type of the data source. Possible values include GZIP and NONE. The default value is NONE. This setting is ignored for Google Cloud Bigtable, Google Cloud Datastore backups, Avro, ORC and Parquet formats. An empty string is an invalid value.
csv_options: Option<CsvOptions>Optional. Additional properties to set if sourceFormat is set to CSV.
json_options: Option<JsonOptions>Optional. Additional properties to set if sourceFormat is set to JSON.
bigtable_options: Option<BigtableOptions>Optional. Additional options if sourceFormat is set to BIGTABLE.
google_sheets_options: Option<GoogleSheetsOptions>Optional. Additional options if sourceFormat is set to GOOGLE_SHEETS.
hive_partitioning_options: Option<HivePartitioningOptions>Optional. When set, configures hive partitioning support. Not all storage formats support hive partitioning – requesting hive partitioning on an unsupported format will lead to an error, as will providing an invalid specification.
connection_id: StringOptional. The connection specifying the credentials to be used to read
external storage, such as Azure Blob, Cloud Storage, or S3. The
connection_id can have the form
{project_id}.{location_id};{connection_id} or
projects/{project_id}/locations/{location_id}/connections/{connection_id}.
decimal_target_types: Vec<DecimalTargetType>Defines the list of possible SQL data types to which the source decimal values are converted. This list and the precision and the scale parameters of the decimal field determine the target type. In the order of NUMERIC, BIGNUMERIC, and STRING, a type is picked if it is in the specified list and if it supports the precision and the scale. STRING supports all precision and scale values. If none of the listed types supports the precision and the scale, the type supporting the widest range in the specified list is picked, and if a value exceeds the supported range when reading the data, an error will be thrown.
Example: Suppose the value of this field is [“NUMERIC”, “BIGNUMERIC”]. If (precision,scale) is:
- (38,9) -> NUMERIC;
- (39,9) -> BIGNUMERIC (NUMERIC cannot hold 30 integer digits);
- (38,10) -> BIGNUMERIC (NUMERIC cannot hold 10 fractional digits);
- (76,38) -> BIGNUMERIC;
- (77,38) -> BIGNUMERIC (error if value exceeds supported range).
This field cannot contain duplicate types. The order of the types in this field is ignored. For example, [“BIGNUMERIC”, “NUMERIC”] is the same as [“NUMERIC”, “BIGNUMERIC”] and NUMERIC always takes precedence over BIGNUMERIC.
Defaults to [“NUMERIC”, “STRING”] for ORC and [“NUMERIC”] for the other file formats.
avro_options: Option<AvroOptions>Optional. Additional properties to set if sourceFormat is set to AVRO.
json_extension: JsonExtensionOptional. Load option to be used together with source_format newline-delimited JSON to indicate that a variant of JSON is being loaded. To load newline-delimited GeoJSON, specify GEOJSON (and source_format must be set to NEWLINE_DELIMITED_JSON).
parquet_options: Option<ParquetOptions>Optional. Additional properties to set if sourceFormat is set to PARQUET.
object_metadata: Option<ObjectMetadata>Optional. ObjectMetadata is used to create Object Tables. Object Tables contain a listing of objects (with their metadata) found at the source_uris. If ObjectMetadata is set, source_format should be omitted.
Currently SIMPLE is the only supported Object Metadata type.
reference_file_schema_uri: Option<StringValue>Optional. When creating an external table, the user can provide a reference file with the table schema. This is enabled for the following formats: AVRO, PARQUET, ORC.
metadata_cache_mode: MetadataCacheModeOptional. Metadata Cache Mode for the table. Set this to enable caching of metadata from external data source.
time_zone: Option<String>Optional. Time zone used when parsing timestamp values that do not have specific time zone information (e.g. 2024-04-20 12:34:56). The expected format is a IANA timezone string (e.g. America/Los_Angeles).
date_format: Option<String>Optional. Format used to parse DATE values. Supports C-style and SQL-style values.
datetime_format: Option<String>Optional. Format used to parse DATETIME values. Supports C-style and SQL-style values.
time_format: Option<String>Optional. Format used to parse TIME values. Supports C-style and SQL-style values.
timestamp_format: Option<String>Optional. Format used to parse TIMESTAMP values. Supports C-style and SQL-style values.
timestamp_target_precision: Vec<i32>Precisions (maximum number of total digits in base 10) for seconds of TIMESTAMP types that are allowed to the destination table for autodetection mode.
Available for the formats: CSV, PARQUET, AVRO, and Iceberg External Table.
Possible values include: Not Specified, [], or [6]: timestamp(6) for all auto detected TIMESTAMP columns [6, 12]: timestamp(6) for all auto detected TIMESTAMP columns that have less than 6 digits of subseconds. timestamp(12) for all auto detected TIMESTAMP columns that have more than 6 digits of subseconds. [12]: timestamp(12) for all auto detected TIMESTAMP columns.
The order of the elements in this array is ignored. Inputs that have higher precision than the highest target precision in this array will be truncated.
Implementations
Sourceimpl ExternalDataConfiguration
impl ExternalDataConfiguration
Sourcepub fn set_source_uris<T, V>(self, v: T) -> Self
pub fn set_source_uris<T, V>(self, v: T) -> Self
Sets the value of source_uris.
Example
let x = ExternalDataConfiguration::new().set_source_uris(["a", "b", "c"]);Sourcepub fn set_file_set_spec_type<T: Into<FileSetSpecType>>(self, v: T) -> Self
pub fn set_file_set_spec_type<T: Into<FileSetSpecType>>(self, v: T) -> Self
Sets the value of file_set_spec_type.
Example
use google_cloud_bigquery_v2::model::FileSetSpecType;
let x0 = ExternalDataConfiguration::new().set_file_set_spec_type(FileSetSpecType::NewLineDelimitedManifest);Sourcepub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
pub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_source_format<T: Into<String>>(self, v: T) -> Self
pub fn set_source_format<T: Into<String>>(self, v: T) -> Self
Sets the value of source_format.
Example
let x = ExternalDataConfiguration::new().set_source_format("example");Sourcepub fn set_max_bad_records<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
pub fn set_max_bad_records<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
Sets the value of max_bad_records.
Example
use wkt::Int32Value;
let x = ExternalDataConfiguration::new().set_max_bad_records(Int32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_bad_records<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
pub fn set_or_clear_max_bad_records<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
Sets or clears the value of max_bad_records.
Example
use wkt::Int32Value;
let x = ExternalDataConfiguration::new().set_or_clear_max_bad_records(Some(Int32Value::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_max_bad_records(None::<Int32Value>);Sourcepub fn set_autodetect<T>(self, v: T) -> Self
pub fn set_autodetect<T>(self, v: T) -> Self
Sets the value of autodetect.
Example
use wkt::BoolValue;
let x = ExternalDataConfiguration::new().set_autodetect(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_autodetect<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_autodetect<T>(self, v: Option<T>) -> Self
Sets or clears the value of autodetect.
Example
use wkt::BoolValue;
let x = ExternalDataConfiguration::new().set_or_clear_autodetect(Some(BoolValue::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_autodetect(None::<BoolValue>);Sourcepub fn set_ignore_unknown_values<T>(self, v: T) -> Self
pub fn set_ignore_unknown_values<T>(self, v: T) -> Self
Sets the value of ignore_unknown_values.
Example
use wkt::BoolValue;
let x = ExternalDataConfiguration::new().set_ignore_unknown_values(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_ignore_unknown_values<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ignore_unknown_values<T>(self, v: Option<T>) -> Self
Sets or clears the value of ignore_unknown_values.
Example
use wkt::BoolValue;
let x = ExternalDataConfiguration::new().set_or_clear_ignore_unknown_values(Some(BoolValue::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_ignore_unknown_values(None::<BoolValue>);Sourcepub fn set_compression<T: Into<String>>(self, v: T) -> Self
pub fn set_compression<T: Into<String>>(self, v: T) -> Self
Sets the value of compression.
Example
let x = ExternalDataConfiguration::new().set_compression("example");Sourcepub fn set_csv_options<T>(self, v: T) -> Selfwhere
T: Into<CsvOptions>,
pub fn set_csv_options<T>(self, v: T) -> Selfwhere
T: Into<CsvOptions>,
Sets the value of csv_options.
Example
use google_cloud_bigquery_v2::model::CsvOptions;
let x = ExternalDataConfiguration::new().set_csv_options(CsvOptions::default()/* use setters */);Sourcepub fn set_or_clear_csv_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<CsvOptions>,
pub fn set_or_clear_csv_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<CsvOptions>,
Sets or clears the value of csv_options.
Example
use google_cloud_bigquery_v2::model::CsvOptions;
let x = ExternalDataConfiguration::new().set_or_clear_csv_options(Some(CsvOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_csv_options(None::<CsvOptions>);Sourcepub fn set_json_options<T>(self, v: T) -> Selfwhere
T: Into<JsonOptions>,
pub fn set_json_options<T>(self, v: T) -> Selfwhere
T: Into<JsonOptions>,
Sets the value of json_options.
Example
use google_cloud_bigquery_v2::model::JsonOptions;
let x = ExternalDataConfiguration::new().set_json_options(JsonOptions::default()/* use setters */);Sourcepub fn set_or_clear_json_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<JsonOptions>,
pub fn set_or_clear_json_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<JsonOptions>,
Sets or clears the value of json_options.
Example
use google_cloud_bigquery_v2::model::JsonOptions;
let x = ExternalDataConfiguration::new().set_or_clear_json_options(Some(JsonOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_json_options(None::<JsonOptions>);Sourcepub fn set_bigtable_options<T>(self, v: T) -> Selfwhere
T: Into<BigtableOptions>,
pub fn set_bigtable_options<T>(self, v: T) -> Selfwhere
T: Into<BigtableOptions>,
Sets the value of bigtable_options.
Example
use google_cloud_bigquery_v2::model::BigtableOptions;
let x = ExternalDataConfiguration::new().set_bigtable_options(BigtableOptions::default()/* use setters */);Sourcepub fn set_or_clear_bigtable_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigtableOptions>,
pub fn set_or_clear_bigtable_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigtableOptions>,
Sets or clears the value of bigtable_options.
Example
use google_cloud_bigquery_v2::model::BigtableOptions;
let x = ExternalDataConfiguration::new().set_or_clear_bigtable_options(Some(BigtableOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_bigtable_options(None::<BigtableOptions>);Sourcepub fn set_google_sheets_options<T>(self, v: T) -> Selfwhere
T: Into<GoogleSheetsOptions>,
pub fn set_google_sheets_options<T>(self, v: T) -> Selfwhere
T: Into<GoogleSheetsOptions>,
Sets the value of google_sheets_options.
Example
use google_cloud_bigquery_v2::model::GoogleSheetsOptions;
let x = ExternalDataConfiguration::new().set_google_sheets_options(GoogleSheetsOptions::default()/* use setters */);Sourcepub fn set_or_clear_google_sheets_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<GoogleSheetsOptions>,
pub fn set_or_clear_google_sheets_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<GoogleSheetsOptions>,
Sets or clears the value of google_sheets_options.
Example
use google_cloud_bigquery_v2::model::GoogleSheetsOptions;
let x = ExternalDataConfiguration::new().set_or_clear_google_sheets_options(Some(GoogleSheetsOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_google_sheets_options(None::<GoogleSheetsOptions>);Sourcepub fn set_hive_partitioning_options<T>(self, v: T) -> Selfwhere
T: Into<HivePartitioningOptions>,
pub fn set_hive_partitioning_options<T>(self, v: T) -> Selfwhere
T: Into<HivePartitioningOptions>,
Sets the value of hive_partitioning_options.
Example
use google_cloud_bigquery_v2::model::HivePartitioningOptions;
let x = ExternalDataConfiguration::new().set_hive_partitioning_options(HivePartitioningOptions::default()/* use setters */);Sourcepub fn set_or_clear_hive_partitioning_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<HivePartitioningOptions>,
pub fn set_or_clear_hive_partitioning_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<HivePartitioningOptions>,
Sets or clears the value of hive_partitioning_options.
Example
use google_cloud_bigquery_v2::model::HivePartitioningOptions;
let x = ExternalDataConfiguration::new().set_or_clear_hive_partitioning_options(Some(HivePartitioningOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_hive_partitioning_options(None::<HivePartitioningOptions>);Sourcepub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
pub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
Sets the value of connection_id.
Example
let x = ExternalDataConfiguration::new().set_connection_id("example");Sourcepub fn set_decimal_target_types<T, V>(self, v: T) -> Self
pub fn set_decimal_target_types<T, V>(self, v: T) -> Self
Sets the value of decimal_target_types.
Example
use google_cloud_bigquery_v2::model::DecimalTargetType;
let x = ExternalDataConfiguration::new().set_decimal_target_types([
DecimalTargetType::Numeric,
DecimalTargetType::Bignumeric,
DecimalTargetType::String,
]);Sourcepub fn set_avro_options<T>(self, v: T) -> Selfwhere
T: Into<AvroOptions>,
pub fn set_avro_options<T>(self, v: T) -> Selfwhere
T: Into<AvroOptions>,
Sets the value of avro_options.
Example
use google_cloud_bigquery_v2::model::AvroOptions;
let x = ExternalDataConfiguration::new().set_avro_options(AvroOptions::default()/* use setters */);Sourcepub fn set_or_clear_avro_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<AvroOptions>,
pub fn set_or_clear_avro_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<AvroOptions>,
Sets or clears the value of avro_options.
Example
use google_cloud_bigquery_v2::model::AvroOptions;
let x = ExternalDataConfiguration::new().set_or_clear_avro_options(Some(AvroOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_avro_options(None::<AvroOptions>);Sourcepub fn set_json_extension<T: Into<JsonExtension>>(self, v: T) -> Self
pub fn set_json_extension<T: Into<JsonExtension>>(self, v: T) -> Self
Sets the value of json_extension.
Example
use google_cloud_bigquery_v2::model::JsonExtension;
let x0 = ExternalDataConfiguration::new().set_json_extension(JsonExtension::Geojson);Sourcepub fn set_parquet_options<T>(self, v: T) -> Selfwhere
T: Into<ParquetOptions>,
pub fn set_parquet_options<T>(self, v: T) -> Selfwhere
T: Into<ParquetOptions>,
Sets the value of parquet_options.
Example
use google_cloud_bigquery_v2::model::ParquetOptions;
let x = ExternalDataConfiguration::new().set_parquet_options(ParquetOptions::default()/* use setters */);Sourcepub fn set_or_clear_parquet_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<ParquetOptions>,
pub fn set_or_clear_parquet_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<ParquetOptions>,
Sets or clears the value of parquet_options.
Example
use google_cloud_bigquery_v2::model::ParquetOptions;
let x = ExternalDataConfiguration::new().set_or_clear_parquet_options(Some(ParquetOptions::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_parquet_options(None::<ParquetOptions>);Sourcepub fn set_object_metadata<T>(self, v: T) -> Selfwhere
T: Into<ObjectMetadata>,
pub fn set_object_metadata<T>(self, v: T) -> Selfwhere
T: Into<ObjectMetadata>,
Sets the value of object_metadata.
Example
use google_cloud_bigquery_v2::model::external_data_configuration::ObjectMetadata;
let x0 = ExternalDataConfiguration::new().set_object_metadata(ObjectMetadata::Directory);
let x1 = ExternalDataConfiguration::new().set_object_metadata(ObjectMetadata::Simple);Sourcepub fn set_or_clear_object_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ObjectMetadata>,
pub fn set_or_clear_object_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ObjectMetadata>,
Sets or clears the value of object_metadata.
Example
use google_cloud_bigquery_v2::model::external_data_configuration::ObjectMetadata;
let x0 = ExternalDataConfiguration::new().set_or_clear_object_metadata(Some(ObjectMetadata::Directory));
let x1 = ExternalDataConfiguration::new().set_or_clear_object_metadata(Some(ObjectMetadata::Simple));
let x_none = ExternalDataConfiguration::new().set_or_clear_object_metadata(None::<ObjectMetadata>);Sourcepub fn set_reference_file_schema_uri<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_reference_file_schema_uri<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of reference_file_schema_uri.
Example
use wkt::StringValue;
let x = ExternalDataConfiguration::new().set_reference_file_schema_uri(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_reference_file_schema_uri<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_reference_file_schema_uri<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of reference_file_schema_uri.
Example
use wkt::StringValue;
let x = ExternalDataConfiguration::new().set_or_clear_reference_file_schema_uri(Some(StringValue::default()/* use setters */));
let x = ExternalDataConfiguration::new().set_or_clear_reference_file_schema_uri(None::<StringValue>);Sourcepub fn set_metadata_cache_mode<T: Into<MetadataCacheMode>>(self, v: T) -> Self
pub fn set_metadata_cache_mode<T: Into<MetadataCacheMode>>(self, v: T) -> Self
Sets the value of metadata_cache_mode.
Example
use google_cloud_bigquery_v2::model::external_data_configuration::MetadataCacheMode;
let x0 = ExternalDataConfiguration::new().set_metadata_cache_mode(MetadataCacheMode::Automatic);
let x1 = ExternalDataConfiguration::new().set_metadata_cache_mode(MetadataCacheMode::Manual);Sourcepub fn set_time_zone<T>(self, v: T) -> Self
pub fn set_time_zone<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_time_zone<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_zone<T>(self, v: Option<T>) -> Self
Sourcepub fn set_date_format<T>(self, v: T) -> Self
pub fn set_date_format<T>(self, v: T) -> Self
Sets the value of date_format.
Example
let x = ExternalDataConfiguration::new().set_date_format("example");Sourcepub fn set_or_clear_date_format<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_date_format<T>(self, v: Option<T>) -> Self
Sets or clears the value of date_format.
Example
let x = ExternalDataConfiguration::new().set_or_clear_date_format(Some("example"));
let x = ExternalDataConfiguration::new().set_or_clear_date_format(None::<String>);Sourcepub fn set_datetime_format<T>(self, v: T) -> Self
pub fn set_datetime_format<T>(self, v: T) -> Self
Sets the value of datetime_format.
Example
let x = ExternalDataConfiguration::new().set_datetime_format("example");Sourcepub fn set_or_clear_datetime_format<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_datetime_format<T>(self, v: Option<T>) -> Self
Sets or clears the value of datetime_format.
Example
let x = ExternalDataConfiguration::new().set_or_clear_datetime_format(Some("example"));
let x = ExternalDataConfiguration::new().set_or_clear_datetime_format(None::<String>);Sourcepub fn set_time_format<T>(self, v: T) -> Self
pub fn set_time_format<T>(self, v: T) -> Self
Sets the value of time_format.
Example
let x = ExternalDataConfiguration::new().set_time_format("example");Sourcepub fn set_or_clear_time_format<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_format<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_format.
Example
let x = ExternalDataConfiguration::new().set_or_clear_time_format(Some("example"));
let x = ExternalDataConfiguration::new().set_or_clear_time_format(None::<String>);Sourcepub fn set_timestamp_format<T>(self, v: T) -> Self
pub fn set_timestamp_format<T>(self, v: T) -> Self
Sets the value of timestamp_format.
Example
let x = ExternalDataConfiguration::new().set_timestamp_format("example");Sourcepub fn set_or_clear_timestamp_format<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_timestamp_format<T>(self, v: Option<T>) -> Self
Sets or clears the value of timestamp_format.
Example
let x = ExternalDataConfiguration::new().set_or_clear_timestamp_format(Some("example"));
let x = ExternalDataConfiguration::new().set_or_clear_timestamp_format(None::<String>);Sourcepub fn set_timestamp_target_precision<T, V>(self, v: T) -> Self
pub fn set_timestamp_target_precision<T, V>(self, v: T) -> Self
Sets the value of timestamp_target_precision.
Example
let x = ExternalDataConfiguration::new().set_timestamp_target_precision([1, 2, 3]);Trait Implementations
Sourceimpl Clone for ExternalDataConfiguration
impl Clone for ExternalDataConfiguration
Sourcefn clone(&self) -> ExternalDataConfiguration
fn clone(&self) -> ExternalDataConfiguration
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExternalDataConfiguration
impl Debug for ExternalDataConfiguration
Sourceimpl Default for ExternalDataConfiguration
impl Default for ExternalDataConfiguration
Sourcefn default() -> ExternalDataConfiguration
fn default() -> ExternalDataConfiguration
Sourceimpl Message for ExternalDataConfiguration
impl Message for ExternalDataConfiguration
impl StructuralPartialEq for ExternalDataConfiguration