#[non_exhaustive]pub struct ExternalDatasetReference {
pub external_source: String,
pub connection: String,
/* private fields */
}Expand description
Configures the access a dataset defined in an external metadata storage.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.external_source: StringRequired. External source that backs this dataset.
connection: StringRequired. The connection id that is used to access the external_source.
Format: projects/{project_id}/locations/{location_id}/connections/{connection_id}
Implementations
Sourceimpl ExternalDatasetReference
impl ExternalDatasetReference
Sourcepub fn set_external_source<T: Into<String>>(self, v: T) -> Self
pub fn set_external_source<T: Into<String>>(self, v: T) -> Self
Sets the value of external_source.
Example
ⓘ
let x = ExternalDatasetReference::new().set_external_source("example");Sourcepub fn set_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_connection<T: Into<String>>(self, v: T) -> Self
Sets the value of connection.
Example
ⓘ
let x = ExternalDatasetReference::new().set_connection("example");Trait Implementations
Sourceimpl Clone for ExternalDatasetReference
impl Clone for ExternalDatasetReference
Sourcefn clone(&self) -> ExternalDatasetReference
fn clone(&self) -> ExternalDatasetReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalDatasetReference
impl Debug for ExternalDatasetReference
Sourceimpl Default for ExternalDatasetReference
impl Default for ExternalDatasetReference
Sourcefn default() -> ExternalDatasetReference
fn default() -> ExternalDatasetReference
Returns the “default value” for a type. Read more
Sourceimpl Message for ExternalDatasetReference
impl Message for ExternalDatasetReference
Sourceimpl PartialEq for ExternalDatasetReference
impl PartialEq for ExternalDatasetReference
impl StructuralPartialEq for ExternalDatasetReference