#[non_exhaustive]pub struct ForeignKey {
pub name: String,
pub referenced_table: Option<TableReference>,
pub column_references: Vec<ColumnReference>,
/* private fields */
}Expand description
Represents a foreign key constraint on a table’s columns.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOptional. Set only if the foreign key constraint is named.
referenced_table: Option<TableReference>Required. The table that holds the primary key and is referenced by this foreign key.
column_references: Vec<ColumnReference>Required. The columns that compose the foreign key.
Implementations
Sourceimpl ForeignKey
impl ForeignKey
Sourcepub fn set_referenced_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_referenced_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of referenced_table.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = ForeignKey::new().set_referenced_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_referenced_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_referenced_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of referenced_table.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = ForeignKey::new().set_or_clear_referenced_table(Some(TableReference::default()/* use setters */));
let x = ForeignKey::new().set_or_clear_referenced_table(None::<TableReference>);Sourcepub fn set_column_references<T, V>(self, v: T) -> Self
pub fn set_column_references<T, V>(self, v: T) -> Self
Sets the value of column_references.
Example
ⓘ
use google_cloud_bigquery_v2::model::ColumnReference;
let x = ForeignKey::new()
.set_column_references([
ColumnReference::default()/* use setters */,
ColumnReference::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ForeignKey
impl Clone for ForeignKey
Sourcefn clone(&self) -> ForeignKey
fn clone(&self) -> ForeignKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForeignKey
impl Debug for ForeignKey
Sourceimpl Default for ForeignKey
impl Default for ForeignKey
Sourcefn default() -> ForeignKey
fn default() -> ForeignKey
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ForeignKey
impl PartialEq for ForeignKey
impl StructuralPartialEq for ForeignKey