#[non_exhaustive]pub struct GcpTag {
pub tag_key: String,
pub tag_value: String,
/* private fields */
}Expand description
A global tag managed by Resource Manager. https://cloud.google.com/iam/docs/tags-access-control#definitions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tag_key: StringRequired. The namespaced friendly name of the tag key, e.g. “12345/environment” where 12345 is org id.
tag_value: StringRequired. The friendly short name of the tag value, e.g. “production”.
Implementations