#[non_exhaustive]pub struct GenAiErrorStats {
pub errors: Vec<String>,
/* private fields */
}Expand description
Provides error statistics for the query job across all AI function calls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.errors: Vec<String>A list of unique errors at query level (up to 5, truncated to 100 chars)
Implementations
Sourceimpl GenAiErrorStats
impl GenAiErrorStats
Sourcepub fn set_errors<T, V>(self, v: T) -> Self
pub fn set_errors<T, V>(self, v: T) -> Self