GenAiFunctionStats

Struct GenAiFunctionStats 

#[non_exhaustive]
pub struct GenAiFunctionStats { pub function_name: Option<String>, pub prompt: Option<String>, pub num_processed_rows: Option<i64>, pub error_stats: Option<GenAiFunctionErrorStats>, pub cost_optimization_stats: Option<GenAiFunctionCostOptimizationStats>, pub cache_stats: Option<GenAiFunctionCacheStats>, /* private fields */ }
Provides statistics for each Ai function call within a query.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
function_name: Option<String>

Name of the function.

prompt: Option<String>

User input prompt of the function (truncated to 20 chars).

num_processed_rows: Option<i64>

Number of rows processed by this GenAi function. This includes all cost_optimized, llm_inferred and failed_rows.

error_stats: Option<GenAiFunctionErrorStats>

Error stats for the function.

cost_optimization_stats: Option<GenAiFunctionCostOptimizationStats>

Cost optimization stats if applied on the rows processed by the function.

cache_stats: Option<GenAiFunctionCacheStats>

Cache stats for the function.

Implementations

Source

impl GenAiFunctionStats

pub fn new() -> Self

Creates a new default instance.

pub fn set_function_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of function_name.

Example
let x = GenAiFunctionStats::new().set_function_name("example");
pub fn set_or_clear_function_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of function_name.

Example
let x = GenAiFunctionStats::new().set_or_clear_function_name(Some("example"));
let x = GenAiFunctionStats::new().set_or_clear_function_name(None::<String>);
pub fn set_prompt<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of prompt.

Example
let x = GenAiFunctionStats::new().set_prompt("example");
pub fn set_or_clear_prompt<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of prompt.

Example
let x = GenAiFunctionStats::new().set_or_clear_prompt(Some("example"));
let x = GenAiFunctionStats::new().set_or_clear_prompt(None::<String>);
pub fn set_num_processed_rows<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of num_processed_rows.

Example
let x = GenAiFunctionStats::new().set_num_processed_rows(42);
pub fn set_or_clear_num_processed_rows<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of num_processed_rows.

Example
let x = GenAiFunctionStats::new().set_or_clear_num_processed_rows(Some(42));
let x = GenAiFunctionStats::new().set_or_clear_num_processed_rows(None::<i32>);
pub fn set_error_stats<T>(self, v: T) -> Self

Sets the value of error_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionErrorStats;
let x = GenAiFunctionStats::new().set_error_stats(GenAiFunctionErrorStats::default()/* use setters */);
pub fn set_or_clear_error_stats<T>(self, v: Option<T>) -> Self

Sets or clears the value of error_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionErrorStats;
let x = GenAiFunctionStats::new().set_or_clear_error_stats(Some(GenAiFunctionErrorStats::default()/* use setters */));
let x = GenAiFunctionStats::new().set_or_clear_error_stats(None::<GenAiFunctionErrorStats>);
pub fn set_cost_optimization_stats<T>(self, v: T) -> Self

Sets the value of cost_optimization_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionCostOptimizationStats;
let x = GenAiFunctionStats::new().set_cost_optimization_stats(GenAiFunctionCostOptimizationStats::default()/* use setters */);
pub fn set_or_clear_cost_optimization_stats<T>(self, v: Option<T>) -> Self

Sets or clears the value of cost_optimization_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionCostOptimizationStats;
let x = GenAiFunctionStats::new().set_or_clear_cost_optimization_stats(Some(GenAiFunctionCostOptimizationStats::default()/* use setters */));
let x = GenAiFunctionStats::new().set_or_clear_cost_optimization_stats(None::<GenAiFunctionCostOptimizationStats>);
pub fn set_cache_stats<T>(self, v: T) -> Self

Sets the value of cache_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionCacheStats;
let x = GenAiFunctionStats::new().set_cache_stats(GenAiFunctionCacheStats::default()/* use setters */);
pub fn set_or_clear_cache_stats<T>(self, v: Option<T>) -> Self

Sets or clears the value of cache_stats.

Example
use google_cloud_bigquery_v2::model::GenAiFunctionCacheStats;
let x = GenAiFunctionStats::new().set_or_clear_cache_stats(Some(GenAiFunctionCacheStats::default()/* use setters */));
let x = GenAiFunctionStats::new().set_or_clear_cache_stats(None::<GenAiFunctionCacheStats>);