#[non_exhaustive]pub struct GetJobRequest {
pub project_id: String,
pub job_id: String,
pub location: String,
/* private fields */
}Expand description
Describes format of a jobs get request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the requested job.
job_id: StringRequired. Job ID of the requested job.
location: StringThe geographic location of the job. You must specify the location to run the job for the following scenarios:
- If the location to run a job is not in the
usor theeumulti-regional location - If the job’s location is in a single region (for example,
us-central1)
For more information, see how to specify locations.
Implementations
Sourceimpl GetJobRequest
impl GetJobRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_job_id<T: Into<String>>(self, v: T) -> Self