#[non_exhaustive]pub struct GetRowAccessPolicyRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub policy_id: String,
/* private fields */
}Expand description
Request message for the GetRowAccessPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the table to get the row access policy.
dataset_id: StringRequired. Dataset ID of the table to get the row access policy.
table_id: StringRequired. Table ID of the table to get the row access policy.
policy_id: StringRequired. Policy ID of the row access policy.
Implementations
Sourceimpl GetRowAccessPolicyRequest
impl GetRowAccessPolicyRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = GetRowAccessPolicyRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = GetRowAccessPolicyRequest::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self