#[non_exhaustive]pub struct GetTableRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub selected_fields: String,
pub view: TableMetadataView,
/* private fields */
}Expand description
Request format for getting table metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the requested table
dataset_id: StringRequired. Dataset ID of the requested table
table_id: StringRequired. Table ID of the requested table
selected_fields: StringList of table schema fields to return (comma-separated). If unspecified, all fields are returned. A fieldMask cannot be used here because the fields will automatically be converted from camelCase to snake_case and the conversion will fail if there are underscores. Since these are fields in BigQuery table schemas, underscores are allowed.
view: TableMetadataViewOptional. Specifies the view that determines which table information is returned. By default, basic table information and storage statistics (STORAGE_STATS) are returned.
Implementations
Sourceimpl GetTableRequest
impl GetTableRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_selected_fields<T: Into<String>>(self, v: T) -> Self
pub fn set_selected_fields<T: Into<String>>(self, v: T) -> Self
Sets the value of selected_fields.
Example
ⓘ
let x = GetTableRequest::new().set_selected_fields("example");Sourcepub fn set_view<T: Into<TableMetadataView>>(self, v: T) -> Self
pub fn set_view<T: Into<TableMetadataView>>(self, v: T) -> Self
Sets the value of view.
Example
ⓘ
use google_cloud_bigquery_v2::model::get_table_request::TableMetadataView;
let x0 = GetTableRequest::new().set_view(TableMetadataView::Basic);
let x1 = GetTableRequest::new().set_view(TableMetadataView::StorageStats);
let x2 = GetTableRequest::new().set_view(TableMetadataView::Full);Trait Implementations
Sourceimpl Clone for GetTableRequest
impl Clone for GetTableRequest
Sourcefn clone(&self) -> GetTableRequest
fn clone(&self) -> GetTableRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetTableRequest
impl Debug for GetTableRequest
Sourceimpl Default for GetTableRequest
impl Default for GetTableRequest
Sourcefn default() -> GetTableRequest
fn default() -> GetTableRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for GetTableRequest
impl Message for GetTableRequest
Sourceimpl PartialEq for GetTableRequest
impl PartialEq for GetTableRequest
impl StructuralPartialEq for GetTableRequest