IncrementalResultStats

Struct IncrementalResultStats 

#[non_exhaustive]
pub struct IncrementalResultStats { pub disabled_reason: DisabledReason, pub disabled_reason_details: String, pub result_set_last_replace_time: Option<Timestamp>, pub result_set_last_modify_time: Option<Timestamp>, pub first_incremental_row_time: Option<Timestamp>, pub last_incremental_row_time: Option<Timestamp>, pub incremental_row_count: Option<i64>, /* private fields */ }
Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
disabled_reason: DisabledReason

Output only. Reason why incremental query results are/were not written by the query.

disabled_reason_details: String

Output only. Additional human-readable clarification, if available, for DisabledReason.

result_set_last_replace_time: Option<Timestamp>

Output only. The time at which the result table’s contents were completely replaced. May be absent if no results have been written or the query has completed.

result_set_last_modify_time: Option<Timestamp>

Output only. The time at which the result table’s contents were modified. May be absent if no results have been written or the query has completed.

first_incremental_row_time: Option<Timestamp>

Output only. The time at which the first incremental result was written. If the query needed to restart internally, this only describes the final attempt.

last_incremental_row_time: Option<Timestamp>

Output only. The time at which the last incremental result was written. Does not include the final result written after query completion.

incremental_row_count: Option<i64>

Output only. Number of rows that were in the latest result set before query completion.

Implementations

Source

impl IncrementalResultStats

pub fn new() -> Self

Creates a new default instance.

pub fn set_disabled_reason<T: Into<DisabledReason>>(self, v: T) -> Self

Sets the value of disabled_reason.

Example
use google_cloud_bigquery_v2::model::incremental_result_stats::DisabledReason;
let x0 = IncrementalResultStats::new().set_disabled_reason(DisabledReason::Other);
let x1 = IncrementalResultStats::new().set_disabled_reason(DisabledReason::UnsupportedOperator);
pub fn set_disabled_reason_details<T: Into<String>>(self, v: T) -> Self

Sets the value of disabled_reason_details.

Example
let x = IncrementalResultStats::new().set_disabled_reason_details("example");
pub fn set_result_set_last_replace_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of result_set_last_replace_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_result_set_last_replace_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_result_set_last_replace_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of result_set_last_replace_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_result_set_last_replace_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_result_set_last_replace_time(None::<Timestamp>);
pub fn set_result_set_last_modify_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of result_set_last_modify_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_result_set_last_modify_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_result_set_last_modify_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of result_set_last_modify_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_result_set_last_modify_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_result_set_last_modify_time(None::<Timestamp>);
pub fn set_first_incremental_row_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of first_incremental_row_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_first_incremental_row_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_first_incremental_row_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of first_incremental_row_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_first_incremental_row_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_first_incremental_row_time(None::<Timestamp>);
pub fn set_last_incremental_row_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of last_incremental_row_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_last_incremental_row_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_last_incremental_row_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of last_incremental_row_time.

Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_last_incremental_row_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_last_incremental_row_time(None::<Timestamp>);
pub fn set_incremental_row_count<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of incremental_row_count.

Example
let x = IncrementalResultStats::new().set_incremental_row_count(42);
pub fn set_or_clear_incremental_row_count<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of incremental_row_count.

Example
let x = IncrementalResultStats::new().set_or_clear_incremental_row_count(Some(42));
let x = IncrementalResultStats::new().set_or_clear_incremental_row_count(None::<i32>);