#[non_exhaustive]pub struct IndexUnusedReason {
pub code: Option<Code>,
pub message: Option<String>,
pub base_table: Option<TableReference>,
pub index_name: Option<String>,
/* private fields */
}Expand description
Reason about why no search index was used in the search query (or sub-query).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: Option<Code>Specifies the high-level reason for the scenario when no search index was used.
message: Option<String>Free form human-readable reason for the scenario when no search index was used.
base_table: Option<TableReference>Specifies the base table involved in the reason that no search index was used.
index_name: Option<String>Specifies the name of the unused search index, if available.
Implementations
Sourceimpl IndexUnusedReason
impl IndexUnusedReason
Sourcepub fn set_code<T>(self, v: T) -> Self
pub fn set_code<T>(self, v: T) -> Self
Sets the value of code.
Example
ⓘ
use google_cloud_bigquery_v2::model::index_unused_reason::Code;
let x0 = IndexUnusedReason::new().set_code(Code::IndexConfigNotAvailable);
let x1 = IndexUnusedReason::new().set_code(Code::PendingIndexCreation);
let x2 = IndexUnusedReason::new().set_code(Code::BaseTableTruncated);Sourcepub fn set_or_clear_code<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_code<T>(self, v: Option<T>) -> Self
Sets or clears the value of code.
Example
ⓘ
use google_cloud_bigquery_v2::model::index_unused_reason::Code;
let x0 = IndexUnusedReason::new().set_or_clear_code(Some(Code::IndexConfigNotAvailable));
let x1 = IndexUnusedReason::new().set_or_clear_code(Some(Code::PendingIndexCreation));
let x2 = IndexUnusedReason::new().set_or_clear_code(Some(Code::BaseTableTruncated));
let x_none = IndexUnusedReason::new().set_or_clear_code(None::<Code>);Sourcepub fn set_message<T>(self, v: T) -> Self
pub fn set_message<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_message<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_message<T>(self, v: Option<T>) -> Self
Sourcepub fn set_base_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_base_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of base_table.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = IndexUnusedReason::new().set_base_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_base_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_base_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of base_table.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = IndexUnusedReason::new().set_or_clear_base_table(Some(TableReference::default()/* use setters */));
let x = IndexUnusedReason::new().set_or_clear_base_table(None::<TableReference>);Sourcepub fn set_index_name<T>(self, v: T) -> Self
pub fn set_index_name<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_index_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_index_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of index_name.
Example
ⓘ
let x = IndexUnusedReason::new().set_or_clear_index_name(Some("example"));
let x = IndexUnusedReason::new().set_or_clear_index_name(None::<String>);Trait Implementations
Sourceimpl Clone for IndexUnusedReason
impl Clone for IndexUnusedReason
Sourcefn clone(&self) -> IndexUnusedReason
fn clone(&self) -> IndexUnusedReason
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexUnusedReason
impl Debug for IndexUnusedReason
Sourceimpl Default for IndexUnusedReason
impl Default for IndexUnusedReason
Sourcefn default() -> IndexUnusedReason
fn default() -> IndexUnusedReason
Returns the “default value” for a type. Read more
Sourceimpl Message for IndexUnusedReason
impl Message for IndexUnusedReason
Sourceimpl PartialEq for IndexUnusedReason
impl PartialEq for IndexUnusedReason
impl StructuralPartialEq for IndexUnusedReason