#[non_exhaustive]pub struct Job {
pub kind: String,
pub etag: String,
pub id: String,
pub self_link: String,
pub user_email: String,
pub configuration: Option<JobConfiguration>,
pub job_reference: Option<JobReference>,
pub statistics: Option<JobStatistics>,
pub status: Option<JobStatus>,
pub principal_subject: String,
pub job_creation_reason: Option<JobCreationReason>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringOutput only. The type of the resource.
etag: StringOutput only. A hash of this resource.
id: StringOutput only. Opaque ID field of the job.
self_link: StringOutput only. A URL that can be used to access the resource again.
user_email: StringOutput only. Email address of the user who ran the job.
configuration: Option<JobConfiguration>Required. Describes the job configuration.
job_reference: Option<JobReference>Optional. Reference describing the unique-per-user name of the job.
statistics: Option<JobStatistics>Output only. Information about the job, including starting time and ending time of the job.
status: Option<JobStatus>Output only. The status of this job. Examine this value when polling an asynchronous job to see if the job is complete.
principal_subject: StringOutput only. [Full-projection-only] String representation of identity of requesting party. Populated for both first- and third-party identities. Only present for APIs that support third-party identities.
job_creation_reason: Option<JobCreationReason>Output only. The reason why a Job was created.
Implementations
Sourceimpl Job
impl Job
Sourcepub fn set_self_link<T: Into<String>>(self, v: T) -> Self
pub fn set_self_link<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_user_email<T: Into<String>>(self, v: T) -> Self
pub fn set_user_email<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
Sets the value of configuration.
Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = Job::new().set_configuration(JobConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
Sets or clears the value of configuration.
Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = Job::new().set_or_clear_configuration(Some(JobConfiguration::default()/* use setters */));
let x = Job::new().set_or_clear_configuration(None::<JobConfiguration>);Sourcepub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
pub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
Sets the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = Job::new().set_job_reference(JobReference::default()/* use setters */);Sourcepub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
pub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
Sets or clears the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = Job::new().set_or_clear_job_reference(Some(JobReference::default()/* use setters */));
let x = Job::new().set_or_clear_job_reference(None::<JobReference>);Sourcepub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
Sets the value of statistics.
Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = Job::new().set_statistics(JobStatistics::default()/* use setters */);Sourcepub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
Sets or clears the value of statistics.
Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = Job::new().set_or_clear_statistics(Some(JobStatistics::default()/* use setters */));
let x = Job::new().set_or_clear_statistics(None::<JobStatistics>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sourcepub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
pub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_creation_reason<T>(self, v: T) -> Selfwhere
T: Into<JobCreationReason>,
pub fn set_job_creation_reason<T>(self, v: T) -> Selfwhere
T: Into<JobCreationReason>,
Sets the value of job_creation_reason.
Example
use google_cloud_bigquery_v2::model::JobCreationReason;
let x = Job::new().set_job_creation_reason(JobCreationReason::default()/* use setters */);Sourcepub fn set_or_clear_job_creation_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobCreationReason>,
pub fn set_or_clear_job_creation_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobCreationReason>,
Sets or clears the value of job_creation_reason.
Example
use google_cloud_bigquery_v2::model::JobCreationReason;
let x = Job::new().set_or_clear_job_creation_reason(Some(JobCreationReason::default()/* use setters */));
let x = Job::new().set_or_clear_job_creation_reason(None::<JobCreationReason>);Trait Implementations
impl StructuralPartialEq for Job