JobConfigurationExtract

Struct JobConfigurationExtract 

#[non_exhaustive]
pub struct JobConfigurationExtract { pub destination_uris: Vec<String>, pub print_header: Option<BoolValue>, pub field_delimiter: String, pub destination_format: String, pub compression: String, pub use_avro_logical_types: Option<BoolValue>, pub model_extract_options: Option<ModelExtractOptions>, pub source: Option<Source>, /* private fields */ }
JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
destination_uris: Vec<String>

[Pick one] A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written.

print_header: Option<BoolValue>

Optional. Whether to print out a header row in the results. Default is true. Not applicable when extracting models.

field_delimiter: String

Optional. When extracting data in CSV format, this defines the delimiter to use between fields in the exported data. Default is ‘,’. Not applicable when extracting models.

destination_format: String

Optional. The exported file format. Possible values include CSV, NEWLINE_DELIMITED_JSON, PARQUET, or AVRO for tables and ML_TF_SAVED_MODEL or ML_XGBOOST_BOOSTER for models. The default value for tables is CSV. Tables with nested or repeated fields cannot be exported as CSV. The default value for models is ML_TF_SAVED_MODEL.

compression: String

Optional. The compression type to use for exported files. Possible values include DEFLATE, GZIP, NONE, SNAPPY, and ZSTD. The default value is NONE. Not all compression formats are support for all file formats. DEFLATE is only supported for Avro. ZSTD is only supported for Parquet. Not applicable when extracting models.

use_avro_logical_types: Option<BoolValue>

Whether to use logical types when extracting to AVRO format. Not applicable when extracting models.

model_extract_options: Option<ModelExtractOptions>

Optional. Model extract options only applicable when extracting models.

source: Option<Source>

Required. Source reference for the export.

Implementations

Source

impl JobConfigurationExtract

pub fn new() -> Self

Creates a new default instance.

pub fn set_destination_uris<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of destination_uris.

Example
let x = JobConfigurationExtract::new().set_destination_uris(["a", "b", "c"]);
pub fn set_print_header<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of print_header.

Example
use wkt::BoolValue;
let x = JobConfigurationExtract::new().set_print_header(BoolValue::default()/* use setters */);
pub fn set_or_clear_print_header<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of print_header.

Example
use wkt::BoolValue;
let x = JobConfigurationExtract::new().set_or_clear_print_header(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationExtract::new().set_or_clear_print_header(None::<BoolValue>);
pub fn set_field_delimiter<T: Into<String>>(self, v: T) -> Self

Sets the value of field_delimiter.

Example
let x = JobConfigurationExtract::new().set_field_delimiter("example");
pub fn set_destination_format<T: Into<String>>(self, v: T) -> Self

Sets the value of destination_format.

Example
let x = JobConfigurationExtract::new().set_destination_format("example");
pub fn set_compression<T: Into<String>>(self, v: T) -> Self

Sets the value of compression.

Example
let x = JobConfigurationExtract::new().set_compression("example");
pub fn set_use_avro_logical_types<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_avro_logical_types.

Example
use wkt::BoolValue;
let x = JobConfigurationExtract::new().set_use_avro_logical_types(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_avro_logical_types<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_avro_logical_types.

Example
use wkt::BoolValue;
let x = JobConfigurationExtract::new().set_or_clear_use_avro_logical_types(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationExtract::new().set_or_clear_use_avro_logical_types(None::<BoolValue>);
pub fn set_model_extract_options<T>(self, v: T) -> Self

Sets the value of model_extract_options.

Example
use google_cloud_bigquery_v2::model::job_configuration_extract::ModelExtractOptions;
let x = JobConfigurationExtract::new().set_model_extract_options(ModelExtractOptions::default()/* use setters */);
pub fn set_or_clear_model_extract_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of model_extract_options.

Example
use google_cloud_bigquery_v2::model::job_configuration_extract::ModelExtractOptions;
let x = JobConfigurationExtract::new().set_or_clear_model_extract_options(Some(ModelExtractOptions::default()/* use setters */));
let x = JobConfigurationExtract::new().set_or_clear_model_extract_options(None::<ModelExtractOptions>);
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self

Sets the value of source.

Note that all the setters affecting source are mutually exclusive.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationExtract::new().set_source(Some(
    google_cloud_bigquery_v2::model::job_configuration_extract::Source::SourceTable(TableReference::default().into())));
pub fn source_table(&self) -> Option<&Box<TableReference>>

The value of source if it holds a SourceTable, None if the field is not set or holds a different branch.

pub fn set_source_table<T: Into<Box<TableReference>>>(self, v: T) -> Self

Sets the value of source to hold a SourceTable.

Note that all the setters affecting source are mutually exclusive.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationExtract::new().set_source_table(TableReference::default()/* use setters */);
assert!(x.source_table().is_some());
assert!(x.source_model().is_none());
pub fn source_model(&self) -> Option<&Box<ModelReference>>

The value of source if it holds a SourceModel, None if the field is not set or holds a different branch.

pub fn set_source_model<T: Into<Box<ModelReference>>>(self, v: T) -> Self

Sets the value of source to hold a SourceModel.

Note that all the setters affecting source are mutually exclusive.

Example
use google_cloud_bigquery_v2::model::ModelReference;
let x = JobConfigurationExtract::new().set_source_model(ModelReference::default()/* use setters */);
assert!(x.source_model().is_some());
assert!(x.source_table().is_none());