JobConfigurationQuery

Struct JobConfigurationQuery 

#[non_exhaustive]
pub struct JobConfigurationQuery {
Show 26 fields pub query: String, pub destination_table: Option<TableReference>, pub external_table_definitions: HashMap<String, ExternalDataConfiguration>, pub user_defined_function_resources: Vec<UserDefinedFunctionResource>, pub create_disposition: String, pub write_disposition: String, pub default_dataset: Option<DatasetReference>, pub priority: String, pub allow_large_results: Option<BoolValue>, pub use_query_cache: Option<BoolValue>, pub flatten_results: Option<BoolValue>, pub maximum_bytes_billed: Option<Int64Value>, pub use_legacy_sql: Option<BoolValue>, pub parameter_mode: String, pub query_parameters: Vec<QueryParameter>, pub system_variables: Option<SystemVariables>, pub schema_update_options: Vec<String>, pub time_partitioning: Option<TimePartitioning>, pub range_partitioning: Option<RangePartitioning>, pub clustering: Option<Clustering>, pub destination_encryption_configuration: Option<EncryptionConfiguration>, pub script_options: Option<ScriptOptions>, pub connection_properties: Vec<ConnectionProperty>, pub create_session: Option<BoolValue>, pub continuous: Option<BoolValue>, pub write_incremental_results: bool, /* private fields */
}
JobConfigurationQuery configures a BigQuery query job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query: String

[Required] SQL query text to execute. The useLegacySql field can be used to indicate whether the query uses legacy SQL or GoogleSQL.

destination_table: Option<TableReference>

Optional. Describes the table where the query results should be stored. This property must be set for large results that exceed the maximum response size. For queries that produce anonymous (cached) results, this field will be populated by BigQuery.

external_table_definitions: HashMap<String, ExternalDataConfiguration>

Optional. You can specify external table definitions, which operate as ephemeral tables that can be queried. These definitions are configured using a JSON map, where the string key represents the table identifier, and the value is the corresponding external data configuration object.

user_defined_function_resources: Vec<UserDefinedFunctionResource>

Describes user-defined function resources used in the query.

create_disposition: String

Optional. Specifies whether the job is allowed to create new tables. The following values are supported:

  • CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
  • CREATE_NEVER: The table must already exist. If it does not, a ‘notFound’ error is returned in the job result.

The default value is CREATE_IF_NEEDED. Creation, truncation and append actions occur as one atomic update upon job completion.

write_disposition: String

Optional. Specifies the action that occurs if the destination table already exists. The following values are supported:

  • WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the data, removes the constraints, and uses the schema from the query result.
  • WRITE_TRUNCATE_DATA: If the table already exists, BigQuery overwrites the data, but keeps the constraints and schema of the existing table.
  • WRITE_APPEND: If the table already exists, BigQuery appends the data to the table.
  • WRITE_EMPTY: If the table already exists and contains data, a ‘duplicate’ error is returned in the job result.

The default value is WRITE_EMPTY. Each action is atomic and only occurs if BigQuery is able to complete the job successfully. Creation, truncation and append actions occur as one atomic update upon job completion.

default_dataset: Option<DatasetReference>

Optional. Specifies the default dataset to use for unqualified table names in the query. This setting does not alter behavior of unqualified dataset names. Setting the system variable @@dataset_id achieves the same behavior. See https://cloud.google.com/bigquery/docs/reference/system-variables for more information on system variables.

priority: String

Optional. Specifies a priority for the query. Possible values include INTERACTIVE and BATCH. The default value is INTERACTIVE.

allow_large_results: Option<BoolValue>

Optional. If true and query uses legacy SQL dialect, allows the query to produce arbitrarily large result tables at a slight cost in performance. Requires destinationTable to be set. For GoogleSQL queries, this flag is ignored and large results are always allowed. However, you must still set destinationTable when result size exceeds the allowed maximum response size.

use_query_cache: Option<BoolValue>

Optional. Whether to look for the result in the query cache. The query cache is a best-effort cache that will be flushed whenever tables in the query are modified. Moreover, the query cache is only available when a query does not have a destination table specified. The default value is true.

flatten_results: Option<BoolValue>

Optional. If true and query uses legacy SQL dialect, flattens all nested and repeated fields in the query results. allowLargeResults must be true if this is set to false. For GoogleSQL queries, this flag is ignored and results are never flattened.

maximum_bytes_billed: Option<Int64Value>

Limits the bytes billed for this job. Queries that will have bytes billed beyond this limit will fail (without incurring a charge). If unspecified, this will be set to your project default.

use_legacy_sql: Option<BoolValue>

Optional. Specifies whether to use BigQuery’s legacy SQL dialect for this query. The default value is true. If set to false, the query uses BigQuery’s GoogleSQL.

When useLegacySql is set to false, the value of flattenResults is ignored; query will be run as if flattenResults is false.

parameter_mode: String

GoogleSQL only. Set to POSITIONAL to use positional (?) query parameters or to NAMED to use named (@myparam) query parameters in this query.

query_parameters: Vec<QueryParameter>

Query parameters for GoogleSQL queries.

system_variables: Option<SystemVariables>

Output only. System variables for GoogleSQL queries. A system variable is output if the variable is settable and its value differs from the system default. “@@” prefix is not included in the name of the System variables.

schema_update_options: Vec<String>

Allows the schema of the destination table to be updated as a side effect of the query job. Schema update options are supported in three cases: when writeDisposition is WRITE_APPEND; when writeDisposition is WRITE_TRUNCATE_DATA; when writeDisposition is WRITE_TRUNCATE and the destination table is a partition of a table, specified by partition decorators. For normal tables, WRITE_TRUNCATE will always overwrite the schema. One or more of the following values are specified:

  • ALLOW_FIELD_ADDITION: allow adding a nullable field to the schema.
  • ALLOW_FIELD_RELAXATION: allow relaxing a required field in the original schema to nullable.
time_partitioning: Option<TimePartitioning>

Time-based partitioning specification for the destination table. Only one of timePartitioning and rangePartitioning should be specified.

range_partitioning: Option<RangePartitioning>

Range partitioning specification for the destination table. Only one of timePartitioning and rangePartitioning should be specified.

clustering: Option<Clustering>

Clustering specification for the destination table.

destination_encryption_configuration: Option<EncryptionConfiguration>

Custom encryption configuration (e.g., Cloud KMS keys)

script_options: Option<ScriptOptions>

Options controlling the execution of scripts.

connection_properties: Vec<ConnectionProperty>

Connection properties which can modify the query behavior.

create_session: Option<BoolValue>

If this property is true, the job creates a new session using a randomly generated session_id. To continue using a created session with subsequent queries, pass the existing session identifier as a ConnectionProperty value. The session identifier is returned as part of the SessionInfo message within the query statistics.

The new session’s location will be set to Job.JobReference.location if it is present, otherwise it’s set to the default location based on existing routing logic.

continuous: Option<BoolValue>

Optional. Whether to run the query as continuous or a regular query. Continuous query is currently in experimental stage and not ready for general usage.

write_incremental_results: bool

Optional. This is only supported for a SELECT query using a temporary table. If set, the query is allowed to write results incrementally to the temporary result table. This may incur a performance penalty. This option cannot be used with Legacy SQL. This feature is not yet available.

Implementations

Source

impl JobConfigurationQuery

pub fn new() -> Self

Creates a new default instance.

pub fn set_query<T: Into<String>>(self, v: T) -> Self

Sets the value of query.

Example
let x = JobConfigurationQuery::new().set_query("example");
pub fn set_destination_table<T>(self, v: T) -> Self
where T: Into<TableReference>,

Sets the value of destination_table.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationQuery::new().set_destination_table(TableReference::default()/* use setters */);
pub fn set_or_clear_destination_table<T>(self, v: Option<T>) -> Self
where T: Into<TableReference>,

Sets or clears the value of destination_table.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationQuery::new().set_or_clear_destination_table(Some(TableReference::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_destination_table(None::<TableReference>);
pub fn set_external_table_definitions<T, K, V>(self, v: T) -> Self

Sets the value of external_table_definitions.

Example
use google_cloud_bigquery_v2::model::ExternalDataConfiguration;
let x = JobConfigurationQuery::new().set_external_table_definitions([
    ("key0", ExternalDataConfiguration::default()/* use setters */),
    ("key1", ExternalDataConfiguration::default()/* use (different) setters */),
]);
pub fn set_user_defined_function_resources<T, V>(self, v: T) -> Self

Sets the value of user_defined_function_resources.

Example
use google_cloud_bigquery_v2::model::UserDefinedFunctionResource;
let x = JobConfigurationQuery::new()
    .set_user_defined_function_resources([
        UserDefinedFunctionResource::default()/* use setters */,
        UserDefinedFunctionResource::default()/* use (different) setters */,
    ]);
pub fn set_create_disposition<T: Into<String>>(self, v: T) -> Self

Sets the value of create_disposition.

Example
let x = JobConfigurationQuery::new().set_create_disposition("example");
pub fn set_write_disposition<T: Into<String>>(self, v: T) -> Self

Sets the value of write_disposition.

Example
let x = JobConfigurationQuery::new().set_write_disposition("example");
pub fn set_default_dataset<T>(self, v: T) -> Self

Sets the value of default_dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobConfigurationQuery::new().set_default_dataset(DatasetReference::default()/* use setters */);
pub fn set_or_clear_default_dataset<T>(self, v: Option<T>) -> Self

Sets or clears the value of default_dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobConfigurationQuery::new().set_or_clear_default_dataset(Some(DatasetReference::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_default_dataset(None::<DatasetReference>);
pub fn set_priority<T: Into<String>>(self, v: T) -> Self

Sets the value of priority.

Example
let x = JobConfigurationQuery::new().set_priority("example");
pub fn set_allow_large_results<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of allow_large_results.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_allow_large_results(BoolValue::default()/* use setters */);
pub fn set_or_clear_allow_large_results<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of allow_large_results.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_allow_large_results(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_allow_large_results(None::<BoolValue>);
pub fn set_use_query_cache<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_query_cache.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_use_query_cache(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_query_cache<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_query_cache.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_use_query_cache(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_use_query_cache(None::<BoolValue>);
pub fn set_flatten_results<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of flatten_results.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_flatten_results(BoolValue::default()/* use setters */);
pub fn set_or_clear_flatten_results<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of flatten_results.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_flatten_results(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_flatten_results(None::<BoolValue>);
pub fn set_maximum_bytes_billed<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of maximum_bytes_billed.

Example
use wkt::Int64Value;
let x = JobConfigurationQuery::new().set_maximum_bytes_billed(Int64Value::default()/* use setters */);
pub fn set_or_clear_maximum_bytes_billed<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of maximum_bytes_billed.

Example
use wkt::Int64Value;
let x = JobConfigurationQuery::new().set_or_clear_maximum_bytes_billed(Some(Int64Value::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_maximum_bytes_billed(None::<Int64Value>);
pub fn set_use_legacy_sql<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_use_legacy_sql(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_legacy_sql<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_use_legacy_sql(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_use_legacy_sql(None::<BoolValue>);
pub fn set_parameter_mode<T: Into<String>>(self, v: T) -> Self

Sets the value of parameter_mode.

Example
let x = JobConfigurationQuery::new().set_parameter_mode("example");
pub fn set_query_parameters<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<QueryParameter>,

Sets the value of query_parameters.

Example
use google_cloud_bigquery_v2::model::QueryParameter;
let x = JobConfigurationQuery::new()
    .set_query_parameters([
        QueryParameter::default()/* use setters */,
        QueryParameter::default()/* use (different) setters */,
    ]);
pub fn set_system_variables<T>(self, v: T) -> Self

Sets the value of system_variables.

Example
use google_cloud_bigquery_v2::model::SystemVariables;
let x = JobConfigurationQuery::new().set_system_variables(SystemVariables::default()/* use setters */);
pub fn set_or_clear_system_variables<T>(self, v: Option<T>) -> Self

Sets or clears the value of system_variables.

Example
use google_cloud_bigquery_v2::model::SystemVariables;
let x = JobConfigurationQuery::new().set_or_clear_system_variables(Some(SystemVariables::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_system_variables(None::<SystemVariables>);
pub fn set_schema_update_options<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of schema_update_options.

Example
let x = JobConfigurationQuery::new().set_schema_update_options(["a", "b", "c"]);
pub fn set_time_partitioning<T>(self, v: T) -> Self

Sets the value of time_partitioning.

Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = JobConfigurationQuery::new().set_time_partitioning(TimePartitioning::default()/* use setters */);
pub fn set_or_clear_time_partitioning<T>(self, v: Option<T>) -> Self

Sets or clears the value of time_partitioning.

Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = JobConfigurationQuery::new().set_or_clear_time_partitioning(Some(TimePartitioning::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_time_partitioning(None::<TimePartitioning>);
pub fn set_range_partitioning<T>(self, v: T) -> Self

Sets the value of range_partitioning.

Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = JobConfigurationQuery::new().set_range_partitioning(RangePartitioning::default()/* use setters */);
pub fn set_or_clear_range_partitioning<T>(self, v: Option<T>) -> Self

Sets or clears the value of range_partitioning.

Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = JobConfigurationQuery::new().set_or_clear_range_partitioning(Some(RangePartitioning::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_range_partitioning(None::<RangePartitioning>);
pub fn set_clustering<T>(self, v: T) -> Self
where T: Into<Clustering>,

Sets the value of clustering.

Example
use google_cloud_bigquery_v2::model::Clustering;
let x = JobConfigurationQuery::new().set_clustering(Clustering::default()/* use setters */);
pub fn set_or_clear_clustering<T>(self, v: Option<T>) -> Self
where T: Into<Clustering>,

Sets or clears the value of clustering.

Example
use google_cloud_bigquery_v2::model::Clustering;
let x = JobConfigurationQuery::new().set_or_clear_clustering(Some(Clustering::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_clustering(None::<Clustering>);
pub fn set_destination_encryption_configuration<T>(self, v: T) -> Self

Sets the value of destination_encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = JobConfigurationQuery::new().set_destination_encryption_configuration(EncryptionConfiguration::default()/* use setters */);
pub fn set_or_clear_destination_encryption_configuration<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of destination_encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = JobConfigurationQuery::new().set_or_clear_destination_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_destination_encryption_configuration(None::<EncryptionConfiguration>);
pub fn set_script_options<T>(self, v: T) -> Self
where T: Into<ScriptOptions>,

Sets the value of script_options.

Example
use google_cloud_bigquery_v2::model::ScriptOptions;
let x = JobConfigurationQuery::new().set_script_options(ScriptOptions::default()/* use setters */);
pub fn set_or_clear_script_options<T>(self, v: Option<T>) -> Self
where T: Into<ScriptOptions>,

Sets or clears the value of script_options.

Example
use google_cloud_bigquery_v2::model::ScriptOptions;
let x = JobConfigurationQuery::new().set_or_clear_script_options(Some(ScriptOptions::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_script_options(None::<ScriptOptions>);
pub fn set_connection_properties<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ConnectionProperty>,

Sets the value of connection_properties.

Example
use google_cloud_bigquery_v2::model::ConnectionProperty;
let x = JobConfigurationQuery::new()
    .set_connection_properties([
        ConnectionProperty::default()/* use setters */,
        ConnectionProperty::default()/* use (different) setters */,
    ]);
pub fn set_create_session<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of create_session.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_create_session(BoolValue::default()/* use setters */);
pub fn set_or_clear_create_session<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of create_session.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_create_session(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_create_session(None::<BoolValue>);
pub fn set_continuous<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of continuous.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_continuous(BoolValue::default()/* use setters */);
pub fn set_or_clear_continuous<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of continuous.

Example
use wkt::BoolValue;
let x = JobConfigurationQuery::new().set_or_clear_continuous(Some(BoolValue::default()/* use setters */));
let x = JobConfigurationQuery::new().set_or_clear_continuous(None::<BoolValue>);
pub fn set_write_incremental_results<T: Into<bool>>(self, v: T) -> Self

Sets the value of write_incremental_results.

Example
let x = JobConfigurationQuery::new().set_write_incremental_results(true);