#[non_exhaustive]pub struct JobCreationReason {
pub code: Code,
/* private fields */
}Expand description
Reason about why a Job was created from a
jobs.query
method when used with JOB_CREATION_OPTIONAL Job creation mode.
For
jobs.insert
method calls it will always be REQUESTED.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: CodeOutput only. Specifies the high level reason why a Job was created.
Implementations