JobStatistics

Struct JobStatistics 

#[non_exhaustive]
pub struct JobStatistics {
Show 24 fields pub creation_time: i64, pub start_time: i64, pub end_time: i64, pub total_bytes_processed: Option<Int64Value>, pub completion_ratio: Option<DoubleValue>, pub quota_deferments: Vec<String>, pub query: Option<JobStatistics2>, pub load: Option<JobStatistics3>, pub extract: Option<JobStatistics4>, pub copy: Option<CopyJobStatistics>, pub total_slot_ms: Option<Int64Value>, pub reservation_id: String, pub num_child_jobs: i64, pub parent_job_id: String, pub script_statistics: Option<ScriptStatistics>, pub row_level_security_statistics: Option<RowLevelSecurityStatistics>, pub data_masking_statistics: Option<DataMaskingStatistics>, pub transaction_info: Option<TransactionInfo>, pub session_info: Option<SessionInfo>, pub final_execution_duration_ms: i64, pub edition: ReservationEdition, pub reservation_group_path: Vec<String>, pub global_query_remote_regions: Vec<String>, pub parent_global_query_job: Option<JobReference>, /* private fields */
}
Statistics for a single job execution.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creation_time: i64

Output only. Creation time of this job, in milliseconds since the epoch. This field will be present on all jobs.

start_time: i64

Output only. Start time of this job, in milliseconds since the epoch. This field will be present when the job transitions from the PENDING state to either RUNNING or DONE.

end_time: i64

Output only. End time of this job, in milliseconds since the epoch. This field will be present whenever a job is in the DONE state.

total_bytes_processed: Option<Int64Value>

Output only. Total bytes processed for the job.

completion_ratio: Option<DoubleValue>

Output only. [TrustedTester] Job progress (0.0 -> 1.0) for LOAD and EXTRACT jobs.

quota_deferments: Vec<String>

Output only. Quotas which delayed this job’s start time.

query: Option<JobStatistics2>

Output only. Statistics for a query job.

load: Option<JobStatistics3>

Output only. Statistics for a load job.

extract: Option<JobStatistics4>

Output only. Statistics for an extract job.

copy: Option<CopyJobStatistics>

Output only. Statistics for a copy job.

total_slot_ms: Option<Int64Value>

Output only. Slot-milliseconds for the job.

reservation_id: String

Output only. Name of the primary reservation assigned to this job. Note that this could be different than reservations reported in the reservation usage field if parent reservations were used to execute this job.

num_child_jobs: i64

Output only. Number of child jobs executed.

parent_job_id: String

Output only. If this is a child job, specifies the job ID of the parent.

script_statistics: Option<ScriptStatistics>

Output only. If this a child job of a script, specifies information about the context of this job within the script.

row_level_security_statistics: Option<RowLevelSecurityStatistics>

Output only. Statistics for row-level security. Present only for query and extract jobs.

data_masking_statistics: Option<DataMaskingStatistics>

Output only. Statistics for data-masking. Present only for query and extract jobs.

transaction_info: Option<TransactionInfo>

Output only. [Alpha] Information of the multi-statement transaction if this job is part of one.

This property is only expected on a child job or a job that is in a session. A script parent job is not part of the transaction started in the script.

session_info: Option<SessionInfo>

Output only. Information of the session if this job is part of one.

final_execution_duration_ms: i64

Output only. The duration in milliseconds of the execution of the final attempt of this job, as BigQuery may internally re-attempt to execute the job.

edition: ReservationEdition

Output only. Name of edition corresponding to the reservation for this job at the time of this update.

reservation_group_path: Vec<String>

Output only. The reservation group path of the reservation assigned to this job. This field has a limit of 10 nested reservation groups. This is to maintain consistency between reservatins info schema and jobs info schema. The first reservation group is the root reservation group and the last is the leaf or lowest level reservation group.

global_query_remote_regions: Vec<String>

Output only. Regions where the global query accesses data.

parent_global_query_job: Option<JobReference>

Output only. The global query that created this job.

Implementations

Source

impl JobStatistics

pub fn new() -> Self

Creates a new default instance.

pub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of creation_time.

Example
let x = JobStatistics::new().set_creation_time(42);
pub fn set_start_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of start_time.

Example
let x = JobStatistics::new().set_start_time(42);
pub fn set_end_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of end_time.

Example
let x = JobStatistics::new().set_end_time(42);
pub fn set_total_bytes_processed<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of total_bytes_processed.

Example
use wkt::Int64Value;
let x = JobStatistics::new().set_total_bytes_processed(Int64Value::default()/* use setters */);
pub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of total_bytes_processed.

Example
use wkt::Int64Value;
let x = JobStatistics::new().set_or_clear_total_bytes_processed(Some(Int64Value::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_total_bytes_processed(None::<Int64Value>);
pub fn set_completion_ratio<T>(self, v: T) -> Self
where T: Into<DoubleValue>,

Sets the value of completion_ratio.

Example
use wkt::DoubleValue;
let x = JobStatistics::new().set_completion_ratio(DoubleValue::default()/* use setters */);
pub fn set_or_clear_completion_ratio<T>(self, v: Option<T>) -> Self
where T: Into<DoubleValue>,

Sets or clears the value of completion_ratio.

Example
use wkt::DoubleValue;
let x = JobStatistics::new().set_or_clear_completion_ratio(Some(DoubleValue::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_completion_ratio(None::<DoubleValue>);
pub fn set_quota_deferments<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of quota_deferments.

Example
let x = JobStatistics::new().set_quota_deferments(["a", "b", "c"]);
pub fn set_query<T>(self, v: T) -> Self
where T: Into<JobStatistics2>,

Sets the value of query.

Example
use google_cloud_bigquery_v2::model::JobStatistics2;
let x = JobStatistics::new().set_query(JobStatistics2::default()/* use setters */);
pub fn set_or_clear_query<T>(self, v: Option<T>) -> Self
where T: Into<JobStatistics2>,

Sets or clears the value of query.

Example
use google_cloud_bigquery_v2::model::JobStatistics2;
let x = JobStatistics::new().set_or_clear_query(Some(JobStatistics2::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_query(None::<JobStatistics2>);
pub fn set_load<T>(self, v: T) -> Self
where T: Into<JobStatistics3>,

Sets the value of load.

Example
use google_cloud_bigquery_v2::model::JobStatistics3;
let x = JobStatistics::new().set_load(JobStatistics3::default()/* use setters */);
pub fn set_or_clear_load<T>(self, v: Option<T>) -> Self
where T: Into<JobStatistics3>,

Sets or clears the value of load.

Example
use google_cloud_bigquery_v2::model::JobStatistics3;
let x = JobStatistics::new().set_or_clear_load(Some(JobStatistics3::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_load(None::<JobStatistics3>);
pub fn set_extract<T>(self, v: T) -> Self
where T: Into<JobStatistics4>,

Sets the value of extract.

Example
use google_cloud_bigquery_v2::model::JobStatistics4;
let x = JobStatistics::new().set_extract(JobStatistics4::default()/* use setters */);
pub fn set_or_clear_extract<T>(self, v: Option<T>) -> Self
where T: Into<JobStatistics4>,

Sets or clears the value of extract.

Example
use google_cloud_bigquery_v2::model::JobStatistics4;
let x = JobStatistics::new().set_or_clear_extract(Some(JobStatistics4::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_extract(None::<JobStatistics4>);
pub fn set_copy<T>(self, v: T) -> Self

Sets the value of copy.

Example
use google_cloud_bigquery_v2::model::CopyJobStatistics;
let x = JobStatistics::new().set_copy(CopyJobStatistics::default()/* use setters */);
pub fn set_or_clear_copy<T>(self, v: Option<T>) -> Self

Sets or clears the value of copy.

Example
use google_cloud_bigquery_v2::model::CopyJobStatistics;
let x = JobStatistics::new().set_or_clear_copy(Some(CopyJobStatistics::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_copy(None::<CopyJobStatistics>);
pub fn set_total_slot_ms<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of total_slot_ms.

Example
use wkt::Int64Value;
let x = JobStatistics::new().set_total_slot_ms(Int64Value::default()/* use setters */);
pub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of total_slot_ms.

Example
use wkt::Int64Value;
let x = JobStatistics::new().set_or_clear_total_slot_ms(Some(Int64Value::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_total_slot_ms(None::<Int64Value>);
pub fn set_reservation_id<T: Into<String>>(self, v: T) -> Self

Sets the value of reservation_id.

Example
let x = JobStatistics::new().set_reservation_id("example");
pub fn set_num_child_jobs<T: Into<i64>>(self, v: T) -> Self

Sets the value of num_child_jobs.

Example
let x = JobStatistics::new().set_num_child_jobs(42);
pub fn set_parent_job_id<T: Into<String>>(self, v: T) -> Self

Sets the value of parent_job_id.

Example
let x = JobStatistics::new().set_parent_job_id("example");
pub fn set_script_statistics<T>(self, v: T) -> Self

Sets the value of script_statistics.

Example
use google_cloud_bigquery_v2::model::ScriptStatistics;
let x = JobStatistics::new().set_script_statistics(ScriptStatistics::default()/* use setters */);
pub fn set_or_clear_script_statistics<T>(self, v: Option<T>) -> Self

Sets or clears the value of script_statistics.

Example
use google_cloud_bigquery_v2::model::ScriptStatistics;
let x = JobStatistics::new().set_or_clear_script_statistics(Some(ScriptStatistics::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_script_statistics(None::<ScriptStatistics>);
pub fn set_row_level_security_statistics<T>(self, v: T) -> Self

Sets the value of row_level_security_statistics.

Example
use google_cloud_bigquery_v2::model::RowLevelSecurityStatistics;
let x = JobStatistics::new().set_row_level_security_statistics(RowLevelSecurityStatistics::default()/* use setters */);
pub fn set_or_clear_row_level_security_statistics<T>(self, v: Option<T>) -> Self

Sets or clears the value of row_level_security_statistics.

Example
use google_cloud_bigquery_v2::model::RowLevelSecurityStatistics;
let x = JobStatistics::new().set_or_clear_row_level_security_statistics(Some(RowLevelSecurityStatistics::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_row_level_security_statistics(None::<RowLevelSecurityStatistics>);
pub fn set_data_masking_statistics<T>(self, v: T) -> Self

Sets the value of data_masking_statistics.

Example
use google_cloud_bigquery_v2::model::DataMaskingStatistics;
let x = JobStatistics::new().set_data_masking_statistics(DataMaskingStatistics::default()/* use setters */);
pub fn set_or_clear_data_masking_statistics<T>(self, v: Option<T>) -> Self

Sets or clears the value of data_masking_statistics.

Example
use google_cloud_bigquery_v2::model::DataMaskingStatistics;
let x = JobStatistics::new().set_or_clear_data_masking_statistics(Some(DataMaskingStatistics::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_data_masking_statistics(None::<DataMaskingStatistics>);
pub fn set_transaction_info<T>(self, v: T) -> Self

Sets the value of transaction_info.

Example
use google_cloud_bigquery_v2::model::job_statistics::TransactionInfo;
let x = JobStatistics::new().set_transaction_info(TransactionInfo::default()/* use setters */);
pub fn set_or_clear_transaction_info<T>(self, v: Option<T>) -> Self

Sets or clears the value of transaction_info.

Example
use google_cloud_bigquery_v2::model::job_statistics::TransactionInfo;
let x = JobStatistics::new().set_or_clear_transaction_info(Some(TransactionInfo::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_transaction_info(None::<TransactionInfo>);
pub fn set_session_info<T>(self, v: T) -> Self
where T: Into<SessionInfo>,

Sets the value of session_info.

Example
use google_cloud_bigquery_v2::model::SessionInfo;
let x = JobStatistics::new().set_session_info(SessionInfo::default()/* use setters */);
pub fn set_or_clear_session_info<T>(self, v: Option<T>) -> Self
where T: Into<SessionInfo>,

Sets or clears the value of session_info.

Example
use google_cloud_bigquery_v2::model::SessionInfo;
let x = JobStatistics::new().set_or_clear_session_info(Some(SessionInfo::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_session_info(None::<SessionInfo>);
pub fn set_final_execution_duration_ms<T: Into<i64>>(self, v: T) -> Self

Sets the value of final_execution_duration_ms.

Example
let x = JobStatistics::new().set_final_execution_duration_ms(42);
pub fn set_edition<T: Into<ReservationEdition>>(self, v: T) -> Self

Sets the value of edition.

Example
use google_cloud_bigquery_v2::model::ReservationEdition;
let x0 = JobStatistics::new().set_edition(ReservationEdition::Standard);
let x1 = JobStatistics::new().set_edition(ReservationEdition::Enterprise);
let x2 = JobStatistics::new().set_edition(ReservationEdition::EnterprisePlus);
pub fn set_reservation_group_path<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of reservation_group_path.

Example
let x = JobStatistics::new().set_reservation_group_path(["a", "b", "c"]);
pub fn set_global_query_remote_regions<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of global_query_remote_regions.

Example
let x = JobStatistics::new().set_global_query_remote_regions(["a", "b", "c"]);
pub fn set_parent_global_query_job<T>(self, v: T) -> Self
where T: Into<JobReference>,

Sets the value of parent_global_query_job.

Example
use google_cloud_bigquery_v2::model::JobReference;
let x = JobStatistics::new().set_parent_global_query_job(JobReference::default()/* use setters */);
pub fn set_or_clear_parent_global_query_job<T>(self, v: Option<T>) -> Self
where T: Into<JobReference>,

Sets or clears the value of parent_global_query_job.

Example
use google_cloud_bigquery_v2::model::JobReference;
let x = JobStatistics::new().set_or_clear_parent_global_query_job(Some(JobReference::default()/* use setters */));
let x = JobStatistics::new().set_or_clear_parent_global_query_job(None::<JobReference>);