#[non_exhaustive]pub struct JobStatistics2 {Show 45 fields
pub query_plan: Vec<ExplainQueryStage>,
pub estimated_bytes_processed: Option<Int64Value>,
pub timeline: Vec<QueryTimelineSample>,
pub total_partitions_processed: Option<Int64Value>,
pub total_bytes_processed: Option<Int64Value>,
pub total_bytes_processed_accuracy: String,
pub total_bytes_billed: Option<Int64Value>,
pub billing_tier: Option<Int32Value>,
pub total_slot_ms: Option<Int64Value>,
pub total_services_sku_slot_ms: Option<i64>,
pub cache_hit: Option<BoolValue>,
pub referenced_tables: Vec<TableReference>,
pub referenced_routines: Vec<RoutineReference>,
pub referenced_property_graphs: Vec<PropertyGraphReference>,
pub schema: Option<TableSchema>,
pub num_dml_affected_rows: Option<Int64Value>,
pub dml_stats: Option<DmlStats>,
pub undeclared_query_parameters: Vec<QueryParameter>,
pub statement_type: String,
pub ddl_operation_performed: String,
pub ddl_target_table: Option<TableReference>,
pub ddl_destination_table: Option<TableReference>,
pub ddl_target_row_access_policy: Option<RowAccessPolicyReference>,
pub ddl_affected_row_access_policy_count: Option<Int64Value>,
pub ddl_target_routine: Option<RoutineReference>,
pub ddl_target_dataset: Option<DatasetReference>,
pub ml_statistics: Option<MlStatistics>,
pub export_data_statistics: Option<ExportDataStatistics>,
pub external_service_costs: Vec<ExternalServiceCost>,
pub bi_engine_statistics: Option<BiEngineStatistics>,
pub load_query_statistics: Option<LoadQueryStatistics>,
pub dcl_target_table: Option<TableReference>,
pub dcl_target_view: Option<TableReference>,
pub dcl_target_dataset: Option<DatasetReference>,
pub search_statistics: Option<SearchStatistics>,
pub vector_search_statistics: Option<VectorSearchStatistics>,
pub performance_insights: Option<PerformanceInsights>,
pub query_info: Option<QueryInfo>,
pub spark_statistics: Option<SparkStatistics>,
pub transferred_bytes: Option<Int64Value>,
pub materialized_view_statistics: Option<MaterializedViewStatistics>,
pub metadata_cache_statistics: Option<MetadataCacheStatistics>,
pub incremental_result_stats: Option<IncrementalResultStats>,
pub gen_ai_stats: Option<GenAiStats>,
pub object_storage_stats: Vec<ObjectStorageStats>,
/* private fields */
}Expand description
Statistics for a query job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_plan: Vec<ExplainQueryStage>Output only. Describes execution plan for the query.
estimated_bytes_processed: Option<Int64Value>Output only. The original estimate of bytes processed for the job.
timeline: Vec<QueryTimelineSample>Output only. Describes a timeline of job execution.
total_partitions_processed: Option<Int64Value>Output only. Total number of partitions processed from all partitioned tables referenced in the job.
total_bytes_processed: Option<Int64Value>Output only. Total bytes processed for the job.
total_bytes_processed_accuracy: StringOutput only. For dry-run jobs, totalBytesProcessed is an estimate and this field specifies the accuracy of the estimate. Possible values can be: UNKNOWN: accuracy of the estimate is unknown. PRECISE: estimate is precise. LOWER_BOUND: estimate is lower bound of what the query would cost. UPPER_BOUND: estimate is upper bound of what the query would cost.
total_bytes_billed: Option<Int64Value>Output only. If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job. If the project is configured to use flat-rate pricing, then you are not billed for bytes and this field is informational only.
billing_tier: Option<Int32Value>Output only. Billing tier for the job. This is a BigQuery-specific concept which is not related to the Google Cloud notion of “free tier”. The value here is a measure of the query’s resource consumption relative to the amount of data scanned. For on-demand queries, the limit is 100, and all queries within this limit are billed at the standard on-demand rates. On-demand queries that exceed this limit will fail with a billingTierLimitExceeded error.
total_slot_ms: Option<Int64Value>Output only. Slot-milliseconds for the job.
total_services_sku_slot_ms: Option<i64>Output only. Total slot milliseconds for the job that ran on external
services and billed on the services SKU. This field is only populated for
jobs that have external service costs, and is the total of the usage for
costs whose billing method is "SERVICES_SKU".
cache_hit: Option<BoolValue>Output only. Whether the query result was fetched from the query cache.
referenced_tables: Vec<TableReference>Output only. Referenced tables for the job.
referenced_routines: Vec<RoutineReference>Output only. Referenced routines for the job.
referenced_property_graphs: Vec<PropertyGraphReference>Output only. Referenced property graphs for the job. Queries that reference more than 50 property graphs will not have a complete list.
schema: Option<TableSchema>Output only. The schema of the results. Present only for successful dry run of non-legacy SQL queries.
num_dml_affected_rows: Option<Int64Value>Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE.
dml_stats: Option<DmlStats>Output only. Detailed statistics for DML statements INSERT, UPDATE, DELETE, MERGE or TRUNCATE.
undeclared_query_parameters: Vec<QueryParameter>Output only. GoogleSQL only: list of undeclared query parameters detected during a dry run validation.
statement_type: StringOutput only. The type of query statement, if valid. Possible values:
SELECT:SELECTstatement.ASSERT:ASSERTstatement.INSERT:INSERTstatement.UPDATE:UPDATEstatement.DELETE:DELETEstatement.MERGE:MERGEstatement.CREATE_TABLE:CREATE TABLEstatement, withoutAS SELECT.CREATE_TABLE_AS_SELECT:CREATE TABLE AS SELECTstatement.CREATE_VIEW:CREATE VIEWstatement.CREATE_MODEL:CREATE MODELstatement.CREATE_MATERIALIZED_VIEW:CREATE MATERIALIZED VIEWstatement.CREATE_FUNCTION:CREATE FUNCTIONstatement.CREATE_TABLE_FUNCTION:CREATE TABLE FUNCTIONstatement.CREATE_PROCEDURE:CREATE PROCEDUREstatement.CREATE_ROW_ACCESS_POLICY:CREATE ROW ACCESS POLICYstatement.CREATE_SCHEMA:CREATE SCHEMAstatement.CREATE_SNAPSHOT_TABLE:CREATE SNAPSHOT TABLEstatement.CREATE_SEARCH_INDEX:CREATE SEARCH INDEXstatement.DROP_TABLE:DROP TABLEstatement.DROP_EXTERNAL_TABLE:DROP EXTERNAL TABLEstatement.DROP_VIEW:DROP VIEWstatement.DROP_MODEL:DROP MODELstatement.DROP_MATERIALIZED_VIEW:DROP MATERIALIZED VIEWstatement.DROP_FUNCTION:DROP FUNCTIONstatement.DROP_TABLE_FUNCTION:DROP TABLE FUNCTIONstatement.DROP_PROCEDURE:DROP PROCEDUREstatement.DROP_SEARCH_INDEX:DROP SEARCH INDEXstatement.DROP_SCHEMA:DROP SCHEMAstatement.DROP_SNAPSHOT_TABLE:DROP SNAPSHOT TABLEstatement.DROP_ROW_ACCESS_POLICY:DROP [ALL] ROW ACCESS POLICY|POLICIESstatement.ALTER_TABLE:ALTER TABLEstatement.ALTER_VIEW:ALTER VIEWstatement.ALTER_MATERIALIZED_VIEW:ALTER MATERIALIZED VIEWstatement.ALTER_SCHEMA:ALTER SCHEMAstatement.SCRIPT:SCRIPT.TRUNCATE_TABLE:TRUNCATE TABLEstatement.CREATE_EXTERNAL_TABLE:CREATE EXTERNAL TABLEstatement.EXPORT_DATA:EXPORT DATAstatement.EXPORT_MODEL:EXPORT MODELstatement.LOAD_DATA:LOAD DATAstatement.CALL:CALLstatement.
ddl_operation_performed: StringOutput only. The DDL operation performed, possibly dependent on the pre-existence of the DDL target.
ddl_target_table: Option<TableReference>Output only. The DDL target table. Present only for CREATE/DROP TABLE/VIEW and DROP ALL ROW ACCESS POLICIES queries.
ddl_destination_table: Option<TableReference>Output only. The table after rename. Present only for ALTER TABLE RENAME TO query.
ddl_target_row_access_policy: Option<RowAccessPolicyReference>Output only. The DDL target row access policy. Present only for CREATE/DROP ROW ACCESS POLICY queries.
ddl_affected_row_access_policy_count: Option<Int64Value>Output only. The number of row access policies affected by a DDL statement. Present only for DROP ALL ROW ACCESS POLICIES queries.
ddl_target_routine: Option<RoutineReference>Output only. [Beta] The DDL target routine. Present only for CREATE/DROP FUNCTION/PROCEDURE queries.
ddl_target_dataset: Option<DatasetReference>Output only. The DDL target dataset. Present only for CREATE/ALTER/DROP SCHEMA(dataset) queries.
ml_statistics: Option<MlStatistics>Output only. Statistics of a BigQuery ML training job.
export_data_statistics: Option<ExportDataStatistics>Output only. Stats for EXPORT DATA statement.
external_service_costs: Vec<ExternalServiceCost>Output only. Job cost breakdown as bigquery internal cost and external service costs.
bi_engine_statistics: Option<BiEngineStatistics>Output only. BI Engine specific Statistics.
load_query_statistics: Option<LoadQueryStatistics>Output only. Statistics for a LOAD query.
dcl_target_table: Option<TableReference>Output only. Referenced table for DCL statement.
dcl_target_view: Option<TableReference>Output only. Referenced view for DCL statement.
dcl_target_dataset: Option<DatasetReference>Output only. Referenced dataset for DCL statement.
search_statistics: Option<SearchStatistics>Output only. Search query specific statistics.
vector_search_statistics: Option<VectorSearchStatistics>Output only. Vector Search query specific statistics.
performance_insights: Option<PerformanceInsights>Output only. Performance insights.
query_info: Option<QueryInfo>Output only. Query optimization information for a QUERY job.
spark_statistics: Option<SparkStatistics>Output only. Statistics of a Spark procedure job.
transferred_bytes: Option<Int64Value>Output only. Total bytes transferred for BigQuery Omni queries from the remote cloud back to Google Cloud. This tracks data movement over Google-managed connections (like query results). It doesn’t include input data read from the external data lake (for example, S3) because that data stays within the remote cloud.
materialized_view_statistics: Option<MaterializedViewStatistics>Output only. Statistics of materialized views of a query job.
metadata_cache_statistics: Option<MetadataCacheStatistics>Output only. Statistics of metadata cache usage in a query for BigLake tables.
incremental_result_stats: Option<IncrementalResultStats>Output only. Statistics related to incremental query results, if enabled for the query. This feature is not yet available.
gen_ai_stats: Option<GenAiStats>Output only. Statistics related to GenAI usage in the query.
object_storage_stats: Vec<ObjectStorageStats>Output only. Storage and caching statistics per cloud provider for queries over object storage.
Implementations
Sourceimpl JobStatistics2
impl JobStatistics2
Sourcepub fn set_query_plan<T, V>(self, v: T) -> Self
pub fn set_query_plan<T, V>(self, v: T) -> Self
Sets the value of query_plan.
Example
use google_cloud_bigquery_v2::model::ExplainQueryStage;
let x = JobStatistics2::new()
.set_query_plan([
ExplainQueryStage::default()/* use setters */,
ExplainQueryStage::default()/* use (different) setters */,
]);Sourcepub fn set_estimated_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_estimated_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of estimated_bytes_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_estimated_bytes_processed(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_estimated_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_estimated_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of estimated_bytes_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_estimated_bytes_processed(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_estimated_bytes_processed(None::<Int64Value>);Sourcepub fn set_timeline<T, V>(self, v: T) -> Self
pub fn set_timeline<T, V>(self, v: T) -> Self
Sourcepub fn set_total_partitions_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_partitions_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_partitions_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_total_partitions_processed(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_partitions_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_partitions_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_partitions_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_total_partitions_processed(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_total_partitions_processed(None::<Int64Value>);Sourcepub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_bytes_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_total_bytes_processed(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_bytes_processed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_total_bytes_processed(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_total_bytes_processed(None::<Int64Value>);Sourcepub fn set_total_bytes_processed_accuracy<T: Into<String>>(self, v: T) -> Self
pub fn set_total_bytes_processed_accuracy<T: Into<String>>(self, v: T) -> Self
Sets the value of total_bytes_processed_accuracy.
Example
let x = JobStatistics2::new().set_total_bytes_processed_accuracy("example");Sourcepub fn set_total_bytes_billed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_bytes_billed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_bytes_billed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_total_bytes_billed(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_bytes_billed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_bytes_billed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_bytes_billed.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_total_bytes_billed(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_total_bytes_billed(None::<Int64Value>);Sourcepub fn set_billing_tier<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
pub fn set_billing_tier<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
Sets the value of billing_tier.
Example
use wkt::Int32Value;
let x = JobStatistics2::new().set_billing_tier(Int32Value::default()/* use setters */);Sourcepub fn set_or_clear_billing_tier<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
pub fn set_or_clear_billing_tier<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
Sets or clears the value of billing_tier.
Example
use wkt::Int32Value;
let x = JobStatistics2::new().set_or_clear_billing_tier(Some(Int32Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_billing_tier(None::<Int32Value>);Sourcepub fn set_total_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_slot_ms.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_total_slot_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_slot_ms.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_total_slot_ms(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_total_slot_ms(None::<Int64Value>);Sourcepub fn set_total_services_sku_slot_ms<T>(self, v: T) -> Self
pub fn set_total_services_sku_slot_ms<T>(self, v: T) -> Self
Sets the value of total_services_sku_slot_ms.
Example
let x = JobStatistics2::new().set_total_services_sku_slot_ms(42);Sourcepub fn set_or_clear_total_services_sku_slot_ms<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_services_sku_slot_ms<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_services_sku_slot_ms.
Example
let x = JobStatistics2::new().set_or_clear_total_services_sku_slot_ms(Some(42));
let x = JobStatistics2::new().set_or_clear_total_services_sku_slot_ms(None::<i32>);Sourcepub fn set_cache_hit<T>(self, v: T) -> Self
pub fn set_cache_hit<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
Sourcepub fn set_referenced_tables<T, V>(self, v: T) -> Self
pub fn set_referenced_tables<T, V>(self, v: T) -> Self
Sets the value of referenced_tables.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new()
.set_referenced_tables([
TableReference::default()/* use setters */,
TableReference::default()/* use (different) setters */,
]);Sourcepub fn set_referenced_routines<T, V>(self, v: T) -> Self
pub fn set_referenced_routines<T, V>(self, v: T) -> Self
Sets the value of referenced_routines.
Example
use google_cloud_bigquery_v2::model::RoutineReference;
let x = JobStatistics2::new()
.set_referenced_routines([
RoutineReference::default()/* use setters */,
RoutineReference::default()/* use (different) setters */,
]);Sourcepub fn set_referenced_property_graphs<T, V>(self, v: T) -> Self
pub fn set_referenced_property_graphs<T, V>(self, v: T) -> Self
Sets the value of referenced_property_graphs.
Example
use google_cloud_bigquery_v2::model::PropertyGraphReference;
let x = JobStatistics2::new()
.set_referenced_property_graphs([
PropertyGraphReference::default()/* use setters */,
PropertyGraphReference::default()/* use (different) setters */,
]);Sourcepub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
pub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_dml_affected_rows.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_num_dml_affected_rows(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_dml_affected_rows.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_num_dml_affected_rows(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_num_dml_affected_rows(None::<Int64Value>);Sourcepub fn set_dml_stats<T>(self, v: T) -> Self
pub fn set_dml_stats<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_dml_stats<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_dml_stats<T>(self, v: Option<T>) -> Self
Sourcepub fn set_undeclared_query_parameters<T, V>(self, v: T) -> Self
pub fn set_undeclared_query_parameters<T, V>(self, v: T) -> Self
Sets the value of undeclared_query_parameters.
Example
use google_cloud_bigquery_v2::model::QueryParameter;
let x = JobStatistics2::new()
.set_undeclared_query_parameters([
QueryParameter::default()/* use setters */,
QueryParameter::default()/* use (different) setters */,
]);Sourcepub fn set_statement_type<T: Into<String>>(self, v: T) -> Self
pub fn set_statement_type<T: Into<String>>(self, v: T) -> Self
Sets the value of statement_type.
Example
let x = JobStatistics2::new().set_statement_type("example");Sourcepub fn set_ddl_operation_performed<T: Into<String>>(self, v: T) -> Self
pub fn set_ddl_operation_performed<T: Into<String>>(self, v: T) -> Self
Sets the value of ddl_operation_performed.
Example
let x = JobStatistics2::new().set_ddl_operation_performed("example");Sourcepub fn set_ddl_target_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_ddl_target_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of ddl_target_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_ddl_target_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_ddl_target_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_ddl_target_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of ddl_target_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_or_clear_ddl_target_table(Some(TableReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_target_table(None::<TableReference>);Sourcepub fn set_ddl_destination_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_ddl_destination_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of ddl_destination_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_ddl_destination_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_ddl_destination_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_ddl_destination_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of ddl_destination_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_or_clear_ddl_destination_table(Some(TableReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_destination_table(None::<TableReference>);Sourcepub fn set_ddl_target_row_access_policy<T>(self, v: T) -> Selfwhere
T: Into<RowAccessPolicyReference>,
pub fn set_ddl_target_row_access_policy<T>(self, v: T) -> Selfwhere
T: Into<RowAccessPolicyReference>,
Sets the value of ddl_target_row_access_policy.
Example
use google_cloud_bigquery_v2::model::RowAccessPolicyReference;
let x = JobStatistics2::new().set_ddl_target_row_access_policy(RowAccessPolicyReference::default()/* use setters */);Sourcepub fn set_or_clear_ddl_target_row_access_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RowAccessPolicyReference>,
pub fn set_or_clear_ddl_target_row_access_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RowAccessPolicyReference>,
Sets or clears the value of ddl_target_row_access_policy.
Example
use google_cloud_bigquery_v2::model::RowAccessPolicyReference;
let x = JobStatistics2::new().set_or_clear_ddl_target_row_access_policy(Some(RowAccessPolicyReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_target_row_access_policy(None::<RowAccessPolicyReference>);Sourcepub fn set_ddl_affected_row_access_policy_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_ddl_affected_row_access_policy_count<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of ddl_affected_row_access_policy_count.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_ddl_affected_row_access_policy_count(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_ddl_affected_row_access_policy_count<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_ddl_affected_row_access_policy_count<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of ddl_affected_row_access_policy_count.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_ddl_affected_row_access_policy_count(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_affected_row_access_policy_count(None::<Int64Value>);Sourcepub fn set_ddl_target_routine<T>(self, v: T) -> Selfwhere
T: Into<RoutineReference>,
pub fn set_ddl_target_routine<T>(self, v: T) -> Selfwhere
T: Into<RoutineReference>,
Sets the value of ddl_target_routine.
Example
use google_cloud_bigquery_v2::model::RoutineReference;
let x = JobStatistics2::new().set_ddl_target_routine(RoutineReference::default()/* use setters */);Sourcepub fn set_or_clear_ddl_target_routine<T>(self, v: Option<T>) -> Selfwhere
T: Into<RoutineReference>,
pub fn set_or_clear_ddl_target_routine<T>(self, v: Option<T>) -> Selfwhere
T: Into<RoutineReference>,
Sets or clears the value of ddl_target_routine.
Example
use google_cloud_bigquery_v2::model::RoutineReference;
let x = JobStatistics2::new().set_or_clear_ddl_target_routine(Some(RoutineReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_target_routine(None::<RoutineReference>);Sourcepub fn set_ddl_target_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_ddl_target_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sets the value of ddl_target_dataset.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobStatistics2::new().set_ddl_target_dataset(DatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_ddl_target_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_ddl_target_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sets or clears the value of ddl_target_dataset.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobStatistics2::new().set_or_clear_ddl_target_dataset(Some(DatasetReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ddl_target_dataset(None::<DatasetReference>);Sourcepub fn set_ml_statistics<T>(self, v: T) -> Selfwhere
T: Into<MlStatistics>,
pub fn set_ml_statistics<T>(self, v: T) -> Selfwhere
T: Into<MlStatistics>,
Sets the value of ml_statistics.
Example
use google_cloud_bigquery_v2::model::MlStatistics;
let x = JobStatistics2::new().set_ml_statistics(MlStatistics::default()/* use setters */);Sourcepub fn set_or_clear_ml_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MlStatistics>,
pub fn set_or_clear_ml_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MlStatistics>,
Sets or clears the value of ml_statistics.
Example
use google_cloud_bigquery_v2::model::MlStatistics;
let x = JobStatistics2::new().set_or_clear_ml_statistics(Some(MlStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_ml_statistics(None::<MlStatistics>);Sourcepub fn set_export_data_statistics<T>(self, v: T) -> Selfwhere
T: Into<ExportDataStatistics>,
pub fn set_export_data_statistics<T>(self, v: T) -> Selfwhere
T: Into<ExportDataStatistics>,
Sets the value of export_data_statistics.
Example
use google_cloud_bigquery_v2::model::ExportDataStatistics;
let x = JobStatistics2::new().set_export_data_statistics(ExportDataStatistics::default()/* use setters */);Sourcepub fn set_or_clear_export_data_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExportDataStatistics>,
pub fn set_or_clear_export_data_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExportDataStatistics>,
Sets or clears the value of export_data_statistics.
Example
use google_cloud_bigquery_v2::model::ExportDataStatistics;
let x = JobStatistics2::new().set_or_clear_export_data_statistics(Some(ExportDataStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_export_data_statistics(None::<ExportDataStatistics>);Sourcepub fn set_external_service_costs<T, V>(self, v: T) -> Self
pub fn set_external_service_costs<T, V>(self, v: T) -> Self
Sets the value of external_service_costs.
Example
use google_cloud_bigquery_v2::model::ExternalServiceCost;
let x = JobStatistics2::new()
.set_external_service_costs([
ExternalServiceCost::default()/* use setters */,
ExternalServiceCost::default()/* use (different) setters */,
]);Sourcepub fn set_bi_engine_statistics<T>(self, v: T) -> Selfwhere
T: Into<BiEngineStatistics>,
pub fn set_bi_engine_statistics<T>(self, v: T) -> Selfwhere
T: Into<BiEngineStatistics>,
Sets the value of bi_engine_statistics.
Example
use google_cloud_bigquery_v2::model::BiEngineStatistics;
let x = JobStatistics2::new().set_bi_engine_statistics(BiEngineStatistics::default()/* use setters */);Sourcepub fn set_or_clear_bi_engine_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<BiEngineStatistics>,
pub fn set_or_clear_bi_engine_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<BiEngineStatistics>,
Sets or clears the value of bi_engine_statistics.
Example
use google_cloud_bigquery_v2::model::BiEngineStatistics;
let x = JobStatistics2::new().set_or_clear_bi_engine_statistics(Some(BiEngineStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_bi_engine_statistics(None::<BiEngineStatistics>);Sourcepub fn set_load_query_statistics<T>(self, v: T) -> Selfwhere
T: Into<LoadQueryStatistics>,
pub fn set_load_query_statistics<T>(self, v: T) -> Selfwhere
T: Into<LoadQueryStatistics>,
Sets the value of load_query_statistics.
Example
use google_cloud_bigquery_v2::model::LoadQueryStatistics;
let x = JobStatistics2::new().set_load_query_statistics(LoadQueryStatistics::default()/* use setters */);Sourcepub fn set_or_clear_load_query_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoadQueryStatistics>,
pub fn set_or_clear_load_query_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoadQueryStatistics>,
Sets or clears the value of load_query_statistics.
Example
use google_cloud_bigquery_v2::model::LoadQueryStatistics;
let x = JobStatistics2::new().set_or_clear_load_query_statistics(Some(LoadQueryStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_load_query_statistics(None::<LoadQueryStatistics>);Sourcepub fn set_dcl_target_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_dcl_target_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of dcl_target_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_dcl_target_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_dcl_target_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_dcl_target_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of dcl_target_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_or_clear_dcl_target_table(Some(TableReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_dcl_target_table(None::<TableReference>);Sourcepub fn set_dcl_target_view<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_dcl_target_view<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of dcl_target_view.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_dcl_target_view(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_dcl_target_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_dcl_target_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of dcl_target_view.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobStatistics2::new().set_or_clear_dcl_target_view(Some(TableReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_dcl_target_view(None::<TableReference>);Sourcepub fn set_dcl_target_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_dcl_target_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sets the value of dcl_target_dataset.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobStatistics2::new().set_dcl_target_dataset(DatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_dcl_target_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_dcl_target_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sets or clears the value of dcl_target_dataset.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = JobStatistics2::new().set_or_clear_dcl_target_dataset(Some(DatasetReference::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_dcl_target_dataset(None::<DatasetReference>);Sourcepub fn set_search_statistics<T>(self, v: T) -> Selfwhere
T: Into<SearchStatistics>,
pub fn set_search_statistics<T>(self, v: T) -> Selfwhere
T: Into<SearchStatistics>,
Sets the value of search_statistics.
Example
use google_cloud_bigquery_v2::model::SearchStatistics;
let x = JobStatistics2::new().set_search_statistics(SearchStatistics::default()/* use setters */);Sourcepub fn set_or_clear_search_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchStatistics>,
pub fn set_or_clear_search_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchStatistics>,
Sets or clears the value of search_statistics.
Example
use google_cloud_bigquery_v2::model::SearchStatistics;
let x = JobStatistics2::new().set_or_clear_search_statistics(Some(SearchStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_search_statistics(None::<SearchStatistics>);Sourcepub fn set_vector_search_statistics<T>(self, v: T) -> Selfwhere
T: Into<VectorSearchStatistics>,
pub fn set_vector_search_statistics<T>(self, v: T) -> Selfwhere
T: Into<VectorSearchStatistics>,
Sets the value of vector_search_statistics.
Example
use google_cloud_bigquery_v2::model::VectorSearchStatistics;
let x = JobStatistics2::new().set_vector_search_statistics(VectorSearchStatistics::default()/* use setters */);Sourcepub fn set_or_clear_vector_search_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<VectorSearchStatistics>,
pub fn set_or_clear_vector_search_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<VectorSearchStatistics>,
Sets or clears the value of vector_search_statistics.
Example
use google_cloud_bigquery_v2::model::VectorSearchStatistics;
let x = JobStatistics2::new().set_or_clear_vector_search_statistics(Some(VectorSearchStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_vector_search_statistics(None::<VectorSearchStatistics>);Sourcepub fn set_performance_insights<T>(self, v: T) -> Selfwhere
T: Into<PerformanceInsights>,
pub fn set_performance_insights<T>(self, v: T) -> Selfwhere
T: Into<PerformanceInsights>,
Sets the value of performance_insights.
Example
use google_cloud_bigquery_v2::model::PerformanceInsights;
let x = JobStatistics2::new().set_performance_insights(PerformanceInsights::default()/* use setters */);Sourcepub fn set_or_clear_performance_insights<T>(self, v: Option<T>) -> Selfwhere
T: Into<PerformanceInsights>,
pub fn set_or_clear_performance_insights<T>(self, v: Option<T>) -> Selfwhere
T: Into<PerformanceInsights>,
Sets or clears the value of performance_insights.
Example
use google_cloud_bigquery_v2::model::PerformanceInsights;
let x = JobStatistics2::new().set_or_clear_performance_insights(Some(PerformanceInsights::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_performance_insights(None::<PerformanceInsights>);Sourcepub fn set_query_info<T>(self, v: T) -> Self
pub fn set_query_info<T>(self, v: T) -> Self
Sets the value of query_info.
Example
use google_cloud_bigquery_v2::model::QueryInfo;
let x = JobStatistics2::new().set_query_info(QueryInfo::default()/* use setters */);Sourcepub fn set_or_clear_query_info<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_query_info<T>(self, v: Option<T>) -> Self
Sets or clears the value of query_info.
Example
use google_cloud_bigquery_v2::model::QueryInfo;
let x = JobStatistics2::new().set_or_clear_query_info(Some(QueryInfo::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_query_info(None::<QueryInfo>);Sourcepub fn set_spark_statistics<T>(self, v: T) -> Selfwhere
T: Into<SparkStatistics>,
pub fn set_spark_statistics<T>(self, v: T) -> Selfwhere
T: Into<SparkStatistics>,
Sets the value of spark_statistics.
Example
use google_cloud_bigquery_v2::model::SparkStatistics;
let x = JobStatistics2::new().set_spark_statistics(SparkStatistics::default()/* use setters */);Sourcepub fn set_or_clear_spark_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<SparkStatistics>,
pub fn set_or_clear_spark_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<SparkStatistics>,
Sets or clears the value of spark_statistics.
Example
use google_cloud_bigquery_v2::model::SparkStatistics;
let x = JobStatistics2::new().set_or_clear_spark_statistics(Some(SparkStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_spark_statistics(None::<SparkStatistics>);Sourcepub fn set_transferred_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_transferred_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of transferred_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_transferred_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_transferred_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_transferred_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of transferred_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics2::new().set_or_clear_transferred_bytes(Some(Int64Value::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_transferred_bytes(None::<Int64Value>);Sourcepub fn set_materialized_view_statistics<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewStatistics>,
pub fn set_materialized_view_statistics<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewStatistics>,
Sets the value of materialized_view_statistics.
Example
use google_cloud_bigquery_v2::model::MaterializedViewStatistics;
let x = JobStatistics2::new().set_materialized_view_statistics(MaterializedViewStatistics::default()/* use setters */);Sourcepub fn set_or_clear_materialized_view_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewStatistics>,
pub fn set_or_clear_materialized_view_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewStatistics>,
Sets or clears the value of materialized_view_statistics.
Example
use google_cloud_bigquery_v2::model::MaterializedViewStatistics;
let x = JobStatistics2::new().set_or_clear_materialized_view_statistics(Some(MaterializedViewStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_materialized_view_statistics(None::<MaterializedViewStatistics>);Sourcepub fn set_metadata_cache_statistics<T>(self, v: T) -> Selfwhere
T: Into<MetadataCacheStatistics>,
pub fn set_metadata_cache_statistics<T>(self, v: T) -> Selfwhere
T: Into<MetadataCacheStatistics>,
Sets the value of metadata_cache_statistics.
Example
use google_cloud_bigquery_v2::model::MetadataCacheStatistics;
let x = JobStatistics2::new().set_metadata_cache_statistics(MetadataCacheStatistics::default()/* use setters */);Sourcepub fn set_or_clear_metadata_cache_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataCacheStatistics>,
pub fn set_or_clear_metadata_cache_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataCacheStatistics>,
Sets or clears the value of metadata_cache_statistics.
Example
use google_cloud_bigquery_v2::model::MetadataCacheStatistics;
let x = JobStatistics2::new().set_or_clear_metadata_cache_statistics(Some(MetadataCacheStatistics::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_metadata_cache_statistics(None::<MetadataCacheStatistics>);Sourcepub fn set_incremental_result_stats<T>(self, v: T) -> Selfwhere
T: Into<IncrementalResultStats>,
pub fn set_incremental_result_stats<T>(self, v: T) -> Selfwhere
T: Into<IncrementalResultStats>,
Sets the value of incremental_result_stats.
Example
use google_cloud_bigquery_v2::model::IncrementalResultStats;
let x = JobStatistics2::new().set_incremental_result_stats(IncrementalResultStats::default()/* use setters */);Sourcepub fn set_or_clear_incremental_result_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<IncrementalResultStats>,
pub fn set_or_clear_incremental_result_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<IncrementalResultStats>,
Sets or clears the value of incremental_result_stats.
Example
use google_cloud_bigquery_v2::model::IncrementalResultStats;
let x = JobStatistics2::new().set_or_clear_incremental_result_stats(Some(IncrementalResultStats::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_incremental_result_stats(None::<IncrementalResultStats>);Sourcepub fn set_gen_ai_stats<T>(self, v: T) -> Selfwhere
T: Into<GenAiStats>,
pub fn set_gen_ai_stats<T>(self, v: T) -> Selfwhere
T: Into<GenAiStats>,
Sets the value of gen_ai_stats.
Example
use google_cloud_bigquery_v2::model::GenAiStats;
let x = JobStatistics2::new().set_gen_ai_stats(GenAiStats::default()/* use setters */);Sourcepub fn set_or_clear_gen_ai_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenAiStats>,
pub fn set_or_clear_gen_ai_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenAiStats>,
Sets or clears the value of gen_ai_stats.
Example
use google_cloud_bigquery_v2::model::GenAiStats;
let x = JobStatistics2::new().set_or_clear_gen_ai_stats(Some(GenAiStats::default()/* use setters */));
let x = JobStatistics2::new().set_or_clear_gen_ai_stats(None::<GenAiStats>);Sourcepub fn set_object_storage_stats<T, V>(self, v: T) -> Self
pub fn set_object_storage_stats<T, V>(self, v: T) -> Self
Sets the value of object_storage_stats.
Example
use google_cloud_bigquery_v2::model::ObjectStorageStats;
let x = JobStatistics2::new()
.set_object_storage_stats([
ObjectStorageStats::default()/* use setters */,
ObjectStorageStats::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for JobStatistics2
impl Clone for JobStatistics2
Sourcefn clone(&self) -> JobStatistics2
fn clone(&self) -> JobStatistics2
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for JobStatistics2
impl Debug for JobStatistics2
Sourceimpl Default for JobStatistics2
impl Default for JobStatistics2
Sourcefn default() -> JobStatistics2
fn default() -> JobStatistics2
Sourceimpl Message for JobStatistics2
impl Message for JobStatistics2
Sourceimpl PartialEq for JobStatistics2
impl PartialEq for JobStatistics2
impl StructuralPartialEq for JobStatistics2