JobStatistics4

Struct JobStatistics4 

#[non_exhaustive]
pub struct JobStatistics4 { pub destination_uri_file_counts: Vec<i64>, pub input_bytes: Option<Int64Value>, pub timeline: Vec<QueryTimelineSample>, /* private fields */ }
Statistics for an extract job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
destination_uri_file_counts: Vec<i64>

Output only. Number of files per destination URI or URI pattern specified in the extract configuration. These values will be in the same order as the URIs specified in the ‘destinationUris’ field.

input_bytes: Option<Int64Value>

Output only. Number of user bytes extracted into the result. This is the byte count as computed by BigQuery for billing purposes and doesn’t have any relationship with the number of actual result bytes extracted in the desired format.

timeline: Vec<QueryTimelineSample>

Output only. Describes a timeline of job execution.

Implementations

Source

impl JobStatistics4

pub fn new() -> Self

Creates a new default instance.

pub fn set_destination_uri_file_counts<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<i64>,

Sets the value of destination_uri_file_counts.

Example
let x = JobStatistics4::new().set_destination_uri_file_counts([1, 2, 3]);
pub fn set_input_bytes<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of input_bytes.

Example
use wkt::Int64Value;
let x = JobStatistics4::new().set_input_bytes(Int64Value::default()/* use setters */);
pub fn set_or_clear_input_bytes<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of input_bytes.

Example
use wkt::Int64Value;
let x = JobStatistics4::new().set_or_clear_input_bytes(Some(Int64Value::default()/* use setters */));
let x = JobStatistics4::new().set_or_clear_input_bytes(None::<Int64Value>);
pub fn set_timeline<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<QueryTimelineSample>,

Sets the value of timeline.

Example
use google_cloud_bigquery_v2::model::QueryTimelineSample;
let x = JobStatistics4::new()
    .set_timeline([
        QueryTimelineSample::default()/* use setters */,
        QueryTimelineSample::default()/* use (different) setters */,
    ]);