JobStatus

Struct JobStatus 

#[non_exhaustive]
pub struct JobStatus { pub error_result: Option<ErrorProto>, pub errors: Vec<ErrorProto>, pub state: String, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
error_result: Option<ErrorProto>

Output only. Final error result of the job. If present, indicates that the job has completed and was unsuccessful.

errors: Vec<ErrorProto>

Output only. The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has not completed or was unsuccessful.

state: String

Output only. Running state of the job. Valid states include ‘PENDING’, ‘RUNNING’, and ‘DONE’.

Implementations

Source

impl JobStatus

pub fn new() -> Self

Creates a new default instance.

pub fn set_error_result<T>(self, v: T) -> Self
where T: Into<ErrorProto>,

Sets the value of error_result.

Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = JobStatus::new().set_error_result(ErrorProto::default()/* use setters */);
pub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Self
where T: Into<ErrorProto>,

Sets or clears the value of error_result.

Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = JobStatus::new().set_or_clear_error_result(Some(ErrorProto::default()/* use setters */));
let x = JobStatus::new().set_or_clear_error_result(None::<ErrorProto>);
pub fn set_errors<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ErrorProto>,

Sets the value of errors.

Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = JobStatus::new()
    .set_errors([
        ErrorProto::default()/* use setters */,
        ErrorProto::default()/* use (different) setters */,
    ]);
pub fn set_state<T: Into<String>>(self, v: T) -> Self

Sets the value of state.

Example
let x = JobStatus::new().set_state("example");