#[non_exhaustive]pub struct JoinRestrictionPolicy {
pub join_condition: Option<JoinCondition>,
pub join_allowed_columns: Vec<String>,
/* private fields */
}Expand description
Represents privacy policy associated with “join restrictions”. Join restriction gives data providers the ability to enforce joins on the ‘join_allowed_columns’ when data is queried from a privacy protected view.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.join_condition: Option<JoinCondition>Optional. Specifies if a join is required or not on queries for the view. Default is JOIN_CONDITION_UNSPECIFIED.
join_allowed_columns: Vec<String>Optional. The only columns that joins are allowed on. This field is must be specified for join_conditions JOIN_ANY and JOIN_ALL and it cannot be set for JOIN_BLOCKED.
Implementations
Sourceimpl JoinRestrictionPolicy
impl JoinRestrictionPolicy
Sourcepub fn set_join_condition<T>(self, v: T) -> Selfwhere
T: Into<JoinCondition>,
pub fn set_join_condition<T>(self, v: T) -> Selfwhere
T: Into<JoinCondition>,
Sets the value of join_condition.
Example
ⓘ
use google_cloud_bigquery_v2::model::join_restriction_policy::JoinCondition;
let x0 = JoinRestrictionPolicy::new().set_join_condition(JoinCondition::JoinAny);
let x1 = JoinRestrictionPolicy::new().set_join_condition(JoinCondition::JoinAll);
let x2 = JoinRestrictionPolicy::new().set_join_condition(JoinCondition::JoinNotRequired);Sourcepub fn set_or_clear_join_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<JoinCondition>,
pub fn set_or_clear_join_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<JoinCondition>,
Sets or clears the value of join_condition.
Example
ⓘ
use google_cloud_bigquery_v2::model::join_restriction_policy::JoinCondition;
let x0 = JoinRestrictionPolicy::new().set_or_clear_join_condition(Some(JoinCondition::JoinAny));
let x1 = JoinRestrictionPolicy::new().set_or_clear_join_condition(Some(JoinCondition::JoinAll));
let x2 = JoinRestrictionPolicy::new().set_or_clear_join_condition(Some(JoinCondition::JoinNotRequired));
let x_none = JoinRestrictionPolicy::new().set_or_clear_join_condition(None::<JoinCondition>);Sourcepub fn set_join_allowed_columns<T, V>(self, v: T) -> Self
pub fn set_join_allowed_columns<T, V>(self, v: T) -> Self
Sets the value of join_allowed_columns.
Example
ⓘ
let x = JoinRestrictionPolicy::new().set_join_allowed_columns(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for JoinRestrictionPolicy
impl Clone for JoinRestrictionPolicy
Sourcefn clone(&self) -> JoinRestrictionPolicy
fn clone(&self) -> JoinRestrictionPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JoinRestrictionPolicy
impl Debug for JoinRestrictionPolicy
Sourceimpl Default for JoinRestrictionPolicy
impl Default for JoinRestrictionPolicy
Sourcefn default() -> JoinRestrictionPolicy
fn default() -> JoinRestrictionPolicy
Returns the “default value” for a type. Read more
Sourceimpl Message for JoinRestrictionPolicy
impl Message for JoinRestrictionPolicy
Sourceimpl PartialEq for JoinRestrictionPolicy
impl PartialEq for JoinRestrictionPolicy
impl StructuralPartialEq for JoinRestrictionPolicy