#[non_exhaustive]pub struct LinkedDatasetSource {
pub source_dataset: Option<DatasetReference>,
/* private fields */
}Expand description
A dataset source type which refers to another BigQuery dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_dataset: Option<DatasetReference>The source dataset reference contains project numbers and not project ids.
Implementations
Sourceimpl LinkedDatasetSource
impl LinkedDatasetSource
Sourcepub fn set_source_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_source_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sets the value of source_dataset.
Example
ⓘ
use google_cloud_bigquery_v2::model::DatasetReference;
let x = LinkedDatasetSource::new().set_source_dataset(DatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_source_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_source_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sets or clears the value of source_dataset.
Example
ⓘ
use google_cloud_bigquery_v2::model::DatasetReference;
let x = LinkedDatasetSource::new().set_or_clear_source_dataset(Some(DatasetReference::default()/* use setters */));
let x = LinkedDatasetSource::new().set_or_clear_source_dataset(None::<DatasetReference>);Trait Implementations
Sourceimpl Clone for LinkedDatasetSource
impl Clone for LinkedDatasetSource
Sourcefn clone(&self) -> LinkedDatasetSource
fn clone(&self) -> LinkedDatasetSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkedDatasetSource
impl Debug for LinkedDatasetSource
Sourceimpl Default for LinkedDatasetSource
impl Default for LinkedDatasetSource
Sourcefn default() -> LinkedDatasetSource
fn default() -> LinkedDatasetSource
Returns the “default value” for a type. Read more
Sourceimpl Message for LinkedDatasetSource
impl Message for LinkedDatasetSource
Sourceimpl PartialEq for LinkedDatasetSource
impl PartialEq for LinkedDatasetSource
impl StructuralPartialEq for LinkedDatasetSource