#[non_exhaustive]pub struct ListDatasetsRequest {
pub project_id: String,
pub max_results: Option<UInt32Value>,
pub page_token: String,
pub all: bool,
pub filter: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the datasets to be listed
max_results: Option<UInt32Value>The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.
page_token: StringPage token, returned by a previous call, to request the next page of results
all: boolWhether to list all datasets, including hidden ones
filter: StringAn expression for filtering the results of the request by label.
The syntax is labels.<name>[:<value>].
Multiple filters can be AND-ed together by connecting with a space.
Example: labels.department:receiving labels.active.
See Filtering datasets using
labels
for details.
Implementations
Sourceimpl ListDatasetsRequest
impl ListDatasetsRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = ListDatasetsRequest::new().set_project_id("example");Sourcepub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
Sets the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListDatasetsRequest::new().set_max_results(UInt32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
Sets or clears the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListDatasetsRequest::new().set_or_clear_max_results(Some(UInt32Value::default()/* use setters */));
let x = ListDatasetsRequest::new().set_or_clear_max_results(None::<UInt32Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListDatasetsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDatasetsRequest
impl Clone for ListDatasetsRequest
Sourcefn clone(&self) -> ListDatasetsRequest
fn clone(&self) -> ListDatasetsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDatasetsRequest
impl Debug for ListDatasetsRequest
Sourceimpl Default for ListDatasetsRequest
impl Default for ListDatasetsRequest
Sourcefn default() -> ListDatasetsRequest
fn default() -> ListDatasetsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListDatasetsRequest
impl Message for ListDatasetsRequest
Sourceimpl PartialEq for ListDatasetsRequest
impl PartialEq for ListDatasetsRequest
impl StructuralPartialEq for ListDatasetsRequest