#[non_exhaustive]pub struct ListFormatDataset {
pub kind: String,
pub id: String,
pub dataset_reference: Option<DatasetReference>,
pub labels: HashMap<String, String>,
pub friendly_name: Option<StringValue>,
pub location: String,
pub type: String,
pub catalog_source: Option<String>,
pub external_dataset_reference: Option<ExternalDatasetReference>,
/* private fields */
}Expand description
A dataset resource with only a subset of fields, to be returned in a list of datasets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringThe resource type. This property always returns the value “bigquery#dataset”
id: StringThe fully-qualified, unique, opaque ID of the dataset.
dataset_reference: Option<DatasetReference>The dataset reference. Use this property to access specific parts of the dataset’s ID, such as project ID or dataset ID.
labels: HashMap<String, String>The labels associated with this dataset. You can use these to organize and group your datasets.
friendly_name: Option<StringValue>An alternate name for the dataset. The friendly name is purely decorative in nature.
location: StringThe geographic location where the dataset resides.
type: StringOutput only. Same as type in Dataset.
The type of the dataset, one of:
- DEFAULT - only accessible by owner and authorized accounts,
- PUBLIC - accessible by everyone,
- LINKED - linked dataset,
- EXTERNAL - dataset with definition in external metadata catalog,
- BIGLAKE_ICEBERG - a Biglake dataset accessible through the Iceberg API,
- BIGLAKE_HIVE - a Biglake dataset accessible through the Hive API.
catalog_source: Option<String>Output only. The origin of the dataset, one of:
- (Unset) - Native BigQuery Dataset.
- BIGLAKE - Dataset is backed by a namespace stored natively in Biglake.
external_dataset_reference: Option<ExternalDatasetReference>Output only. Reference to a read-only external dataset defined in data catalogs outside of BigQuery. Filled out when the dataset type is EXTERNAL.
Implementations
Sourceimpl ListFormatDataset
impl ListFormatDataset
Sourcepub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sets the value of dataset_reference.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = ListFormatDataset::new().set_dataset_reference(DatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sets or clears the value of dataset_reference.
Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = ListFormatDataset::new().set_or_clear_dataset_reference(Some(DatasetReference::default()/* use setters */));
let x = ListFormatDataset::new().set_or_clear_dataset_reference(None::<DatasetReference>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = ListFormatDataset::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = ListFormatDataset::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = ListFormatDataset::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_catalog_source<T>(self, v: T) -> Self
pub fn set_catalog_source<T>(self, v: T) -> Self
Sets the value of catalog_source.
Example
let x = ListFormatDataset::new().set_catalog_source("example");Sourcepub fn set_or_clear_catalog_source<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_catalog_source<T>(self, v: Option<T>) -> Self
Sets or clears the value of catalog_source.
Example
let x = ListFormatDataset::new().set_or_clear_catalog_source(Some("example"));
let x = ListFormatDataset::new().set_or_clear_catalog_source(None::<String>);Sourcepub fn set_external_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<ExternalDatasetReference>,
pub fn set_external_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<ExternalDatasetReference>,
Sets the value of external_dataset_reference.
Example
use google_cloud_bigquery_v2::model::ExternalDatasetReference;
let x = ListFormatDataset::new().set_external_dataset_reference(ExternalDatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_external_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDatasetReference>,
pub fn set_or_clear_external_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDatasetReference>,
Sets or clears the value of external_dataset_reference.
Example
use google_cloud_bigquery_v2::model::ExternalDatasetReference;
let x = ListFormatDataset::new().set_or_clear_external_dataset_reference(Some(ExternalDatasetReference::default()/* use setters */));
let x = ListFormatDataset::new().set_or_clear_external_dataset_reference(None::<ExternalDatasetReference>);Trait Implementations
Sourceimpl Clone for ListFormatDataset
impl Clone for ListFormatDataset
Sourcefn clone(&self) -> ListFormatDataset
fn clone(&self) -> ListFormatDataset
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListFormatDataset
impl Debug for ListFormatDataset
Sourceimpl Default for ListFormatDataset
impl Default for ListFormatDataset
Sourcefn default() -> ListFormatDataset
fn default() -> ListFormatDataset
Sourceimpl Message for ListFormatDataset
impl Message for ListFormatDataset
Sourceimpl PartialEq for ListFormatDataset
impl PartialEq for ListFormatDataset
impl StructuralPartialEq for ListFormatDataset