ListFormatJob

Struct ListFormatJob 

#[non_exhaustive]
pub struct ListFormatJob { pub id: String, pub kind: String, pub job_reference: Option<JobReference>, pub state: String, pub error_result: Option<ErrorProto>, pub statistics: Option<JobStatistics>, pub configuration: Option<JobConfiguration>, pub status: Option<JobStatus>, pub user_email: String, pub principal_subject: String, /* private fields */ }
ListFormatJob is a partial projection of job information returned as part of a jobs.list response.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: String

Unique opaque ID of the job.

kind: String

The resource type.

job_reference: Option<JobReference>

Unique opaque ID of the job.

state: String

Running state of the job. When the state is DONE, errorResult can be checked to determine whether the job succeeded or failed.

error_result: Option<ErrorProto>

A result object that will be present only if the job has failed.

statistics: Option<JobStatistics>

Output only. Information about the job, including starting time and ending time of the job.

configuration: Option<JobConfiguration>

Required. Describes the job configuration.

status: Option<JobStatus>

[Full-projection-only] Describes the status of this job.

user_email: String

[Full-projection-only] Email address of the user who ran the job.

principal_subject: String

[Full-projection-only] String representation of identity of requesting party. Populated for both first- and third-party identities. Only present for APIs that support third-party identities.

Implementations

Source

impl ListFormatJob

pub fn new() -> Self

Creates a new default instance.

pub fn set_id<T: Into<String>>(self, v: T) -> Self

Sets the value of id.

Example
let x = ListFormatJob::new().set_id("example");
pub fn set_kind<T: Into<String>>(self, v: T) -> Self

Sets the value of kind.

Example
let x = ListFormatJob::new().set_kind("example");
pub fn set_job_reference<T>(self, v: T) -> Self
where T: Into<JobReference>,

Sets the value of job_reference.

Example
use google_cloud_bigquery_v2::model::JobReference;
let x = ListFormatJob::new().set_job_reference(JobReference::default()/* use setters */);
pub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Self
where T: Into<JobReference>,

Sets or clears the value of job_reference.

Example
use google_cloud_bigquery_v2::model::JobReference;
let x = ListFormatJob::new().set_or_clear_job_reference(Some(JobReference::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_job_reference(None::<JobReference>);
pub fn set_state<T: Into<String>>(self, v: T) -> Self

Sets the value of state.

Example
let x = ListFormatJob::new().set_state("example");
pub fn set_error_result<T>(self, v: T) -> Self
where T: Into<ErrorProto>,

Sets the value of error_result.

Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = ListFormatJob::new().set_error_result(ErrorProto::default()/* use setters */);
pub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Self
where T: Into<ErrorProto>,

Sets or clears the value of error_result.

Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = ListFormatJob::new().set_or_clear_error_result(Some(ErrorProto::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_error_result(None::<ErrorProto>);
pub fn set_statistics<T>(self, v: T) -> Self
where T: Into<JobStatistics>,

Sets the value of statistics.

Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = ListFormatJob::new().set_statistics(JobStatistics::default()/* use setters */);
pub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Self
where T: Into<JobStatistics>,

Sets or clears the value of statistics.

Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = ListFormatJob::new().set_or_clear_statistics(Some(JobStatistics::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_statistics(None::<JobStatistics>);
pub fn set_configuration<T>(self, v: T) -> Self

Sets the value of configuration.

Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = ListFormatJob::new().set_configuration(JobConfiguration::default()/* use setters */);
pub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Self

Sets or clears the value of configuration.

Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = ListFormatJob::new().set_or_clear_configuration(Some(JobConfiguration::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_configuration(None::<JobConfiguration>);
pub fn set_status<T>(self, v: T) -> Self
where T: Into<JobStatus>,

Sets the value of status.

Example
use google_cloud_bigquery_v2::model::JobStatus;
let x = ListFormatJob::new().set_status(JobStatus::default()/* use setters */);
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
where T: Into<JobStatus>,

Sets or clears the value of status.

Example
use google_cloud_bigquery_v2::model::JobStatus;
let x = ListFormatJob::new().set_or_clear_status(Some(JobStatus::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_status(None::<JobStatus>);
pub fn set_user_email<T: Into<String>>(self, v: T) -> Self

Sets the value of user_email.

Example
let x = ListFormatJob::new().set_user_email("example");
pub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self

Sets the value of principal_subject.

Example
let x = ListFormatJob::new().set_principal_subject("example");