#[non_exhaustive]pub struct ListFormatTable {Show 13 fields
pub kind: String,
pub id: String,
pub table_reference: Option<TableReference>,
pub friendly_name: Option<StringValue>,
pub type: String,
pub time_partitioning: Option<TimePartitioning>,
pub range_partitioning: Option<RangePartitioning>,
pub clustering: Option<Clustering>,
pub labels: HashMap<String, String>,
pub view: Option<ListFormatView>,
pub creation_time: i64,
pub expiration_time: i64,
pub require_partition_filter: Option<BoolValue>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringThe resource type.
id: StringAn opaque ID of the table.
table_reference: Option<TableReference>A reference uniquely identifying table.
friendly_name: Option<StringValue>The user-friendly name for this table.
type: StringThe type of table.
time_partitioning: Option<TimePartitioning>The time-based partitioning for this table.
range_partitioning: Option<RangePartitioning>The range partitioning for this table.
clustering: Option<Clustering>Clustering specification for this table, if configured.
labels: HashMap<String, String>The labels associated with this table. You can use these to organize and group your tables.
view: Option<ListFormatView>Additional details for a view.
creation_time: i64Output only. The time when this table was created, in milliseconds since the epoch.
expiration_time: i64The time when this table expires, in milliseconds since the epoch. If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed.
require_partition_filter: Option<BoolValue>Optional. If set to true, queries including this table must specify a partition filter. This filter is used for partition elimination.
Implementations
Sourceimpl ListFormatTable
impl ListFormatTable
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = ListFormatTable::new().set_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = ListFormatTable::new().set_or_clear_table_reference(Some(TableReference::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_table_reference(None::<TableReference>);Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = ListFormatTable::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = ListFormatTable::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_time_partitioning<T>(self, v: T) -> Selfwhere
T: Into<TimePartitioning>,
pub fn set_time_partitioning<T>(self, v: T) -> Selfwhere
T: Into<TimePartitioning>,
Sets the value of time_partitioning.
Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = ListFormatTable::new().set_time_partitioning(TimePartitioning::default()/* use setters */);Sourcepub fn set_or_clear_time_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimePartitioning>,
pub fn set_or_clear_time_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimePartitioning>,
Sets or clears the value of time_partitioning.
Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = ListFormatTable::new().set_or_clear_time_partitioning(Some(TimePartitioning::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_time_partitioning(None::<TimePartitioning>);Sourcepub fn set_range_partitioning<T>(self, v: T) -> Selfwhere
T: Into<RangePartitioning>,
pub fn set_range_partitioning<T>(self, v: T) -> Selfwhere
T: Into<RangePartitioning>,
Sets the value of range_partitioning.
Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = ListFormatTable::new().set_range_partitioning(RangePartitioning::default()/* use setters */);Sourcepub fn set_or_clear_range_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangePartitioning>,
pub fn set_or_clear_range_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangePartitioning>,
Sets or clears the value of range_partitioning.
Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = ListFormatTable::new().set_or_clear_range_partitioning(Some(RangePartitioning::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_range_partitioning(None::<RangePartitioning>);Sourcepub fn set_clustering<T>(self, v: T) -> Selfwhere
T: Into<Clustering>,
pub fn set_clustering<T>(self, v: T) -> Selfwhere
T: Into<Clustering>,
Sets the value of clustering.
Example
use google_cloud_bigquery_v2::model::Clustering;
let x = ListFormatTable::new().set_clustering(Clustering::default()/* use setters */);Sourcepub fn set_or_clear_clustering<T>(self, v: Option<T>) -> Selfwhere
T: Into<Clustering>,
pub fn set_or_clear_clustering<T>(self, v: Option<T>) -> Selfwhere
T: Into<Clustering>,
Sets or clears the value of clustering.
Example
use google_cloud_bigquery_v2::model::Clustering;
let x = ListFormatTable::new().set_or_clear_clustering(Some(Clustering::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_clustering(None::<Clustering>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_view<T>(self, v: T) -> Selfwhere
T: Into<ListFormatView>,
pub fn set_view<T>(self, v: T) -> Selfwhere
T: Into<ListFormatView>,
Sourcepub fn set_or_clear_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<ListFormatView>,
pub fn set_or_clear_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<ListFormatView>,
Sourcepub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_expiration_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_expiration_time<T: Into<i64>>(self, v: T) -> Self
Sets the value of expiration_time.
Example
let x = ListFormatTable::new().set_expiration_time(42);Sourcepub fn set_require_partition_filter<T>(self, v: T) -> Self
pub fn set_require_partition_filter<T>(self, v: T) -> Self
Sets the value of require_partition_filter.
Example
use wkt::BoolValue;
let x = ListFormatTable::new().set_require_partition_filter(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_require_partition_filter<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_require_partition_filter<T>(self, v: Option<T>) -> Self
Sets or clears the value of require_partition_filter.
Example
use wkt::BoolValue;
let x = ListFormatTable::new().set_or_clear_require_partition_filter(Some(BoolValue::default()/* use setters */));
let x = ListFormatTable::new().set_or_clear_require_partition_filter(None::<BoolValue>);Trait Implementations
Sourceimpl Clone for ListFormatTable
impl Clone for ListFormatTable
Sourcefn clone(&self) -> ListFormatTable
fn clone(&self) -> ListFormatTable
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListFormatTable
impl Debug for ListFormatTable
Sourceimpl Default for ListFormatTable
impl Default for ListFormatTable
Sourcefn default() -> ListFormatTable
fn default() -> ListFormatTable
Sourceimpl Message for ListFormatTable
impl Message for ListFormatTable
Sourceimpl PartialEq for ListFormatTable
impl PartialEq for ListFormatTable
impl StructuralPartialEq for ListFormatTable