#[non_exhaustive]pub struct ListJobsRequest {
pub project_id: String,
pub all_users: bool,
pub max_results: Option<Int32Value>,
pub min_creation_time: u64,
pub max_creation_time: Option<UInt64Value>,
pub page_token: String,
pub projection: Projection,
pub state_filter: Vec<StateFilter>,
pub parent_job_id: String,
/* private fields */
}Expand description
Describes the format of the list jobs request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringProject ID of the jobs to list.
all_users: boolWhether to display jobs owned by all users in the project. Default False.
max_results: Option<Int32Value>The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.
min_creation_time: u64Min value for job creation time, in milliseconds since the POSIX epoch. If set, only jobs created after or at this timestamp are returned.
max_creation_time: Option<UInt64Value>Max value for job creation time, in milliseconds since the POSIX epoch. If set, only jobs created before or at this timestamp are returned.
page_token: StringPage token, returned by a previous call, to request the next page of results.
projection: ProjectionRestrict information returned to a set of selected fields
state_filter: Vec<StateFilter>Filter for job state
parent_job_id: StringIf set, show only child jobs of the specified parent. Otherwise, show all top-level jobs.
Implementations
Sourceimpl ListJobsRequest
impl ListJobsRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_all_users<T: Into<bool>>(self, v: T) -> Self
pub fn set_all_users<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
pub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
Sets the value of max_results.
Example
use wkt::Int32Value;
let x = ListJobsRequest::new().set_max_results(Int32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
Sets or clears the value of max_results.
Example
use wkt::Int32Value;
let x = ListJobsRequest::new().set_or_clear_max_results(Some(Int32Value::default()/* use setters */));
let x = ListJobsRequest::new().set_or_clear_max_results(None::<Int32Value>);Sourcepub fn set_min_creation_time<T: Into<u64>>(self, v: T) -> Self
pub fn set_min_creation_time<T: Into<u64>>(self, v: T) -> Self
Sets the value of min_creation_time.
Example
let x = ListJobsRequest::new().set_min_creation_time(42_u32);Sourcepub fn set_max_creation_time<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_max_creation_time<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
Sets the value of max_creation_time.
Example
use wkt::UInt64Value;
let x = ListJobsRequest::new().set_max_creation_time(UInt64Value::default()/* use setters */);Sourcepub fn set_or_clear_max_creation_time<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_or_clear_max_creation_time<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
Sets or clears the value of max_creation_time.
Example
use wkt::UInt64Value;
let x = ListJobsRequest::new().set_or_clear_max_creation_time(Some(UInt64Value::default()/* use setters */));
let x = ListJobsRequest::new().set_or_clear_max_creation_time(None::<UInt64Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_projection<T: Into<Projection>>(self, v: T) -> Self
pub fn set_projection<T: Into<Projection>>(self, v: T) -> Self
Sets the value of projection.
Example
use google_cloud_bigquery_v2::model::list_jobs_request::Projection;
let x0 = ListJobsRequest::new().set_projection(Projection::Full);Sourcepub fn set_state_filter<T, V>(self, v: T) -> Self
pub fn set_state_filter<T, V>(self, v: T) -> Self
Sets the value of state_filter.
Example
use google_cloud_bigquery_v2::model::list_jobs_request::StateFilter;
let x = ListJobsRequest::new().set_state_filter([
StateFilter::Pending,
StateFilter::Running,
]);Sourcepub fn set_parent_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_parent_job_id<T: Into<String>>(self, v: T) -> Self
Sets the value of parent_job_id.
Example
let x = ListJobsRequest::new().set_parent_job_id("example");Trait Implementations
Sourceimpl Clone for ListJobsRequest
impl Clone for ListJobsRequest
Sourcefn clone(&self) -> ListJobsRequest
fn clone(&self) -> ListJobsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListJobsRequest
impl Debug for ListJobsRequest
Sourceimpl Default for ListJobsRequest
impl Default for ListJobsRequest
Sourcefn default() -> ListJobsRequest
fn default() -> ListJobsRequest
Sourceimpl Message for ListJobsRequest
impl Message for ListJobsRequest
Sourceimpl PartialEq for ListJobsRequest
impl PartialEq for ListJobsRequest
impl StructuralPartialEq for ListJobsRequest