#[non_exhaustive]pub struct ListModelsRequest {
pub project_id: String,
pub dataset_id: String,
pub max_results: Option<UInt32Value>,
pub page_token: String,
/* private fields */
}Expand description
Request format for listing BigQuery ML models.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the models to list.
dataset_id: StringRequired. Dataset ID of the models to list.
max_results: Option<UInt32Value>The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.
page_token: StringPage token, returned by a previous call to request the next page of results
Implementations
Sourceimpl ListModelsRequest
impl ListModelsRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
Sets the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListModelsRequest::new().set_max_results(UInt32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
Sets or clears the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListModelsRequest::new().set_or_clear_max_results(Some(UInt32Value::default()/* use setters */));
let x = ListModelsRequest::new().set_or_clear_max_results(None::<UInt32Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self