#[non_exhaustive]pub struct ListRoutinesRequest {
pub project_id: String,
pub dataset_id: String,
pub max_results: Option<UInt32Value>,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Describes the format for listing routines.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the routines to list
dataset_id: StringRequired. Dataset ID of the routines to list
max_results: Option<UInt32Value>The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.
page_token: StringPage token, returned by a previous call, to request the next page of results
filter: StringIf set, then only the Routines matching this filter are returned.
The supported format is routineType:{RoutineType}, where {RoutineType}
is a RoutineType enum. For example: routineType:SCALAR_FUNCTION.
Implementations
Sourceimpl ListRoutinesRequest
impl ListRoutinesRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = ListRoutinesRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = ListRoutinesRequest::new().set_dataset_id("example");Sourcepub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
Sets the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListRoutinesRequest::new().set_max_results(UInt32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
Sets or clears the value of max_results.
Example
ⓘ
use wkt::UInt32Value;
let x = ListRoutinesRequest::new().set_or_clear_max_results(Some(UInt32Value::default()/* use setters */));
let x = ListRoutinesRequest::new().set_or_clear_max_results(None::<UInt32Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListRoutinesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListRoutinesRequest
impl Clone for ListRoutinesRequest
Sourcefn clone(&self) -> ListRoutinesRequest
fn clone(&self) -> ListRoutinesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRoutinesRequest
impl Debug for ListRoutinesRequest
Sourceimpl Default for ListRoutinesRequest
impl Default for ListRoutinesRequest
Sourcefn default() -> ListRoutinesRequest
fn default() -> ListRoutinesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListRoutinesRequest
impl Message for ListRoutinesRequest
Sourceimpl PartialEq for ListRoutinesRequest
impl PartialEq for ListRoutinesRequest
impl StructuralPartialEq for ListRoutinesRequest