#[non_exhaustive]pub struct ListRoutinesResponse {
pub routines: Vec<Routine>,
pub next_page_token: String,
/* private fields */
}Expand description
Describes the format of a single result page when listing routines.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.routines: Vec<Routine>Routines in the requested dataset. Unless read_mask is set in the request, only the following fields are populated: etag, project_id, dataset_id, routine_id, routine_type, creation_time, last_modified_time, language, and remote_function_options.
next_page_token: StringA token to request the next page of results.
Implementations
Sourceimpl ListRoutinesResponse
impl ListRoutinesResponse
Sourcepub fn set_routines<T, V>(self, v: T) -> Self
pub fn set_routines<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListRoutinesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListRoutinesResponse
impl Clone for ListRoutinesResponse
Sourcefn clone(&self) -> ListRoutinesResponse
fn clone(&self) -> ListRoutinesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRoutinesResponse
impl Debug for ListRoutinesResponse
Sourceimpl Default for ListRoutinesResponse
impl Default for ListRoutinesResponse
Sourcefn default() -> ListRoutinesResponse
fn default() -> ListRoutinesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListRoutinesResponse
impl Message for ListRoutinesResponse
Sourceimpl PartialEq for ListRoutinesResponse
impl PartialEq for ListRoutinesResponse
impl StructuralPartialEq for ListRoutinesResponse