#[non_exhaustive]pub struct ListRowAccessPoliciesRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub page_token: String,
pub page_size: i32,
/* private fields */
}Expand description
Request message for the ListRowAccessPolicies method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the row access policies to list.
dataset_id: StringRequired. Dataset ID of row access policies to list.
table_id: StringRequired. Table ID of the table to list row access policies.
page_token: StringPage token, returned by a previous call, to request the next page of results.
page_size: i32The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.
Implementations
Sourceimpl ListRowAccessPoliciesRequest
impl ListRowAccessPoliciesRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = ListRowAccessPoliciesRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = ListRowAccessPoliciesRequest::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListRowAccessPoliciesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListRowAccessPoliciesRequest
impl Clone for ListRowAccessPoliciesRequest
Sourcefn clone(&self) -> ListRowAccessPoliciesRequest
fn clone(&self) -> ListRowAccessPoliciesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRowAccessPoliciesRequest
impl Debug for ListRowAccessPoliciesRequest
Sourceimpl Default for ListRowAccessPoliciesRequest
impl Default for ListRowAccessPoliciesRequest
Sourcefn default() -> ListRowAccessPoliciesRequest
fn default() -> ListRowAccessPoliciesRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListRowAccessPoliciesRequest