#[non_exhaustive]pub struct MaterializedView {
pub table_reference: Option<TableReference>,
pub chosen: Option<bool>,
pub estimated_bytes_saved: Option<i64>,
pub rejected_reason: Option<RejectedReason>,
/* private fields */
}Expand description
A materialized view considered for a query job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_reference: Option<TableReference>The candidate materialized view.
chosen: Option<bool>Whether the materialized view is chosen for the query.
A materialized view can be chosen to rewrite multiple parts of the same query. If a materialized view is chosen to rewrite any part of the query, then this field is true, even if the materialized view was not chosen to rewrite others parts.
estimated_bytes_saved: Option<i64>If present, specifies a best-effort estimation of the bytes saved by using the materialized view rather than its base tables.
rejected_reason: Option<RejectedReason>If present, specifies the reason why the materialized view was not chosen for the query.
Implementations
Sourceimpl MaterializedView
impl MaterializedView
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = MaterializedView::new().set_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = MaterializedView::new().set_or_clear_table_reference(Some(TableReference::default()/* use setters */));
let x = MaterializedView::new().set_or_clear_table_reference(None::<TableReference>);Sourcepub fn set_chosen<T>(self, v: T) -> Self
pub fn set_chosen<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_chosen<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_chosen<T>(self, v: Option<T>) -> Self
Sourcepub fn set_estimated_bytes_saved<T>(self, v: T) -> Self
pub fn set_estimated_bytes_saved<T>(self, v: T) -> Self
Sets the value of estimated_bytes_saved.
Example
let x = MaterializedView::new().set_estimated_bytes_saved(42);Sourcepub fn set_or_clear_estimated_bytes_saved<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_estimated_bytes_saved<T>(self, v: Option<T>) -> Self
Sets or clears the value of estimated_bytes_saved.
Example
let x = MaterializedView::new().set_or_clear_estimated_bytes_saved(Some(42));
let x = MaterializedView::new().set_or_clear_estimated_bytes_saved(None::<i32>);Sourcepub fn set_rejected_reason<T>(self, v: T) -> Selfwhere
T: Into<RejectedReason>,
pub fn set_rejected_reason<T>(self, v: T) -> Selfwhere
T: Into<RejectedReason>,
Sets the value of rejected_reason.
Example
use google_cloud_bigquery_v2::model::materialized_view::RejectedReason;
let x0 = MaterializedView::new().set_rejected_reason(RejectedReason::NoData);
let x1 = MaterializedView::new().set_rejected_reason(RejectedReason::Cost);
let x2 = MaterializedView::new().set_rejected_reason(RejectedReason::BaseTableTruncated);Sourcepub fn set_or_clear_rejected_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<RejectedReason>,
pub fn set_or_clear_rejected_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<RejectedReason>,
Sets or clears the value of rejected_reason.
Example
use google_cloud_bigquery_v2::model::materialized_view::RejectedReason;
let x0 = MaterializedView::new().set_or_clear_rejected_reason(Some(RejectedReason::NoData));
let x1 = MaterializedView::new().set_or_clear_rejected_reason(Some(RejectedReason::Cost));
let x2 = MaterializedView::new().set_or_clear_rejected_reason(Some(RejectedReason::BaseTableTruncated));
let x_none = MaterializedView::new().set_or_clear_rejected_reason(None::<RejectedReason>);Trait Implementations
Sourceimpl Clone for MaterializedView
impl Clone for MaterializedView
Sourcefn clone(&self) -> MaterializedView
fn clone(&self) -> MaterializedView
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MaterializedView
impl Debug for MaterializedView
Sourceimpl Default for MaterializedView
impl Default for MaterializedView
Sourcefn default() -> MaterializedView
fn default() -> MaterializedView
Sourceimpl Message for MaterializedView
impl Message for MaterializedView
Sourceimpl PartialEq for MaterializedView
impl PartialEq for MaterializedView
impl StructuralPartialEq for MaterializedView