#[non_exhaustive]pub struct MaterializedViewStatistics {
pub materialized_view: Vec<MaterializedView>,
/* private fields */
}Expand description
Statistics of materialized views considered in a query job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.materialized_view: Vec<MaterializedView>Materialized views considered for the query job. Only certain materialized views are used. For a detailed list, see the child message.
If many materialized views are considered, then the list might be incomplete.
Implementations
Sourceimpl MaterializedViewStatistics
impl MaterializedViewStatistics
Sourcepub fn set_materialized_view<T, V>(self, v: T) -> Self
pub fn set_materialized_view<T, V>(self, v: T) -> Self
Sets the value of materialized_view.
Example
ⓘ
use google_cloud_bigquery_v2::model::MaterializedView;
let x = MaterializedViewStatistics::new()
.set_materialized_view([
MaterializedView::default()/* use setters */,
MaterializedView::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for MaterializedViewStatistics
impl Clone for MaterializedViewStatistics
Sourcefn clone(&self) -> MaterializedViewStatistics
fn clone(&self) -> MaterializedViewStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterializedViewStatistics
impl Debug for MaterializedViewStatistics
Sourceimpl Default for MaterializedViewStatistics
impl Default for MaterializedViewStatistics
Sourcefn default() -> MaterializedViewStatistics
fn default() -> MaterializedViewStatistics
Returns the “default value” for a type. Read more
Sourceimpl Message for MaterializedViewStatistics
impl Message for MaterializedViewStatistics
impl StructuralPartialEq for MaterializedViewStatistics