#[non_exhaustive]pub struct MaterializedViewStatus {
pub refresh_watermark: Option<Timestamp>,
pub last_refresh_status: Option<ErrorProto>,
/* private fields */
}Expand description
Status of a materialized view. The last refresh timestamp status is omitted here, but is present in the MaterializedViewDefinition message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.refresh_watermark: Option<Timestamp>Output only. Refresh watermark of materialized view. The base tables’ data were collected into the materialized view cache until this time.
last_refresh_status: Option<ErrorProto>Output only. Error result of the last automatic refresh. If present, indicates that the last automatic refresh was unsuccessful.
Implementations
Sourceimpl MaterializedViewStatus
impl MaterializedViewStatus
Sourcepub fn set_refresh_watermark<T>(self, v: T) -> Self
pub fn set_refresh_watermark<T>(self, v: T) -> Self
Sets the value of refresh_watermark.
Example
ⓘ
use wkt::Timestamp;
let x = MaterializedViewStatus::new().set_refresh_watermark(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_refresh_watermark<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_refresh_watermark<T>(self, v: Option<T>) -> Self
Sets or clears the value of refresh_watermark.
Example
ⓘ
use wkt::Timestamp;
let x = MaterializedViewStatus::new().set_or_clear_refresh_watermark(Some(Timestamp::default()/* use setters */));
let x = MaterializedViewStatus::new().set_or_clear_refresh_watermark(None::<Timestamp>);Sourcepub fn set_last_refresh_status<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_last_refresh_status<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
Sets the value of last_refresh_status.
Example
ⓘ
use google_cloud_bigquery_v2::model::ErrorProto;
let x = MaterializedViewStatus::new().set_last_refresh_status(ErrorProto::default()/* use setters */);Sourcepub fn set_or_clear_last_refresh_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_or_clear_last_refresh_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
Sets or clears the value of last_refresh_status.
Example
ⓘ
use google_cloud_bigquery_v2::model::ErrorProto;
let x = MaterializedViewStatus::new().set_or_clear_last_refresh_status(Some(ErrorProto::default()/* use setters */));
let x = MaterializedViewStatus::new().set_or_clear_last_refresh_status(None::<ErrorProto>);Trait Implementations
Sourceimpl Clone for MaterializedViewStatus
impl Clone for MaterializedViewStatus
Sourcefn clone(&self) -> MaterializedViewStatus
fn clone(&self) -> MaterializedViewStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterializedViewStatus
impl Debug for MaterializedViewStatus
Sourceimpl Default for MaterializedViewStatus
impl Default for MaterializedViewStatus
Sourcefn default() -> MaterializedViewStatus
fn default() -> MaterializedViewStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for MaterializedViewStatus
impl Message for MaterializedViewStatus
Sourceimpl PartialEq for MaterializedViewStatus
impl PartialEq for MaterializedViewStatus
impl StructuralPartialEq for MaterializedViewStatus