#[non_exhaustive]pub struct MetadataCacheStalenessInsight {
pub avg_previous_staleness_ms: Option<Duration>,
pub staleness_percentage_increase: f64,
/* private fields */
}Expand description
Column Metadata Index staleness detailed infnormation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.avg_previous_staleness_ms: Option<Duration>Output only. Average column metadata index staleness of previous runs with the same query hash.
staleness_percentage_increase: f64Output only. The percent increase in staleness between the current job and the average staleness of previous jobs with the same query hash.
Implementations
Sourceimpl MetadataCacheStalenessInsight
impl MetadataCacheStalenessInsight
Sourcepub fn set_avg_previous_staleness_ms<T>(self, v: T) -> Self
pub fn set_avg_previous_staleness_ms<T>(self, v: T) -> Self
Sets the value of avg_previous_staleness_ms.
Example
ⓘ
use wkt::Duration;
let x = MetadataCacheStalenessInsight::new().set_avg_previous_staleness_ms(Duration::default()/* use setters */);Sourcepub fn set_or_clear_avg_previous_staleness_ms<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_avg_previous_staleness_ms<T>(self, v: Option<T>) -> Self
Sets or clears the value of avg_previous_staleness_ms.
Example
ⓘ
use wkt::Duration;
let x = MetadataCacheStalenessInsight::new().set_or_clear_avg_previous_staleness_ms(Some(Duration::default()/* use setters */));
let x = MetadataCacheStalenessInsight::new().set_or_clear_avg_previous_staleness_ms(None::<Duration>);Sourcepub fn set_staleness_percentage_increase<T: Into<f64>>(self, v: T) -> Self
pub fn set_staleness_percentage_increase<T: Into<f64>>(self, v: T) -> Self
Sets the value of staleness_percentage_increase.
Example
ⓘ
let x = MetadataCacheStalenessInsight::new().set_staleness_percentage_increase(42.0);Trait Implementations
Sourceimpl Clone for MetadataCacheStalenessInsight
impl Clone for MetadataCacheStalenessInsight
Sourcefn clone(&self) -> MetadataCacheStalenessInsight
fn clone(&self) -> MetadataCacheStalenessInsight
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for MetadataCacheStalenessInsight
impl Default for MetadataCacheStalenessInsight
Sourcefn default() -> MetadataCacheStalenessInsight
fn default() -> MetadataCacheStalenessInsight
Returns the “default value” for a type. Read more
impl StructuralPartialEq for MetadataCacheStalenessInsight