Model

Struct Model 

#[non_exhaustive]
pub struct Model {
Show 20 fields pub etag: String, pub model_reference: Option<ModelReference>, pub creation_time: i64, pub last_modified_time: i64, pub description: String, pub friendly_name: String, pub labels: HashMap<String, String>, pub expiration_time: i64, pub location: String, pub encryption_configuration: Option<EncryptionConfiguration>, pub model_type: ModelType, pub training_runs: Vec<TrainingRun>, pub feature_columns: Vec<StandardSqlField>, pub label_columns: Vec<StandardSqlField>, pub transform_columns: Vec<TransformColumn>, pub hparam_search_spaces: Option<HparamSearchSpaces>, pub default_trial_id: i64, pub hparam_trials: Vec<HparamTuningTrial>, pub optimal_trial_ids: Vec<i64>, pub remote_model_info: Option<RemoteModelInfo>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
etag: String

Output only. A hash of this resource.

model_reference: Option<ModelReference>

Required. Unique identifier for this model.

creation_time: i64

Output only. The time when this model was created, in millisecs since the epoch.

last_modified_time: i64

Output only. The time when this model was last modified, in millisecs since the epoch.

description: String

Optional. A user-friendly description of this model.

friendly_name: String

Optional. A descriptive name for this model.

labels: HashMap<String, String>

The labels associated with this model. You can use these to organize and group your models. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter and each label in the list must have a different key.

expiration_time: i64

Optional. The time when this model expires, in milliseconds since the epoch. If not present, the model will persist indefinitely. Expired models will be deleted and their storage reclaimed. The defaultTableExpirationMs property of the encapsulating dataset can be used to set a default expirationTime on newly created models.

location: String

Output only. The geographic location where the model resides. This value is inherited from the dataset.

encryption_configuration: Option<EncryptionConfiguration>

Custom encryption configuration (e.g., Cloud KMS keys). This shows the encryption configuration of the model data while stored in BigQuery storage. This field can be used with PatchModel to update encryption key for an already encrypted model.

model_type: ModelType

Output only. Type of the model resource.

training_runs: Vec<TrainingRun>

Information for all training runs in increasing order of start_time.

feature_columns: Vec<StandardSqlField>

Output only. Input feature columns for the model inference. If the model is trained with TRANSFORM clause, these are the input of the TRANSFORM clause.

label_columns: Vec<StandardSqlField>

Output only. Label columns that were used to train this model. The output of the model will have a “predicted_” prefix to these columns.

transform_columns: Vec<TransformColumn>

Output only. This field will be populated if a TRANSFORM clause was used to train a model. TRANSFORM clause (if used) takes feature_columns as input and outputs transform_columns. transform_columns then are used to train the model.

hparam_search_spaces: Option<HparamSearchSpaces>

Output only. All hyperparameter search spaces in this model.

default_trial_id: i64

Output only. The default trial_id to use in TVFs when the trial_id is not passed in. For single-objective hyperparameter tuning models, this is the best trial ID. For multi-objective hyperparameter tuning models, this is the smallest trial ID among all Pareto optimal trials.

hparam_trials: Vec<HparamTuningTrial>

Output only. Trials of a hyperparameter tuning model sorted by trial_id.

optimal_trial_ids: Vec<i64>

Output only. For single-objective hyperparameter tuning models, it only contains the best trial. For multi-objective hyperparameter tuning models, it contains all Pareto optimal trials sorted by trial_id.

remote_model_info: Option<RemoteModelInfo>

Output only. Remote model info

Implementations

Source

impl Model

pub fn new() -> Self

Creates a new default instance.

pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = Model::new().set_etag("example");
pub fn set_model_reference<T>(self, v: T) -> Self
where T: Into<ModelReference>,

Sets the value of model_reference.

Example
use google_cloud_bigquery_v2::model::ModelReference;
let x = Model::new().set_model_reference(ModelReference::default()/* use setters */);
pub fn set_or_clear_model_reference<T>(self, v: Option<T>) -> Self
where T: Into<ModelReference>,

Sets or clears the value of model_reference.

Example
use google_cloud_bigquery_v2::model::ModelReference;
let x = Model::new().set_or_clear_model_reference(Some(ModelReference::default()/* use setters */));
let x = Model::new().set_or_clear_model_reference(None::<ModelReference>);
pub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of creation_time.

Example
let x = Model::new().set_creation_time(42);
pub fn set_last_modified_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of last_modified_time.

Example
let x = Model::new().set_last_modified_time(42);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = Model::new().set_description("example");
pub fn set_friendly_name<T: Into<String>>(self, v: T) -> Self

Sets the value of friendly_name.

Example
let x = Model::new().set_friendly_name("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Model::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_expiration_time<T: Into<i64>>(self, v: T) -> Self

Sets the value of expiration_time.

Example
let x = Model::new().set_expiration_time(42);
pub fn set_location<T: Into<String>>(self, v: T) -> Self

Sets the value of location.

Example
let x = Model::new().set_location("example");
pub fn set_encryption_configuration<T>(self, v: T) -> Self

Sets the value of encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Model::new().set_encryption_configuration(EncryptionConfiguration::default()/* use setters */);
pub fn set_or_clear_encryption_configuration<T>(self, v: Option<T>) -> Self

Sets or clears the value of encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Model::new().set_or_clear_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = Model::new().set_or_clear_encryption_configuration(None::<EncryptionConfiguration>);
pub fn set_model_type<T: Into<ModelType>>(self, v: T) -> Self

Sets the value of model_type.

Example
use google_cloud_bigquery_v2::model::model::ModelType;
let x0 = Model::new().set_model_type(ModelType::LinearRegression);
let x1 = Model::new().set_model_type(ModelType::LogisticRegression);
let x2 = Model::new().set_model_type(ModelType::Kmeans);
pub fn set_training_runs<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TrainingRun>,

Sets the value of training_runs.

Example
use google_cloud_bigquery_v2::model::model::TrainingRun;
let x = Model::new()
    .set_training_runs([
        TrainingRun::default()/* use setters */,
        TrainingRun::default()/* use (different) setters */,
    ]);
pub fn set_feature_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<StandardSqlField>,

Sets the value of feature_columns.

Example
use google_cloud_bigquery_v2::model::StandardSqlField;
let x = Model::new()
    .set_feature_columns([
        StandardSqlField::default()/* use setters */,
        StandardSqlField::default()/* use (different) setters */,
    ]);
pub fn set_label_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<StandardSqlField>,

Sets the value of label_columns.

Example
use google_cloud_bigquery_v2::model::StandardSqlField;
let x = Model::new()
    .set_label_columns([
        StandardSqlField::default()/* use setters */,
        StandardSqlField::default()/* use (different) setters */,
    ]);
pub fn set_transform_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TransformColumn>,

Sets the value of transform_columns.

Example
use google_cloud_bigquery_v2::model::TransformColumn;
let x = Model::new()
    .set_transform_columns([
        TransformColumn::default()/* use setters */,
        TransformColumn::default()/* use (different) setters */,
    ]);
pub fn set_hparam_search_spaces<T>(self, v: T) -> Self

Sets the value of hparam_search_spaces.

Example
use google_cloud_bigquery_v2::model::model::HparamSearchSpaces;
let x = Model::new().set_hparam_search_spaces(HparamSearchSpaces::default()/* use setters */);
pub fn set_or_clear_hparam_search_spaces<T>(self, v: Option<T>) -> Self

Sets or clears the value of hparam_search_spaces.

Example
use google_cloud_bigquery_v2::model::model::HparamSearchSpaces;
let x = Model::new().set_or_clear_hparam_search_spaces(Some(HparamSearchSpaces::default()/* use setters */));
let x = Model::new().set_or_clear_hparam_search_spaces(None::<HparamSearchSpaces>);
pub fn set_default_trial_id<T: Into<i64>>(self, v: T) -> Self

Sets the value of default_trial_id.

Example
let x = Model::new().set_default_trial_id(42);
pub fn set_hparam_trials<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<HparamTuningTrial>,

Sets the value of hparam_trials.

Example
use google_cloud_bigquery_v2::model::model::HparamTuningTrial;
let x = Model::new()
    .set_hparam_trials([
        HparamTuningTrial::default()/* use setters */,
        HparamTuningTrial::default()/* use (different) setters */,
    ]);
pub fn set_optimal_trial_ids<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<i64>,

Sets the value of optimal_trial_ids.

Example
let x = Model::new().set_optimal_trial_ids([1, 2, 3]);
pub fn set_remote_model_info<T>(self, v: T) -> Self

Sets the value of remote_model_info.

Example
use google_cloud_bigquery_v2::model::RemoteModelInfo;
let x = Model::new().set_remote_model_info(RemoteModelInfo::default()/* use setters */);
pub fn set_or_clear_remote_model_info<T>(self, v: Option<T>) -> Self

Sets or clears the value of remote_model_info.

Example
use google_cloud_bigquery_v2::model::RemoteModelInfo;
let x = Model::new().set_or_clear_remote_model_info(Some(RemoteModelInfo::default()/* use setters */));
let x = Model::new().set_or_clear_remote_model_info(None::<RemoteModelInfo>);