#[non_exhaustive]pub struct ParquetOptions {
pub enum_as_string: Option<BoolValue>,
pub enable_list_inference: Option<BoolValue>,
pub map_target_type: MapTargetType,
/* private fields */
}Expand description
Parquet Options for load and make external tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enum_as_string: Option<BoolValue>Optional. Indicates whether to infer Parquet ENUM logical type as STRING instead of BYTES by default.
enable_list_inference: Option<BoolValue>Optional. Indicates whether to use schema inference specifically for Parquet LIST logical type.
map_target_type: MapTargetTypeOptional. Indicates how to represent a Parquet map if present.
Implementations
Sourceimpl ParquetOptions
impl ParquetOptions
Sourcepub fn set_enum_as_string<T>(self, v: T) -> Self
pub fn set_enum_as_string<T>(self, v: T) -> Self
Sets the value of enum_as_string.
Example
ⓘ
use wkt::BoolValue;
let x = ParquetOptions::new().set_enum_as_string(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_enum_as_string<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enum_as_string<T>(self, v: Option<T>) -> Self
Sets or clears the value of enum_as_string.
Example
ⓘ
use wkt::BoolValue;
let x = ParquetOptions::new().set_or_clear_enum_as_string(Some(BoolValue::default()/* use setters */));
let x = ParquetOptions::new().set_or_clear_enum_as_string(None::<BoolValue>);Sourcepub fn set_enable_list_inference<T>(self, v: T) -> Self
pub fn set_enable_list_inference<T>(self, v: T) -> Self
Sets the value of enable_list_inference.
Example
ⓘ
use wkt::BoolValue;
let x = ParquetOptions::new().set_enable_list_inference(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_enable_list_inference<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_list_inference<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_list_inference.
Example
ⓘ
use wkt::BoolValue;
let x = ParquetOptions::new().set_or_clear_enable_list_inference(Some(BoolValue::default()/* use setters */));
let x = ParquetOptions::new().set_or_clear_enable_list_inference(None::<BoolValue>);Sourcepub fn set_map_target_type<T: Into<MapTargetType>>(self, v: T) -> Self
pub fn set_map_target_type<T: Into<MapTargetType>>(self, v: T) -> Self
Sets the value of map_target_type.
Example
ⓘ
use google_cloud_bigquery_v2::model::MapTargetType;
let x0 = ParquetOptions::new().set_map_target_type(MapTargetType::ArrayOfStruct);Trait Implementations
Sourceimpl Clone for ParquetOptions
impl Clone for ParquetOptions
Sourcefn clone(&self) -> ParquetOptions
fn clone(&self) -> ParquetOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParquetOptions
impl Debug for ParquetOptions
Sourceimpl Default for ParquetOptions
impl Default for ParquetOptions
Sourcefn default() -> ParquetOptions
fn default() -> ParquetOptions
Returns the “default value” for a type. Read more
Sourceimpl Message for ParquetOptions
impl Message for ParquetOptions
Sourceimpl PartialEq for ParquetOptions
impl PartialEq for ParquetOptions
impl StructuralPartialEq for ParquetOptions