#[non_exhaustive]pub struct PartitioningDefinition {
pub partitioned_column: Vec<PartitionedColumn>,
/* private fields */
}Expand description
The partitioning information, which includes managed table, external table and metastore partitioned table partition information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.partitioned_column: Vec<PartitionedColumn>Optional. Details about each partitioning column. This field is output only for all partitioning types other than metastore partitioned tables. BigQuery native tables only support 1 partitioning column. Other table types may support 0, 1 or more partitioning columns. For metastore partitioned tables, the order must match the definition order in the Hive Metastore, where it must match the physical layout of the table. For example,
CREATE TABLE a_table(id BIGINT, name STRING) PARTITIONED BY (city STRING, state STRING).
In this case the values must be [‘city’, ‘state’] in that order.
Implementations
Sourceimpl PartitioningDefinition
impl PartitioningDefinition
Sourcepub fn set_partitioned_column<T, V>(self, v: T) -> Self
pub fn set_partitioned_column<T, V>(self, v: T) -> Self
Sets the value of partitioned_column.
Example
use google_cloud_bigquery_v2::model::PartitionedColumn;
let x = PartitioningDefinition::new()
.set_partitioned_column([
PartitionedColumn::default()/* use setters */,
PartitionedColumn::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for PartitioningDefinition
impl Clone for PartitioningDefinition
Sourcefn clone(&self) -> PartitioningDefinition
fn clone(&self) -> PartitioningDefinition
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PartitioningDefinition
impl Debug for PartitioningDefinition
Sourceimpl Default for PartitioningDefinition
impl Default for PartitioningDefinition
Sourcefn default() -> PartitioningDefinition
fn default() -> PartitioningDefinition
Sourceimpl Message for PartitioningDefinition
impl Message for PartitioningDefinition
Sourceimpl PartialEq for PartitioningDefinition
impl PartialEq for PartitioningDefinition
impl StructuralPartialEq for PartitioningDefinition