#[non_exhaustive]pub struct PerformanceInsights {
pub avg_previous_execution_ms: i64,
pub stage_performance_standalone_insights: Vec<StagePerformanceStandaloneInsight>,
pub stage_performance_change_insights: Vec<StagePerformanceChangeInsight>,
pub table_change_insights: Vec<TableChangeInsight>,
/* private fields */
}Expand description
Performance insights for the job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.avg_previous_execution_ms: i64Output only. Average execution ms of previous runs. Indicates the job ran slow compared to previous executions. To find previous executions, use INFORMATION_SCHEMA tables and filter jobs with same query hash.
stage_performance_standalone_insights: Vec<StagePerformanceStandaloneInsight>Output only. Standalone query stage performance insights, for exploring potential improvements.
stage_performance_change_insights: Vec<StagePerformanceChangeInsight>Output only. Query stage performance insights compared to previous runs, for diagnosing performance regression.
table_change_insights: Vec<TableChangeInsight>Output only. Performance insights for table-level attributes that changed compared to previous runs.
Implementations
Sourceimpl PerformanceInsights
impl PerformanceInsights
Sourcepub fn set_avg_previous_execution_ms<T: Into<i64>>(self, v: T) -> Self
pub fn set_avg_previous_execution_ms<T: Into<i64>>(self, v: T) -> Self
Sets the value of avg_previous_execution_ms.
Example
ⓘ
let x = PerformanceInsights::new().set_avg_previous_execution_ms(42);Sourcepub fn set_stage_performance_standalone_insights<T, V>(self, v: T) -> Self
pub fn set_stage_performance_standalone_insights<T, V>(self, v: T) -> Self
Sets the value of stage_performance_standalone_insights.
Example
ⓘ
use google_cloud_bigquery_v2::model::StagePerformanceStandaloneInsight;
let x = PerformanceInsights::new()
.set_stage_performance_standalone_insights([
StagePerformanceStandaloneInsight::default()/* use setters */,
StagePerformanceStandaloneInsight::default()/* use (different) setters */,
]);Sourcepub fn set_stage_performance_change_insights<T, V>(self, v: T) -> Self
pub fn set_stage_performance_change_insights<T, V>(self, v: T) -> Self
Sets the value of stage_performance_change_insights.
Example
ⓘ
use google_cloud_bigquery_v2::model::StagePerformanceChangeInsight;
let x = PerformanceInsights::new()
.set_stage_performance_change_insights([
StagePerformanceChangeInsight::default()/* use setters */,
StagePerformanceChangeInsight::default()/* use (different) setters */,
]);Sourcepub fn set_table_change_insights<T, V>(self, v: T) -> Self
pub fn set_table_change_insights<T, V>(self, v: T) -> Self
Sets the value of table_change_insights.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableChangeInsight;
let x = PerformanceInsights::new()
.set_table_change_insights([
TableChangeInsight::default()/* use setters */,
TableChangeInsight::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for PerformanceInsights
impl Clone for PerformanceInsights
Sourcefn clone(&self) -> PerformanceInsights
fn clone(&self) -> PerformanceInsights
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PerformanceInsights
impl Debug for PerformanceInsights
Sourceimpl Default for PerformanceInsights
impl Default for PerformanceInsights
Sourcefn default() -> PerformanceInsights
fn default() -> PerformanceInsights
Returns the “default value” for a type. Read more
Sourceimpl Message for PerformanceInsights
impl Message for PerformanceInsights
Sourceimpl PartialEq for PerformanceInsights
impl PartialEq for PerformanceInsights
impl StructuralPartialEq for PerformanceInsights