#[non_exhaustive]pub struct PythonOptions {
pub entry_point: String,
pub packages: Vec<String>,
/* private fields */
}Expand description
Options for a user-defined Python function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry_point: StringRequired. The name of the function defined in Python code as the entry point when the Python UDF is invoked.
packages: Vec<String>Optional. A list of Python package names along with versions to be installed. Example: [“pandas>=2.1”, “google-cloud-translate==3.11”]. For more information, see Use third-party packages.
Implementations
Sourceimpl PythonOptions
impl PythonOptions
Sourcepub fn set_entry_point<T: Into<String>>(self, v: T) -> Self
pub fn set_entry_point<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_packages<T, V>(self, v: T) -> Self
pub fn set_packages<T, V>(self, v: T) -> Self