#[non_exhaustive]pub struct QueryParameterType {
pub type: String,
pub timestamp_precision: Option<i64>,
pub array_type: Option<Box<QueryParameterType>>,
pub struct_types: Vec<QueryParameterStructType>,
pub range_element_type: Option<Box<QueryParameterType>>,
/* private fields */
}Expand description
The type of a query parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: StringRequired. The top level type of this field.
timestamp_precision: Option<i64>Optional. Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type.
Possible values include:
- 6 (Default, for TIMESTAMP type with microsecond precision)
- 12 (For TIMESTAMP type with picosecond precision)
array_type: Option<Box<QueryParameterType>>Optional. The type of the array’s elements, if this is an array.
struct_types: Vec<QueryParameterStructType>Optional. The types of the fields of this struct, in order, if this is a struct.
range_element_type: Option<Box<QueryParameterType>>Optional. The element type of the range, if this is a range.
Implementations
Sourceimpl QueryParameterType
impl QueryParameterType
Sourcepub fn set_timestamp_precision<T>(self, v: T) -> Self
pub fn set_timestamp_precision<T>(self, v: T) -> Self
Sets the value of timestamp_precision.
Example
ⓘ
let x = QueryParameterType::new().set_timestamp_precision(42);Sourcepub fn set_or_clear_timestamp_precision<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_timestamp_precision<T>(self, v: Option<T>) -> Self
Sets or clears the value of timestamp_precision.
Example
ⓘ
let x = QueryParameterType::new().set_or_clear_timestamp_precision(Some(42));
let x = QueryParameterType::new().set_or_clear_timestamp_precision(None::<i32>);Sourcepub fn set_array_type<T>(self, v: T) -> Selfwhere
T: Into<QueryParameterType>,
pub fn set_array_type<T>(self, v: T) -> Selfwhere
T: Into<QueryParameterType>,
Sets the value of array_type.
Example
ⓘ
let x = QueryParameterType::new().set_array_type(QueryParameterType::default()/* use setters */);Sourcepub fn set_or_clear_array_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameterType>,
pub fn set_or_clear_array_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameterType>,
Sets or clears the value of array_type.
Example
ⓘ
let x = QueryParameterType::new().set_or_clear_array_type(Some(QueryParameterType::default()/* use setters */));
let x = QueryParameterType::new().set_or_clear_array_type(None::<QueryParameterType>);Sourcepub fn set_struct_types<T, V>(self, v: T) -> Self
pub fn set_struct_types<T, V>(self, v: T) -> Self
Sets the value of struct_types.
Example
ⓘ
use google_cloud_bigquery_v2::model::QueryParameterStructType;
let x = QueryParameterType::new()
.set_struct_types([
QueryParameterStructType::default()/* use setters */,
QueryParameterStructType::default()/* use (different) setters */,
]);Sourcepub fn set_range_element_type<T>(self, v: T) -> Selfwhere
T: Into<QueryParameterType>,
pub fn set_range_element_type<T>(self, v: T) -> Selfwhere
T: Into<QueryParameterType>,
Sets the value of range_element_type.
Example
ⓘ
let x = QueryParameterType::new().set_range_element_type(QueryParameterType::default()/* use setters */);Sourcepub fn set_or_clear_range_element_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameterType>,
pub fn set_or_clear_range_element_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameterType>,
Sets or clears the value of range_element_type.
Example
ⓘ
let x = QueryParameterType::new().set_or_clear_range_element_type(Some(QueryParameterType::default()/* use setters */));
let x = QueryParameterType::new().set_or_clear_range_element_type(None::<QueryParameterType>);Trait Implementations
Sourceimpl Clone for QueryParameterType
impl Clone for QueryParameterType
Sourcefn clone(&self) -> QueryParameterType
fn clone(&self) -> QueryParameterType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryParameterType
impl Debug for QueryParameterType
Sourceimpl Default for QueryParameterType
impl Default for QueryParameterType
Sourcefn default() -> QueryParameterType
fn default() -> QueryParameterType
Returns the “default value” for a type. Read more
Sourceimpl Message for QueryParameterType
impl Message for QueryParameterType
Sourceimpl PartialEq for QueryParameterType
impl PartialEq for QueryParameterType
impl StructuralPartialEq for QueryParameterType