#[non_exhaustive]pub struct QueryParameterValue {
pub value: Option<StringValue>,
pub array_values: Vec<QueryParameterValue>,
pub struct_values: HashMap<String, QueryParameterValue>,
pub range_value: Option<Box<RangeValue>>,
pub alt_struct_values: Vec<Value>,
/* private fields */
}Expand description
The value of a query parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: Option<StringValue>Optional. The value of this value, if a simple scalar type.
array_values: Vec<QueryParameterValue>Optional. The array values, if this is an array type.
struct_values: HashMap<String, QueryParameterValue>The struct field values.
range_value: Option<Box<RangeValue>>Optional. The range value, if this is a range type.
alt_struct_values: Vec<Value>This field should not be used.
Implementations
Sourceimpl QueryParameterValue
impl QueryParameterValue
Sourcepub fn set_value<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_value<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sourcepub fn set_or_clear_value<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_value<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sourcepub fn set_array_values<T, V>(self, v: T) -> Self
pub fn set_array_values<T, V>(self, v: T) -> Self
Sets the value of array_values.
Example
ⓘ
let x = QueryParameterValue::new()
.set_array_values([
QueryParameterValue::default()/* use setters */,
QueryParameterValue::default()/* use (different) setters */,
]);Sourcepub fn set_struct_values<T, K, V>(self, v: T) -> Self
pub fn set_struct_values<T, K, V>(self, v: T) -> Self
Sets the value of struct_values.
Example
ⓘ
let x = QueryParameterValue::new().set_struct_values([
("key0", QueryParameterValue::default()/* use setters */),
("key1", QueryParameterValue::default()/* use (different) setters */),
]);Sourcepub fn set_range_value<T>(self, v: T) -> Selfwhere
T: Into<RangeValue>,
pub fn set_range_value<T>(self, v: T) -> Selfwhere
T: Into<RangeValue>,
Sets the value of range_value.
Example
ⓘ
use google_cloud_bigquery_v2::model::RangeValue;
let x = QueryParameterValue::new().set_range_value(RangeValue::default()/* use setters */);Sourcepub fn set_or_clear_range_value<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangeValue>,
pub fn set_or_clear_range_value<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangeValue>,
Sets or clears the value of range_value.
Example
ⓘ
use google_cloud_bigquery_v2::model::RangeValue;
let x = QueryParameterValue::new().set_or_clear_range_value(Some(RangeValue::default()/* use setters */));
let x = QueryParameterValue::new().set_or_clear_range_value(None::<RangeValue>);Sourcepub fn set_alt_struct_values<T, V>(self, v: T) -> Self
pub fn set_alt_struct_values<T, V>(self, v: T) -> Self
Sets the value of alt_struct_values.
Example
ⓘ
use wkt::Value;
let x = QueryParameterValue::new()
.set_alt_struct_values([
Value::default()/* use setters */,
Value::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for QueryParameterValue
impl Clone for QueryParameterValue
Sourcefn clone(&self) -> QueryParameterValue
fn clone(&self) -> QueryParameterValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryParameterValue
impl Debug for QueryParameterValue
Sourceimpl Default for QueryParameterValue
impl Default for QueryParameterValue
Sourcefn default() -> QueryParameterValue
fn default() -> QueryParameterValue
Returns the “default value” for a type. Read more
Sourceimpl Message for QueryParameterValue
impl Message for QueryParameterValue
Sourceimpl PartialEq for QueryParameterValue
impl PartialEq for QueryParameterValue
impl StructuralPartialEq for QueryParameterValue