QueryRequest

Struct QueryRequest 

#[non_exhaustive]
pub struct QueryRequest {
Show 25 fields pub kind: String, pub query: String, pub max_results: Option<UInt32Value>, pub default_dataset: Option<DatasetReference>, pub timeout_ms: Option<UInt32Value>, pub job_timeout_ms: Option<i64>, pub max_slots: Option<i32>, pub destination_encryption_configuration: Option<EncryptionConfiguration>, pub dry_run: bool, pub use_query_cache: Option<BoolValue>, pub use_legacy_sql: Option<BoolValue>, pub parameter_mode: String, pub query_parameters: Vec<QueryParameter>, pub location: String, pub format_options: Option<DataFormatOptions>, pub connection_properties: Vec<ConnectionProperty>, pub labels: HashMap<String, String>, pub maximum_bytes_billed: Option<Int64Value>, pub request_id: String, pub create_session: Option<BoolValue>, pub job_creation_mode: JobCreationMode, pub reservation: Option<String>, pub write_incremental_results: bool, pub query_results_format: QueryResultsFormat, pub results_format_serialization_options: Option<ResultsFormatSerializationOptions>, /* private fields */
}
Describes the format of the jobs.query request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: String

The resource type of the request.

query: String

Required. A query string to execute, using Google Standard SQL or legacy SQL syntax. Example: “SELECT COUNT(f1) FROM myProjectId.myDatasetId.myTableId”.

max_results: Option<UInt32Value>

Optional. The maximum number of rows of data to return per page of results. Setting this flag to a small value such as 1000 and then paging through results might improve reliability when the query result set is large. In addition to this limit, responses are also limited to 10 MB. By default, there is no maximum row count, and only the byte limit applies.

default_dataset: Option<DatasetReference>

Optional. Specifies the default datasetId and projectId to assume for any unqualified table names in the query. If not set, all table names in the query string must be qualified in the format ‘datasetId.tableId’.

timeout_ms: Option<UInt32Value>

Optional. Optional: Specifies the maximum amount of time, in milliseconds, that the client is willing to wait for the query to complete. By default, this limit is 10 seconds (10,000 milliseconds). If the query is complete, the jobComplete field in the response is true. If the query has not yet completed, jobComplete is false.

You can request a longer timeout period in the timeoutMs field. However, the call is not guaranteed to wait for the specified timeout; it typically returns after around 200 seconds (200,000 milliseconds), even if the query is not complete.

If jobComplete is false, you can continue to wait for the query to complete by calling the getQueryResults method until the jobComplete field in the getQueryResults response is true.

job_timeout_ms: Option<i64>

Optional. Job timeout in milliseconds. If this time limit is exceeded, BigQuery will attempt to stop a longer job, but may not always succeed in canceling it before the job completes. For example, a job that takes more than 60 seconds to complete has a better chance of being stopped than a job that takes 10 seconds to complete. This timeout applies to the query even if a job does not need to be created.

max_slots: Option<i32>

Optional. A target limit on the rate of slot consumption by this query. If set to a value > 0, BigQuery will attempt to limit the rate of slot consumption by this query to keep it below the configured limit, even if the query is eligible for more slots based on fair scheduling. The unused slots will be available for other jobs and queries to use.

Note: This feature is not yet generally available.

destination_encryption_configuration: Option<EncryptionConfiguration>

Optional. Custom encryption configuration (e.g., Cloud KMS keys)

dry_run: bool

Optional. If set to true, BigQuery doesn’t run the job. Instead, if the query is valid, BigQuery returns statistics about the job such as how many bytes would be processed. If the query is invalid, an error returns. The default value is false.

use_query_cache: Option<BoolValue>

Optional. Whether to look for the result in the query cache. The query cache is a best-effort cache that will be flushed whenever tables in the query are modified. The default value is true.

use_legacy_sql: Option<BoolValue>

Specifies whether to use BigQuery’s legacy SQL dialect for this query. The default value is true. If set to false, the query uses BigQuery’s GoogleSQL. When useLegacySql is set to false, the value of flattenResults is ignored; query will be run as if flattenResults is false.

parameter_mode: String

GoogleSQL only. Set to POSITIONAL to use positional (?) query parameters or to NAMED to use named (@myparam) query parameters in this query.

query_parameters: Vec<QueryParameter>

Query parameters for GoogleSQL queries.

location: String

The geographic location where the job should run. For more information, see how to specify locations.

format_options: Option<DataFormatOptions>

Optional. Output format adjustments.

connection_properties: Vec<ConnectionProperty>

Optional. Connection properties which can modify the query behavior.

labels: HashMap<String, String>

Optional. The labels associated with this query. Labels can be used to organize and group query jobs. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label keys must start with a letter and each label in the list must have a different key.

maximum_bytes_billed: Option<Int64Value>

Optional. Limits the bytes billed for this query. Queries with bytes billed above this limit will fail (without incurring a charge). If unspecified, the project default is used.

request_id: String

Optional. A unique user provided identifier to ensure idempotent behavior for queries. Note that this is different from the job_id. It has the following properties:

  1. It is case-sensitive, limited to up to 36 ASCII characters. A UUID is recommended.

  2. Read only queries can ignore this token since they are nullipotent by definition.

  3. For the purposes of idempotency ensured by the request_id, a request is considered duplicate of another only if they have the same request_id and are actually duplicates. When determining whether a request is a duplicate of another request, all parameters in the request that may affect the result are considered. For example, query, connection_properties, query_parameters, use_legacy_sql are parameters that affect the result and are considered when determining whether a request is a duplicate, but properties like timeout_ms don’t affect the result and are thus not considered. Dry run query requests are never considered duplicate of another request.

  4. When a duplicate mutating query request is detected, it returns: a. the results of the mutation if it completes successfully within the timeout. b. the running operation if it is still in progress at the end of the timeout.

  5. Its lifetime is limited to 15 minutes. In other words, if two requests are sent with the same request_id, but more than 15 minutes apart, idempotency is not guaranteed.

create_session: Option<BoolValue>

Optional. If true, creates a new session using a randomly generated session_id. If false, runs query with an existing session_id passed in ConnectionProperty, otherwise runs query in non-session mode.

The session location will be set to QueryRequest.location if it is present, otherwise it’s set to the default location based on existing routing logic.

job_creation_mode: JobCreationMode

Optional. If not set, jobs are always required.

If set, the query request will follow the behavior described JobCreationMode.

reservation: Option<String>

Optional. The reservation that jobs.query request would use. User can specify a reservation to execute the job.query. The expected format is projects/{project}/locations/{location}/reservations/{reservation}. Forces the query to use on-demand billing when set to none. This requires the project or organization to have reservation_override_mode set to ALLOW_ANY_OVERRIDE.

write_incremental_results: bool

Optional. This is only supported for SELECT query. If set, the query is allowed to write results incrementally to the temporary result table. This may incur a performance penalty. This option cannot be used with Legacy SQL. This feature is not yet available.

query_results_format: QueryResultsFormat

Optional. The query results format. If the value is anything other than STRUCT_ENCODING or unspecified:

  • The schema of the results will be provided in QueryResponse.results_schema field.
  • The results of the first page will be provided in QueryResponse.results field.
  • The QueryResponse.rows will not be populated.
  • The QueryResponse.schema for QueryResponse.rows will also not be populated since it is the schema of the QueryResponse.rows.

This feature is not yet available.

results_format_serialization_options: Option<ResultsFormatSerializationOptions>

Results serialization options for query_results_format other than STRUCT_ENCODING.

This feature is not yet available.

Implementations

Source

impl QueryRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_kind<T: Into<String>>(self, v: T) -> Self

Sets the value of kind.

Example
let x = QueryRequest::new().set_kind("example");
pub fn set_query<T: Into<String>>(self, v: T) -> Self

Sets the value of query.

Example
let x = QueryRequest::new().set_query("example");
pub fn set_max_results<T>(self, v: T) -> Self
where T: Into<UInt32Value>,

Sets the value of max_results.

Example
use wkt::UInt32Value;
let x = QueryRequest::new().set_max_results(UInt32Value::default()/* use setters */);
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Self
where T: Into<UInt32Value>,

Sets or clears the value of max_results.

Example
use wkt::UInt32Value;
let x = QueryRequest::new().set_or_clear_max_results(Some(UInt32Value::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_max_results(None::<UInt32Value>);
pub fn set_default_dataset<T>(self, v: T) -> Self

Sets the value of default_dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = QueryRequest::new().set_default_dataset(DatasetReference::default()/* use setters */);
pub fn set_or_clear_default_dataset<T>(self, v: Option<T>) -> Self

Sets or clears the value of default_dataset.

Example
use google_cloud_bigquery_v2::model::DatasetReference;
let x = QueryRequest::new().set_or_clear_default_dataset(Some(DatasetReference::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_default_dataset(None::<DatasetReference>);
pub fn set_timeout_ms<T>(self, v: T) -> Self
where T: Into<UInt32Value>,

Sets the value of timeout_ms.

Example
use wkt::UInt32Value;
let x = QueryRequest::new().set_timeout_ms(UInt32Value::default()/* use setters */);
pub fn set_or_clear_timeout_ms<T>(self, v: Option<T>) -> Self
where T: Into<UInt32Value>,

Sets or clears the value of timeout_ms.

Example
use wkt::UInt32Value;
let x = QueryRequest::new().set_or_clear_timeout_ms(Some(UInt32Value::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_timeout_ms(None::<UInt32Value>);
pub fn set_job_timeout_ms<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of job_timeout_ms.

Example
let x = QueryRequest::new().set_job_timeout_ms(42);
pub fn set_or_clear_job_timeout_ms<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of job_timeout_ms.

Example
let x = QueryRequest::new().set_or_clear_job_timeout_ms(Some(42));
let x = QueryRequest::new().set_or_clear_job_timeout_ms(None::<i32>);
pub fn set_max_slots<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of max_slots.

Example
let x = QueryRequest::new().set_max_slots(42);
pub fn set_or_clear_max_slots<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of max_slots.

Example
let x = QueryRequest::new().set_or_clear_max_slots(Some(42));
let x = QueryRequest::new().set_or_clear_max_slots(None::<i32>);
pub fn set_destination_encryption_configuration<T>(self, v: T) -> Self

Sets the value of destination_encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = QueryRequest::new().set_destination_encryption_configuration(EncryptionConfiguration::default()/* use setters */);
pub fn set_or_clear_destination_encryption_configuration<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of destination_encryption_configuration.

Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = QueryRequest::new().set_or_clear_destination_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_destination_encryption_configuration(None::<EncryptionConfiguration>);
pub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self

Sets the value of dry_run.

Example
let x = QueryRequest::new().set_dry_run(true);
pub fn set_use_query_cache<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_query_cache.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_use_query_cache(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_query_cache<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_query_cache.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_or_clear_use_query_cache(Some(BoolValue::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_use_query_cache(None::<BoolValue>);
pub fn set_use_legacy_sql<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_use_legacy_sql(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_legacy_sql<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_or_clear_use_legacy_sql(Some(BoolValue::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_use_legacy_sql(None::<BoolValue>);
pub fn set_parameter_mode<T: Into<String>>(self, v: T) -> Self

Sets the value of parameter_mode.

Example
let x = QueryRequest::new().set_parameter_mode("example");
pub fn set_query_parameters<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<QueryParameter>,

Sets the value of query_parameters.

Example
use google_cloud_bigquery_v2::model::QueryParameter;
let x = QueryRequest::new()
    .set_query_parameters([
        QueryParameter::default()/* use setters */,
        QueryParameter::default()/* use (different) setters */,
    ]);
pub fn set_location<T: Into<String>>(self, v: T) -> Self

Sets the value of location.

Example
let x = QueryRequest::new().set_location("example");
pub fn set_format_options<T>(self, v: T) -> Self

Sets the value of format_options.

Example
use google_cloud_bigquery_v2::model::DataFormatOptions;
let x = QueryRequest::new().set_format_options(DataFormatOptions::default()/* use setters */);
pub fn set_or_clear_format_options<T>(self, v: Option<T>) -> Self

Sets or clears the value of format_options.

Example
use google_cloud_bigquery_v2::model::DataFormatOptions;
let x = QueryRequest::new().set_or_clear_format_options(Some(DataFormatOptions::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_format_options(None::<DataFormatOptions>);
pub fn set_connection_properties<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ConnectionProperty>,

Sets the value of connection_properties.

Example
use google_cloud_bigquery_v2::model::ConnectionProperty;
let x = QueryRequest::new()
    .set_connection_properties([
        ConnectionProperty::default()/* use setters */,
        ConnectionProperty::default()/* use (different) setters */,
    ]);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = QueryRequest::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_maximum_bytes_billed<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of maximum_bytes_billed.

Example
use wkt::Int64Value;
let x = QueryRequest::new().set_maximum_bytes_billed(Int64Value::default()/* use setters */);
pub fn set_or_clear_maximum_bytes_billed<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of maximum_bytes_billed.

Example
use wkt::Int64Value;
let x = QueryRequest::new().set_or_clear_maximum_bytes_billed(Some(Int64Value::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_maximum_bytes_billed(None::<Int64Value>);
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = QueryRequest::new().set_request_id("example");
pub fn set_create_session<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of create_session.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_create_session(BoolValue::default()/* use setters */);
pub fn set_or_clear_create_session<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of create_session.

Example
use wkt::BoolValue;
let x = QueryRequest::new().set_or_clear_create_session(Some(BoolValue::default()/* use setters */));
let x = QueryRequest::new().set_or_clear_create_session(None::<BoolValue>);
pub fn set_job_creation_mode<T: Into<JobCreationMode>>(self, v: T) -> Self

Sets the value of job_creation_mode.

Example
use google_cloud_bigquery_v2::model::query_request::JobCreationMode;
let x0 = QueryRequest::new().set_job_creation_mode(JobCreationMode::JobCreationRequired);
let x1 = QueryRequest::new().set_job_creation_mode(JobCreationMode::JobCreationOptional);
pub fn set_reservation<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of reservation.

Example
let x = QueryRequest::new().set_reservation("example");
pub fn set_or_clear_reservation<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of reservation.

Example
let x = QueryRequest::new().set_or_clear_reservation(Some("example"));
let x = QueryRequest::new().set_or_clear_reservation(None::<String>);
pub fn set_write_incremental_results<T: Into<bool>>(self, v: T) -> Self

Sets the value of write_incremental_results.

Example
let x = QueryRequest::new().set_write_incremental_results(true);
pub fn set_query_results_format<T: Into<QueryResultsFormat>>(self, v: T) -> Self

Sets the value of query_results_format.

Example
use google_cloud_bigquery_v2::model::query_request::QueryResultsFormat;
let x0 = QueryRequest::new().set_query_results_format(QueryResultsFormat::StructEncoding);
let x1 = QueryRequest::new().set_query_results_format(QueryResultsFormat::Arrow);
pub fn set_results_format_serialization_options<T: Into<Option<ResultsFormatSerializationOptions>>>( self, v: T, ) -> Self

Sets the value of results_format_serialization_options.

Note that all the setters affecting results_format_serialization_options are mutually exclusive.

Example
use google_cloud_bigquery_v2::model::ArrowSerializationOptions;
let x = QueryRequest::new().set_results_format_serialization_options(Some(
    google_cloud_bigquery_v2::model::query_request::ResultsFormatSerializationOptions::ArrowSerializationOptions(ArrowSerializationOptions::default().into())));
pub fn arrow_serialization_options( &self, ) -> Option<&Box<ArrowSerializationOptions>>

The value of results_format_serialization_options if it holds a ArrowSerializationOptions, None if the field is not set or holds a different branch.

pub fn set_arrow_serialization_options<T: Into<Box<ArrowSerializationOptions>>>( self, v: T, ) -> Self

Sets the value of results_format_serialization_options to hold a ArrowSerializationOptions.

Note that all the setters affecting results_format_serialization_options are mutually exclusive.

Example
use google_cloud_bigquery_v2::model::ArrowSerializationOptions;
let x = QueryRequest::new().set_arrow_serialization_options(ArrowSerializationOptions::default()/* use setters */);
assert!(x.arrow_serialization_options().is_some());