#[non_exhaustive]pub struct RemoteModelInfo {
pub connection: String,
pub max_batching_rows: i64,
pub remote_model_version: String,
pub speech_recognizer: String,
pub remote_service: Option<RemoteService>,
/* private fields */
}Expand description
Remote Model Info
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection: StringOutput only. Fully qualified name of the user-provided connection object of
the remote model. Format:
"projects/{project_id}/locations/{location_id}/connections/{connection_id}"
max_batching_rows: i64Output only. Max number of rows in each batch sent to the remote service. If unset, the number of rows in each batch is set dynamically.
remote_model_version: StringOutput only. The model version for LLM.
speech_recognizer: StringOutput only. The name of the speech recognizer to use for speech
recognition. The expected format is
projects/{project}/locations/{location}/recognizers/{recognizer}.
Customers can specify this field at model creation. If not specified, a
default recognizer projects/{model project}/locations/global/recognizers/_ will be used. See more details at
recognizers
remote_service: Option<RemoteService>Remote services are services outside of BigQuery used by remote models for predictions. A remote service is backed by either an arbitrary endpoint or a selected remote service type, but not both.
Implementations
Sourceimpl RemoteModelInfo
impl RemoteModelInfo
Sourcepub fn set_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_connection<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
pub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
Sets the value of max_batching_rows.
Example
let x = RemoteModelInfo::new().set_max_batching_rows(42);Sourcepub fn set_remote_model_version<T: Into<String>>(self, v: T) -> Self
pub fn set_remote_model_version<T: Into<String>>(self, v: T) -> Self
Sets the value of remote_model_version.
Example
let x = RemoteModelInfo::new().set_remote_model_version("example");Sourcepub fn set_speech_recognizer<T: Into<String>>(self, v: T) -> Self
pub fn set_speech_recognizer<T: Into<String>>(self, v: T) -> Self
Sets the value of speech_recognizer.
Example
let x = RemoteModelInfo::new().set_speech_recognizer("example");Sourcepub fn set_remote_service<T: Into<Option<RemoteService>>>(self, v: T) -> Self
pub fn set_remote_service<T: Into<Option<RemoteService>>>(self, v: T) -> Self
Sets the value of remote_service.
Note that all the setters affecting remote_service are mutually
exclusive.
Example
use google_cloud_bigquery_v2::model::remote_model_info::RemoteService;
let x = RemoteModelInfo::new().set_remote_service(Some(RemoteService::Endpoint("example".to_string())));Sourcepub fn endpoint(&self) -> Option<&String>
pub fn endpoint(&self) -> Option<&String>
The value of remote_service
if it holds a Endpoint, None if the field is not set or
holds a different branch.
Sourcepub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
pub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
Sets the value of remote_service
to hold a Endpoint.
Note that all the setters affecting remote_service are
mutually exclusive.
Example
let x = RemoteModelInfo::new().set_endpoint("example");
assert!(x.endpoint().is_some());
assert!(x.remote_service_type().is_none());Sourcepub fn remote_service_type(&self) -> Option<&RemoteServiceType>
pub fn remote_service_type(&self) -> Option<&RemoteServiceType>
The value of remote_service
if it holds a RemoteServiceType, None if the field is not set or
holds a different branch.
Sourcepub fn set_remote_service_type<T: Into<RemoteServiceType>>(self, v: T) -> Self
pub fn set_remote_service_type<T: Into<RemoteServiceType>>(self, v: T) -> Self
Sets the value of remote_service
to hold a RemoteServiceType.
Note that all the setters affecting remote_service are
mutually exclusive.
Example
use google_cloud_bigquery_v2::model::remote_model_info::RemoteServiceType;
let x0 = RemoteModelInfo::new().set_remote_service_type(RemoteServiceType::CloudAiTranslateV3);
let x1 = RemoteModelInfo::new().set_remote_service_type(RemoteServiceType::CloudAiVisionV1);
let x2 = RemoteModelInfo::new().set_remote_service_type(RemoteServiceType::CloudAiNaturalLanguageV1);
assert!(x0.remote_service_type().is_some());
assert!(x0.endpoint().is_none());
assert!(x1.remote_service_type().is_some());
assert!(x1.endpoint().is_none());
assert!(x2.remote_service_type().is_some());
assert!(x2.endpoint().is_none());Trait Implementations
Sourceimpl Clone for RemoteModelInfo
impl Clone for RemoteModelInfo
Sourcefn clone(&self) -> RemoteModelInfo
fn clone(&self) -> RemoteModelInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RemoteModelInfo
impl Debug for RemoteModelInfo
Sourceimpl Default for RemoteModelInfo
impl Default for RemoteModelInfo
Sourcefn default() -> RemoteModelInfo
fn default() -> RemoteModelInfo
Sourceimpl Message for RemoteModelInfo
impl Message for RemoteModelInfo
Sourceimpl PartialEq for RemoteModelInfo
impl PartialEq for RemoteModelInfo
impl StructuralPartialEq for RemoteModelInfo