#[non_exhaustive]pub struct RoutineBuildStatus {
pub build_state: BuildState,
pub error_result: Option<ErrorProto>,
pub build_state_update_time: Option<Timestamp>,
pub build_duration: Option<Duration>,
pub image_size_bytes: i64,
/* private fields */
}Expand description
The status of a routine build.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.build_state: BuildStateOutput only. The current build state of the routine.
error_result: Option<ErrorProto>Output only. A result object that will be present only if the build has failed.
build_state_update_time: Option<Timestamp>Output only. The time when the build state was updated last.
build_duration: Option<Duration>Output only. The time taken for the image build. Populated only after the build succeeds or fails.
image_size_bytes: i64Output only. The size of the image in bytes. Populated only after the build succeeds.
Implementations
Sourceimpl RoutineBuildStatus
impl RoutineBuildStatus
Sourcepub fn set_build_state<T: Into<BuildState>>(self, v: T) -> Self
pub fn set_build_state<T: Into<BuildState>>(self, v: T) -> Self
Sets the value of build_state.
Example
ⓘ
use google_cloud_bigquery_v2::model::routine_build_status::BuildState;
let x0 = RoutineBuildStatus::new().set_build_state(BuildState::InProgress);
let x1 = RoutineBuildStatus::new().set_build_state(BuildState::Succeeded);
let x2 = RoutineBuildStatus::new().set_build_state(BuildState::Failed);Sourcepub fn set_error_result<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_error_result<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
Sets the value of error_result.
Example
ⓘ
use google_cloud_bigquery_v2::model::ErrorProto;
let x = RoutineBuildStatus::new().set_error_result(ErrorProto::default()/* use setters */);Sourcepub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
Sets or clears the value of error_result.
Example
ⓘ
use google_cloud_bigquery_v2::model::ErrorProto;
let x = RoutineBuildStatus::new().set_or_clear_error_result(Some(ErrorProto::default()/* use setters */));
let x = RoutineBuildStatus::new().set_or_clear_error_result(None::<ErrorProto>);Sourcepub fn set_build_state_update_time<T>(self, v: T) -> Self
pub fn set_build_state_update_time<T>(self, v: T) -> Self
Sets the value of build_state_update_time.
Example
ⓘ
use wkt::Timestamp;
let x = RoutineBuildStatus::new().set_build_state_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_build_state_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_build_state_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of build_state_update_time.
Example
ⓘ
use wkt::Timestamp;
let x = RoutineBuildStatus::new().set_or_clear_build_state_update_time(Some(Timestamp::default()/* use setters */));
let x = RoutineBuildStatus::new().set_or_clear_build_state_update_time(None::<Timestamp>);Sourcepub fn set_build_duration<T>(self, v: T) -> Self
pub fn set_build_duration<T>(self, v: T) -> Self
Sets the value of build_duration.
Example
ⓘ
use wkt::Duration;
let x = RoutineBuildStatus::new().set_build_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_build_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_build_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of build_duration.
Example
ⓘ
use wkt::Duration;
let x = RoutineBuildStatus::new().set_or_clear_build_duration(Some(Duration::default()/* use setters */));
let x = RoutineBuildStatus::new().set_or_clear_build_duration(None::<Duration>);Sourcepub fn set_image_size_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_image_size_bytes<T: Into<i64>>(self, v: T) -> Self
Sets the value of image_size_bytes.
Example
ⓘ
let x = RoutineBuildStatus::new().set_image_size_bytes(42);Trait Implementations
Sourceimpl Clone for RoutineBuildStatus
impl Clone for RoutineBuildStatus
Sourcefn clone(&self) -> RoutineBuildStatus
fn clone(&self) -> RoutineBuildStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoutineBuildStatus
impl Debug for RoutineBuildStatus
Sourceimpl Default for RoutineBuildStatus
impl Default for RoutineBuildStatus
Sourcefn default() -> RoutineBuildStatus
fn default() -> RoutineBuildStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for RoutineBuildStatus
impl Message for RoutineBuildStatus
Sourceimpl PartialEq for RoutineBuildStatus
impl PartialEq for RoutineBuildStatus
impl StructuralPartialEq for RoutineBuildStatus