RowAccessPolicy

Struct RowAccessPolicy 

#[non_exhaustive]
pub struct RowAccessPolicy { pub etag: String, pub row_access_policy_reference: Option<RowAccessPolicyReference>, pub filter_predicate: String, pub creation_time: Option<Timestamp>, pub last_modified_time: Option<Timestamp>, pub grantees: Vec<String>, /* private fields */ }
Represents access on a subset of rows on the specified table, defined by its filter predicate. Access to the subset of rows is controlled by its IAM policy.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
etag: String

Output only. A hash of this resource.

row_access_policy_reference: Option<RowAccessPolicyReference>

Required. Reference describing the ID of this row access policy.

filter_predicate: String

Required. A SQL boolean expression that represents the rows defined by this row access policy, similar to the boolean expression in a WHERE clause of a SELECT query on a table. References to other tables, routines, and temporary functions are not supported.

Examples: region=“EU” date_field = CAST(‘2019-9-27’ as DATE) nullable_field is not NULL numeric_field BETWEEN 1.0 AND 5.0

creation_time: Option<Timestamp>

Output only. The time when this row access policy was created, in milliseconds since the epoch.

last_modified_time: Option<Timestamp>

Output only. The time when this row access policy was last modified, in milliseconds since the epoch.

grantees: Vec<String>

Optional. Input only. The optional list of iam_member users or groups that specifies the initial members that the row-level access policy should be created with.

grantees types:

  • “user:alice@example.com”: An email address that represents a specific Google account.
  • “serviceAccount:my-other-app@appspot.gserviceaccount.com”: An email address that represents a service account.
  • “group:admins@example.com”: An email address that represents a Google group.
  • “domain:example.com”:The Google Workspace domain (primary) that represents all the users of that domain.
  • “allAuthenticatedUsers”: A special identifier that represents all service accounts and all users on the internet who have authenticated with a Google Account. This identifier includes accounts that aren’t connected to a Google Workspace or Cloud Identity domain, such as personal Gmail accounts. Users who aren’t authenticated, such as anonymous visitors, aren’t included.
  • “allUsers”:A special identifier that represents anyone who is on the internet, including authenticated and unauthenticated users. Because BigQuery requires authentication before a user can access the service, allUsers includes only authenticated users.

Implementations

Source

impl RowAccessPolicy

pub fn new() -> Self

Creates a new default instance.

pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = RowAccessPolicy::new().set_etag("example");
pub fn set_row_access_policy_reference<T>(self, v: T) -> Self

Sets the value of row_access_policy_reference.

Example
use google_cloud_bigquery_v2::model::RowAccessPolicyReference;
let x = RowAccessPolicy::new().set_row_access_policy_reference(RowAccessPolicyReference::default()/* use setters */);
pub fn set_or_clear_row_access_policy_reference<T>(self, v: Option<T>) -> Self

Sets or clears the value of row_access_policy_reference.

Example
use google_cloud_bigquery_v2::model::RowAccessPolicyReference;
let x = RowAccessPolicy::new().set_or_clear_row_access_policy_reference(Some(RowAccessPolicyReference::default()/* use setters */));
let x = RowAccessPolicy::new().set_or_clear_row_access_policy_reference(None::<RowAccessPolicyReference>);
pub fn set_filter_predicate<T: Into<String>>(self, v: T) -> Self

Sets the value of filter_predicate.

Example
let x = RowAccessPolicy::new().set_filter_predicate("example");
pub fn set_creation_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of creation_time.

Example
use wkt::Timestamp;
let x = RowAccessPolicy::new().set_creation_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_creation_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of creation_time.

Example
use wkt::Timestamp;
let x = RowAccessPolicy::new().set_or_clear_creation_time(Some(Timestamp::default()/* use setters */));
let x = RowAccessPolicy::new().set_or_clear_creation_time(None::<Timestamp>);
pub fn set_last_modified_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of last_modified_time.

Example
use wkt::Timestamp;
let x = RowAccessPolicy::new().set_last_modified_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_last_modified_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of last_modified_time.

Example
use wkt::Timestamp;
let x = RowAccessPolicy::new().set_or_clear_last_modified_time(Some(Timestamp::default()/* use setters */));
let x = RowAccessPolicy::new().set_or_clear_last_modified_time(None::<Timestamp>);
pub fn set_grantees<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of grantees.

Example
let x = RowAccessPolicy::new().set_grantees(["a", "b", "c"]);