#[non_exhaustive]pub struct RowAccessPolicyReference {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub policy_id: String,
/* private fields */
}Expand description
Id path of a row access policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. The ID of the project containing this row access policy.
dataset_id: StringRequired. The ID of the dataset containing this row access policy.
table_id: StringRequired. The ID of the table containing this row access policy.
policy_id: StringRequired. The ID of the row access policy. The ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters.
Implementations
Sourceimpl RowAccessPolicyReference
impl RowAccessPolicyReference
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = RowAccessPolicyReference::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = RowAccessPolicyReference::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self