ScriptOptions

Struct ScriptOptions 

#[non_exhaustive]
pub struct ScriptOptions { pub statement_timeout_ms: Option<Int64Value>, pub statement_byte_budget: Option<Int64Value>, pub key_result_statement: KeyResultStatementKind, /* private fields */ }
Options related to script execution.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
statement_timeout_ms: Option<Int64Value>

Timeout period for each statement in a script.

statement_byte_budget: Option<Int64Value>

Limit on the number of bytes billed per statement. Exceeding this budget results in an error.

key_result_statement: KeyResultStatementKind

Determines which statement in the script represents the “key result”, used to populate the schema and query results of the script job. Default is LAST.

Implementations

Source

impl ScriptOptions

pub fn new() -> Self

Creates a new default instance.

pub fn set_statement_timeout_ms<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of statement_timeout_ms.

Example
use wkt::Int64Value;
let x = ScriptOptions::new().set_statement_timeout_ms(Int64Value::default()/* use setters */);
pub fn set_or_clear_statement_timeout_ms<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of statement_timeout_ms.

Example
use wkt::Int64Value;
let x = ScriptOptions::new().set_or_clear_statement_timeout_ms(Some(Int64Value::default()/* use setters */));
let x = ScriptOptions::new().set_or_clear_statement_timeout_ms(None::<Int64Value>);
pub fn set_statement_byte_budget<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of statement_byte_budget.

Example
use wkt::Int64Value;
let x = ScriptOptions::new().set_statement_byte_budget(Int64Value::default()/* use setters */);
pub fn set_or_clear_statement_byte_budget<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of statement_byte_budget.

Example
use wkt::Int64Value;
let x = ScriptOptions::new().set_or_clear_statement_byte_budget(Some(Int64Value::default()/* use setters */));
let x = ScriptOptions::new().set_or_clear_statement_byte_budget(None::<Int64Value>);
pub fn set_key_result_statement<T: Into<KeyResultStatementKind>>( self, v: T, ) -> Self

Sets the value of key_result_statement.

Example
use google_cloud_bigquery_v2::model::script_options::KeyResultStatementKind;
let x0 = ScriptOptions::new().set_key_result_statement(KeyResultStatementKind::Last);
let x1 = ScriptOptions::new().set_key_result_statement(KeyResultStatementKind::FirstSelect);