#[non_exhaustive]pub struct ScriptStatistics {
pub evaluation_kind: EvaluationKind,
pub stack_frames: Vec<ScriptStackFrame>,
/* private fields */
}Expand description
Job statistics specific to the child job of a script.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation_kind: EvaluationKindWhether this child job was a statement or expression.
stack_frames: Vec<ScriptStackFrame>Stack trace showing the line/column/procedure name of each frame on the stack at the point where the current evaluation happened. The leaf frame is first, the primary script is last. Never empty.
Implementations
Sourceimpl ScriptStatistics
impl ScriptStatistics
Sourcepub fn set_evaluation_kind<T: Into<EvaluationKind>>(self, v: T) -> Self
pub fn set_evaluation_kind<T: Into<EvaluationKind>>(self, v: T) -> Self
Sets the value of evaluation_kind.
Example
ⓘ
use google_cloud_bigquery_v2::model::script_statistics::EvaluationKind;
let x0 = ScriptStatistics::new().set_evaluation_kind(EvaluationKind::Statement);
let x1 = ScriptStatistics::new().set_evaluation_kind(EvaluationKind::Expression);Sourcepub fn set_stack_frames<T, V>(self, v: T) -> Self
pub fn set_stack_frames<T, V>(self, v: T) -> Self
Sets the value of stack_frames.
Example
ⓘ
use google_cloud_bigquery_v2::model::script_statistics::ScriptStackFrame;
let x = ScriptStatistics::new()
.set_stack_frames([
ScriptStackFrame::default()/* use setters */,
ScriptStackFrame::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ScriptStatistics
impl Clone for ScriptStatistics
Sourcefn clone(&self) -> ScriptStatistics
fn clone(&self) -> ScriptStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScriptStatistics
impl Debug for ScriptStatistics
Sourceimpl Default for ScriptStatistics
impl Default for ScriptStatistics
Sourcefn default() -> ScriptStatistics
fn default() -> ScriptStatistics
Returns the “default value” for a type. Read more
Sourceimpl Message for ScriptStatistics
impl Message for ScriptStatistics
Sourceimpl PartialEq for ScriptStatistics
impl PartialEq for ScriptStatistics
impl StructuralPartialEq for ScriptStatistics