#[non_exhaustive]pub struct SearchStatistics {
pub index_usage_mode: IndexUsageMode,
pub index_unused_reasons: Vec<IndexUnusedReason>,
pub index_pruning_stats: Vec<IndexPruningStats>,
/* private fields */
}Expand description
Statistics for a search query. Populated as part of JobStatistics2.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index_usage_mode: IndexUsageModeSpecifies the index usage mode for the query.
index_unused_reasons: Vec<IndexUnusedReason>When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains
why indexes were not used in all or part of the search query. If
indexUsageMode is FULLY_USED, this field is not populated.
index_pruning_stats: Vec<IndexPruningStats>Search index pruning statistics, one for each base table that has a search index. If a base table does not have a search index or the index does not help with pruning on the base table, then there is no pruning statistics for that table.
Implementations
Sourceimpl SearchStatistics
impl SearchStatistics
Sourcepub fn set_index_usage_mode<T: Into<IndexUsageMode>>(self, v: T) -> Self
pub fn set_index_usage_mode<T: Into<IndexUsageMode>>(self, v: T) -> Self
Sets the value of index_usage_mode.
Example
ⓘ
use google_cloud_bigquery_v2::model::search_statistics::IndexUsageMode;
let x0 = SearchStatistics::new().set_index_usage_mode(IndexUsageMode::Unused);
let x1 = SearchStatistics::new().set_index_usage_mode(IndexUsageMode::PartiallyUsed);
let x2 = SearchStatistics::new().set_index_usage_mode(IndexUsageMode::FullyUsed);Sourcepub fn set_index_unused_reasons<T, V>(self, v: T) -> Self
pub fn set_index_unused_reasons<T, V>(self, v: T) -> Self
Sets the value of index_unused_reasons.
Example
ⓘ
use google_cloud_bigquery_v2::model::IndexUnusedReason;
let x = SearchStatistics::new()
.set_index_unused_reasons([
IndexUnusedReason::default()/* use setters */,
IndexUnusedReason::default()/* use (different) setters */,
]);Sourcepub fn set_index_pruning_stats<T, V>(self, v: T) -> Self
pub fn set_index_pruning_stats<T, V>(self, v: T) -> Self
Sets the value of index_pruning_stats.
Example
ⓘ
use google_cloud_bigquery_v2::model::IndexPruningStats;
let x = SearchStatistics::new()
.set_index_pruning_stats([
IndexPruningStats::default()/* use setters */,
IndexPruningStats::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for SearchStatistics
impl Clone for SearchStatistics
Sourcefn clone(&self) -> SearchStatistics
fn clone(&self) -> SearchStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchStatistics
impl Debug for SearchStatistics
Sourceimpl Default for SearchStatistics
impl Default for SearchStatistics
Sourcefn default() -> SearchStatistics
fn default() -> SearchStatistics
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchStatistics
impl Message for SearchStatistics
Sourceimpl PartialEq for SearchStatistics
impl PartialEq for SearchStatistics
impl StructuralPartialEq for SearchStatistics