#[non_exhaustive]pub struct SerDeInfo {
pub name: String,
pub serialization_library: String,
pub parameters: HashMap<String, String>,
/* private fields */
}Expand description
Serializer and deserializer information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOptional. Name of the SerDe. The maximum length is 256 characters.
serialization_library: StringRequired. Specifies a fully-qualified class name of the serialization library that is responsible for the translation of data between table representation and the underlying low-level input and output format structures. The maximum length is 256 characters.
parameters: HashMap<String, String>Optional. Key-value pairs that define the initialization parameters for the serialization library. Maximum size 10 Kib.
Implementations
Sourceimpl SerDeInfo
impl SerDeInfo
Sourcepub fn set_serialization_library<T: Into<String>>(self, v: T) -> Self
pub fn set_serialization_library<T: Into<String>>(self, v: T) -> Self
Sets the value of serialization_library.
Example
ⓘ
let x = SerDeInfo::new().set_serialization_library("example");Sourcepub fn set_parameters<T, K, V>(self, v: T) -> Self
pub fn set_parameters<T, K, V>(self, v: T) -> Self
Sets the value of parameters.
Example
ⓘ
let x = SerDeInfo::new().set_parameters([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
impl StructuralPartialEq for SerDeInfo