#[non_exhaustive]pub struct SnapshotDefinition {
pub base_table_reference: Option<TableReference>,
pub snapshot_time: Option<Timestamp>,
/* private fields */
}Expand description
Information about base table and snapshot time of the snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.base_table_reference: Option<TableReference>Required. Reference describing the ID of the table that was snapshot.
snapshot_time: Option<Timestamp>Required. The time at which the base table was snapshot. This value is reported in the JSON response using RFC3339 format.
Implementations
Sourceimpl SnapshotDefinition
impl SnapshotDefinition
Sourcepub fn set_base_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_base_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of base_table_reference.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = SnapshotDefinition::new().set_base_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_base_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_base_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of base_table_reference.
Example
ⓘ
use google_cloud_bigquery_v2::model::TableReference;
let x = SnapshotDefinition::new().set_or_clear_base_table_reference(Some(TableReference::default()/* use setters */));
let x = SnapshotDefinition::new().set_or_clear_base_table_reference(None::<TableReference>);Sourcepub fn set_snapshot_time<T>(self, v: T) -> Self
pub fn set_snapshot_time<T>(self, v: T) -> Self
Sets the value of snapshot_time.
Example
ⓘ
use wkt::Timestamp;
let x = SnapshotDefinition::new().set_snapshot_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_snapshot_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_snapshot_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of snapshot_time.
Example
ⓘ
use wkt::Timestamp;
let x = SnapshotDefinition::new().set_or_clear_snapshot_time(Some(Timestamp::default()/* use setters */));
let x = SnapshotDefinition::new().set_or_clear_snapshot_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for SnapshotDefinition
impl Clone for SnapshotDefinition
Sourcefn clone(&self) -> SnapshotDefinition
fn clone(&self) -> SnapshotDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotDefinition
impl Debug for SnapshotDefinition
Sourceimpl Default for SnapshotDefinition
impl Default for SnapshotDefinition
Sourcefn default() -> SnapshotDefinition
fn default() -> SnapshotDefinition
Returns the “default value” for a type. Read more
Sourceimpl Message for SnapshotDefinition
impl Message for SnapshotDefinition
Sourceimpl PartialEq for SnapshotDefinition
impl PartialEq for SnapshotDefinition
impl StructuralPartialEq for SnapshotDefinition