SparkStatistics

Struct SparkStatistics 

#[non_exhaustive]
pub struct SparkStatistics { pub spark_job_id: Option<String>, pub spark_job_location: Option<String>, pub endpoints: HashMap<String, String>, pub logging_info: Option<LoggingInfo>, pub kms_key_name: Option<String>, pub gcs_staging_bucket: Option<String>, /* private fields */ }
Statistics for a BigSpark query. Populated as part of JobStatistics2

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
spark_job_id: Option<String>

Output only. Spark job ID if a Spark job is created successfully.

spark_job_location: Option<String>

Output only. Location where the Spark job is executed. A location is selected by BigQueury for jobs configured to run in a multi-region.

endpoints: HashMap<String, String>

Output only. Endpoints returned from Dataproc. Key list:

  • history_server_endpoint: A link to Spark job UI.
logging_info: Option<LoggingInfo>

Output only. Logging info is used to generate a link to Cloud Logging.

kms_key_name: Option<String>

Output only. The Cloud KMS encryption key that is used to protect the resources created by the Spark job. If the Spark procedure uses the invoker security mode, the Cloud KMS encryption key is either inferred from the provided system variable, @@spark_proc_properties.kms_key_name, or the default key of the BigQuery job’s project (if the CMEK organization policy is enforced). Otherwise, the Cloud KMS key is either inferred from the Spark connection associated with the procedure (if it is provided), or from the default key of the Spark connection’s project if the CMEK organization policy is enforced.

Example:

  • projects/[kms_project_id]/locations/[region]/keyRings/[key_region]/cryptoKeys/[key]
gcs_staging_bucket: Option<String>

Output only. The Google Cloud Storage bucket that is used as the default file system by the Spark application. This field is only filled when the Spark procedure uses the invoker security mode. The gcsStagingBucket bucket is inferred from the @@spark_proc_properties.staging_bucket system variable (if it is provided). Otherwise, BigQuery creates a default staging bucket for the job and returns the bucket name in this field.

Example:

  • gs://[bucket_name]

Implementations

Source

impl SparkStatistics

pub fn new() -> Self

Creates a new default instance.

pub fn set_spark_job_id<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of spark_job_id.

Example
let x = SparkStatistics::new().set_spark_job_id("example");
pub fn set_or_clear_spark_job_id<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of spark_job_id.

Example
let x = SparkStatistics::new().set_or_clear_spark_job_id(Some("example"));
let x = SparkStatistics::new().set_or_clear_spark_job_id(None::<String>);
pub fn set_spark_job_location<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of spark_job_location.

Example
let x = SparkStatistics::new().set_spark_job_location("example");
pub fn set_or_clear_spark_job_location<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of spark_job_location.

Example
let x = SparkStatistics::new().set_or_clear_spark_job_location(Some("example"));
let x = SparkStatistics::new().set_or_clear_spark_job_location(None::<String>);
pub fn set_endpoints<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of endpoints.

Example
let x = SparkStatistics::new().set_endpoints([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_logging_info<T>(self, v: T) -> Self
where T: Into<LoggingInfo>,

Sets the value of logging_info.

Example
use google_cloud_bigquery_v2::model::spark_statistics::LoggingInfo;
let x = SparkStatistics::new().set_logging_info(LoggingInfo::default()/* use setters */);
pub fn set_or_clear_logging_info<T>(self, v: Option<T>) -> Self
where T: Into<LoggingInfo>,

Sets or clears the value of logging_info.

Example
use google_cloud_bigquery_v2::model::spark_statistics::LoggingInfo;
let x = SparkStatistics::new().set_or_clear_logging_info(Some(LoggingInfo::default()/* use setters */));
let x = SparkStatistics::new().set_or_clear_logging_info(None::<LoggingInfo>);
pub fn set_kms_key_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kms_key_name.

Example
let x = SparkStatistics::new().set_kms_key_name("example");
pub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kms_key_name.

Example
let x = SparkStatistics::new().set_or_clear_kms_key_name(Some("example"));
let x = SparkStatistics::new().set_or_clear_kms_key_name(None::<String>);
pub fn set_gcs_staging_bucket<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of gcs_staging_bucket.

Example
let x = SparkStatistics::new().set_gcs_staging_bucket("example");
pub fn set_or_clear_gcs_staging_bucket<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of gcs_staging_bucket.

Example
let x = SparkStatistics::new().set_or_clear_gcs_staging_bucket(Some("example"));
let x = SparkStatistics::new().set_or_clear_gcs_staging_bucket(None::<String>);