#[non_exhaustive]pub struct StandardSqlDataType {
pub type_kind: TypeKind,
pub sub_type: Option<SubType>,
/* private fields */
}Expand description
The data type of a variable such as a function argument. Examples include:
-
INT64:
{"typeKind": "INT64"} -
ARRAY<STRING>:
{ “typeKind”: “ARRAY”, “arrayElementType”: {“typeKind”: “STRING”} }
-
STRUCT<x STRING, y ARRAY<DATE>>:
{ “typeKind”: “STRUCT”, “structType”: { “fields”: [ { “name”: “x”, “type”: {“typeKind”: “STRING”} }, { “name”: “y”, “type”: { “typeKind”: “ARRAY”, “arrayElementType”: {“typeKind”: “DATE”} } } ] } }
-
RANGE<DATE>:
{ “typeKind”: “RANGE”, “rangeElementType”: {“typeKind”: “DATE”} }
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_kind: TypeKindRequired. The top level type of this field. Can be any GoogleSQL data type (e.g., “INT64”, “DATE”, “ARRAY”).
sub_type: Option<SubType>For complex types, the sub type information.
Implementations
Sourceimpl StandardSqlDataType
impl StandardSqlDataType
Sourcepub fn set_type_kind<T: Into<TypeKind>>(self, v: T) -> Self
pub fn set_type_kind<T: Into<TypeKind>>(self, v: T) -> Self
Sets the value of type_kind.
Example
use google_cloud_bigquery_v2::model::standard_sql_data_type::TypeKind;
let x0 = StandardSqlDataType::new().set_type_kind(TypeKind::Int64);
let x1 = StandardSqlDataType::new().set_type_kind(TypeKind::Bool);
let x2 = StandardSqlDataType::new().set_type_kind(TypeKind::Float64);Sourcepub fn set_sub_type<T: Into<Option<SubType>>>(self, v: T) -> Self
pub fn set_sub_type<T: Into<Option<SubType>>>(self, v: T) -> Self
Sourcepub fn array_element_type(&self) -> Option<&Box<StandardSqlDataType>>
pub fn array_element_type(&self) -> Option<&Box<StandardSqlDataType>>
The value of sub_type
if it holds a ArrayElementType, None if the field is not set or
holds a different branch.
Sourcepub fn set_array_element_type<T: Into<Box<StandardSqlDataType>>>(
self,
v: T,
) -> Self
pub fn set_array_element_type<T: Into<Box<StandardSqlDataType>>>( self, v: T, ) -> Self
Sets the value of sub_type
to hold a ArrayElementType.
Note that all the setters affecting sub_type are
mutually exclusive.
Example
let x = StandardSqlDataType::new().set_array_element_type(StandardSqlDataType::default()/* use setters */);
assert!(x.array_element_type().is_some());
assert!(x.struct_type().is_none());
assert!(x.range_element_type().is_none());Sourcepub fn struct_type(&self) -> Option<&Box<StandardSqlStructType>>
pub fn struct_type(&self) -> Option<&Box<StandardSqlStructType>>
The value of sub_type
if it holds a StructType, None if the field is not set or
holds a different branch.
Sourcepub fn set_struct_type<T: Into<Box<StandardSqlStructType>>>(self, v: T) -> Self
pub fn set_struct_type<T: Into<Box<StandardSqlStructType>>>(self, v: T) -> Self
Sets the value of sub_type
to hold a StructType.
Note that all the setters affecting sub_type are
mutually exclusive.
Example
use google_cloud_bigquery_v2::model::StandardSqlStructType;
let x = StandardSqlDataType::new().set_struct_type(StandardSqlStructType::default()/* use setters */);
assert!(x.struct_type().is_some());
assert!(x.array_element_type().is_none());
assert!(x.range_element_type().is_none());Sourcepub fn range_element_type(&self) -> Option<&Box<StandardSqlDataType>>
pub fn range_element_type(&self) -> Option<&Box<StandardSqlDataType>>
The value of sub_type
if it holds a RangeElementType, None if the field is not set or
holds a different branch.
Sourcepub fn set_range_element_type<T: Into<Box<StandardSqlDataType>>>(
self,
v: T,
) -> Self
pub fn set_range_element_type<T: Into<Box<StandardSqlDataType>>>( self, v: T, ) -> Self
Sets the value of sub_type
to hold a RangeElementType.
Note that all the setters affecting sub_type are
mutually exclusive.
Example
let x = StandardSqlDataType::new().set_range_element_type(StandardSqlDataType::default()/* use setters */);
assert!(x.range_element_type().is_some());
assert!(x.array_element_type().is_none());
assert!(x.struct_type().is_none());Trait Implementations
Sourceimpl Clone for StandardSqlDataType
impl Clone for StandardSqlDataType
Sourcefn clone(&self) -> StandardSqlDataType
fn clone(&self) -> StandardSqlDataType
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StandardSqlDataType
impl Debug for StandardSqlDataType
Sourceimpl Default for StandardSqlDataType
impl Default for StandardSqlDataType
Sourcefn default() -> StandardSqlDataType
fn default() -> StandardSqlDataType
Sourceimpl Message for StandardSqlDataType
impl Message for StandardSqlDataType
Sourceimpl PartialEq for StandardSqlDataType
impl PartialEq for StandardSqlDataType
impl StructuralPartialEq for StandardSqlDataType