#[non_exhaustive]pub struct StorageDescriptor {
pub location_uri: String,
pub input_format: String,
pub output_format: String,
pub serde_info: Option<SerDeInfo>,
/* private fields */
}Expand description
Contains information about how a table’s data is stored and accessed by open source query engines.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location_uri: StringOptional. The physical location of the table
(e.g. gs://spark-dataproc-data/pangea-data/case_sensitive/ or
gs://spark-dataproc-data/pangea-data/*).
The maximum length is 2056 bytes.
input_format: StringOptional. Specifies the fully qualified class name of the InputFormat (e.g. “org.apache.hadoop.hive.ql.io.orc.OrcInputFormat”). The maximum length is 128 characters.
output_format: StringOptional. Specifies the fully qualified class name of the OutputFormat (e.g. “org.apache.hadoop.hive.ql.io.orc.OrcOutputFormat”). The maximum length is 128 characters.
serde_info: Option<SerDeInfo>Optional. Serializer and deserializer information.
Implementations
Sourceimpl StorageDescriptor
impl StorageDescriptor
Sourcepub fn set_location_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_location_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of location_uri.
Example
let x = StorageDescriptor::new().set_location_uri("example");Sourcepub fn set_input_format<T: Into<String>>(self, v: T) -> Self
pub fn set_input_format<T: Into<String>>(self, v: T) -> Self
Sets the value of input_format.
Example
let x = StorageDescriptor::new().set_input_format("example");Sourcepub fn set_output_format<T: Into<String>>(self, v: T) -> Self
pub fn set_output_format<T: Into<String>>(self, v: T) -> Self
Sets the value of output_format.
Example
let x = StorageDescriptor::new().set_output_format("example");Sourcepub fn set_serde_info<T>(self, v: T) -> Self
pub fn set_serde_info<T>(self, v: T) -> Self
Sets the value of serde_info.
Example
use google_cloud_bigquery_v2::model::SerDeInfo;
let x = StorageDescriptor::new().set_serde_info(SerDeInfo::default()/* use setters */);Sourcepub fn set_or_clear_serde_info<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_serde_info<T>(self, v: Option<T>) -> Self
Sets or clears the value of serde_info.
Example
use google_cloud_bigquery_v2::model::SerDeInfo;
let x = StorageDescriptor::new().set_or_clear_serde_info(Some(SerDeInfo::default()/* use setters */));
let x = StorageDescriptor::new().set_or_clear_serde_info(None::<SerDeInfo>);Trait Implementations
Sourceimpl Clone for StorageDescriptor
impl Clone for StorageDescriptor
Sourcefn clone(&self) -> StorageDescriptor
fn clone(&self) -> StorageDescriptor
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StorageDescriptor
impl Debug for StorageDescriptor
Sourceimpl Default for StorageDescriptor
impl Default for StorageDescriptor
Sourcefn default() -> StorageDescriptor
fn default() -> StorageDescriptor
Sourceimpl Message for StorageDescriptor
impl Message for StorageDescriptor
Sourceimpl PartialEq for StorageDescriptor
impl PartialEq for StorageDescriptor
impl StructuralPartialEq for StorageDescriptor