#[non_exhaustive]pub struct Streamingbuffer {
pub estimated_bytes: u64,
pub estimated_rows: u64,
pub oldest_entry_time: u64,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.estimated_bytes: u64Output only. A lower-bound estimate of the number of bytes currently in the streaming buffer.
estimated_rows: u64Output only. A lower-bound estimate of the number of rows currently in the streaming buffer.
oldest_entry_time: u64Output only. Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available.
Implementations
Sourceimpl Streamingbuffer
impl Streamingbuffer
Sourcepub fn set_estimated_bytes<T: Into<u64>>(self, v: T) -> Self
pub fn set_estimated_bytes<T: Into<u64>>(self, v: T) -> Self
Sets the value of estimated_bytes.
Example
ⓘ
let x = Streamingbuffer::new().set_estimated_bytes(42_u32);Sourcepub fn set_estimated_rows<T: Into<u64>>(self, v: T) -> Self
pub fn set_estimated_rows<T: Into<u64>>(self, v: T) -> Self
Sets the value of estimated_rows.
Example
ⓘ
let x = Streamingbuffer::new().set_estimated_rows(42_u32);Sourcepub fn set_oldest_entry_time<T: Into<u64>>(self, v: T) -> Self
pub fn set_oldest_entry_time<T: Into<u64>>(self, v: T) -> Self
Sets the value of oldest_entry_time.
Example
ⓘ
let x = Streamingbuffer::new().set_oldest_entry_time(42_u32);Trait Implementations
Sourceimpl Clone for Streamingbuffer
impl Clone for Streamingbuffer
Sourcefn clone(&self) -> Streamingbuffer
fn clone(&self) -> Streamingbuffer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Streamingbuffer
impl Debug for Streamingbuffer
Sourceimpl Default for Streamingbuffer
impl Default for Streamingbuffer
Sourcefn default() -> Streamingbuffer
fn default() -> Streamingbuffer
Returns the “default value” for a type. Read more
Sourceimpl Message for Streamingbuffer
impl Message for Streamingbuffer
Sourceimpl PartialEq for Streamingbuffer
impl PartialEq for Streamingbuffer
impl StructuralPartialEq for Streamingbuffer