#[non_exhaustive]pub struct TableChangeInsight {
pub table_reference: Option<TableReference>,
pub metadata_cache_staleness_insight: Option<MetadataCacheStalenessInsight>,
pub metadata_cache_not_used_but_used_previously: Option<bool>,
/* private fields */
}Expand description
Table-level performance insights compared to previous runs. These insights don’t apply to specific query stages, rather they apply to the whole table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_reference: Option<TableReference>Output only. The table that was queried.
metadata_cache_staleness_insight: Option<MetadataCacheStalenessInsight>Output only. If present, indicates that the table’s metadata column index staleness has increased significantly compared to previous jobs with the same query hash.
metadata_cache_not_used_but_used_previously: Option<bool>Output only. True if the table’s column metadata index was not used in the current job, but was used in a previous job with the same query hash.
Implementations
Sourceimpl TableChangeInsight
impl TableChangeInsight
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableChangeInsight::new().set_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableChangeInsight::new().set_or_clear_table_reference(Some(TableReference::default()/* use setters */));
let x = TableChangeInsight::new().set_or_clear_table_reference(None::<TableReference>);Sourcepub fn set_metadata_cache_staleness_insight<T>(self, v: T) -> Selfwhere
T: Into<MetadataCacheStalenessInsight>,
pub fn set_metadata_cache_staleness_insight<T>(self, v: T) -> Selfwhere
T: Into<MetadataCacheStalenessInsight>,
Sets the value of metadata_cache_staleness_insight.
Example
use google_cloud_bigquery_v2::model::MetadataCacheStalenessInsight;
let x = TableChangeInsight::new().set_metadata_cache_staleness_insight(MetadataCacheStalenessInsight::default()/* use setters */);Sourcepub fn set_or_clear_metadata_cache_staleness_insight<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MetadataCacheStalenessInsight>,
pub fn set_or_clear_metadata_cache_staleness_insight<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MetadataCacheStalenessInsight>,
Sets or clears the value of metadata_cache_staleness_insight.
Example
use google_cloud_bigquery_v2::model::MetadataCacheStalenessInsight;
let x = TableChangeInsight::new().set_or_clear_metadata_cache_staleness_insight(Some(MetadataCacheStalenessInsight::default()/* use setters */));
let x = TableChangeInsight::new().set_or_clear_metadata_cache_staleness_insight(None::<MetadataCacheStalenessInsight>);Sourcepub fn set_metadata_cache_not_used_but_used_previously<T>(self, v: T) -> Self
pub fn set_metadata_cache_not_used_but_used_previously<T>(self, v: T) -> Self
Sets the value of metadata_cache_not_used_but_used_previously.
Example
let x = TableChangeInsight::new().set_metadata_cache_not_used_but_used_previously(true);Sourcepub fn set_or_clear_metadata_cache_not_used_but_used_previously<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_metadata_cache_not_used_but_used_previously<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of metadata_cache_not_used_but_used_previously.
Example
let x = TableChangeInsight::new().set_or_clear_metadata_cache_not_used_but_used_previously(Some(false));
let x = TableChangeInsight::new().set_or_clear_metadata_cache_not_used_but_used_previously(None::<bool>);Trait Implementations
Sourceimpl Clone for TableChangeInsight
impl Clone for TableChangeInsight
Sourcefn clone(&self) -> TableChangeInsight
fn clone(&self) -> TableChangeInsight
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TableChangeInsight
impl Debug for TableChangeInsight
Sourceimpl Default for TableChangeInsight
impl Default for TableChangeInsight
Sourcefn default() -> TableChangeInsight
fn default() -> TableChangeInsight
Sourceimpl Message for TableChangeInsight
impl Message for TableChangeInsight
Sourceimpl PartialEq for TableChangeInsight
impl PartialEq for TableChangeInsight
impl StructuralPartialEq for TableChangeInsight