#[non_exhaustive]pub struct TableConstraints {
pub primary_key: Option<PrimaryKey>,
pub foreign_keys: Vec<ForeignKey>,
/* private fields */
}Expand description
The TableConstraints defines the primary key and foreign key.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.primary_key: Option<PrimaryKey>Optional. Represents a primary key constraint on a table’s columns. Present only if the table has a primary key. The primary key is not enforced.
foreign_keys: Vec<ForeignKey>Optional. Present only if the table has a foreign key. The foreign key is not enforced.
Implementations
Sourceimpl TableConstraints
impl TableConstraints
Sourcepub fn set_primary_key<T>(self, v: T) -> Selfwhere
T: Into<PrimaryKey>,
pub fn set_primary_key<T>(self, v: T) -> Selfwhere
T: Into<PrimaryKey>,
Sets the value of primary_key.
Example
ⓘ
use google_cloud_bigquery_v2::model::PrimaryKey;
let x = TableConstraints::new().set_primary_key(PrimaryKey::default()/* use setters */);Sourcepub fn set_or_clear_primary_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrimaryKey>,
pub fn set_or_clear_primary_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrimaryKey>,
Sets or clears the value of primary_key.
Example
ⓘ
use google_cloud_bigquery_v2::model::PrimaryKey;
let x = TableConstraints::new().set_or_clear_primary_key(Some(PrimaryKey::default()/* use setters */));
let x = TableConstraints::new().set_or_clear_primary_key(None::<PrimaryKey>);Sourcepub fn set_foreign_keys<T, V>(self, v: T) -> Self
pub fn set_foreign_keys<T, V>(self, v: T) -> Self
Sets the value of foreign_keys.
Example
ⓘ
use google_cloud_bigquery_v2::model::ForeignKey;
let x = TableConstraints::new()
.set_foreign_keys([
ForeignKey::default()/* use setters */,
ForeignKey::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for TableConstraints
impl Clone for TableConstraints
Sourcefn clone(&self) -> TableConstraints
fn clone(&self) -> TableConstraints
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableConstraints
impl Debug for TableConstraints
Sourceimpl Default for TableConstraints
impl Default for TableConstraints
Sourcefn default() -> TableConstraints
fn default() -> TableConstraints
Returns the “default value” for a type. Read more
Sourceimpl Message for TableConstraints
impl Message for TableConstraints
Sourceimpl PartialEq for TableConstraints
impl PartialEq for TableConstraints
impl StructuralPartialEq for TableConstraints