#[non_exhaustive]pub struct TableList {
pub kind: String,
pub etag: String,
pub next_page_token: String,
pub tables: Vec<ListFormatTable>,
pub total_items: Option<Int32Value>,
/* private fields */
}Expand description
Partial projection of the metadata for a given table in a list response.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringThe type of list.
etag: StringA hash of this page of results.
next_page_token: StringA token to request the next page of results.
tables: Vec<ListFormatTable>Tables in the requested dataset.
total_items: Option<Int32Value>The total number of tables in the dataset.
Implementations
Sourceimpl TableList
impl TableList
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = TableList::new().set_next_page_token("example");Sourcepub fn set_tables<T, V>(self, v: T) -> Self
pub fn set_tables<T, V>(self, v: T) -> Self
Sourcepub fn set_total_items<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
pub fn set_total_items<T>(self, v: T) -> Selfwhere
T: Into<Int32Value>,
Sets the value of total_items.
Example
ⓘ
use wkt::Int32Value;
let x = TableList::new().set_total_items(Int32Value::default()/* use setters */);Sourcepub fn set_or_clear_total_items<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
pub fn set_or_clear_total_items<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int32Value>,
Sets or clears the value of total_items.
Example
ⓘ
use wkt::Int32Value;
let x = TableList::new().set_or_clear_total_items(Some(Int32Value::default()/* use setters */));
let x = TableList::new().set_or_clear_total_items(None::<Int32Value>);Trait Implementations
impl StructuralPartialEq for TableList