#[non_exhaustive]pub struct TableMetadataCacheUsage {
pub table_reference: Option<TableReference>,
pub unused_reason: Option<UnusedReason>,
pub explanation: Option<String>,
pub staleness: Option<Duration>,
pub table_type: String,
pub pruning_stats: Option<PruningStats>,
/* private fields */
}Expand description
Table level detail on the usage of metadata caching. Only set for Metadata caching eligible tables referenced in the query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_reference: Option<TableReference>Metadata caching eligible table referenced in the query.
unused_reason: Option<UnusedReason>Reason for not using metadata caching for the table.
explanation: Option<String>Free form human-readable reason metadata caching was unused for the job.
staleness: Option<Duration>Duration since last refresh as of this job for managed tables (indicates metadata cache staleness as seen by this job).
table_type: Stringpruning_stats: Option<PruningStats>The column metadata index pruning statistics.
Implementations
Sourceimpl TableMetadataCacheUsage
impl TableMetadataCacheUsage
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableMetadataCacheUsage::new().set_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableMetadataCacheUsage::new().set_or_clear_table_reference(Some(TableReference::default()/* use setters */));
let x = TableMetadataCacheUsage::new().set_or_clear_table_reference(None::<TableReference>);Sourcepub fn set_unused_reason<T>(self, v: T) -> Selfwhere
T: Into<UnusedReason>,
pub fn set_unused_reason<T>(self, v: T) -> Selfwhere
T: Into<UnusedReason>,
Sets the value of unused_reason.
Example
use google_cloud_bigquery_v2::model::table_metadata_cache_usage::UnusedReason;
let x0 = TableMetadataCacheUsage::new().set_unused_reason(UnusedReason::ExceededMaxStaleness);
let x1 = TableMetadataCacheUsage::new().set_unused_reason(UnusedReason::MetadataCachingNotEnabled);
let x2 = TableMetadataCacheUsage::new().set_unused_reason(UnusedReason::OtherReason);Sourcepub fn set_or_clear_unused_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<UnusedReason>,
pub fn set_or_clear_unused_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<UnusedReason>,
Sets or clears the value of unused_reason.
Example
use google_cloud_bigquery_v2::model::table_metadata_cache_usage::UnusedReason;
let x0 = TableMetadataCacheUsage::new().set_or_clear_unused_reason(Some(UnusedReason::ExceededMaxStaleness));
let x1 = TableMetadataCacheUsage::new().set_or_clear_unused_reason(Some(UnusedReason::MetadataCachingNotEnabled));
let x2 = TableMetadataCacheUsage::new().set_or_clear_unused_reason(Some(UnusedReason::OtherReason));
let x_none = TableMetadataCacheUsage::new().set_or_clear_unused_reason(None::<UnusedReason>);Sourcepub fn set_explanation<T>(self, v: T) -> Self
pub fn set_explanation<T>(self, v: T) -> Self
Sets the value of explanation.
Example
let x = TableMetadataCacheUsage::new().set_explanation("example");Sourcepub fn set_or_clear_explanation<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_explanation<T>(self, v: Option<T>) -> Self
Sets or clears the value of explanation.
Example
let x = TableMetadataCacheUsage::new().set_or_clear_explanation(Some("example"));
let x = TableMetadataCacheUsage::new().set_or_clear_explanation(None::<String>);Sourcepub fn set_staleness<T>(self, v: T) -> Self
pub fn set_staleness<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_staleness<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_staleness<T>(self, v: Option<T>) -> Self
Sourcepub fn set_table_type<T: Into<String>>(self, v: T) -> Self
pub fn set_table_type<T: Into<String>>(self, v: T) -> Self
Sets the value of table_type.
Example
let x = TableMetadataCacheUsage::new().set_table_type("example");Sourcepub fn set_pruning_stats<T>(self, v: T) -> Selfwhere
T: Into<PruningStats>,
pub fn set_pruning_stats<T>(self, v: T) -> Selfwhere
T: Into<PruningStats>,
Sets the value of pruning_stats.
Example
use google_cloud_bigquery_v2::model::PruningStats;
let x = TableMetadataCacheUsage::new().set_pruning_stats(PruningStats::default()/* use setters */);Sourcepub fn set_or_clear_pruning_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<PruningStats>,
pub fn set_or_clear_pruning_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<PruningStats>,
Sets or clears the value of pruning_stats.
Example
use google_cloud_bigquery_v2::model::PruningStats;
let x = TableMetadataCacheUsage::new().set_or_clear_pruning_stats(Some(PruningStats::default()/* use setters */));
let x = TableMetadataCacheUsage::new().set_or_clear_pruning_stats(None::<PruningStats>);Trait Implementations
Sourceimpl Clone for TableMetadataCacheUsage
impl Clone for TableMetadataCacheUsage
Sourcefn clone(&self) -> TableMetadataCacheUsage
fn clone(&self) -> TableMetadataCacheUsage
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TableMetadataCacheUsage
impl Debug for TableMetadataCacheUsage
Sourceimpl Default for TableMetadataCacheUsage
impl Default for TableMetadataCacheUsage
Sourcefn default() -> TableMetadataCacheUsage
fn default() -> TableMetadataCacheUsage
Sourceimpl Message for TableMetadataCacheUsage
impl Message for TableMetadataCacheUsage
Sourceimpl PartialEq for TableMetadataCacheUsage
impl PartialEq for TableMetadataCacheUsage
impl StructuralPartialEq for TableMetadataCacheUsage