#[non_exhaustive]pub struct TableReplicationInfo {
pub source_table: Option<TableReference>,
pub replication_interval_ms: i64,
pub replicated_source_last_refresh_time: i64,
pub replication_status: ReplicationStatus,
pub replication_error: Option<ErrorProto>,
/* private fields */
}Expand description
Replication info of a table created using AS REPLICA DDL like:
CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_table: Option<TableReference>Required. Source table reference that is replicated.
replication_interval_ms: i64Optional. Specifies the interval at which the source table is polled for updates. It’s Optional. If not specified, default replication interval would be applied.
replicated_source_last_refresh_time: i64Optional. Output only. If source is a materialized view, this field signifies the last refresh time of the source.
replication_status: ReplicationStatusOptional. Output only. Replication status of configured replication.
replication_error: Option<ErrorProto>Optional. Output only. Replication error that will permanently stopped table replication.
Implementations
Sourceimpl TableReplicationInfo
impl TableReplicationInfo
Sourcepub fn set_source_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_source_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of source_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableReplicationInfo::new().set_source_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_source_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_source_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of source_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = TableReplicationInfo::new().set_or_clear_source_table(Some(TableReference::default()/* use setters */));
let x = TableReplicationInfo::new().set_or_clear_source_table(None::<TableReference>);Sourcepub fn set_replication_interval_ms<T: Into<i64>>(self, v: T) -> Self
pub fn set_replication_interval_ms<T: Into<i64>>(self, v: T) -> Self
Sets the value of replication_interval_ms.
Example
let x = TableReplicationInfo::new().set_replication_interval_ms(42);Sourcepub fn set_replicated_source_last_refresh_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_replicated_source_last_refresh_time<T: Into<i64>>(self, v: T) -> Self
Sets the value of replicated_source_last_refresh_time.
Example
let x = TableReplicationInfo::new().set_replicated_source_last_refresh_time(42);Sourcepub fn set_replication_status<T: Into<ReplicationStatus>>(self, v: T) -> Self
pub fn set_replication_status<T: Into<ReplicationStatus>>(self, v: T) -> Self
Sets the value of replication_status.
Example
use google_cloud_bigquery_v2::model::table_replication_info::ReplicationStatus;
let x0 = TableReplicationInfo::new().set_replication_status(ReplicationStatus::Active);
let x1 = TableReplicationInfo::new().set_replication_status(ReplicationStatus::SourceDeleted);
let x2 = TableReplicationInfo::new().set_replication_status(ReplicationStatus::PermissionDenied);Sourcepub fn set_replication_error<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_replication_error<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
Sets the value of replication_error.
Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = TableReplicationInfo::new().set_replication_error(ErrorProto::default()/* use setters */);Sourcepub fn set_or_clear_replication_error<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_or_clear_replication_error<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
Sets or clears the value of replication_error.
Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = TableReplicationInfo::new().set_or_clear_replication_error(Some(ErrorProto::default()/* use setters */));
let x = TableReplicationInfo::new().set_or_clear_replication_error(None::<ErrorProto>);Trait Implementations
Sourceimpl Clone for TableReplicationInfo
impl Clone for TableReplicationInfo
Sourcefn clone(&self) -> TableReplicationInfo
fn clone(&self) -> TableReplicationInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TableReplicationInfo
impl Debug for TableReplicationInfo
Sourceimpl Default for TableReplicationInfo
impl Default for TableReplicationInfo
Sourcefn default() -> TableReplicationInfo
fn default() -> TableReplicationInfo
Sourceimpl Message for TableReplicationInfo
impl Message for TableReplicationInfo
Sourceimpl PartialEq for TableReplicationInfo
impl PartialEq for TableReplicationInfo
impl StructuralPartialEq for TableReplicationInfo