#[non_exhaustive]pub struct TimePartitioning {
pub type: String,
pub expiration_ms: Option<Int64Value>,
pub field: Option<StringValue>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: StringRequired. The supported types are DAY, HOUR, MONTH, and YEAR, which will generate one partition per day, hour, month, and year, respectively.
expiration_ms: Option<Int64Value>Optional. Number of milliseconds for which to keep the storage for a partition. A wrapper is used here because 0 is an invalid value.
field: Option<StringValue>Optional. If not set, the table is partitioned by pseudo column ‘_PARTITIONTIME’; if set, the table is partitioned by this field. The field must be a top-level TIMESTAMP or DATE field. Its mode must be NULLABLE or REQUIRED. A wrapper is used here because an empty string is an invalid value.
Implementations
Sourceimpl TimePartitioning
impl TimePartitioning
Sourcepub fn set_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_expiration_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of expiration_ms.
Example
ⓘ
use wkt::Int64Value;
let x = TimePartitioning::new().set_expiration_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_expiration_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_expiration_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of expiration_ms.
Example
ⓘ
use wkt::Int64Value;
let x = TimePartitioning::new().set_or_clear_expiration_ms(Some(Int64Value::default()/* use setters */));
let x = TimePartitioning::new().set_or_clear_expiration_ms(None::<Int64Value>);Sourcepub fn set_field<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_field<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sourcepub fn set_or_clear_field<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_field<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,