#[non_exhaustive]pub struct UpdateOrPatchDatasetRequest {
pub project_id: String,
pub dataset_id: String,
pub dataset: Option<Dataset>,
pub update_mode: UpdateMode,
pub access_policy_version: i32,
/* private fields */
}Expand description
Message for updating or patching a dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the dataset being updated
dataset_id: StringRequired. Dataset ID of the dataset being updated
dataset: Option<Dataset>Required. Datasets resource which will replace or patch the specified dataset.
update_mode: UpdateModeOptional. Specifies the fields of dataset that update/patch operation is targeting By default, both metadata and ACL fields are updated.
access_policy_version: i32Optional. The version of the provided access policy schema. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected.
This version refers to the schema version of the access policy and not the version of access policy. This field’s value can be equal or more than the access policy schema provided in the request. For example,
- Operations updating conditional access policy binding in datasets must
specify
version 3. Some of the operations are :
- Adding a new access policy entry with condition.
- Removing an access policy entry with condition.
- Updating an access policy entry with condition.
- But dataset with no conditional role bindings in access policy may specify any valid value or leave the field unset. If unset or if 0 or 1 value is used for dataset with conditional bindings, request will be rejected.
This field will be mapped to IAM Policy version (https://cloud.google.com/iam/docs/policies#versions) and will be used to set policy in IAM.
Implementations
Sourceimpl UpdateOrPatchDatasetRequest
impl UpdateOrPatchDatasetRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = UpdateOrPatchDatasetRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
let x = UpdateOrPatchDatasetRequest::new().set_dataset_id("example");Sourcepub fn set_dataset<T>(self, v: T) -> Self
pub fn set_dataset<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mode<T: Into<UpdateMode>>(self, v: T) -> Self
pub fn set_update_mode<T: Into<UpdateMode>>(self, v: T) -> Self
Sets the value of update_mode.
Example
use google_cloud_bigquery_v2::model::update_or_patch_dataset_request::UpdateMode;
let x0 = UpdateOrPatchDatasetRequest::new().set_update_mode(UpdateMode::UpdateMetadata);
let x1 = UpdateOrPatchDatasetRequest::new().set_update_mode(UpdateMode::UpdateAcl);
let x2 = UpdateOrPatchDatasetRequest::new().set_update_mode(UpdateMode::UpdateFull);Sourcepub fn set_access_policy_version<T: Into<i32>>(self, v: T) -> Self
pub fn set_access_policy_version<T: Into<i32>>(self, v: T) -> Self
Sets the value of access_policy_version.
Example
let x = UpdateOrPatchDatasetRequest::new().set_access_policy_version(42);Trait Implementations
Sourceimpl Clone for UpdateOrPatchDatasetRequest
impl Clone for UpdateOrPatchDatasetRequest
Sourcefn clone(&self) -> UpdateOrPatchDatasetRequest
fn clone(&self) -> UpdateOrPatchDatasetRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateOrPatchDatasetRequest
impl Debug for UpdateOrPatchDatasetRequest
Sourceimpl Default for UpdateOrPatchDatasetRequest
impl Default for UpdateOrPatchDatasetRequest
Sourcefn default() -> UpdateOrPatchDatasetRequest
fn default() -> UpdateOrPatchDatasetRequest
impl StructuralPartialEq for UpdateOrPatchDatasetRequest