#[non_exhaustive]pub struct UpdateOrPatchTableRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub table: Option<Table>,
pub autodetect_schema: bool,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the table to update
dataset_id: StringRequired. Dataset ID of the table to update
table_id: StringRequired. Table ID of the table to update
table: Option<Table>Required. A tables resource which will replace or patch the specified table
autodetect_schema: boolOptional. When true will autodetect schema, else will keep original schema.
Implementations
Sourceimpl UpdateOrPatchTableRequest
impl UpdateOrPatchTableRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = UpdateOrPatchTableRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = UpdateOrPatchTableRequest::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_table<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_table<T>(self, v: Option<T>) -> Self
Sourcepub fn set_autodetect_schema<T: Into<bool>>(self, v: T) -> Self
pub fn set_autodetect_schema<T: Into<bool>>(self, v: T) -> Self
Sets the value of autodetect_schema.
Example
ⓘ
let x = UpdateOrPatchTableRequest::new().set_autodetect_schema(true);Trait Implementations
Sourceimpl Clone for UpdateOrPatchTableRequest
impl Clone for UpdateOrPatchTableRequest
Sourcefn clone(&self) -> UpdateOrPatchTableRequest
fn clone(&self) -> UpdateOrPatchTableRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateOrPatchTableRequest
impl Debug for UpdateOrPatchTableRequest
Sourceimpl Default for UpdateOrPatchTableRequest
impl Default for UpdateOrPatchTableRequest
Sourcefn default() -> UpdateOrPatchTableRequest
fn default() -> UpdateOrPatchTableRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateOrPatchTableRequest
impl Message for UpdateOrPatchTableRequest
impl StructuralPartialEq for UpdateOrPatchTableRequest