#[non_exhaustive]pub struct UpdateRowAccessPolicyRequest {
pub project_id: String,
pub dataset_id: String,
pub table_id: String,
pub policy_id: String,
pub row_access_policy: Option<RowAccessPolicy>,
/* private fields */
}Expand description
Request message for the UpdateRowAccessPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the table to get the row access policy.
dataset_id: StringRequired. Dataset ID of the table to get the row access policy.
table_id: StringRequired. Table ID of the table to get the row access policy.
policy_id: StringRequired. Policy ID of the row access policy.
row_access_policy: Option<RowAccessPolicy>Required. The row access policy to update.
Implementations
Sourceimpl UpdateRowAccessPolicyRequest
impl UpdateRowAccessPolicyRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = UpdateRowAccessPolicyRequest::new().set_project_id("example");Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_id.
Example
ⓘ
let x = UpdateRowAccessPolicyRequest::new().set_dataset_id("example");Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_policy_id<T: Into<String>>(self, v: T) -> Self
pub fn set_policy_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_row_access_policy<T>(self, v: T) -> Selfwhere
T: Into<RowAccessPolicy>,
pub fn set_row_access_policy<T>(self, v: T) -> Selfwhere
T: Into<RowAccessPolicy>,
Sets the value of row_access_policy.
Example
ⓘ
use google_cloud_bigquery_v2::model::RowAccessPolicy;
let x = UpdateRowAccessPolicyRequest::new().set_row_access_policy(RowAccessPolicy::default()/* use setters */);Sourcepub fn set_or_clear_row_access_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RowAccessPolicy>,
pub fn set_or_clear_row_access_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RowAccessPolicy>,
Sets or clears the value of row_access_policy.
Example
ⓘ
use google_cloud_bigquery_v2::model::RowAccessPolicy;
let x = UpdateRowAccessPolicyRequest::new().set_or_clear_row_access_policy(Some(RowAccessPolicy::default()/* use setters */));
let x = UpdateRowAccessPolicyRequest::new().set_or_clear_row_access_policy(None::<RowAccessPolicy>);Trait Implementations
Sourceimpl Clone for UpdateRowAccessPolicyRequest
impl Clone for UpdateRowAccessPolicyRequest
Sourcefn clone(&self) -> UpdateRowAccessPolicyRequest
fn clone(&self) -> UpdateRowAccessPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRowAccessPolicyRequest
impl Debug for UpdateRowAccessPolicyRequest
Sourceimpl Default for UpdateRowAccessPolicyRequest
impl Default for UpdateRowAccessPolicyRequest
Sourcefn default() -> UpdateRowAccessPolicyRequest
fn default() -> UpdateRowAccessPolicyRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for UpdateRowAccessPolicyRequest