#[non_exhaustive]pub struct UserDefinedFunctionResource {
pub resource_uri: Option<StringValue>,
pub inline_code: Option<StringValue>,
/* private fields */
}Expand description
This is used for defining User Defined Function (UDF) resources only when using legacy SQL. Users of GoogleSQL should leverage either DDL (e.g. CREATE [TEMPORARY] FUNCTION … ) or the Routines API to define UDF resources.
For additional information on migrating, see: https://cloud.google.com/bigquery/docs/reference/standard-sql/migrating-from-legacy-sql#differences_in_user-defined_javascript_functions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_uri: Option<StringValue>[Pick one] A code resource to load from a Google Cloud Storage URI (gs://bucket/path).
inline_code: Option<StringValue>[Pick one] An inline resource that contains code for a user-defined function (UDF). Providing a inline code resource is equivalent to providing a URI for a file containing the same code.
Implementations
Sourceimpl UserDefinedFunctionResource
impl UserDefinedFunctionResource
Sourcepub fn set_resource_uri<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_resource_uri<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of resource_uri.
Example
use wkt::StringValue;
let x = UserDefinedFunctionResource::new().set_resource_uri(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_resource_uri<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_resource_uri<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of resource_uri.
Example
use wkt::StringValue;
let x = UserDefinedFunctionResource::new().set_or_clear_resource_uri(Some(StringValue::default()/* use setters */));
let x = UserDefinedFunctionResource::new().set_or_clear_resource_uri(None::<StringValue>);Sourcepub fn set_inline_code<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_inline_code<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of inline_code.
Example
use wkt::StringValue;
let x = UserDefinedFunctionResource::new().set_inline_code(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_inline_code<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_inline_code<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of inline_code.
Example
use wkt::StringValue;
let x = UserDefinedFunctionResource::new().set_or_clear_inline_code(Some(StringValue::default()/* use setters */));
let x = UserDefinedFunctionResource::new().set_or_clear_inline_code(None::<StringValue>);Trait Implementations
Sourceimpl Clone for UserDefinedFunctionResource
impl Clone for UserDefinedFunctionResource
Sourcefn clone(&self) -> UserDefinedFunctionResource
fn clone(&self) -> UserDefinedFunctionResource
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UserDefinedFunctionResource
impl Debug for UserDefinedFunctionResource
Sourceimpl Default for UserDefinedFunctionResource
impl Default for UserDefinedFunctionResource
Sourcefn default() -> UserDefinedFunctionResource
fn default() -> UserDefinedFunctionResource
impl StructuralPartialEq for UserDefinedFunctionResource