#[non_exhaustive]pub struct VectorSearchStatistics {
pub index_usage_mode: IndexUsageMode,
pub index_unused_reasons: Vec<IndexUnusedReason>,
pub stored_columns_usages: Vec<StoredColumnsUsage>,
/* private fields */
}Expand description
Statistics for a vector search query. Populated as part of JobStatistics2.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index_usage_mode: IndexUsageModeSpecifies the index usage mode for the query.
index_unused_reasons: Vec<IndexUnusedReason>When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains
why indexes were not used in all or part of the vector search query. If
indexUsageMode is FULLY_USED, this field is not populated.
stored_columns_usages: Vec<StoredColumnsUsage>Specifies the usage of stored columns in the query when stored columns are used in the query.
Implementations
Sourceimpl VectorSearchStatistics
impl VectorSearchStatistics
Sourcepub fn set_index_usage_mode<T: Into<IndexUsageMode>>(self, v: T) -> Self
pub fn set_index_usage_mode<T: Into<IndexUsageMode>>(self, v: T) -> Self
Sets the value of index_usage_mode.
Example
ⓘ
use google_cloud_bigquery_v2::model::vector_search_statistics::IndexUsageMode;
let x0 = VectorSearchStatistics::new().set_index_usage_mode(IndexUsageMode::Unused);
let x1 = VectorSearchStatistics::new().set_index_usage_mode(IndexUsageMode::PartiallyUsed);
let x2 = VectorSearchStatistics::new().set_index_usage_mode(IndexUsageMode::FullyUsed);Sourcepub fn set_index_unused_reasons<T, V>(self, v: T) -> Self
pub fn set_index_unused_reasons<T, V>(self, v: T) -> Self
Sets the value of index_unused_reasons.
Example
ⓘ
use google_cloud_bigquery_v2::model::IndexUnusedReason;
let x = VectorSearchStatistics::new()
.set_index_unused_reasons([
IndexUnusedReason::default()/* use setters */,
IndexUnusedReason::default()/* use (different) setters */,
]);Sourcepub fn set_stored_columns_usages<T, V>(self, v: T) -> Self
pub fn set_stored_columns_usages<T, V>(self, v: T) -> Self
Sets the value of stored_columns_usages.
Example
ⓘ
use google_cloud_bigquery_v2::model::StoredColumnsUsage;
let x = VectorSearchStatistics::new()
.set_stored_columns_usages([
StoredColumnsUsage::default()/* use setters */,
StoredColumnsUsage::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for VectorSearchStatistics
impl Clone for VectorSearchStatistics
Sourcefn clone(&self) -> VectorSearchStatistics
fn clone(&self) -> VectorSearchStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorSearchStatistics
impl Debug for VectorSearchStatistics
Sourceimpl Default for VectorSearchStatistics
impl Default for VectorSearchStatistics
Sourcefn default() -> VectorSearchStatistics
fn default() -> VectorSearchStatistics
Returns the “default value” for a type. Read more
Sourceimpl Message for VectorSearchStatistics
impl Message for VectorSearchStatistics
Sourceimpl PartialEq for VectorSearchStatistics
impl PartialEq for VectorSearchStatistics
impl StructuralPartialEq for VectorSearchStatistics