ViewDefinition

Struct ViewDefinition 

#[non_exhaustive]
pub struct ViewDefinition { pub query: String, pub user_defined_function_resources: Vec<UserDefinedFunctionResource>, pub use_legacy_sql: Option<BoolValue>, pub use_explicit_column_names: bool, pub privacy_policy: Option<PrivacyPolicy>, pub foreign_definitions: Vec<ForeignViewDefinition>, /* private fields */ }
Describes the definition of a logical view.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query: String

Required. A query that BigQuery executes when the view is referenced.

user_defined_function_resources: Vec<UserDefinedFunctionResource>

Describes user-defined function resources used in the query.

use_legacy_sql: Option<BoolValue>

Specifies whether to use BigQuery’s legacy SQL for this view. The default value is true. If set to false, the view uses BigQuery’s GoogleSQL.

Queries and views that reference this view must use the same flag value. A wrapper is used here because the default value is True.

use_explicit_column_names: bool

True if the column names are explicitly specified. For example by using the ‘CREATE VIEW v(c1, c2) AS …’ syntax. Can only be set for GoogleSQL views.

privacy_policy: Option<PrivacyPolicy>

Optional. Specifies the privacy policy for the view.

foreign_definitions: Vec<ForeignViewDefinition>

Optional. Foreign view representations.

Implementations

Source

impl ViewDefinition

pub fn new() -> Self

Creates a new default instance.

pub fn set_query<T: Into<String>>(self, v: T) -> Self

Sets the value of query.

Example
let x = ViewDefinition::new().set_query("example");
pub fn set_user_defined_function_resources<T, V>(self, v: T) -> Self

Sets the value of user_defined_function_resources.

Example
use google_cloud_bigquery_v2::model::UserDefinedFunctionResource;
let x = ViewDefinition::new()
    .set_user_defined_function_resources([
        UserDefinedFunctionResource::default()/* use setters */,
        UserDefinedFunctionResource::default()/* use (different) setters */,
    ]);
pub fn set_use_legacy_sql<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = ViewDefinition::new().set_use_legacy_sql(BoolValue::default()/* use setters */);
pub fn set_or_clear_use_legacy_sql<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of use_legacy_sql.

Example
use wkt::BoolValue;
let x = ViewDefinition::new().set_or_clear_use_legacy_sql(Some(BoolValue::default()/* use setters */));
let x = ViewDefinition::new().set_or_clear_use_legacy_sql(None::<BoolValue>);
pub fn set_use_explicit_column_names<T: Into<bool>>(self, v: T) -> Self

Sets the value of use_explicit_column_names.

Example
let x = ViewDefinition::new().set_use_explicit_column_names(true);
pub fn set_privacy_policy<T>(self, v: T) -> Self
where T: Into<PrivacyPolicy>,

Sets the value of privacy_policy.

Example
use google_cloud_bigquery_v2::model::PrivacyPolicy;
let x = ViewDefinition::new().set_privacy_policy(PrivacyPolicy::default()/* use setters */);
pub fn set_or_clear_privacy_policy<T>(self, v: Option<T>) -> Self
where T: Into<PrivacyPolicy>,

Sets or clears the value of privacy_policy.

Example
use google_cloud_bigquery_v2::model::PrivacyPolicy;
let x = ViewDefinition::new().set_or_clear_privacy_policy(Some(PrivacyPolicy::default()/* use setters */));
let x = ViewDefinition::new().set_or_clear_privacy_policy(None::<PrivacyPolicy>);
pub fn set_foreign_definitions<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ForeignViewDefinition>,

Sets the value of foreign_definitions.

Example
use google_cloud_bigquery_v2::model::ForeignViewDefinition;
let x = ViewDefinition::new()
    .set_foreign_definitions([
        ForeignViewDefinition::default()/* use setters */,
        ForeignViewDefinition::default()/* use (different) setters */,
    ]);