#[non_exhaustive]pub enum RoundingMode {
Unspecified,
RoundHalfAwayFromZero,
RoundHalfEven,
UnknownValue(UnknownValue),
}Expand description
Rounding mode options that can be used when storing NUMERIC or BIGNUMERIC values.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified will default to using ROUND_HALF_AWAY_FROM_ZERO.
RoundHalfAwayFromZero
ROUND_HALF_AWAY_FROM_ZERO rounds half values away from zero when applying precision and scale upon writing of NUMERIC and BIGNUMERIC values. For Scale: 0 1.1, 1.2, 1.3, 1.4 => 1 1.5, 1.6, 1.7, 1.8, 1.9 => 2
RoundHalfEven
ROUND_HALF_EVEN rounds half values to the nearest even value when applying precision and scale upon writing of NUMERIC and BIGNUMERIC values. For Scale: 0 1.1, 1.2, 1.3, 1.4 => 1 1.5 => 2 1.6, 1.7, 1.8, 1.9 => 2 2.5 => 2
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using RoundingMode::value or RoundingMode::name.
Implementations