#[non_exhaustive]pub enum GeneratedMode {
Unspecified,
GeneratedAlways,
GeneratedByDefault,
UnknownValue(UnknownValue),
}Expand description
Dictates when system generated values are used to populate the field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified GeneratedMode will default to GENERATED_ALWAYS.
GeneratedAlways
Field can only have system generated values. Users cannot manually insert values into the field.
GeneratedByDefault
Use system generated values only if the user does not explicitly provide a value.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using GeneratedMode::value or GeneratedMode::name.
Implementations