#[non_exhaustive]pub struct GeneratedExpressionInfo {
pub generation_expression: Option<String>,
pub asynchronous: Option<bool>,
pub stored: Option<bool>,
/* private fields */
}Expand description
Definition of the expression used to generate the field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generation_expression: Option<String>Optional. The generation expression (e.g. AI.EMBED(…)) used to generate the field.
asynchronous: Option<bool>Optional. Whether the column generation is done asynchronously.
stored: Option<bool>Optional. Whether the generated column is stored in the table.
Implementations
Sourceimpl GeneratedExpressionInfo
impl GeneratedExpressionInfo
Sourcepub fn set_generation_expression<T>(self, v: T) -> Self
pub fn set_generation_expression<T>(self, v: T) -> Self
Sets the value of generation_expression.
Example
ⓘ
let x = GeneratedExpressionInfo::new().set_generation_expression("example");Sourcepub fn set_or_clear_generation_expression<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_generation_expression<T>(self, v: Option<T>) -> Self
Sets or clears the value of generation_expression.
Example
ⓘ
let x = GeneratedExpressionInfo::new().set_or_clear_generation_expression(Some("example"));
let x = GeneratedExpressionInfo::new().set_or_clear_generation_expression(None::<String>);Sourcepub fn set_asynchronous<T>(self, v: T) -> Self
pub fn set_asynchronous<T>(self, v: T) -> Self
Sets the value of asynchronous.
Example
ⓘ
let x = GeneratedExpressionInfo::new().set_asynchronous(true);Sourcepub fn set_or_clear_asynchronous<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_asynchronous<T>(self, v: Option<T>) -> Self
Sets or clears the value of asynchronous.
Example
ⓘ
let x = GeneratedExpressionInfo::new().set_or_clear_asynchronous(Some(false));
let x = GeneratedExpressionInfo::new().set_or_clear_asynchronous(None::<bool>);Sourcepub fn set_stored<T>(self, v: T) -> Self
pub fn set_stored<T>(self, v: T) -> Self