#[non_exhaustive]pub enum UnusedReason {
Unspecified,
ExceededMaxStaleness,
MetadataCachingNotEnabled,
OtherReason,
UnknownValue(UnknownValue),
}Expand description
Reasons for not using metadata caching.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unused reasons not specified.
ExceededMaxStaleness
Metadata cache was outside the table’s maxStaleness.
MetadataCachingNotEnabled
Metadata caching feature is not enabled. [Update BigLake tables] (/bigquery/docs/create-cloud-storage-table-biglake#update-biglake-tables) to enable the metadata caching.
OtherReason
Other unknown reason.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using UnusedReason::value or UnusedReason::name.
Implementations