#[non_exhaustive]pub enum UpdateMode {
Unspecified,
UpdateMetadata,
UpdateAcl,
UpdateFull,
UnknownValue(UnknownValue),
}Expand description
UpdateMode specifies which dataset fields is updated.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. Default to the UPDATE_FULL.
UpdateMetadata
Includes metadata information for the dataset, such as friendlyName, description, labels, etc.
UpdateAcl
Includes ACL information for the dataset, which defines dataset access for one or more entities.
UpdateFull
Includes both dataset metadata and ACL information.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using UpdateMode::value or UpdateMode::name.
Implementations