#[non_exhaustive]pub enum IndexUsageMode {
Unspecified,
Unused,
PartiallyUsed,
FullyUsed,
UnknownValue(UnknownValue),
}Expand description
Indicates the type of vector index usage in the entire vector search query.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Index usage mode not specified.
Unused
No vector indexes were used in the vector search query. See
[indexUnusedReasons]
(/bigquery/docs/reference/rest/v2/Job#IndexUnusedReason)
for detailed reasons.
PartiallyUsed
Part of the vector search query used vector indexes. See
[indexUnusedReasons]
(/bigquery/docs/reference/rest/v2/Job#IndexUnusedReason)
for why other parts of the query did not use vector indexes.
FullyUsed
The entire vector search query used vector indexes.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using IndexUsageMode::value or IndexUsageMode::name.
Implementations