pub struct JobPoller { /* private fields */ }Expand description
A poller that monitors the status of an inserted BigQuery job and handles retries.
Implementations
Sourceimpl JobPoller
impl JobPoller
Sourcepub fn with_attempt_limit(self, limit: u32) -> Self
pub fn with_attempt_limit(self, limit: u32) -> Self
Sets the maximum number of job-level attempts.
Sourcepub fn with_job_retry_backoff(self, backoff: ExponentialBackoff) -> Self
pub fn with_job_retry_backoff(self, backoff: ExponentialBackoff) -> Self
Sets the exponential backoff policy for job-level retries.
Sourcepub async fn until_done(self) -> Result<Job, JobPollerError>
pub async fn until_done(self) -> Result<Job, JobPollerError>
Polls the job until it is done, returning the final Job status.