Module stub

Module stub 

Traits to mock the clients in this library.

Application developers may need to mock the clients in this library to test how their application works with different (and sometimes hard to trigger) client and service behavior. Such test can define mocks implementing the trait(s) defined in this module, initialize the client with an instance of this mock in their tests, and verify their application responds as expected.

Traits

DatasetService
Defines the trait used to implement super::client::DatasetService.
JobService
Defines the trait used to implement super::client::JobService.
ModelService
Defines the trait used to implement super::client::ModelService.
ProjectService
Defines the trait used to implement super::client::ProjectService.
RoutineService
Defines the trait used to implement super::client::RoutineService.
RowAccessPolicyService
Defines the trait used to implement super::client::RowAccessPolicyService.
TableService
Defines the trait used to implement super::client::TableService.