pub trait JobService:
Debug
+ Send
+ Sync {
// Provided methods
fn cancel_job(
&self,
_req: CancelJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<JobCancelResponse>>> + Send { ... }
fn get_job(
&self,
_req: GetJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Job>>> + Send { ... }
fn insert_job(
&self,
_req: InsertJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Job>>> + Send { ... }
fn delete_job(
&self,
_req: DeleteJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn list_jobs(
&self,
_req: ListJobsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<JobList>>> + Send { ... }
fn get_query_results(
&self,
_req: GetQueryResultsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<GetQueryResultsResponse>>> + Send { ... }
fn query(
&self,
_req: PostQueryRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<QueryResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::JobService.
Application developers may need to implement this trait to mock
client::JobService. In other use-cases, application developers only
use client::JobService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn cancel_job(
&self,
_req: CancelJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<JobCancelResponse>>> + Send
fn cancel_job( &self, _req: CancelJobRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<JobCancelResponse>>> + Send
Implements super::client::JobService::cancel_job.
Sourcefn get_job(
&self,
_req: GetJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Job>>> + Send
fn get_job( &self, _req: GetJobRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Job>>> + Send
Implements super::client::JobService::get_job.
Sourcefn insert_job(
&self,
_req: InsertJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Job>>> + Send
fn insert_job( &self, _req: InsertJobRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Job>>> + Send
Implements super::client::JobService::insert_job.
Sourcefn delete_job(
&self,
_req: DeleteJobRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_job( &self, _req: DeleteJobRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Implements super::client::JobService::delete_job.
Sourcefn list_jobs(
&self,
_req: ListJobsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<JobList>>> + Send
fn list_jobs( &self, _req: ListJobsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<JobList>>> + Send
Implements super::client::JobService::list_jobs.
Sourcefn get_query_results(
&self,
_req: GetQueryResultsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<GetQueryResultsResponse>>> + Send
fn get_query_results( &self, _req: GetQueryResultsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<GetQueryResultsResponse>>> + Send
Implements super::client::JobService::get_query_results.
Sourcefn query(
&self,
_req: PostQueryRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<QueryResponse>>> + Send
fn query( &self, _req: PostQueryRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<QueryResponse>>> + Send
Implements super::client::JobService::query.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".