pub trait RoutineService:
Debug
+ Send
+ Sync {
// Provided methods
fn get_routine(
&self,
_req: GetRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send { ... }
fn insert_routine(
&self,
_req: InsertRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send { ... }
fn update_routine(
&self,
_req: UpdateRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send { ... }
fn delete_routine(
&self,
_req: DeleteRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn list_routines(
&self,
_req: ListRoutinesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListRoutinesResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::RoutineService.
Application developers may need to implement this trait to mock
client::RoutineService. In other use-cases, application developers only
use client::RoutineService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn get_routine(
&self,
_req: GetRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send
fn get_routine( &self, _req: GetRoutineRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Routine>>> + Send
Implements super::client::RoutineService::get_routine.
Sourcefn insert_routine(
&self,
_req: InsertRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send
fn insert_routine( &self, _req: InsertRoutineRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Routine>>> + Send
Implements super::client::RoutineService::insert_routine.
Sourcefn update_routine(
&self,
_req: UpdateRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Routine>>> + Send
fn update_routine( &self, _req: UpdateRoutineRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Routine>>> + Send
Implements super::client::RoutineService::update_routine.
Sourcefn delete_routine(
&self,
_req: DeleteRoutineRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_routine( &self, _req: DeleteRoutineRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Implements super::client::RoutineService::delete_routine.
Sourcefn list_routines(
&self,
_req: ListRoutinesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListRoutinesResponse>>> + Send
fn list_routines( &self, _req: ListRoutinesRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListRoutinesResponse>>> + Send
Implements super::client::RoutineService::list_routines.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".