pub trait RowAccessPolicyService:
Debug
+ Send
+ Sync {
// Provided methods
fn list_row_access_policies(
&self,
_req: ListRowAccessPoliciesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListRowAccessPoliciesResponse>>> + Send { ... }
fn get_row_access_policy(
&self,
_req: GetRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send { ... }
fn create_row_access_policy(
&self,
_req: CreateRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send { ... }
fn update_row_access_policy(
&self,
_req: UpdateRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send { ... }
fn delete_row_access_policy(
&self,
_req: DeleteRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn batch_delete_row_access_policies(
&self,
_req: BatchDeleteRowAccessPoliciesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::RowAccessPolicyService.
Application developers may need to implement this trait to mock
client::RowAccessPolicyService. In other use-cases, application developers only
use client::RowAccessPolicyService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn list_row_access_policies(
&self,
_req: ListRowAccessPoliciesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ListRowAccessPoliciesResponse>>> + Send
fn list_row_access_policies( &self, _req: ListRowAccessPoliciesRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListRowAccessPoliciesResponse>>> + Send
Sourcefn get_row_access_policy(
&self,
_req: GetRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
fn get_row_access_policy( &self, _req: GetRowAccessPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
Sourcefn create_row_access_policy(
&self,
_req: CreateRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
fn create_row_access_policy( &self, _req: CreateRowAccessPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
Sourcefn update_row_access_policy(
&self,
_req: UpdateRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
fn update_row_access_policy( &self, _req: UpdateRowAccessPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<RowAccessPolicy>>> + Send
Sourcefn delete_row_access_policy(
&self,
_req: DeleteRowAccessPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_row_access_policy( &self, _req: DeleteRowAccessPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Sourcefn batch_delete_row_access_policies(
&self,
_req: BatchDeleteRowAccessPoliciesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn batch_delete_row_access_policies( &self, _req: BatchDeleteRowAccessPoliciesRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".