pub trait TableService:
Debug
+ Send
+ Sync {
// Provided methods
fn get_table(
&self,
_req: GetTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send { ... }
fn insert_table(
&self,
_req: InsertTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send { ... }
fn patch_table(
&self,
_req: UpdateOrPatchTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send { ... }
fn update_table(
&self,
_req: UpdateOrPatchTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send { ... }
fn delete_table(
&self,
_req: DeleteTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn list_tables(
&self,
_req: ListTablesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TableList>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::TableService.
Application developers may need to implement this trait to mock
client::TableService. In other use-cases, application developers only
use client::TableService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn get_table(
&self,
_req: GetTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send
fn get_table( &self, _req: GetTableRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Table>>> + Send
Implements super::client::TableService::get_table.
Sourcefn insert_table(
&self,
_req: InsertTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send
fn insert_table( &self, _req: InsertTableRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Table>>> + Send
Implements super::client::TableService::insert_table.
Sourcefn patch_table(
&self,
_req: UpdateOrPatchTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send
fn patch_table( &self, _req: UpdateOrPatchTableRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Table>>> + Send
Implements super::client::TableService::patch_table.
Sourcefn update_table(
&self,
_req: UpdateOrPatchTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Table>>> + Send
fn update_table( &self, _req: UpdateOrPatchTableRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Table>>> + Send
Implements super::client::TableService::update_table.
Sourcefn delete_table(
&self,
_req: DeleteTableRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_table( &self, _req: DeleteTableRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Implements super::client::TableService::delete_table.
Sourcefn list_tables(
&self,
_req: ListTablesRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TableList>>> + Send
fn list_tables( &self, _req: ListTablesRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<TableList>>> + Send
Implements super::client::TableService::list_tables.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".