Crate google_cloud_bigquery_v2

Crate google_cloud_bigquery_v2 

Google Cloud Client Libraries for Rust - BigQuery API

FEEDBACK WANTED: We believe the APIs in this crate are stable, and do not anticipate any breaking changes are needed. We are looking for feedback before labeling the APIs “1.0”. Changes (even breaking changes) are still possible, but not expected.

We also believe the implementation is ready for production, bugs are still possible, but not expected.

This crate contains traits, types, and functions to interact with BigQuery API Most applications will use the structs defined in the client module.

Available Clients

Features

  • default-rustls-provider: enabled by default. Use the default rustls crypto provider (aws-lc-rs) for TLS and authentication. Applications with specific requirements for cryptography (such as exclusively using the ring crate) should disable this default and call rustls::crypto::CryptoProvider::install_default().

Modules

builder
Request builders.
client
Example
model
The messages and enums that are part of this client library.
operation
stub
Traits to mock the clients in this library.

Structs

Error
The core error returned by all client libraries.

Type Aliases

Result
An alias of std::result::Result where the error is always Error.