pub struct ModelService { /* private fields */ }Expand description
Implements a client for the BigQuery API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = ModelService::builder().build().await?;
let response = client.get_model()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Model Service for BigQuery ML
Configuration
To configure ModelService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://bigquery.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ModelService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ModelService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ModelService
impl ModelService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ModelService.
let client = ModelService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ModelService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ModelService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_model(&self) -> GetModel
pub fn get_model(&self) -> GetModel
Gets the specified model resource by model ID.
IAM Permissions
Requires the bigquery.models.getMetadata permission on the model.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &ModelService
) -> Result<()> {
let response = client.get_model()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_models(&self) -> ListModels
pub fn list_models(&self) -> ListModels
Lists all models in the specified dataset. Requires the READER dataset role. After retrieving the list of models, you can get information about a particular model by calling the models.get method.
IAM Permissions
Requires the bigquery.models.list permission on the dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &ModelService
) -> Result<()> {
let mut list = client.list_models()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn patch_model(&self) -> PatchModel
pub fn patch_model(&self) -> PatchModel
Patch specific fields in the specified model.
IAM Permissions
Requires the bigquery.models.updateMetadata permission on the model.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &ModelService
) -> Result<()> {
let response = client.patch_model()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_model(&self) -> DeleteModel
pub fn delete_model(&self) -> DeleteModel
Deletes the model specified by modelId from the dataset.
IAM Permissions
Requires the bigquery.models.delete permission on the model.
Example
use google_cloud_bigquery_v2::Result;
async fn sample(
client: &ModelService
) -> Result<()> {
client.delete_model()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ModelService
impl Clone for ModelService
Sourcefn clone(&self) -> ModelService
fn clone(&self) -> ModelService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for ModelService
impl !UnwindSafe for ModelService
impl Freeze for ModelService
impl Send for ModelService
impl Sync for ModelService
impl Unpin for ModelService
impl UnsafeUnpin for ModelService