The messages and enums that are part of this client library.
Modules
- arrow_
serialization_ options - Defines additional types related to ArrowSerializationOptions.
- bi_
engine_ reason - Defines additional types related to BiEngineReason.
- bi_
engine_ statistics - Defines additional types related to BiEngineStatistics.
- big_
lake_ configuration - Defines additional types related to BigLakeConfiguration.
- data_
format_ options - Defines additional types related to DataFormatOptions.
- dataset
- Defines additional types related to Dataset.
- dataset_
access_ entry - Defines additional types related to DatasetAccessEntry.
- dml_
stats - Defines additional types related to DmlStats.
- explain_
query_ stage - Defines additional types related to ExplainQueryStage.
- external_
data_ configuration - Defines additional types related to ExternalDataConfiguration.
- foreign_
type_ info - Defines additional types related to ForeignTypeInfo.
- get_
dataset_ request - Defines additional types related to GetDatasetRequest.
- get_
table_ request - Defines additional types related to GetTableRequest.
- incremental_
result_ stats - Defines additional types related to IncrementalResultStats.
- index_
unused_ reason - Defines additional types related to IndexUnusedReason.
- job_
configuration_ extract - Defines additional types related to JobConfigurationExtract.
- job_
configuration_ load - Defines additional types related to JobConfigurationLoad.
- job_
configuration_ table_ copy - Defines additional types related to JobConfigurationTableCopy.
- job_
creation_ reason - Defines additional types related to JobCreationReason.
- job_
statistics - Defines additional types related to JobStatistics.
- join_
restriction_ policy - Defines additional types related to JoinRestrictionPolicy.
- linked_
dataset_ metadata - Defines additional types related to LinkedDatasetMetadata.
- list_
jobs_ request - Defines additional types related to ListJobsRequest.
- materialized_
view - Defines additional types related to MaterializedView.
- ml_
statistics - Defines additional types related to MlStatistics.
- model
- Defines additional types related to Model.
- object_
storage_ stats - Defines additional types related to ObjectStorageStats.
- partition_
skew - Defines additional types related to PartitionSkew.
- privacy_
policy - Defines additional types related to PrivacyPolicy.
- query_
request - Defines additional types related to QueryRequest.
- query_
response - Defines additional types related to QueryResponse.
- range_
partitioning - Defines additional types related to RangePartitioning.
- remote_
model_ info - Defines additional types related to RemoteModelInfo.
- restriction_
config - Defines additional types related to RestrictionConfig.
- routine
- Defines additional types related to Routine.
- routine_
build_ status - Defines additional types related to RoutineBuildStatus.
- script_
options - Defines additional types related to ScriptOptions.
- script_
statistics - Defines additional types related to ScriptStatistics.
- search_
statistics - Defines additional types related to SearchStatistics.
- spark_
statistics - Defines additional types related to SparkStatistics.
- standard_
sql_ data_ type - Defines additional types related to StandardSqlDataType.
- stored_
columns_ usage - Defines additional types related to StoredColumnsUsage.
- table_
field_ schema - Defines additional types related to TableFieldSchema.
- table_
metadata_ cache_ usage - Defines additional types related to TableMetadataCacheUsage.
- table_
replication_ info - Defines additional types related to TableReplicationInfo.
- update_
or_ patch_ dataset_ request - Defines additional types related to UpdateOrPatchDatasetRequest.
- vector_
search_ statistics - Defines additional types related to VectorSearchStatistics.
Structs
- Access
- An object that defines dataset access for an entity.
- Aggregation
Threshold Policy - Represents privacy policy associated with “aggregation threshold” method.
- Arrow
Record Batch - Arrow RecordBatch.
- Arrow
Schema - Arrow schema as specified in https://arrow.apache.org/docs/python/api/datatypes.html and serialized to bytes using IPC: https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
- Arrow
Serialization Options - Contains options specific to Arrow Serialization.
- Avro
Options - Options for external data sources.
- Batch
Delete RowAccess Policies Request - Request message for the BatchDeleteRowAccessPoliciesRequest method.
- BiEngine
Reason - Reason why BI Engine didn’t accelerate the query (or sub-query).
- BiEngine
Statistics - Statistics for a BI Engine specific query. Populated as part of JobStatistics2
- BigLake
Configuration - Configuration for BigQuery tables for Apache Iceberg (formerly BigLake managed tables.)
- Bigtable
Column - Information related to a Bigtable column.
- Bigtable
Column Family - Information related to a Bigtable column family.
- Bigtable
Options - Options specific to Google Cloud Bigtable data sources.
- Bigtable
Proto Config - Information related to a Bigtable protobuf column.
- Cancel
JobRequest - Describes format of a jobs cancellation request.
- Clone
Definition - Information about base table and clone time of a table clone.
- Clustering
- Configures table clustering.
- Column
Reference - The pair of the foreign key column and primary key column.
- Connection
Property - A connection-level property to customize query behavior. Under JDBC, these correspond directly to connection properties passed to the DriverManager. Under ODBC, these correspond to properties in the connection string.
- Copy
JobStatistics - Statistics for a copy job.
- Create
RowAccess Policy Request - Request message for the CreateRowAccessPolicy method.
- CsvOptions
- Information related to a CSV data source.
- Data
Format Options - Options for data format adjustments.
- Data
Masking Statistics - Statistics for data-masking.
- Data
Policy List - A list of data policy options. For more information, see Mask data by applying data policies to a column.
- Data
Policy Option - Data policy option. For more information, see Mask data by applying data policies to a column.
- Dataset
- Represents a BigQuery dataset.
- Dataset
Access Entry - Grants all resources of particular types in a particular dataset read access to the current dataset.
- Dataset
List - Response format for a page of results when listing datasets.
- Dataset
Reference - Identifier for a dataset.
- Delete
Dataset Request - Request format for deleting a dataset.
- Delete
JobRequest - Describes the format of a jobs deletion request.
- Delete
Model Request - Request format for deleting BigQuery ML models.
- Delete
Routine Request - Describes the format for deleting a routine.
- Delete
RowAccess Policy Request - Request message for the DeleteRowAccessPolicy method.
- Delete
Table Request - Request format for deleting a table.
- Destination
Table Properties - Properties for the destination table.
- Differential
Privacy Policy - Represents privacy policy associated with “differential privacy” method.
- DmlStats
- Detailed statistics for DML statements
- Encryption
Configuration - Configuration for Cloud KMS encryption settings.
- Error
Proto - Error details.
- Explain
Query Stage - A single stage of query execution.
- Explain
Query Step - An operation within a stage.
- Export
Data Statistics - Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4.
- External
Catalog Dataset Options - Options defining open source compatible datasets living in the BigQuery catalog. Contains metadata of open source database, schema, or namespace represented by the current dataset.
- External
Catalog Table Options - Metadata about open source compatible table. The fields contained in these options correspond to Hive metastore’s table-level properties.
- External
Data Configuration - External
Dataset Reference - Configures the access a dataset defined in an external metadata storage.
- External
Runtime Options - Options for the runtime of the external system.
- External
Service Cost - The external service cost is a portion of the total cost, these costs are not additive with total_bytes_billed. Moreover, this field only track external service costs that will show up as BigQuery costs (e.g. training BigQuery ML job with google cloud CAIP or Automl Tables services), not other costs which may be accrued by running the query (e.g. reading from Bigtable or Cloud Storage). The external service costs with different billing sku (e.g. CAIP job is charged based on VM usage) are converted to BigQuery billed_bytes and slot_ms with equivalent amount of US dollars. Services may not directly correlate to these metrics, but these are the equivalents for billing purposes. Output only.
- Foreign
Key - Represents a foreign key constraint on a table’s columns.
- Foreign
Type Info - Metadata about the foreign data type definition such as the system in which the type is defined.
- Foreign
View Definition - A view can be represented in multiple ways. Each representation has its own dialect. This message stores the metadata required for these representations.
- GcpTag
- A global tag managed by Resource Manager. https://cloud.google.com/iam/docs/tags-access-control#definitions
- GenAi
Error Stats - Provides error statistics for the query job across all AI function calls.
- GenAi
Function Cache Stats - Provides cache statistics for a GenAi function call.
- GenAi
Function Cost Optimization Stats - Provides cost optimization statistics for a GenAi function call.
- GenAi
Function Error Stats - Provides error statistics for a GenAi function call.
- GenAi
Function Stats - Provides statistics for each Ai function call within a query.
- GenAi
Stats - GenAi stats for the query job.
- GetDataset
Request - Request format for getting information about a dataset.
- GetJob
Request - Describes format of a jobs get request.
- GetModel
Request - Request format for getting information about a BigQuery ML model.
- GetQuery
Results Request - Request object of GetQueryResults.
- GetQuery
Results Response - Response object of GetQueryResults.
- GetRoutine
Request - Describes the format for getting information about a routine.
- GetRow
Access Policy Request - Request message for the GetRowAccessPolicy method.
- GetService
Account Request - Request object of GetServiceAccount
- GetService
Account Response - Response object of GetServiceAccount
- GetTable
Request - Request format for getting table metadata.
- Google
Sheets Options - Options specific to Google Sheets data sources.
- High
Cardinality Join - High cardinality join detailed information.
- Hive
Partitioning Options - Options for configuring hive partitioning detect.
- Incremental
Result Stats - Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.
- Index
Pruning Stats - Statistics for index pruning.
- Index
Unused Reason - Reason about why no search index was used in the search query (or sub-query).
- Input
Data Change - Details about the input data change insight.
- Insert
Dataset Request - Request format for inserting a dataset.
- Insert
JobRequest - Describes format of a job insertion request.
- Insert
Routine Request - Describes the format for inserting a routine.
- Insert
Table Request - Request format for inserting table metadata.
- Job
- JobCancel
Response - Describes format of a jobs cancellation response.
- JobConfiguration
- JobConfiguration
Extract - JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.
- JobConfiguration
Load - JobConfigurationLoad contains the configuration properties for loading data into a destination table.
- JobConfiguration
Query - JobConfigurationQuery configures a BigQuery query job.
- JobConfiguration
Table Copy - JobConfigurationTableCopy configures a job that copies data from one table to another. For more information on copying tables, see Copy a table.
- JobCreation
Reason - Reason about why a Job was created from a
jobs.querymethod when used withJOB_CREATION_OPTIONALJob creation mode. - JobList
- JobList is the response format for a jobs.list call.
- JobReference
- A job reference is a fully qualified identifier for referring to a job.
- JobStatistics
- Statistics for a single job execution.
- JobStatistics2
- Statistics for a query job.
- JobStatistics3
- Statistics for a load job.
- JobStatistics4
- Statistics for an extract job.
- JobStatus
- Join
Restriction Policy - Represents privacy policy associated with “join restrictions”. Join restriction gives data providers the ability to enforce joins on the ‘join_allowed_columns’ when data is queried from a privacy protected view.
- Json
Options - Json Options for load and make external tables.
- Linked
Dataset Metadata - Metadata about the Linked Dataset.
- Linked
Dataset Source - A dataset source type which refers to another BigQuery dataset.
- List
Datasets Request - List
Format Dataset - A dataset resource with only a subset of fields, to be returned in a list of datasets.
- List
Format Job - ListFormatJob is a partial projection of job information returned as part of a jobs.list response.
- List
Format Table - List
Format View - Information about a logical view.
- List
Jobs Request - Describes the format of the list jobs request.
- List
Models Request - Request format for listing BigQuery ML models.
- List
Models Response - Response format for a single page when listing BigQuery ML models.
- List
Routines Request - Describes the format for listing routines.
- List
Routines Response - Describes the format of a single result page when listing routines.
- List
RowAccess Policies Request - Request message for the ListRowAccessPolicies method.
- List
RowAccess Policies Response - Response message for the ListRowAccessPolicies method.
- List
Tables Request - Request format for enumerating tables.
- Load
Query Statistics - Statistics for a LOAD query.
- Location
Metadata - BigQuery-specific metadata about a location. This will be set on google.cloud.location.Location.metadata in Cloud Location API responses.
- Materialized
View - A materialized view considered for a query job.
- Materialized
View Definition - Definition and configuration of a materialized view.
- Materialized
View Statistics - Statistics of materialized views considered in a query job.
- Materialized
View Status - Status of a materialized view. The last refresh timestamp status is omitted here, but is present in the MaterializedViewDefinition message.
- Metadata
Cache Staleness Insight - Column Metadata Index staleness detailed infnormation.
- Metadata
Cache Statistics - Statistics for metadata caching in queried tables.
- MlStatistics
- Job statistics specific to a BigQuery ML training job.
- Model
- Model
Reference - Id path of a model.
- Object
Storage Stats - Storage and caching statistics for object storage.
- Parquet
Options - Parquet Options for load and make external tables.
- Partition
Skew - Partition skew detailed information.
- Partitioned
Column - The partitioning column information.
- Partitioning
Definition - The partitioning information, which includes managed table, external table and metastore partitioned table partition information.
- Patch
Model Request - Performance
Insights - Performance insights for the job.
- Post
Query Request - Request format for the query request.
- Primary
Key - Represents the primary key constraint on a table’s columns.
- Privacy
Policy - Represents privacy policy that contains the privacy requirements specified by the data owner. Currently, this is only supported on views.
- Property
Graph Reference - Id path of a property graph.
- Pruning
Stats - The column metadata index pruning statistics.
- Python
Options - Options for a user-defined Python function.
- Query
Info - Query optimization information for a QUERY job.
- Query
Parameter - A parameter given to a query.
- Query
Parameter Struct Type - The type of a struct parameter.
- Query
Parameter Type - The type of a query parameter.
- Query
Parameter Value - The value of a query parameter.
- Query
Request - Describes the format of the jobs.query request.
- Query
Response - Query
Timeline Sample - Summary of the state of query execution at a given time.
- Range
Partitioning - Range
Value - Represents the value of a range.
- Remote
Model Info - Remote Model Info
- Restriction
Config - Routine
- A user-defined function or a stored procedure.
- Routine
Build Status - The status of a routine build.
- Routine
Reference - Id path of a routine.
- RowAccess
Policy - Represents access on a subset of rows on the specified table, defined by its filter predicate. Access to the subset of rows is controlled by its IAM policy.
- RowAccess
Policy Reference - Id path of a row access policy.
- RowLevel
Security Statistics - Statistics for row-level security.
- Script
Options - Options related to script execution.
- Script
Statistics - Job statistics specific to the child job of a script.
- Search
Statistics - Statistics for a search query. Populated as part of JobStatistics2.
- SerDe
Info - Serializer and deserializer information.
- Session
Info - [Preview] Information related to sessions.
- Snapshot
Definition - Information about base table and snapshot time of the snapshot.
- Spark
Options - Options for a user-defined Spark routine.
- Spark
Statistics - Statistics for a BigSpark query. Populated as part of JobStatistics2
- Stage
Performance Change Insight - Performance insights compared to the previous executions for a specific stage.
- Stage
Performance Standalone Insight - Standalone performance insights for a specific stage.
- Standard
SqlData Type - The data type of a variable such as a function argument. Examples include:
- Standard
SqlField - A field or a column.
- Standard
SqlStruct Type - The representation of a SQL STRUCT type.
- Standard
SqlTable Type - A table type
- Storage
Descriptor - Contains information about how a table’s data is stored and accessed by open source query engines.
- Stored
Columns Usage - Indicates the stored columns usage in the query.
- Streamingbuffer
- System
Variables - System variables given to a query.
- Table
- Table
Change Insight - Table-level performance insights compared to previous runs. These insights don’t apply to specific query stages, rather they apply to the whole table.
- Table
Constraints - The TableConstraints defines the primary key and foreign key.
- Table
Field Schema - A field in TableSchema
- Table
List - Partial projection of the metadata for a given table in a list response.
- Table
Metadata Cache Usage - Table level detail on the usage of metadata caching. Only set for Metadata caching eligible tables referenced in the query.
- Table
Reference - Table
Replication Info - Replication info of a table created using
AS REPLICADDL like:CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv - Table
Schema - Schema of a table
- Time
Partitioning - Transform
Column - Information about a single transform column.
- Undelete
Dataset Request - Request format for undeleting a dataset.
- Update
OrPatch Dataset Request - Message for updating or patching a dataset.
- Update
OrPatch Table Request - Update
Routine Request - Describes the format for updating a routine.
- Update
RowAccess Policy Request - Request message for the UpdateRowAccessPolicy method.
- User
Defined Function Resource - This is used for defining User Defined Function (UDF) resources only when using legacy SQL. Users of GoogleSQL should leverage either DDL (e.g. CREATE [TEMPORARY] FUNCTION … ) or the Routines API to define UDF resources.
- Vector
Search Statistics - Statistics for a vector search query. Populated as part of JobStatistics2.
- View
Definition - Describes the definition of a logical view.
Enums
- Decimal
Target Type - The data types that could be used as a target type when converting decimal values.
- File
SetSpec Type - This enum defines how to interpret source URIs for load jobs and external tables.
- Json
Extension - Used to indicate that a JSON variant, rather than normal JSON, is being used as the source_format. This should only be used in combination with the JSON source format.
- Managed
Table Type - The classification of managed table types that can be created.
- MapTarget
Type - Indicates the map target type. Only applies to parquet maps.
- Reservation
Edition - The type of editions. Different features and behaviors are provided to different editions Capacity commitments and reservations are linked to editions.