#[non_exhaustive]pub struct TrainingRun {
pub training_options: Option<TrainingOptions>,
pub start_time: Option<Timestamp>,
pub results: Vec<IterationResult>,
pub evaluation_metrics: Option<EvaluationMetrics>,
pub data_split_result: Option<DataSplitResult>,
pub model_level_global_explanation: Option<GlobalExplanation>,
pub class_level_global_explanations: Vec<GlobalExplanation>,
pub vertex_ai_model_id: String,
pub vertex_ai_model_version: String,
/* private fields */
}Expand description
Information about a single training query run for the model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.training_options: Option<TrainingOptions>Output only. Options that were used for this training run, includes user specified and default options that were used.
start_time: Option<Timestamp>Output only. The start time of this training run.
results: Vec<IterationResult>Output only. Output of each iteration run, results.size() <= max_iterations.
evaluation_metrics: Option<EvaluationMetrics>Output only. The evaluation metrics over training/eval data that were computed at the end of training.
data_split_result: Option<DataSplitResult>Output only. Data split result of the training run. Only set when the input data is actually split.
model_level_global_explanation: Option<GlobalExplanation>Output only. Global explanation contains the explanation of top features on the model level. Applies to both regression and classification models.
class_level_global_explanations: Vec<GlobalExplanation>Output only. Global explanation contains the explanation of top features on the class level. Applies to classification models only.
vertex_ai_model_id: StringThe model id in the Vertex AI Model Registry for this training run.
vertex_ai_model_version: StringOutput only. The model version in the Vertex AI Model Registry for this training run.
Implementations
Sourceimpl TrainingRun
impl TrainingRun
Sourcepub fn set_training_options<T>(self, v: T) -> Selfwhere
T: Into<TrainingOptions>,
pub fn set_training_options<T>(self, v: T) -> Selfwhere
T: Into<TrainingOptions>,
Sets the value of training_options.
Example
use google_cloud_bigquery_v2::model::model::training_run::TrainingOptions;
let x = TrainingRun::new().set_training_options(TrainingOptions::default()/* use setters */);Sourcepub fn set_or_clear_training_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<TrainingOptions>,
pub fn set_or_clear_training_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<TrainingOptions>,
Sets or clears the value of training_options.
Example
use google_cloud_bigquery_v2::model::model::training_run::TrainingOptions;
let x = TrainingRun::new().set_or_clear_training_options(Some(TrainingOptions::default()/* use setters */));
let x = TrainingRun::new().set_or_clear_training_options(None::<TrainingOptions>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = TrainingRun::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = TrainingRun::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = TrainingRun::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_results<T, V>(self, v: T) -> Self
pub fn set_results<T, V>(self, v: T) -> Self
Sourcepub fn set_evaluation_metrics<T>(self, v: T) -> Selfwhere
T: Into<EvaluationMetrics>,
pub fn set_evaluation_metrics<T>(self, v: T) -> Selfwhere
T: Into<EvaluationMetrics>,
Sets the value of evaluation_metrics.
Example
use google_cloud_bigquery_v2::model::model::EvaluationMetrics;
let x = TrainingRun::new().set_evaluation_metrics(EvaluationMetrics::default()/* use setters */);Sourcepub fn set_or_clear_evaluation_metrics<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationMetrics>,
pub fn set_or_clear_evaluation_metrics<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationMetrics>,
Sets or clears the value of evaluation_metrics.
Example
use google_cloud_bigquery_v2::model::model::EvaluationMetrics;
let x = TrainingRun::new().set_or_clear_evaluation_metrics(Some(EvaluationMetrics::default()/* use setters */));
let x = TrainingRun::new().set_or_clear_evaluation_metrics(None::<EvaluationMetrics>);Sourcepub fn set_data_split_result<T>(self, v: T) -> Selfwhere
T: Into<DataSplitResult>,
pub fn set_data_split_result<T>(self, v: T) -> Selfwhere
T: Into<DataSplitResult>,
Sets the value of data_split_result.
Example
use google_cloud_bigquery_v2::model::model::DataSplitResult;
let x = TrainingRun::new().set_data_split_result(DataSplitResult::default()/* use setters */);Sourcepub fn set_or_clear_data_split_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataSplitResult>,
pub fn set_or_clear_data_split_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataSplitResult>,
Sets or clears the value of data_split_result.
Example
use google_cloud_bigquery_v2::model::model::DataSplitResult;
let x = TrainingRun::new().set_or_clear_data_split_result(Some(DataSplitResult::default()/* use setters */));
let x = TrainingRun::new().set_or_clear_data_split_result(None::<DataSplitResult>);Sourcepub fn set_model_level_global_explanation<T>(self, v: T) -> Selfwhere
T: Into<GlobalExplanation>,
pub fn set_model_level_global_explanation<T>(self, v: T) -> Selfwhere
T: Into<GlobalExplanation>,
Sets the value of model_level_global_explanation.
Example
use google_cloud_bigquery_v2::model::model::GlobalExplanation;
let x = TrainingRun::new().set_model_level_global_explanation(GlobalExplanation::default()/* use setters */);Sourcepub fn set_or_clear_model_level_global_explanation<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<GlobalExplanation>,
pub fn set_or_clear_model_level_global_explanation<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<GlobalExplanation>,
Sets or clears the value of model_level_global_explanation.
Example
use google_cloud_bigquery_v2::model::model::GlobalExplanation;
let x = TrainingRun::new().set_or_clear_model_level_global_explanation(Some(GlobalExplanation::default()/* use setters */));
let x = TrainingRun::new().set_or_clear_model_level_global_explanation(None::<GlobalExplanation>);Sourcepub fn set_class_level_global_explanations<T, V>(self, v: T) -> Self
pub fn set_class_level_global_explanations<T, V>(self, v: T) -> Self
Sets the value of class_level_global_explanations.
Example
use google_cloud_bigquery_v2::model::model::GlobalExplanation;
let x = TrainingRun::new()
.set_class_level_global_explanations([
GlobalExplanation::default()/* use setters */,
GlobalExplanation::default()/* use (different) setters */,
]);Sourcepub fn set_vertex_ai_model_id<T: Into<String>>(self, v: T) -> Self
pub fn set_vertex_ai_model_id<T: Into<String>>(self, v: T) -> Self
Sets the value of vertex_ai_model_id.
Example
let x = TrainingRun::new().set_vertex_ai_model_id("example");Sourcepub fn set_vertex_ai_model_version<T: Into<String>>(self, v: T) -> Self
pub fn set_vertex_ai_model_version<T: Into<String>>(self, v: T) -> Self
Sets the value of vertex_ai_model_version.
Example
let x = TrainingRun::new().set_vertex_ai_model_version("example");Trait Implementations
Sourceimpl Clone for TrainingRun
impl Clone for TrainingRun
Sourceimpl Debug for TrainingRun
impl Debug for TrainingRun
Sourceimpl Default for TrainingRun
impl Default for TrainingRun
Sourceimpl Message for TrainingRun
impl Message for TrainingRun
Sourceimpl PartialEq for TrainingRun
impl PartialEq for TrainingRun
impl StructuralPartialEq for TrainingRun