#[non_exhaustive]pub struct Argument {
pub name: String,
pub argument_kind: ArgumentKind,
pub mode: Mode,
pub data_type: Option<StandardSqlDataType>,
pub table_type: Option<StandardSqlTableType>,
pub is_aggregate: Option<BoolValue>,
/* private fields */
}Expand description
Input/output argument of a function or a stored procedure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOptional. The name of this argument. Can be absent for function return argument.
argument_kind: ArgumentKindOptional. Defaults to FIXED_TYPE.
mode: ModeOptional. Specifies whether the argument is input or output. Can be set for procedures only.
data_type: Option<StandardSqlDataType>Set if argument_kind == FIXED_TYPE.
table_type: Option<StandardSqlTableType>Optional. Set if argument_kind == FIXED_TABLE.
is_aggregate: Option<BoolValue>Optional. Whether the argument is an aggregate function parameter. Must be Unset for routine types other than AGGREGATE_FUNCTION. For AGGREGATE_FUNCTION, if set to false, it is equivalent to adding “NOT AGGREGATE” clause in DDL; Otherwise, it is equivalent to omitting “NOT AGGREGATE” clause in DDL.
Implementations
Sourceimpl Argument
impl Argument
Sourcepub fn set_argument_kind<T: Into<ArgumentKind>>(self, v: T) -> Self
pub fn set_argument_kind<T: Into<ArgumentKind>>(self, v: T) -> Self
Sets the value of argument_kind.
Example
use google_cloud_bigquery_v2::model::routine::argument::ArgumentKind;
let x0 = Argument::new().set_argument_kind(ArgumentKind::FixedType);
let x1 = Argument::new().set_argument_kind(ArgumentKind::AnyType);
let x2 = Argument::new().set_argument_kind(ArgumentKind::FixedTable);Sourcepub fn set_data_type<T>(self, v: T) -> Selfwhere
T: Into<StandardSqlDataType>,
pub fn set_data_type<T>(self, v: T) -> Selfwhere
T: Into<StandardSqlDataType>,
Sourcepub fn set_or_clear_data_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<StandardSqlDataType>,
pub fn set_or_clear_data_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<StandardSqlDataType>,
Sourcepub fn set_table_type<T>(self, v: T) -> Selfwhere
T: Into<StandardSqlTableType>,
pub fn set_table_type<T>(self, v: T) -> Selfwhere
T: Into<StandardSqlTableType>,
Sets the value of table_type.
Example
use google_cloud_bigquery_v2::model::StandardSqlTableType;
let x = Argument::new().set_table_type(StandardSqlTableType::default()/* use setters */);Sourcepub fn set_or_clear_table_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<StandardSqlTableType>,
pub fn set_or_clear_table_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<StandardSqlTableType>,
Sets or clears the value of table_type.
Example
use google_cloud_bigquery_v2::model::StandardSqlTableType;
let x = Argument::new().set_or_clear_table_type(Some(StandardSqlTableType::default()/* use setters */));
let x = Argument::new().set_or_clear_table_type(None::<StandardSqlTableType>);Sourcepub fn set_is_aggregate<T>(self, v: T) -> Self
pub fn set_is_aggregate<T>(self, v: T) -> Self
Sets the value of is_aggregate.
Example
use wkt::BoolValue;
let x = Argument::new().set_is_aggregate(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_is_aggregate<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_is_aggregate<T>(self, v: Option<T>) -> Self
Sets or clears the value of is_aggregate.
Example
use wkt::BoolValue;
let x = Argument::new().set_or_clear_is_aggregate(Some(BoolValue::default()/* use setters */));
let x = Argument::new().set_or_clear_is_aggregate(None::<BoolValue>);Trait Implementations
impl StructuralPartialEq for Argument