#[non_exhaustive]pub struct RemoteFunctionOptions {
pub endpoint: String,
pub connection: String,
pub user_defined_context: HashMap<String, String>,
pub max_batching_rows: i64,
/* private fields */
}Expand description
Options for a remote user-defined function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: StringEndpoint of the user-provided remote service, e.g.
<https://us-east1-my_gcf_project.cloudfunctions.net/remote_add>
connection: StringFully qualified name of the user-provided connection object which holds
the authentication information to send requests to the remote service.
Format:
"projects/{projectId}/locations/{locationId}/connections/{connectionId}"
user_defined_context: HashMap<String, String>User-defined context as a set of key/value pairs, which will be sent as function invocation context together with batched arguments in the requests to the remote service. The total number of bytes of keys and values must be less than 8KB.
max_batching_rows: i64Max number of rows in each batch sent to the remote service. If absent or if 0, BigQuery dynamically decides the number of rows in a batch.
Implementations
Sourceimpl RemoteFunctionOptions
impl RemoteFunctionOptions
Sourcepub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
pub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_connection<T: Into<String>>(self, v: T) -> Self
Sets the value of connection.
Example
let x = RemoteFunctionOptions::new().set_connection("example");Sourcepub fn set_user_defined_context<T, K, V>(self, v: T) -> Self
pub fn set_user_defined_context<T, K, V>(self, v: T) -> Self
Sets the value of user_defined_context.
Example
let x = RemoteFunctionOptions::new().set_user_defined_context([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
pub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
Sets the value of max_batching_rows.
Example
let x = RemoteFunctionOptions::new().set_max_batching_rows(42);Trait Implementations
Sourceimpl Clone for RemoteFunctionOptions
impl Clone for RemoteFunctionOptions
Sourcefn clone(&self) -> RemoteFunctionOptions
fn clone(&self) -> RemoteFunctionOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RemoteFunctionOptions
impl Debug for RemoteFunctionOptions
Sourceimpl Default for RemoteFunctionOptions
impl Default for RemoteFunctionOptions
Sourcefn default() -> RemoteFunctionOptions
fn default() -> RemoteFunctionOptions
Sourceimpl Message for RemoteFunctionOptions
impl Message for RemoteFunctionOptions
Sourceimpl PartialEq for RemoteFunctionOptions
impl PartialEq for RemoteFunctionOptions
impl StructuralPartialEq for RemoteFunctionOptions