Access

Struct Access 

#[non_exhaustive]
pub struct Access { pub role: String, pub user_by_email: String, pub group_by_email: String, pub domain: String, pub special_group: String, pub iam_member: String, pub view: Option<TableReference>, pub routine: Option<RoutineReference>, pub dataset: Option<DatasetAccessEntry>, pub condition: Option<Expr>, /* private fields */ }
An object that defines dataset access for an entity.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
role: String

An IAM role ID that should be granted to the user, group, or domain specified in this access entry. The following legacy mappings will be applied:

  • OWNER: roles/bigquery.dataOwner
  • WRITER: roles/bigquery.dataEditor
  • READER: roles/bigquery.dataViewer

This field will accept any of the above formats, but will return only the legacy format. For example, if you set this field to “roles/bigquery.dataOwner”, it will be returned back as “OWNER”.

user_by_email: String

[Pick one] An email address of a user to grant access to. For example: fred@example.com. Maps to IAM policy member “user:EMAIL” or “serviceAccount:EMAIL”.

group_by_email: String

[Pick one] An email address of a Google Group to grant access to. Maps to IAM policy member “group:GROUP”.

domain: String

[Pick one] A domain to grant access to. Any users signed in with the domain specified will be granted the specified access. Example: “example.com”. Maps to IAM policy member “domain:DOMAIN”.

special_group: String

[Pick one] A special group to grant access to. Possible values include:

  • projectOwners: Owners of the enclosing project.
  • projectReaders: Readers of the enclosing project.
  • projectWriters: Writers of the enclosing project.
  • allAuthenticatedUsers: All authenticated BigQuery users.

Maps to similarly-named IAM members.

iam_member: String

[Pick one] Some other type of member that appears in the IAM Policy but isn’t a user, group, domain, or special group.

view: Option<TableReference>

[Pick one] A view from a different dataset to grant access to. Queries executed against that view will have read access to views/tables/routines in this dataset. The role field is not required when this field is set. If that view is updated by any user, access to the view needs to be granted again via an update operation.

routine: Option<RoutineReference>

[Pick one] A routine from a different dataset to grant access to. Queries executed against that routine will have read access to views/tables/routines in this dataset. Only UDF is supported for now. The role field is not required when this field is set. If that routine is updated by any user, access to the routine needs to be granted again via an update operation.

dataset: Option<DatasetAccessEntry>

[Pick one] A grant authorizing all resources of a particular type in a particular dataset access to this dataset. Only views are supported for now. The role field is not required when this field is set. If that dataset is deleted and re-created, its access needs to be granted again via an update operation.

condition: Option<Expr>

Optional. condition for the binding. If CEL expression in this field is true, this access binding will be considered

Implementations

Source

impl Access

pub fn new() -> Self

Creates a new default instance.

pub fn set_role<T: Into<String>>(self, v: T) -> Self

Sets the value of role.

Example
let x = Access::new().set_role("example");
pub fn set_user_by_email<T: Into<String>>(self, v: T) -> Self

Sets the value of user_by_email.

Example
let x = Access::new().set_user_by_email("example");
pub fn set_group_by_email<T: Into<String>>(self, v: T) -> Self

Sets the value of group_by_email.

Example
let x = Access::new().set_group_by_email("example");
pub fn set_domain<T: Into<String>>(self, v: T) -> Self

Sets the value of domain.

Example
let x = Access::new().set_domain("example");
pub fn set_special_group<T: Into<String>>(self, v: T) -> Self

Sets the value of special_group.

Example
let x = Access::new().set_special_group("example");
pub fn set_iam_member<T: Into<String>>(self, v: T) -> Self

Sets the value of iam_member.

Example
let x = Access::new().set_iam_member("example");
pub fn set_view<T>(self, v: T) -> Self
where T: Into<TableReference>,

Sets the value of view.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = Access::new().set_view(TableReference::default()/* use setters */);
pub fn set_or_clear_view<T>(self, v: Option<T>) -> Self
where T: Into<TableReference>,

Sets or clears the value of view.

Example
use google_cloud_bigquery_v2::model::TableReference;
let x = Access::new().set_or_clear_view(Some(TableReference::default()/* use setters */));
let x = Access::new().set_or_clear_view(None::<TableReference>);
pub fn set_routine<T>(self, v: T) -> Self

Sets the value of routine.

Example
use google_cloud_bigquery_v2::model::RoutineReference;
let x = Access::new().set_routine(RoutineReference::default()/* use setters */);
pub fn set_or_clear_routine<T>(self, v: Option<T>) -> Self

Sets or clears the value of routine.

Example
use google_cloud_bigquery_v2::model::RoutineReference;
let x = Access::new().set_or_clear_routine(Some(RoutineReference::default()/* use setters */));
let x = Access::new().set_or_clear_routine(None::<RoutineReference>);
pub fn set_dataset<T>(self, v: T) -> Self

Sets the value of dataset.

Example
use google_cloud_bigquery_v2::model::DatasetAccessEntry;
let x = Access::new().set_dataset(DatasetAccessEntry::default()/* use setters */);
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Self

Sets or clears the value of dataset.

Example
use google_cloud_bigquery_v2::model::DatasetAccessEntry;
let x = Access::new().set_or_clear_dataset(Some(DatasetAccessEntry::default()/* use setters */));
let x = Access::new().set_or_clear_dataset(None::<DatasetAccessEntry>);
pub fn set_condition<T>(self, v: T) -> Self
where T: Into<Expr>,

Sets the value of condition.

Example
use google_cloud_type::model::Expr;
let x = Access::new().set_condition(Expr::default()/* use setters */);
pub fn set_or_clear_condition<T>(self, v: Option<T>) -> Self
where T: Into<Expr>,

Sets or clears the value of condition.

Example
use google_cloud_type::model::Expr;
let x = Access::new().set_or_clear_condition(Some(Expr::default()/* use setters */));
let x = Access::new().set_or_clear_condition(None::<Expr>);