#[non_exhaustive]pub struct AggregationThresholdPolicy {
pub threshold: Option<i64>,
pub privacy_unit_columns: Vec<String>,
/* private fields */
}Expand description
Represents privacy policy associated with “aggregation threshold” method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threshold: Option<i64>Optional. The threshold for the “aggregation threshold” policy.
privacy_unit_columns: Vec<String>Optional. The privacy unit column(s) associated with this policy. For now, only one column per data source object (table, view) is allowed as a privacy unit column. Representing as a repeated field in metadata for extensibility to multiple columns in future. Duplicates and Repeated struct fields are not allowed. For nested fields, use dot notation (“outer.inner”)
Implementations
Sourceimpl AggregationThresholdPolicy
impl AggregationThresholdPolicy
Sourcepub fn set_threshold<T>(self, v: T) -> Self
pub fn set_threshold<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_threshold<T>(self, v: Option<T>) -> Self
Sourcepub fn set_privacy_unit_columns<T, V>(self, v: T) -> Self
pub fn set_privacy_unit_columns<T, V>(self, v: T) -> Self
Sets the value of privacy_unit_columns.
Example
ⓘ
let x = AggregationThresholdPolicy::new().set_privacy_unit_columns(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for AggregationThresholdPolicy
impl Clone for AggregationThresholdPolicy
Sourcefn clone(&self) -> AggregationThresholdPolicy
fn clone(&self) -> AggregationThresholdPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregationThresholdPolicy
impl Debug for AggregationThresholdPolicy
Sourceimpl Default for AggregationThresholdPolicy
impl Default for AggregationThresholdPolicy
Sourcefn default() -> AggregationThresholdPolicy
fn default() -> AggregationThresholdPolicy
Returns the “default value” for a type. Read more
Sourceimpl Message for AggregationThresholdPolicy
impl Message for AggregationThresholdPolicy
impl StructuralPartialEq for AggregationThresholdPolicy