#[non_exhaustive]pub struct BiEngineStatistics {
pub bi_engine_mode: BiEngineMode,
pub acceleration_mode: BiEngineAccelerationMode,
pub bi_engine_reasons: Vec<BiEngineReason>,
/* private fields */
}Expand description
Statistics for a BI Engine specific query. Populated as part of JobStatistics2
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bi_engine_mode: BiEngineModeOutput only. Specifies which mode of BI Engine acceleration was performed (if any).
acceleration_mode: BiEngineAccelerationModeOutput only. Specifies which mode of BI Engine acceleration was performed (if any).
bi_engine_reasons: Vec<BiEngineReason>In case of DISABLED or PARTIAL bi_engine_mode, these contain the explanatory reasons as to why BI Engine could not accelerate. In case the full query was accelerated, this field is not populated.
Implementations
Sourceimpl BiEngineStatistics
impl BiEngineStatistics
Sourcepub fn set_bi_engine_mode<T: Into<BiEngineMode>>(self, v: T) -> Self
pub fn set_bi_engine_mode<T: Into<BiEngineMode>>(self, v: T) -> Self
Sets the value of bi_engine_mode.
Example
ⓘ
use google_cloud_bigquery_v2::model::bi_engine_statistics::BiEngineMode;
let x0 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Disabled);
let x1 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Partial);
let x2 = BiEngineStatistics::new().set_bi_engine_mode(BiEngineMode::Full);Sourcepub fn set_acceleration_mode<T: Into<BiEngineAccelerationMode>>(
self,
v: T,
) -> Self
pub fn set_acceleration_mode<T: Into<BiEngineAccelerationMode>>( self, v: T, ) -> Self
Sets the value of acceleration_mode.
Example
ⓘ
use google_cloud_bigquery_v2::model::bi_engine_statistics::BiEngineAccelerationMode;
let x0 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::BiEngineDisabled);
let x1 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::PartialInput);
let x2 = BiEngineStatistics::new().set_acceleration_mode(BiEngineAccelerationMode::FullInput);Sourcepub fn set_bi_engine_reasons<T, V>(self, v: T) -> Self
pub fn set_bi_engine_reasons<T, V>(self, v: T) -> Self
Sets the value of bi_engine_reasons.
Example
ⓘ
use google_cloud_bigquery_v2::model::BiEngineReason;
let x = BiEngineStatistics::new()
.set_bi_engine_reasons([
BiEngineReason::default()/* use setters */,
BiEngineReason::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for BiEngineStatistics
impl Clone for BiEngineStatistics
Sourcefn clone(&self) -> BiEngineStatistics
fn clone(&self) -> BiEngineStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BiEngineStatistics
impl Debug for BiEngineStatistics
Sourceimpl Default for BiEngineStatistics
impl Default for BiEngineStatistics
Sourcefn default() -> BiEngineStatistics
fn default() -> BiEngineStatistics
Returns the “default value” for a type. Read more
Sourceimpl Message for BiEngineStatistics
impl Message for BiEngineStatistics
Sourceimpl PartialEq for BiEngineStatistics
impl PartialEq for BiEngineStatistics
impl StructuralPartialEq for BiEngineStatistics