#[non_exhaustive]pub struct BigtableColumnFamily {
pub family_id: String,
pub type: String,
pub encoding: String,
pub columns: Vec<BigtableColumn>,
pub only_read_latest: Option<BoolValue>,
pub proto_config: Option<BigtableProtoConfig>,
/* private fields */
}Expand description
Information related to a Bigtable column family.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.family_id: StringIdentifier of the column family.
type: StringOptional. The type to convert the value in cells of this column family. The values are expected to be encoded using HBase Bytes.toBytes function when using the BINARY encoding value. Following BigQuery types are allowed (case-sensitive):
- BYTES
- STRING
- INTEGER
- FLOAT
- BOOLEAN
- JSON
Default type is BYTES. This can be overridden for a specific column by listing that column in ‘columns’ and specifying a type for it.
encoding: StringOptional. The encoding of the values when the type is not STRING. Acceptable encoding values are: TEXT - indicates values are alphanumeric text strings. BINARY - indicates values are encoded using HBase Bytes.toBytes family of functions. PROTO_BINARY - indicates values are encoded using serialized proto messages. This can only be used in combination with JSON type. This can be overridden for a specific column by listing that column in ‘columns’ and specifying an encoding for it.
columns: Vec<BigtableColumn>Optional. Lists of columns that should be exposed as individual fields as
opposed to a list of (column name, value) pairs.
All columns whose qualifier matches a qualifier in this list can be
accessed as <family field name>.<column field name>.
Other columns can be accessed as a list through
the <family field name>.Column field.
only_read_latest: Option<BoolValue>Optional. If this is set only the latest version of value are exposed for all columns in this column family. This can be overridden for a specific column by listing that column in ‘columns’ and specifying a different setting for that column.
proto_config: Option<BigtableProtoConfig>Optional. Protobuf-specific configurations, only takes effect when the encoding is PROTO_BINARY.
Implementations
Sourceimpl BigtableColumnFamily
impl BigtableColumnFamily
Sourcepub fn set_family_id<T: Into<String>>(self, v: T) -> Self
pub fn set_family_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_encoding<T: Into<String>>(self, v: T) -> Self
pub fn set_encoding<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_columns<T, V>(self, v: T) -> Self
pub fn set_columns<T, V>(self, v: T) -> Self
Sourcepub fn set_only_read_latest<T>(self, v: T) -> Self
pub fn set_only_read_latest<T>(self, v: T) -> Self
Sets the value of only_read_latest.
Example
use wkt::BoolValue;
let x = BigtableColumnFamily::new().set_only_read_latest(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_only_read_latest<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_only_read_latest<T>(self, v: Option<T>) -> Self
Sets or clears the value of only_read_latest.
Example
use wkt::BoolValue;
let x = BigtableColumnFamily::new().set_or_clear_only_read_latest(Some(BoolValue::default()/* use setters */));
let x = BigtableColumnFamily::new().set_or_clear_only_read_latest(None::<BoolValue>);Sourcepub fn set_proto_config<T>(self, v: T) -> Selfwhere
T: Into<BigtableProtoConfig>,
pub fn set_proto_config<T>(self, v: T) -> Selfwhere
T: Into<BigtableProtoConfig>,
Sets the value of proto_config.
Example
use google_cloud_bigquery_v2::model::BigtableProtoConfig;
let x = BigtableColumnFamily::new().set_proto_config(BigtableProtoConfig::default()/* use setters */);Sourcepub fn set_or_clear_proto_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigtableProtoConfig>,
pub fn set_or_clear_proto_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigtableProtoConfig>,
Sets or clears the value of proto_config.
Example
use google_cloud_bigquery_v2::model::BigtableProtoConfig;
let x = BigtableColumnFamily::new().set_or_clear_proto_config(Some(BigtableProtoConfig::default()/* use setters */));
let x = BigtableColumnFamily::new().set_or_clear_proto_config(None::<BigtableProtoConfig>);Trait Implementations
Sourceimpl Clone for BigtableColumnFamily
impl Clone for BigtableColumnFamily
Sourcefn clone(&self) -> BigtableColumnFamily
fn clone(&self) -> BigtableColumnFamily
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BigtableColumnFamily
impl Debug for BigtableColumnFamily
Sourceimpl Default for BigtableColumnFamily
impl Default for BigtableColumnFamily
Sourcefn default() -> BigtableColumnFamily
fn default() -> BigtableColumnFamily
Sourceimpl Message for BigtableColumnFamily
impl Message for BigtableColumnFamily
Sourceimpl PartialEq for BigtableColumnFamily
impl PartialEq for BigtableColumnFamily
impl StructuralPartialEq for BigtableColumnFamily