#[non_exhaustive]pub struct BigtableOptions {
pub column_families: Vec<BigtableColumnFamily>,
pub ignore_unspecified_column_families: Option<BoolValue>,
pub read_rowkey_as_string: Option<BoolValue>,
pub output_column_families_as_json: Option<BoolValue>,
/* private fields */
}Expand description
Options specific to Google Cloud Bigtable data sources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.column_families: Vec<BigtableColumnFamily>Optional. List of column families to expose in the table schema along with their types. This list restricts the column families that can be referenced in queries and specifies their value types. You can use this list to do type conversions - see the ‘type’ field for more details. If you leave this list empty, all column families are present in the table schema and their values are read as BYTES. During a query only the column families referenced in that query are read from Bigtable.
ignore_unspecified_column_families: Option<BoolValue>Optional. If field is true, then the column families that are not specified in columnFamilies list are not exposed in the table schema. Otherwise, they are read with BYTES type values. The default value is false.
read_rowkey_as_string: Option<BoolValue>Optional. If field is true, then the rowkey column families will be read and converted to string. Otherwise they are read with BYTES type values and users need to manually cast them with CAST if necessary. The default value is false.
output_column_families_as_json: Option<BoolValue>Optional. If field is true, then each column family will be read as a single JSON column. Otherwise they are read as a repeated cell structure containing timestamp/value tuples. The default value is false.
Implementations
Sourceimpl BigtableOptions
impl BigtableOptions
Sourcepub fn set_column_families<T, V>(self, v: T) -> Self
pub fn set_column_families<T, V>(self, v: T) -> Self
Sets the value of column_families.
Example
use google_cloud_bigquery_v2::model::BigtableColumnFamily;
let x = BigtableOptions::new()
.set_column_families([
BigtableColumnFamily::default()/* use setters */,
BigtableColumnFamily::default()/* use (different) setters */,
]);Sourcepub fn set_ignore_unspecified_column_families<T>(self, v: T) -> Self
pub fn set_ignore_unspecified_column_families<T>(self, v: T) -> Self
Sets the value of ignore_unspecified_column_families.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_ignore_unspecified_column_families(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_ignore_unspecified_column_families<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_ignore_unspecified_column_families<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of ignore_unspecified_column_families.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_or_clear_ignore_unspecified_column_families(Some(BoolValue::default()/* use setters */));
let x = BigtableOptions::new().set_or_clear_ignore_unspecified_column_families(None::<BoolValue>);Sourcepub fn set_read_rowkey_as_string<T>(self, v: T) -> Self
pub fn set_read_rowkey_as_string<T>(self, v: T) -> Self
Sets the value of read_rowkey_as_string.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_read_rowkey_as_string(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_read_rowkey_as_string<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_read_rowkey_as_string<T>(self, v: Option<T>) -> Self
Sets or clears the value of read_rowkey_as_string.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_or_clear_read_rowkey_as_string(Some(BoolValue::default()/* use setters */));
let x = BigtableOptions::new().set_or_clear_read_rowkey_as_string(None::<BoolValue>);Sourcepub fn set_output_column_families_as_json<T>(self, v: T) -> Self
pub fn set_output_column_families_as_json<T>(self, v: T) -> Self
Sets the value of output_column_families_as_json.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_output_column_families_as_json(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_output_column_families_as_json<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_output_column_families_as_json<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of output_column_families_as_json.
Example
use wkt::BoolValue;
let x = BigtableOptions::new().set_or_clear_output_column_families_as_json(Some(BoolValue::default()/* use setters */));
let x = BigtableOptions::new().set_or_clear_output_column_families_as_json(None::<BoolValue>);Trait Implementations
Sourceimpl Clone for BigtableOptions
impl Clone for BigtableOptions
Sourcefn clone(&self) -> BigtableOptions
fn clone(&self) -> BigtableOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BigtableOptions
impl Debug for BigtableOptions
Sourceimpl Default for BigtableOptions
impl Default for BigtableOptions
Sourcefn default() -> BigtableOptions
fn default() -> BigtableOptions
Sourceimpl Message for BigtableOptions
impl Message for BigtableOptions
Sourceimpl PartialEq for BigtableOptions
impl PartialEq for BigtableOptions
impl StructuralPartialEq for BigtableOptions