#[non_exhaustive]pub struct DatasetAccessEntry {
pub dataset: Option<DatasetReference>,
pub target_types: Vec<TargetType>,
/* private fields */
}Expand description
Grants all resources of particular types in a particular dataset read access to the current dataset.
Similar to how individually authorized views work, updates to any resource granted through its dataset (including creation of new resources) requires read permission to referenced resources, plus write permission to the authorizing dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset: Option<DatasetReference>The dataset this entry applies to
target_types: Vec<TargetType>Which resources in the dataset this entry applies to. Currently, only views are supported, but additional target types may be added in the future.
Implementations
Sourceimpl DatasetAccessEntry
impl DatasetAccessEntry
Sourcepub fn set_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_dataset<T>(self, v: T) -> Selfwhere
T: Into<DatasetReference>,
Sourcepub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetReference>,
Sourcepub fn set_target_types<T, V>(self, v: T) -> Self
pub fn set_target_types<T, V>(self, v: T) -> Self
Sets the value of target_types.
Example
ⓘ
use google_cloud_bigquery_v2::model::dataset_access_entry::TargetType;
let x = DatasetAccessEntry::new().set_target_types([
TargetType::Views,
TargetType::Routines,
]);Trait Implementations
Sourceimpl Clone for DatasetAccessEntry
impl Clone for DatasetAccessEntry
Sourcefn clone(&self) -> DatasetAccessEntry
fn clone(&self) -> DatasetAccessEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatasetAccessEntry
impl Debug for DatasetAccessEntry
Sourceimpl Default for DatasetAccessEntry
impl Default for DatasetAccessEntry
Sourcefn default() -> DatasetAccessEntry
fn default() -> DatasetAccessEntry
Returns the “default value” for a type. Read more
Sourceimpl Message for DatasetAccessEntry
impl Message for DatasetAccessEntry
Sourceimpl PartialEq for DatasetAccessEntry
impl PartialEq for DatasetAccessEntry
impl StructuralPartialEq for DatasetAccessEntry