DeleteRowAccessPolicyRequest

Struct DeleteRowAccessPolicyRequest 

#[non_exhaustive]
pub struct DeleteRowAccessPolicyRequest { pub project_id: String, pub dataset_id: String, pub table_id: String, pub policy_id: String, pub force: Option<bool>, /* private fields */ }
Request message for the DeleteRowAccessPolicy method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
project_id: String

Required. Project ID of the table to delete the row access policy.

dataset_id: String

Required. Dataset ID of the table to delete the row access policy.

table_id: String

Required. Table ID of the table to delete the row access policy.

policy_id: String

Required. Policy ID of the row access policy.

force: Option<bool>

If set to true, it deletes the row access policy even if it’s the last row access policy on the table and the deletion will widen the access rather narrowing it.

Implementations

Source

impl DeleteRowAccessPolicyRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of project_id.

Example
let x = DeleteRowAccessPolicyRequest::new().set_project_id("example");
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self

Sets the value of dataset_id.

Example
let x = DeleteRowAccessPolicyRequest::new().set_dataset_id("example");
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self

Sets the value of table_id.

Example
let x = DeleteRowAccessPolicyRequest::new().set_table_id("example");
pub fn set_policy_id<T: Into<String>>(self, v: T) -> Self

Sets the value of policy_id.

Example
let x = DeleteRowAccessPolicyRequest::new().set_policy_id("example");
pub fn set_force<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of force.

Example
let x = DeleteRowAccessPolicyRequest::new().set_force(true);
pub fn set_or_clear_force<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of force.

Example
let x = DeleteRowAccessPolicyRequest::new().set_or_clear_force(Some(false));
let x = DeleteRowAccessPolicyRequest::new().set_or_clear_force(None::<bool>);