#[non_exhaustive]pub struct DestinationTableProperties {
pub friendly_name: Option<StringValue>,
pub description: Option<StringValue>,
pub labels: HashMap<String, String>,
/* private fields */
}Expand description
Properties for the destination table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.friendly_name: Option<StringValue>Optional. Friendly name for the destination table. If the table already exists, it should be same as the existing friendly name.
description: Option<StringValue>Optional. The description for the destination table. This will only be used if the destination table is newly created. If the table already exists and a value different than the current description is provided, the job will fail.
labels: HashMap<String, String>Optional. The labels associated with this table. You can use these to organize and group your tables. This will only be used if the destination table is newly created. If the table already exists and labels are different than the current labels are provided, the job will fail.
Implementations
Sourceimpl DestinationTableProperties
impl DestinationTableProperties
Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = DestinationTableProperties::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of description.
Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_description(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of description.
Example
use wkt::StringValue;
let x = DestinationTableProperties::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = DestinationTableProperties::new().set_or_clear_description(None::<StringValue>);Trait Implementations
Sourceimpl Clone for DestinationTableProperties
impl Clone for DestinationTableProperties
Sourcefn clone(&self) -> DestinationTableProperties
fn clone(&self) -> DestinationTableProperties
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DestinationTableProperties
impl Debug for DestinationTableProperties
Sourceimpl Default for DestinationTableProperties
impl Default for DestinationTableProperties
Sourcefn default() -> DestinationTableProperties
fn default() -> DestinationTableProperties
Sourceimpl Message for DestinationTableProperties
impl Message for DestinationTableProperties
impl StructuralPartialEq for DestinationTableProperties