#[non_exhaustive]pub struct ExplainQueryStage {Show 31 fields
pub name: String,
pub id: Option<Int64Value>,
pub start_ms: i64,
pub end_ms: i64,
pub input_stages: Vec<i64>,
pub wait_ratio_avg: Option<DoubleValue>,
pub wait_ms_avg: Option<Int64Value>,
pub wait_ratio_max: Option<DoubleValue>,
pub wait_ms_max: Option<Int64Value>,
pub read_ratio_avg: Option<DoubleValue>,
pub read_ms_avg: Option<Int64Value>,
pub read_ratio_max: Option<DoubleValue>,
pub read_ms_max: Option<Int64Value>,
pub compute_ratio_avg: Option<DoubleValue>,
pub compute_ms_avg: Option<Int64Value>,
pub compute_ratio_max: Option<DoubleValue>,
pub compute_ms_max: Option<Int64Value>,
pub write_ratio_avg: Option<DoubleValue>,
pub write_ms_avg: Option<Int64Value>,
pub write_ratio_max: Option<DoubleValue>,
pub write_ms_max: Option<Int64Value>,
pub shuffle_output_bytes: Option<Int64Value>,
pub shuffle_output_bytes_spilled: Option<Int64Value>,
pub records_read: Option<Int64Value>,
pub records_written: Option<Int64Value>,
pub parallel_inputs: Option<Int64Value>,
pub completed_parallel_inputs: Option<Int64Value>,
pub status: String,
pub steps: Vec<ExplainQueryStep>,
pub slot_ms: Option<Int64Value>,
pub compute_mode: ComputeMode,
/* private fields */
}Expand description
A single stage of query execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name for the stage.
id: Option<Int64Value>Unique ID for the stage within the plan.
start_ms: i64Stage start time represented as milliseconds since the epoch.
end_ms: i64Stage end time represented as milliseconds since the epoch.
input_stages: Vec<i64>IDs for stages that are inputs to this stage.
wait_ratio_avg: Option<DoubleValue>Relative amount of time the average shard spent waiting to be scheduled.
wait_ms_avg: Option<Int64Value>Milliseconds the average shard spent waiting to be scheduled.
wait_ratio_max: Option<DoubleValue>Relative amount of time the slowest shard spent waiting to be scheduled.
wait_ms_max: Option<Int64Value>Milliseconds the slowest shard spent waiting to be scheduled.
read_ratio_avg: Option<DoubleValue>Relative amount of time the average shard spent reading input.
read_ms_avg: Option<Int64Value>Milliseconds the average shard spent reading input.
read_ratio_max: Option<DoubleValue>Relative amount of time the slowest shard spent reading input.
read_ms_max: Option<Int64Value>Milliseconds the slowest shard spent reading input.
compute_ratio_avg: Option<DoubleValue>Relative amount of time the average shard spent on CPU-bound tasks.
compute_ms_avg: Option<Int64Value>Milliseconds the average shard spent on CPU-bound tasks.
compute_ratio_max: Option<DoubleValue>Relative amount of time the slowest shard spent on CPU-bound tasks.
compute_ms_max: Option<Int64Value>Milliseconds the slowest shard spent on CPU-bound tasks.
write_ratio_avg: Option<DoubleValue>Relative amount of time the average shard spent on writing output.
write_ms_avg: Option<Int64Value>Milliseconds the average shard spent on writing output.
write_ratio_max: Option<DoubleValue>Relative amount of time the slowest shard spent on writing output.
write_ms_max: Option<Int64Value>Milliseconds the slowest shard spent on writing output.
shuffle_output_bytes: Option<Int64Value>Total number of bytes written to shuffle.
shuffle_output_bytes_spilled: Option<Int64Value>Total number of bytes written to shuffle and spilled to disk.
records_read: Option<Int64Value>Number of records read into the stage.
records_written: Option<Int64Value>Number of records written by the stage.
parallel_inputs: Option<Int64Value>Number of parallel input segments to be processed
completed_parallel_inputs: Option<Int64Value>Number of parallel input segments completed.
status: StringCurrent status for this stage.
steps: Vec<ExplainQueryStep>List of operations within the stage in dependency order (approximately chronological).
slot_ms: Option<Int64Value>Slot-milliseconds used by the stage.
compute_mode: ComputeModeOutput only. Compute mode for this stage.
Implementations
Sourceimpl ExplainQueryStage
impl ExplainQueryStage
Sourcepub fn set_id<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_id<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_start_ms<T: Into<i64>>(self, v: T) -> Self
pub fn set_start_ms<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_end_ms<T: Into<i64>>(self, v: T) -> Self
pub fn set_end_ms<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_input_stages<T, V>(self, v: T) -> Self
pub fn set_input_stages<T, V>(self, v: T) -> Self
Sets the value of input_stages.
Example
let x = ExplainQueryStage::new().set_input_stages([1, 2, 3]);Sourcepub fn set_wait_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_wait_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of wait_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_wait_ratio_avg(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_wait_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_wait_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of wait_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_avg(None::<DoubleValue>);Sourcepub fn set_wait_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_wait_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of wait_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_wait_ms_avg(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_wait_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_wait_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of wait_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_wait_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ms_avg(None::<Int64Value>);Sourcepub fn set_wait_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_wait_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of wait_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_wait_ratio_max(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_wait_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_wait_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of wait_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ratio_max(None::<DoubleValue>);Sourcepub fn set_wait_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_wait_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of wait_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_wait_ms_max(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_wait_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_wait_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of wait_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_wait_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_wait_ms_max(None::<Int64Value>);Sourcepub fn set_read_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_read_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of read_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_read_ratio_avg(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_read_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_read_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of read_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_read_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ratio_avg(None::<DoubleValue>);Sourcepub fn set_read_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_read_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of read_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_read_ms_avg(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_read_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_read_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of read_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_read_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ms_avg(None::<Int64Value>);Sourcepub fn set_read_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_read_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of read_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_read_ratio_max(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_read_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_read_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of read_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_read_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ratio_max(None::<DoubleValue>);Sourcepub fn set_read_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_read_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of read_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_read_ms_max(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_read_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_read_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of read_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_read_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_read_ms_max(None::<Int64Value>);Sourcepub fn set_compute_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_compute_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of compute_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_compute_ratio_avg(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_compute_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_compute_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of compute_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_avg(None::<DoubleValue>);Sourcepub fn set_compute_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_compute_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of compute_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_compute_ms_avg(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_compute_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_compute_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of compute_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_compute_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ms_avg(None::<Int64Value>);Sourcepub fn set_compute_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_compute_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of compute_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_compute_ratio_max(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_compute_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_compute_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of compute_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ratio_max(None::<DoubleValue>);Sourcepub fn set_compute_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_compute_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of compute_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_compute_ms_max(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_compute_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_compute_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of compute_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_compute_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_compute_ms_max(None::<Int64Value>);Sourcepub fn set_write_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_write_ratio_avg<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of write_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_write_ratio_avg(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_write_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_write_ratio_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of write_ratio_avg.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_write_ratio_avg(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ratio_avg(None::<DoubleValue>);Sourcepub fn set_write_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_write_ms_avg<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of write_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_write_ms_avg(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_write_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_write_ms_avg<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of write_ms_avg.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_write_ms_avg(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ms_avg(None::<Int64Value>);Sourcepub fn set_write_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_write_ratio_max<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of write_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_write_ratio_max(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_write_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_write_ratio_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of write_ratio_max.
Example
use wkt::DoubleValue;
let x = ExplainQueryStage::new().set_or_clear_write_ratio_max(Some(DoubleValue::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ratio_max(None::<DoubleValue>);Sourcepub fn set_write_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_write_ms_max<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of write_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_write_ms_max(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_write_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_write_ms_max<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of write_ms_max.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_write_ms_max(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_write_ms_max(None::<Int64Value>);Sourcepub fn set_shuffle_output_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_shuffle_output_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of shuffle_output_bytes.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_shuffle_output_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_shuffle_output_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_shuffle_output_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of shuffle_output_bytes.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes(None::<Int64Value>);Sourcepub fn set_shuffle_output_bytes_spilled<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_shuffle_output_bytes_spilled<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of shuffle_output_bytes_spilled.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_shuffle_output_bytes_spilled(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_shuffle_output_bytes_spilled<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_shuffle_output_bytes_spilled<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of shuffle_output_bytes_spilled.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes_spilled(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_shuffle_output_bytes_spilled(None::<Int64Value>);Sourcepub fn set_records_read<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_records_read<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of records_read.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_records_read(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_records_read<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_records_read<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of records_read.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_records_read(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_records_read(None::<Int64Value>);Sourcepub fn set_records_written<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_records_written<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of records_written.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_records_written(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_records_written<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_records_written<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of records_written.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_records_written(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_records_written(None::<Int64Value>);Sourcepub fn set_parallel_inputs<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_parallel_inputs<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of parallel_inputs.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_parallel_inputs(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_parallel_inputs<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_parallel_inputs<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of parallel_inputs.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_parallel_inputs(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_parallel_inputs(None::<Int64Value>);Sourcepub fn set_completed_parallel_inputs<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_completed_parallel_inputs<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of completed_parallel_inputs.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_completed_parallel_inputs(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_completed_parallel_inputs<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_completed_parallel_inputs<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of completed_parallel_inputs.
Example
use wkt::Int64Value;
let x = ExplainQueryStage::new().set_or_clear_completed_parallel_inputs(Some(Int64Value::default()/* use setters */));
let x = ExplainQueryStage::new().set_or_clear_completed_parallel_inputs(None::<Int64Value>);Sourcepub fn set_status<T: Into<String>>(self, v: T) -> Self
pub fn set_status<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_compute_mode<T: Into<ComputeMode>>(self, v: T) -> Self
pub fn set_compute_mode<T: Into<ComputeMode>>(self, v: T) -> Self
Sets the value of compute_mode.
Example
use google_cloud_bigquery_v2::model::explain_query_stage::ComputeMode;
let x0 = ExplainQueryStage::new().set_compute_mode(ComputeMode::Bigquery);
let x1 = ExplainQueryStage::new().set_compute_mode(ComputeMode::BiEngine);Trait Implementations
Sourceimpl Clone for ExplainQueryStage
impl Clone for ExplainQueryStage
Sourcefn clone(&self) -> ExplainQueryStage
fn clone(&self) -> ExplainQueryStage
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExplainQueryStage
impl Debug for ExplainQueryStage
Sourceimpl Default for ExplainQueryStage
impl Default for ExplainQueryStage
Sourcefn default() -> ExplainQueryStage
fn default() -> ExplainQueryStage
Sourceimpl Message for ExplainQueryStage
impl Message for ExplainQueryStage
Sourceimpl PartialEq for ExplainQueryStage
impl PartialEq for ExplainQueryStage
impl StructuralPartialEq for ExplainQueryStage