#[non_exhaustive]pub struct ExternalCatalogTableOptions {
pub parameters: HashMap<String, String>,
pub storage_descriptor: Option<StorageDescriptor>,
pub connection_id: String,
/* private fields */
}Expand description
Metadata about open source compatible table. The fields contained in these options correspond to Hive metastore’s table-level properties.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameters: HashMap<String, String>Optional. A map of the key-value pairs defining the parameters and properties of the open source table. Corresponds with Hive metastore table parameters. Maximum size of 4MiB.
storage_descriptor: Option<StorageDescriptor>Optional. A storage descriptor containing information about the physical storage of this table.
connection_id: StringOptional. A connection ID that specifies the credentials to be used to read
external storage, such as Azure Blob, Cloud Storage, or Amazon S3. This
connection is needed to read the open source table from BigQuery. The
connection_id format must be either
<project_id>.<location_id>.<connection_id> or
projects/<project_id>/locations/<location_id>/connections/<connection_id>.
Implementations
Sourceimpl ExternalCatalogTableOptions
impl ExternalCatalogTableOptions
Sourcepub fn set_parameters<T, K, V>(self, v: T) -> Self
pub fn set_parameters<T, K, V>(self, v: T) -> Self
Sets the value of parameters.
Example
let x = ExternalCatalogTableOptions::new().set_parameters([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_storage_descriptor<T>(self, v: T) -> Selfwhere
T: Into<StorageDescriptor>,
pub fn set_storage_descriptor<T>(self, v: T) -> Selfwhere
T: Into<StorageDescriptor>,
Sets the value of storage_descriptor.
Example
use google_cloud_bigquery_v2::model::StorageDescriptor;
let x = ExternalCatalogTableOptions::new().set_storage_descriptor(StorageDescriptor::default()/* use setters */);Sourcepub fn set_or_clear_storage_descriptor<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageDescriptor>,
pub fn set_or_clear_storage_descriptor<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageDescriptor>,
Sets or clears the value of storage_descriptor.
Example
use google_cloud_bigquery_v2::model::StorageDescriptor;
let x = ExternalCatalogTableOptions::new().set_or_clear_storage_descriptor(Some(StorageDescriptor::default()/* use setters */));
let x = ExternalCatalogTableOptions::new().set_or_clear_storage_descriptor(None::<StorageDescriptor>);Sourcepub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
pub fn set_connection_id<T: Into<String>>(self, v: T) -> Self
Sets the value of connection_id.
Example
let x = ExternalCatalogTableOptions::new().set_connection_id("example");Trait Implementations
Sourceimpl Clone for ExternalCatalogTableOptions
impl Clone for ExternalCatalogTableOptions
Sourcefn clone(&self) -> ExternalCatalogTableOptions
fn clone(&self) -> ExternalCatalogTableOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExternalCatalogTableOptions
impl Debug for ExternalCatalogTableOptions
Sourceimpl Default for ExternalCatalogTableOptions
impl Default for ExternalCatalogTableOptions
Sourcefn default() -> ExternalCatalogTableOptions
fn default() -> ExternalCatalogTableOptions
impl StructuralPartialEq for ExternalCatalogTableOptions