#[non_exhaustive]pub struct ExternalRuntimeOptions {
pub container_memory: String,
pub container_cpu: f64,
pub runtime_connection: String,
pub max_batching_rows: i64,
pub runtime_version: String,
pub container_request_concurrency: i64,
/* private fields */
}Expand description
Options for the runtime of the external system.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_memory: StringOptional. Amount of memory provisioned for a Python UDF container instance. Format: {number}{unit} where unit is one of “M”, “G”, “Mi” and “Gi” (e.g. 1G, 512Mi). If not specified, the default value is 512Mi. For more information, see Configure container limits for Python UDFs
container_cpu: f64Optional. Amount of CPU provisioned for a Python UDF container instance. For more information, see Configure container limits for Python UDFs
runtime_connection: StringOptional. Fully qualified name of the connection whose service account will
be used to execute the code in the container. Format:
"projects/{project_id}/locations/{location_id}/connections/{connection_id}"
max_batching_rows: i64Optional. Maximum number of rows in each batch sent to the external runtime. If absent or if 0, BigQuery dynamically decides the number of rows in a batch.
runtime_version: StringOptional. Language runtime version. Example: python-3.11.
container_request_concurrency: i64Optional. Maximum number of requests that a Python UDF instance can handle
concurrently. If absent or if 0, the default concurrency value is used.
For more information, see Configure container limits for Python
UDFs.
Implementations
Sourceimpl ExternalRuntimeOptions
impl ExternalRuntimeOptions
Sourcepub fn set_container_memory<T: Into<String>>(self, v: T) -> Self
pub fn set_container_memory<T: Into<String>>(self, v: T) -> Self
Sets the value of container_memory.
Example
let x = ExternalRuntimeOptions::new().set_container_memory("example");Sourcepub fn set_container_cpu<T: Into<f64>>(self, v: T) -> Self
pub fn set_container_cpu<T: Into<f64>>(self, v: T) -> Self
Sets the value of container_cpu.
Example
let x = ExternalRuntimeOptions::new().set_container_cpu(42.0);Sourcepub fn set_runtime_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_connection<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_connection.
Example
let x = ExternalRuntimeOptions::new().set_runtime_connection("example");Sourcepub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
pub fn set_max_batching_rows<T: Into<i64>>(self, v: T) -> Self
Sets the value of max_batching_rows.
Example
let x = ExternalRuntimeOptions::new().set_max_batching_rows(42);Sourcepub fn set_runtime_version<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_version<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_version.
Example
let x = ExternalRuntimeOptions::new().set_runtime_version("example");Sourcepub fn set_container_request_concurrency<T: Into<i64>>(self, v: T) -> Self
pub fn set_container_request_concurrency<T: Into<i64>>(self, v: T) -> Self
Sets the value of container_request_concurrency.
Example
let x = ExternalRuntimeOptions::new().set_container_request_concurrency(42);Trait Implementations
Sourceimpl Clone for ExternalRuntimeOptions
impl Clone for ExternalRuntimeOptions
Sourcefn clone(&self) -> ExternalRuntimeOptions
fn clone(&self) -> ExternalRuntimeOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExternalRuntimeOptions
impl Debug for ExternalRuntimeOptions
Sourceimpl Default for ExternalRuntimeOptions
impl Default for ExternalRuntimeOptions
Sourcefn default() -> ExternalRuntimeOptions
fn default() -> ExternalRuntimeOptions
Sourceimpl Message for ExternalRuntimeOptions
impl Message for ExternalRuntimeOptions
Sourceimpl PartialEq for ExternalRuntimeOptions
impl PartialEq for ExternalRuntimeOptions
impl StructuralPartialEq for ExternalRuntimeOptions