#[non_exhaustive]pub struct GetDatasetRequest {
pub project_id: String,
pub dataset_id: String,
pub dataset_view: DatasetView,
pub access_policy_version: i32,
/* private fields */
}Expand description
Request format for getting information about a dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the requested dataset
dataset_id: StringRequired. Dataset ID of the requested dataset
dataset_view: DatasetViewOptional. Specifies the view that determines which dataset information is returned. By default, metadata and ACL information are returned.
access_policy_version: i32Optional. The version of the access policy schema to fetch. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected.
Requests for conditional access policy binding in datasets must specify version 3. Dataset with no conditional role bindings in access policy may specify any valid value or leave the field unset.
This field will be mapped to [IAM Policy version] (https://cloud.google.com/iam/docs/policies#versions) and will be used to fetch policy from IAM.
If unset or if 0 or 1 value is used for dataset with conditional bindings, access entry with condition will have role string appended by ‘withcond’ string followed by a hash value. For example : { “access”: [ { “role”: “roles/bigquery.dataViewer_with_conditionalbinding_7a34awqsda”, “userByEmail”: “user@example.com”, } ] } Please refer https://cloud.google.com/iam/docs/troubleshooting-withcond for more details.
Implementations
Sourceimpl GetDatasetRequest
impl GetDatasetRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_view<T: Into<DatasetView>>(self, v: T) -> Self
pub fn set_dataset_view<T: Into<DatasetView>>(self, v: T) -> Self
Sets the value of dataset_view.
Example
use google_cloud_bigquery_v2::model::get_dataset_request::DatasetView;
let x0 = GetDatasetRequest::new().set_dataset_view(DatasetView::Metadata);
let x1 = GetDatasetRequest::new().set_dataset_view(DatasetView::Acl);
let x2 = GetDatasetRequest::new().set_dataset_view(DatasetView::Full);Sourcepub fn set_access_policy_version<T: Into<i32>>(self, v: T) -> Self
pub fn set_access_policy_version<T: Into<i32>>(self, v: T) -> Self
Sets the value of access_policy_version.
Example
let x = GetDatasetRequest::new().set_access_policy_version(42);Trait Implementations
Sourceimpl Clone for GetDatasetRequest
impl Clone for GetDatasetRequest
Sourcefn clone(&self) -> GetDatasetRequest
fn clone(&self) -> GetDatasetRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GetDatasetRequest
impl Debug for GetDatasetRequest
Sourceimpl Default for GetDatasetRequest
impl Default for GetDatasetRequest
Sourcefn default() -> GetDatasetRequest
fn default() -> GetDatasetRequest
Sourceimpl Message for GetDatasetRequest
impl Message for GetDatasetRequest
Sourceimpl PartialEq for GetDatasetRequest
impl PartialEq for GetDatasetRequest
impl StructuralPartialEq for GetDatasetRequest