#[non_exhaustive]pub struct GetQueryResultsRequest {
pub project_id: String,
pub job_id: String,
pub start_index: Option<UInt64Value>,
pub page_token: String,
pub max_results: Option<UInt32Value>,
pub timeout_ms: Option<UInt32Value>,
pub location: String,
pub format_options: Option<DataFormatOptions>,
/* private fields */
}Expand description
Request object of GetQueryResults.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID of the query job.
job_id: StringRequired. Job ID of the query job.
start_index: Option<UInt64Value>Zero-based index of the starting row.
page_token: StringPage token, returned by a previous call, to request the next page of results.
max_results: Option<UInt32Value>Maximum number of results to read.
timeout_ms: Option<UInt32Value>Optional: Specifies the maximum amount of time, in milliseconds, that the client is willing to wait for the query to complete. By default, this limit is 10 seconds (10,000 milliseconds). If the query is complete, the jobComplete field in the response is true. If the query has not yet completed, jobComplete is false.
You can request a longer timeout period in the timeoutMs field. However, the call is not guaranteed to wait for the specified timeout; it typically returns after around 200 seconds (200,000 milliseconds), even if the query is not complete.
If jobComplete is false, you can continue to wait for the query to complete by calling the getQueryResults method until the jobComplete field in the getQueryResults response is true.
location: StringThe geographic location of the job. You must specify the location to run the job for the following scenarios:
- If the location to run a job is not in the
usor theeumulti-regional location - If the job’s location is in a single region (for example,
us-central1)
For more information, see how to specify locations.
format_options: Option<DataFormatOptions>Optional. Output format adjustments.
Implementations
Sourceimpl GetQueryResultsRequest
impl GetQueryResultsRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = GetQueryResultsRequest::new().set_project_id("example");Sourcepub fn set_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_job_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_start_index<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_start_index<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
Sets the value of start_index.
Example
use wkt::UInt64Value;
let x = GetQueryResultsRequest::new().set_start_index(UInt64Value::default()/* use setters */);Sourcepub fn set_or_clear_start_index<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_or_clear_start_index<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
Sets or clears the value of start_index.
Example
use wkt::UInt64Value;
let x = GetQueryResultsRequest::new().set_or_clear_start_index(Some(UInt64Value::default()/* use setters */));
let x = GetQueryResultsRequest::new().set_or_clear_start_index(None::<UInt64Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = GetQueryResultsRequest::new().set_page_token("example");Sourcepub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_max_results<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
Sets the value of max_results.
Example
use wkt::UInt32Value;
let x = GetQueryResultsRequest::new().set_max_results(UInt32Value::default()/* use setters */);Sourcepub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_or_clear_max_results<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
Sets or clears the value of max_results.
Example
use wkt::UInt32Value;
let x = GetQueryResultsRequest::new().set_or_clear_max_results(Some(UInt32Value::default()/* use setters */));
let x = GetQueryResultsRequest::new().set_or_clear_max_results(None::<UInt32Value>);Sourcepub fn set_timeout_ms<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_timeout_ms<T>(self, v: T) -> Selfwhere
T: Into<UInt32Value>,
Sets the value of timeout_ms.
Example
use wkt::UInt32Value;
let x = GetQueryResultsRequest::new().set_timeout_ms(UInt32Value::default()/* use setters */);Sourcepub fn set_or_clear_timeout_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
pub fn set_or_clear_timeout_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt32Value>,
Sets or clears the value of timeout_ms.
Example
use wkt::UInt32Value;
let x = GetQueryResultsRequest::new().set_or_clear_timeout_ms(Some(UInt32Value::default()/* use setters */));
let x = GetQueryResultsRequest::new().set_or_clear_timeout_ms(None::<UInt32Value>);Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_format_options<T>(self, v: T) -> Selfwhere
T: Into<DataFormatOptions>,
pub fn set_format_options<T>(self, v: T) -> Selfwhere
T: Into<DataFormatOptions>,
Sets the value of format_options.
Example
use google_cloud_bigquery_v2::model::DataFormatOptions;
let x = GetQueryResultsRequest::new().set_format_options(DataFormatOptions::default()/* use setters */);Sourcepub fn set_or_clear_format_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataFormatOptions>,
pub fn set_or_clear_format_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataFormatOptions>,
Sets or clears the value of format_options.
Example
use google_cloud_bigquery_v2::model::DataFormatOptions;
let x = GetQueryResultsRequest::new().set_or_clear_format_options(Some(DataFormatOptions::default()/* use setters */));
let x = GetQueryResultsRequest::new().set_or_clear_format_options(None::<DataFormatOptions>);Trait Implementations
Sourceimpl Clone for GetQueryResultsRequest
impl Clone for GetQueryResultsRequest
Sourcefn clone(&self) -> GetQueryResultsRequest
fn clone(&self) -> GetQueryResultsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GetQueryResultsRequest
impl Debug for GetQueryResultsRequest
Sourceimpl Default for GetQueryResultsRequest
impl Default for GetQueryResultsRequest
Sourcefn default() -> GetQueryResultsRequest
fn default() -> GetQueryResultsRequest
Sourceimpl Message for GetQueryResultsRequest
impl Message for GetQueryResultsRequest
Sourceimpl PartialEq for GetQueryResultsRequest
impl PartialEq for GetQueryResultsRequest
impl StructuralPartialEq for GetQueryResultsRequest