#[non_exhaustive]pub struct GetQueryResultsResponse {
pub kind: String,
pub etag: String,
pub schema: Option<TableSchema>,
pub job_reference: Option<JobReference>,
pub total_rows: Option<UInt64Value>,
pub page_token: String,
pub rows: Vec<Struct>,
pub total_bytes_processed: Option<Int64Value>,
pub job_complete: Option<BoolValue>,
pub errors: Vec<ErrorProto>,
pub cache_hit: Option<BoolValue>,
pub num_dml_affected_rows: Option<Int64Value>,
/* private fields */
}Expand description
Response object of GetQueryResults.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringThe resource type of the response.
etag: StringA hash of this response.
schema: Option<TableSchema>The schema of the results. Present only when the query completes successfully.
job_reference: Option<JobReference>Reference to the BigQuery Job that was created to run the query. This field will be present even if the original request timed out, in which case GetQueryResults can be used to read the results once the query has completed. Since this API only returns the first page of results, subsequent pages can be fetched via the same mechanism (GetQueryResults).
total_rows: Option<UInt64Value>The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results. Present only when the query completes successfully.
page_token: StringA token used for paging results. When this token is non-empty, it indicates additional results are available.
rows: Vec<Struct>An object with as many results as can be contained within the maximum permitted reply size. To get any additional rows, you can call GetQueryResults and specify the jobReference returned above. Present only when the query completes successfully.
The REST-based representation of this data leverages a series of JSON f,v objects for indicating fields and values.
total_bytes_processed: Option<Int64Value>The total number of bytes processed for this query.
job_complete: Option<BoolValue>Whether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available.
errors: Vec<ErrorProto>Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages.
cache_hit: Option<BoolValue>Whether the query result was fetched from the query cache.
num_dml_affected_rows: Option<Int64Value>Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE.
Implementations
Sourceimpl GetQueryResultsResponse
impl GetQueryResultsResponse
Sourcepub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
pub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
pub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
Sets the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = GetQueryResultsResponse::new().set_job_reference(JobReference::default()/* use setters */);Sourcepub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
pub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
Sets or clears the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = GetQueryResultsResponse::new().set_or_clear_job_reference(Some(JobReference::default()/* use setters */));
let x = GetQueryResultsResponse::new().set_or_clear_job_reference(None::<JobReference>);Sourcepub fn set_total_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_total_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
Sets the value of total_rows.
Example
use wkt::UInt64Value;
let x = GetQueryResultsResponse::new().set_total_rows(UInt64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_or_clear_total_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
Sets or clears the value of total_rows.
Example
use wkt::UInt64Value;
let x = GetQueryResultsResponse::new().set_or_clear_total_rows(Some(UInt64Value::default()/* use setters */));
let x = GetQueryResultsResponse::new().set_or_clear_total_rows(None::<UInt64Value>);Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = GetQueryResultsResponse::new().set_page_token("example");Sourcepub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_bytes_processed.
Example
use wkt::Int64Value;
let x = GetQueryResultsResponse::new().set_total_bytes_processed(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_bytes_processed.
Example
use wkt::Int64Value;
let x = GetQueryResultsResponse::new().set_or_clear_total_bytes_processed(Some(Int64Value::default()/* use setters */));
let x = GetQueryResultsResponse::new().set_or_clear_total_bytes_processed(None::<Int64Value>);Sourcepub fn set_job_complete<T>(self, v: T) -> Self
pub fn set_job_complete<T>(self, v: T) -> Self
Sets the value of job_complete.
Example
use wkt::BoolValue;
let x = GetQueryResultsResponse::new().set_job_complete(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_job_complete<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_job_complete<T>(self, v: Option<T>) -> Self
Sets or clears the value of job_complete.
Example
use wkt::BoolValue;
let x = GetQueryResultsResponse::new().set_or_clear_job_complete(Some(BoolValue::default()/* use setters */));
let x = GetQueryResultsResponse::new().set_or_clear_job_complete(None::<BoolValue>);Sourcepub fn set_errors<T, V>(self, v: T) -> Self
pub fn set_errors<T, V>(self, v: T) -> Self
Sourcepub fn set_cache_hit<T>(self, v: T) -> Self
pub fn set_cache_hit<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
Sourcepub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_dml_affected_rows.
Example
use wkt::Int64Value;
let x = GetQueryResultsResponse::new().set_num_dml_affected_rows(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_dml_affected_rows.
Example
use wkt::Int64Value;
let x = GetQueryResultsResponse::new().set_or_clear_num_dml_affected_rows(Some(Int64Value::default()/* use setters */));
let x = GetQueryResultsResponse::new().set_or_clear_num_dml_affected_rows(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for GetQueryResultsResponse
impl Clone for GetQueryResultsResponse
Sourcefn clone(&self) -> GetQueryResultsResponse
fn clone(&self) -> GetQueryResultsResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GetQueryResultsResponse
impl Debug for GetQueryResultsResponse
Sourceimpl Default for GetQueryResultsResponse
impl Default for GetQueryResultsResponse
Sourcefn default() -> GetQueryResultsResponse
fn default() -> GetQueryResultsResponse
Sourceimpl Message for GetQueryResultsResponse
impl Message for GetQueryResultsResponse
Sourceimpl PartialEq for GetQueryResultsResponse
impl PartialEq for GetQueryResultsResponse
impl StructuralPartialEq for GetQueryResultsResponse