#[non_exhaustive]pub struct GoogleSheetsOptions {
pub skip_leading_rows: Option<Int64Value>,
pub range: String,
/* private fields */
}Expand description
Options specific to Google Sheets data sources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.skip_leading_rows: Option<Int64Value>Optional. The number of rows at the top of a sheet that BigQuery will skip when reading the data. The default value is 0. This property is useful if you have header rows that should be skipped. When autodetect is on, the behavior is the following:
- skipLeadingRows unspecified - Autodetect tries to detect headers in the first row. If they are not detected, the row is read as data. Otherwise data is read starting from the second row.
- skipLeadingRows is 0 - Instructs autodetect that there are no headers and data should be read starting from the first row.
- skipLeadingRows = N > 0 - Autodetect skips N-1 rows and tries to detect headers in row N. If headers are not detected, row N is just skipped. Otherwise row N is used to extract column names for the detected schema.
range: StringOptional. Range of a sheet to query from. Only used when non-empty. Typical format: sheet_name!top_left_cell_id:bottom_right_cell_id For example: sheet1!A1:B20
Implementations
Sourceimpl GoogleSheetsOptions
impl GoogleSheetsOptions
Sourcepub fn set_skip_leading_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_skip_leading_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of skip_leading_rows.
Example
ⓘ
use wkt::Int64Value;
let x = GoogleSheetsOptions::new().set_skip_leading_rows(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_skip_leading_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_skip_leading_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of skip_leading_rows.
Example
ⓘ
use wkt::Int64Value;
let x = GoogleSheetsOptions::new().set_or_clear_skip_leading_rows(Some(Int64Value::default()/* use setters */));
let x = GoogleSheetsOptions::new().set_or_clear_skip_leading_rows(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for GoogleSheetsOptions
impl Clone for GoogleSheetsOptions
Sourcefn clone(&self) -> GoogleSheetsOptions
fn clone(&self) -> GoogleSheetsOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GoogleSheetsOptions
impl Debug for GoogleSheetsOptions
Sourceimpl Default for GoogleSheetsOptions
impl Default for GoogleSheetsOptions
Sourcefn default() -> GoogleSheetsOptions
fn default() -> GoogleSheetsOptions
Returns the “default value” for a type. Read more
Sourceimpl Message for GoogleSheetsOptions
impl Message for GoogleSheetsOptions
Sourceimpl PartialEq for GoogleSheetsOptions
impl PartialEq for GoogleSheetsOptions
impl StructuralPartialEq for GoogleSheetsOptions