HivePartitioningOptions

Struct HivePartitioningOptions 

#[non_exhaustive]
pub struct HivePartitioningOptions { pub mode: String, pub source_uri_prefix: String, pub require_partition_filter: Option<BoolValue>, pub fields: Vec<String>, /* private fields */ }
Options for configuring hive partitioning detect.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mode: String

Optional. When set, what mode of hive partitioning to use when reading data. The following modes are supported:

  • AUTO: automatically infer partition key name(s) and type(s).

  • STRINGS: automatically infer partition key name(s). All types are strings.

  • CUSTOM: partition key schema is encoded in the source URI prefix.

Not all storage formats support hive partitioning. Requesting hive partitioning on an unsupported format will lead to an error. Currently supported formats are: JSON, CSV, ORC, Avro and Parquet.

source_uri_prefix: String

Optional. When hive partition detection is requested, a common prefix for all source uris must be required. The prefix must end immediately before the partition key encoding begins. For example, consider files following this data layout:

gs://bucket/path_to_table/dt=2019-06-01/country=USA/id=7/file.avro

gs://bucket/path_to_table/dt=2019-05-31/country=CA/id=3/file.avro

When hive partitioning is requested with either AUTO or STRINGS detection, the common prefix can be either of gs://bucket/path_to_table or gs://bucket/path_to_table/.

CUSTOM detection requires encoding the partitioning schema immediately after the common prefix. For CUSTOM, any of

  • gs://bucket/path_to_table/{dt:DATE}/{country:STRING}/{id:INTEGER}

  • gs://bucket/path_to_table/{dt:STRING}/{country:STRING}/{id:INTEGER}

  • gs://bucket/path_to_table/{dt:DATE}/{country:STRING}/{id:STRING}

would all be valid source URI prefixes.

require_partition_filter: Option<BoolValue>

Optional. If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.

Note that this field should only be true when creating a permanent external table or querying a temporary external table.

Hive-partitioned loads with require_partition_filter explicitly set to true will fail.

fields: Vec<String>

Output only. For permanent external tables, this field is populated with the hive partition keys in the order they were inferred. The types of the partition keys can be deduced by checking the table schema (which will include the partition keys). Not every API will populate this field in the output. For example, Tables.Get will populate it, but Tables.List will not contain this field.

Implementations

Source

impl HivePartitioningOptions

pub fn new() -> Self

Creates a new default instance.

pub fn set_mode<T: Into<String>>(self, v: T) -> Self

Sets the value of mode.

Example
let x = HivePartitioningOptions::new().set_mode("example");
pub fn set_source_uri_prefix<T: Into<String>>(self, v: T) -> Self

Sets the value of source_uri_prefix.

Example
let x = HivePartitioningOptions::new().set_source_uri_prefix("example");
pub fn set_require_partition_filter<T>(self, v: T) -> Self
where T: Into<BoolValue>,

Sets the value of require_partition_filter.

Example
use wkt::BoolValue;
let x = HivePartitioningOptions::new().set_require_partition_filter(BoolValue::default()/* use setters */);
pub fn set_or_clear_require_partition_filter<T>(self, v: Option<T>) -> Self
where T: Into<BoolValue>,

Sets or clears the value of require_partition_filter.

Example
use wkt::BoolValue;
let x = HivePartitioningOptions::new().set_or_clear_require_partition_filter(Some(BoolValue::default()/* use setters */));
let x = HivePartitioningOptions::new().set_or_clear_require_partition_filter(None::<BoolValue>);
pub fn set_fields<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of fields.

Example
let x = HivePartitioningOptions::new().set_fields(["a", "b", "c"]);