#[non_exhaustive]pub struct IncrementalResultStats {
pub disabled_reason: DisabledReason,
pub disabled_reason_details: String,
pub result_set_last_replace_time: Option<Timestamp>,
pub result_set_last_modify_time: Option<Timestamp>,
pub first_incremental_row_time: Option<Timestamp>,
pub last_incremental_row_time: Option<Timestamp>,
pub incremental_row_count: Option<i64>,
/* private fields */
}Expand description
Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disabled_reason: DisabledReasonOutput only. Reason why incremental query results are/were not written by the query.
disabled_reason_details: StringOutput only. Additional human-readable clarification, if available, for DisabledReason.
result_set_last_replace_time: Option<Timestamp>Output only. The time at which the result table’s contents were completely replaced. May be absent if no results have been written or the query has completed.
result_set_last_modify_time: Option<Timestamp>Output only. The time at which the result table’s contents were modified. May be absent if no results have been written or the query has completed.
first_incremental_row_time: Option<Timestamp>Output only. The time at which the first incremental result was written. If the query needed to restart internally, this only describes the final attempt.
last_incremental_row_time: Option<Timestamp>Output only. The time at which the last incremental result was written. Does not include the final result written after query completion.
incremental_row_count: Option<i64>Output only. Number of rows that were in the latest result set before query completion.
Implementations
Sourceimpl IncrementalResultStats
impl IncrementalResultStats
Sourcepub fn set_disabled_reason<T: Into<DisabledReason>>(self, v: T) -> Self
pub fn set_disabled_reason<T: Into<DisabledReason>>(self, v: T) -> Self
Sets the value of disabled_reason.
Example
use google_cloud_bigquery_v2::model::incremental_result_stats::DisabledReason;
let x0 = IncrementalResultStats::new().set_disabled_reason(DisabledReason::Other);
let x1 = IncrementalResultStats::new().set_disabled_reason(DisabledReason::UnsupportedOperator);Sourcepub fn set_disabled_reason_details<T: Into<String>>(self, v: T) -> Self
pub fn set_disabled_reason_details<T: Into<String>>(self, v: T) -> Self
Sets the value of disabled_reason_details.
Example
let x = IncrementalResultStats::new().set_disabled_reason_details("example");Sourcepub fn set_result_set_last_replace_time<T>(self, v: T) -> Self
pub fn set_result_set_last_replace_time<T>(self, v: T) -> Self
Sets the value of result_set_last_replace_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_result_set_last_replace_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_result_set_last_replace_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_result_set_last_replace_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of result_set_last_replace_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_result_set_last_replace_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_result_set_last_replace_time(None::<Timestamp>);Sourcepub fn set_result_set_last_modify_time<T>(self, v: T) -> Self
pub fn set_result_set_last_modify_time<T>(self, v: T) -> Self
Sets the value of result_set_last_modify_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_result_set_last_modify_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_result_set_last_modify_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_result_set_last_modify_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of result_set_last_modify_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_result_set_last_modify_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_result_set_last_modify_time(None::<Timestamp>);Sourcepub fn set_first_incremental_row_time<T>(self, v: T) -> Self
pub fn set_first_incremental_row_time<T>(self, v: T) -> Self
Sets the value of first_incremental_row_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_first_incremental_row_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_first_incremental_row_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_first_incremental_row_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of first_incremental_row_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_first_incremental_row_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_first_incremental_row_time(None::<Timestamp>);Sourcepub fn set_last_incremental_row_time<T>(self, v: T) -> Self
pub fn set_last_incremental_row_time<T>(self, v: T) -> Self
Sets the value of last_incremental_row_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_last_incremental_row_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_incremental_row_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_incremental_row_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_incremental_row_time.
Example
use wkt::Timestamp;
let x = IncrementalResultStats::new().set_or_clear_last_incremental_row_time(Some(Timestamp::default()/* use setters */));
let x = IncrementalResultStats::new().set_or_clear_last_incremental_row_time(None::<Timestamp>);Sourcepub fn set_incremental_row_count<T>(self, v: T) -> Self
pub fn set_incremental_row_count<T>(self, v: T) -> Self
Sets the value of incremental_row_count.
Example
let x = IncrementalResultStats::new().set_incremental_row_count(42);Sourcepub fn set_or_clear_incremental_row_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_incremental_row_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of incremental_row_count.
Example
let x = IncrementalResultStats::new().set_or_clear_incremental_row_count(Some(42));
let x = IncrementalResultStats::new().set_or_clear_incremental_row_count(None::<i32>);Trait Implementations
Sourceimpl Clone for IncrementalResultStats
impl Clone for IncrementalResultStats
Sourcefn clone(&self) -> IncrementalResultStats
fn clone(&self) -> IncrementalResultStats
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IncrementalResultStats
impl Debug for IncrementalResultStats
Sourceimpl Default for IncrementalResultStats
impl Default for IncrementalResultStats
Sourcefn default() -> IncrementalResultStats
fn default() -> IncrementalResultStats
Sourceimpl Message for IncrementalResultStats
impl Message for IncrementalResultStats
Sourceimpl PartialEq for IncrementalResultStats
impl PartialEq for IncrementalResultStats
impl StructuralPartialEq for IncrementalResultStats