InsertDatasetRequest

Struct InsertDatasetRequest 

#[non_exhaustive]
pub struct InsertDatasetRequest { pub project_id: String, pub dataset: Option<Dataset>, pub access_policy_version: i32, /* private fields */ }
Request format for inserting a dataset.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
project_id: String

Required. Project ID of the new dataset

dataset: Option<Dataset>

Required. Datasets resource to use for the new dataset

access_policy_version: i32

Optional. The version of the provided access policy schema. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected.

This version refers to the schema version of the access policy and not the version of access policy. This field’s value can be equal or more than the access policy schema provided in the request. For example,

  • Requests with conditional access policy binding in datasets must specify version 3.
  • But dataset with no conditional role bindings in access policy may specify any valid value or leave the field unset. If unset or if 0 or 1 value is used for dataset with conditional bindings, request will be rejected.

This field will be mapped to IAM Policy version (https://cloud.google.com/iam/docs/policies#versions) and will be used to set policy in IAM.

Implementations

Source

impl InsertDatasetRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of project_id.

Example
let x = InsertDatasetRequest::new().set_project_id("example");
pub fn set_dataset<T>(self, v: T) -> Self
where T: Into<Dataset>,

Sets the value of dataset.

Example
use google_cloud_bigquery_v2::model::Dataset;
let x = InsertDatasetRequest::new().set_dataset(Dataset::default()/* use setters */);
pub fn set_or_clear_dataset<T>(self, v: Option<T>) -> Self
where T: Into<Dataset>,

Sets or clears the value of dataset.

Example
use google_cloud_bigquery_v2::model::Dataset;
let x = InsertDatasetRequest::new().set_or_clear_dataset(Some(Dataset::default()/* use setters */));
let x = InsertDatasetRequest::new().set_or_clear_dataset(None::<Dataset>);
pub fn set_access_policy_version<T: Into<i32>>(self, v: T) -> Self

Sets the value of access_policy_version.

Example
let x = InsertDatasetRequest::new().set_access_policy_version(42);