#[non_exhaustive]pub struct JobConfiguration {
pub job_type: String,
pub query: Option<JobConfigurationQuery>,
pub load: Option<JobConfigurationLoad>,
pub copy: Option<JobConfigurationTableCopy>,
pub extract: Option<JobConfigurationExtract>,
pub dry_run: Option<BoolValue>,
pub job_timeout_ms: Option<Int64Value>,
pub max_slots: Option<i32>,
pub labels: HashMap<String, String>,
pub reservation: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_type: StringOutput only. The type of the job. Can be QUERY, LOAD, EXTRACT, COPY or UNKNOWN.
query: Option<JobConfigurationQuery>[Pick one] Configures a query job.
load: Option<JobConfigurationLoad>[Pick one] Configures a load job.
copy: Option<JobConfigurationTableCopy>[Pick one] Copies a table.
extract: Option<JobConfigurationExtract>[Pick one] Configures an extract job.
dry_run: Option<BoolValue>Optional. If set, don’t actually run this job. A valid query will return a mostly empty response with some processing statistics, while an invalid query will return the same error it would if it wasn’t a dry run. Behavior of non-query jobs is undefined.
job_timeout_ms: Option<Int64Value>Optional. Job timeout in milliseconds relative to the job creation time. If this time limit is exceeded, BigQuery attempts to stop the job, but might not always succeed in canceling it before the job completes. For example, a job that takes more than 60 seconds to complete has a better chance of being stopped than a job that takes 10 seconds to complete.
max_slots: Option<i32>Optional. A target limit on the rate of slot consumption by this job. If set to a value > 0, BigQuery will attempt to limit the rate of slot consumption by this job to keep it below the configured limit, even if the job is eligible for more slots based on fair scheduling. The unused slots will be available for other jobs and queries to use.
Note: This feature is not yet generally available.
labels: HashMap<String, String>The labels associated with this job. You can use these to organize and group your jobs. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter and each label in the list must have a different key.
reservation: Option<String>Optional. The reservation that job would use. User can specify a
reservation to execute the job. If reservation is not set, reservation is
determined based on the rules defined by the reservation assignments. The
expected format is
projects/{project}/locations/{location}/reservations/{reservation}.
Forces the query to use on-demand billing when set to none, which
requires the project or organization to have
reservation_override_mode set to ALLOW_ANY_OVERRIDE.
Implementations
Sourceimpl JobConfiguration
impl JobConfiguration
Sourcepub fn set_job_type<T: Into<String>>(self, v: T) -> Self
pub fn set_job_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_query<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationQuery>,
pub fn set_query<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationQuery>,
Sourcepub fn set_or_clear_query<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationQuery>,
pub fn set_or_clear_query<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationQuery>,
Sourcepub fn set_load<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationLoad>,
pub fn set_load<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationLoad>,
Sourcepub fn set_or_clear_load<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationLoad>,
pub fn set_or_clear_load<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationLoad>,
Sourcepub fn set_copy<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationTableCopy>,
pub fn set_copy<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationTableCopy>,
Sourcepub fn set_or_clear_copy<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationTableCopy>,
pub fn set_or_clear_copy<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationTableCopy>,
Sets or clears the value of copy.
Example
use google_cloud_bigquery_v2::model::JobConfigurationTableCopy;
let x = JobConfiguration::new().set_or_clear_copy(Some(JobConfigurationTableCopy::default()/* use setters */));
let x = JobConfiguration::new().set_or_clear_copy(None::<JobConfigurationTableCopy>);Sourcepub fn set_extract<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationExtract>,
pub fn set_extract<T>(self, v: T) -> Selfwhere
T: Into<JobConfigurationExtract>,
Sourcepub fn set_or_clear_extract<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationExtract>,
pub fn set_or_clear_extract<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfigurationExtract>,
Sets or clears the value of extract.
Example
use google_cloud_bigquery_v2::model::JobConfigurationExtract;
let x = JobConfiguration::new().set_or_clear_extract(Some(JobConfigurationExtract::default()/* use setters */));
let x = JobConfiguration::new().set_or_clear_extract(None::<JobConfigurationExtract>);Sourcepub fn set_dry_run<T>(self, v: T) -> Self
pub fn set_dry_run<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_dry_run<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_dry_run<T>(self, v: Option<T>) -> Self
Sourcepub fn set_job_timeout_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_job_timeout_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of job_timeout_ms.
Example
use wkt::Int64Value;
let x = JobConfiguration::new().set_job_timeout_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_job_timeout_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_job_timeout_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of job_timeout_ms.
Example
use wkt::Int64Value;
let x = JobConfiguration::new().set_or_clear_job_timeout_ms(Some(Int64Value::default()/* use setters */));
let x = JobConfiguration::new().set_or_clear_job_timeout_ms(None::<Int64Value>);Sourcepub fn set_max_slots<T>(self, v: T) -> Self
pub fn set_max_slots<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_max_slots<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_slots<T>(self, v: Option<T>) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_reservation<T>(self, v: T) -> Self
pub fn set_reservation<T>(self, v: T) -> Self
Sets the value of reservation.
Example
let x = JobConfiguration::new().set_reservation("example");Sourcepub fn set_or_clear_reservation<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_reservation<T>(self, v: Option<T>) -> Self
Sets or clears the value of reservation.
Example
let x = JobConfiguration::new().set_or_clear_reservation(Some("example"));
let x = JobConfiguration::new().set_or_clear_reservation(None::<String>);Trait Implementations
Sourceimpl Clone for JobConfiguration
impl Clone for JobConfiguration
Sourcefn clone(&self) -> JobConfiguration
fn clone(&self) -> JobConfiguration
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for JobConfiguration
impl Debug for JobConfiguration
Sourceimpl Default for JobConfiguration
impl Default for JobConfiguration
Sourcefn default() -> JobConfiguration
fn default() -> JobConfiguration
Sourceimpl Message for JobConfiguration
impl Message for JobConfiguration
Sourceimpl PartialEq for JobConfiguration
impl PartialEq for JobConfiguration
impl StructuralPartialEq for JobConfiguration