#[non_exhaustive]pub struct JobConfigurationTableCopy {
pub source_table: Option<TableReference>,
pub source_tables: Vec<TableReference>,
pub destination_table: Option<TableReference>,
pub create_disposition: String,
pub write_disposition: String,
pub destination_encryption_configuration: Option<EncryptionConfiguration>,
pub operation_type: OperationType,
pub destination_expiration_time: Option<Timestamp>,
/* private fields */
}Expand description
JobConfigurationTableCopy configures a job that copies data from one table to another. For more information on copying tables, see Copy a table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_table: Option<TableReference>[Pick one] Source table to copy.
source_tables: Vec<TableReference>[Pick one] Source tables to copy.
destination_table: Option<TableReference>[Required] The destination table.
create_disposition: StringOptional. Specifies whether the job is allowed to create new tables. The following values are supported:
- CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
- CREATE_NEVER: The table must already exist. If it does not, a ‘notFound’ error is returned in the job result.
The default value is CREATE_IF_NEEDED. Creation, truncation and append actions occur as one atomic update upon job completion.
write_disposition: StringOptional. Specifies the action that occurs if the destination table already exists. The following values are supported:
- WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the table data and uses the schema and table constraints from the source table.
- WRITE_APPEND: If the table already exists, BigQuery appends the data to the table.
- WRITE_EMPTY: If the table already exists and contains data, a ‘duplicate’ error is returned in the job result.
The default value is WRITE_EMPTY. Each action is atomic and only occurs if BigQuery is able to complete the job successfully. Creation, truncation and append actions occur as one atomic update upon job completion.
destination_encryption_configuration: Option<EncryptionConfiguration>Custom encryption configuration (e.g., Cloud KMS keys).
operation_type: OperationTypeOptional. Supported operation types in table copy job.
destination_expiration_time: Option<Timestamp>Optional. The time when the destination table expires. Expired tables will be deleted and their storage reclaimed.
Implementations
Sourceimpl JobConfigurationTableCopy
impl JobConfigurationTableCopy
Sourcepub fn set_source_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_source_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of source_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationTableCopy::new().set_source_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_source_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_source_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of source_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationTableCopy::new().set_or_clear_source_table(Some(TableReference::default()/* use setters */));
let x = JobConfigurationTableCopy::new().set_or_clear_source_table(None::<TableReference>);Sourcepub fn set_source_tables<T, V>(self, v: T) -> Self
pub fn set_source_tables<T, V>(self, v: T) -> Self
Sets the value of source_tables.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationTableCopy::new()
.set_source_tables([
TableReference::default()/* use setters */,
TableReference::default()/* use (different) setters */,
]);Sourcepub fn set_destination_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_destination_table<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of destination_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationTableCopy::new().set_destination_table(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_destination_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_destination_table<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of destination_table.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = JobConfigurationTableCopy::new().set_or_clear_destination_table(Some(TableReference::default()/* use setters */));
let x = JobConfigurationTableCopy::new().set_or_clear_destination_table(None::<TableReference>);Sourcepub fn set_create_disposition<T: Into<String>>(self, v: T) -> Self
pub fn set_create_disposition<T: Into<String>>(self, v: T) -> Self
Sets the value of create_disposition.
Example
let x = JobConfigurationTableCopy::new().set_create_disposition("example");Sourcepub fn set_write_disposition<T: Into<String>>(self, v: T) -> Self
pub fn set_write_disposition<T: Into<String>>(self, v: T) -> Self
Sets the value of write_disposition.
Example
let x = JobConfigurationTableCopy::new().set_write_disposition("example");Sourcepub fn set_destination_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_destination_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets the value of destination_encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = JobConfigurationTableCopy::new().set_destination_encryption_configuration(EncryptionConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_destination_encryption_configuration<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_or_clear_destination_encryption_configuration<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets or clears the value of destination_encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = JobConfigurationTableCopy::new().set_or_clear_destination_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = JobConfigurationTableCopy::new().set_or_clear_destination_encryption_configuration(None::<EncryptionConfiguration>);Sourcepub fn set_operation_type<T: Into<OperationType>>(self, v: T) -> Self
pub fn set_operation_type<T: Into<OperationType>>(self, v: T) -> Self
Sets the value of operation_type.
Example
use google_cloud_bigquery_v2::model::job_configuration_table_copy::OperationType;
let x0 = JobConfigurationTableCopy::new().set_operation_type(OperationType::Copy);
let x1 = JobConfigurationTableCopy::new().set_operation_type(OperationType::Snapshot);
let x2 = JobConfigurationTableCopy::new().set_operation_type(OperationType::Restore);Sourcepub fn set_destination_expiration_time<T>(self, v: T) -> Self
pub fn set_destination_expiration_time<T>(self, v: T) -> Self
Sets the value of destination_expiration_time.
Example
use wkt::Timestamp;
let x = JobConfigurationTableCopy::new().set_destination_expiration_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_destination_expiration_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_destination_expiration_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of destination_expiration_time.
Example
use wkt::Timestamp;
let x = JobConfigurationTableCopy::new().set_or_clear_destination_expiration_time(Some(Timestamp::default()/* use setters */));
let x = JobConfigurationTableCopy::new().set_or_clear_destination_expiration_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for JobConfigurationTableCopy
impl Clone for JobConfigurationTableCopy
Sourcefn clone(&self) -> JobConfigurationTableCopy
fn clone(&self) -> JobConfigurationTableCopy
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for JobConfigurationTableCopy
impl Debug for JobConfigurationTableCopy
Sourceimpl Default for JobConfigurationTableCopy
impl Default for JobConfigurationTableCopy
Sourcefn default() -> JobConfigurationTableCopy
fn default() -> JobConfigurationTableCopy
Sourceimpl Message for JobConfigurationTableCopy
impl Message for JobConfigurationTableCopy
impl StructuralPartialEq for JobConfigurationTableCopy