#[non_exhaustive]pub struct JobStatistics3 {
pub input_files: Option<Int64Value>,
pub input_file_bytes: Option<Int64Value>,
pub output_rows: Option<Int64Value>,
pub output_bytes: Option<Int64Value>,
pub bad_records: Option<Int64Value>,
pub timeline: Vec<QueryTimelineSample>,
/* private fields */
}Expand description
Statistics for a load job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_files: Option<Int64Value>Output only. Number of source files in a load job.
input_file_bytes: Option<Int64Value>Output only. Number of bytes of source data in a load job.
output_rows: Option<Int64Value>Output only. Number of rows imported in a load job. Note that while an import job is in the running state, this value may change.
output_bytes: Option<Int64Value>Output only. Size of the loaded data in bytes. Note that while a load job is in the running state, this value may change.
bad_records: Option<Int64Value>Output only. The number of bad records encountered. Note that if the job has failed because of more bad records encountered than the maximum allowed in the load job configuration, then this number can be less than the total number of bad records present in the input data.
timeline: Vec<QueryTimelineSample>Output only. Describes a timeline of job execution.
Implementations
Sourceimpl JobStatistics3
impl JobStatistics3
Sourcepub fn set_input_files<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_input_files<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of input_files.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_input_files(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_input_files<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_input_files<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of input_files.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_or_clear_input_files(Some(Int64Value::default()/* use setters */));
let x = JobStatistics3::new().set_or_clear_input_files(None::<Int64Value>);Sourcepub fn set_input_file_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_input_file_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of input_file_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_input_file_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_input_file_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_input_file_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of input_file_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_or_clear_input_file_bytes(Some(Int64Value::default()/* use setters */));
let x = JobStatistics3::new().set_or_clear_input_file_bytes(None::<Int64Value>);Sourcepub fn set_output_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_output_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of output_rows.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_output_rows(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_output_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_output_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of output_rows.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_or_clear_output_rows(Some(Int64Value::default()/* use setters */));
let x = JobStatistics3::new().set_or_clear_output_rows(None::<Int64Value>);Sourcepub fn set_output_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_output_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of output_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_output_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_output_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_output_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of output_bytes.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_or_clear_output_bytes(Some(Int64Value::default()/* use setters */));
let x = JobStatistics3::new().set_or_clear_output_bytes(None::<Int64Value>);Sourcepub fn set_bad_records<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_bad_records<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of bad_records.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_bad_records(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_bad_records<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_bad_records<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of bad_records.
Example
use wkt::Int64Value;
let x = JobStatistics3::new().set_or_clear_bad_records(Some(Int64Value::default()/* use setters */));
let x = JobStatistics3::new().set_or_clear_bad_records(None::<Int64Value>);Sourcepub fn set_timeline<T, V>(self, v: T) -> Self
pub fn set_timeline<T, V>(self, v: T) -> Self