#[non_exhaustive]pub struct ListFormatJob {
pub id: String,
pub kind: String,
pub job_reference: Option<JobReference>,
pub state: String,
pub error_result: Option<ErrorProto>,
pub statistics: Option<JobStatistics>,
pub configuration: Option<JobConfiguration>,
pub status: Option<JobStatus>,
pub user_email: String,
pub principal_subject: String,
/* private fields */
}Expand description
ListFormatJob is a partial projection of job information returned as part of a jobs.list response.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique opaque ID of the job.
kind: StringThe resource type.
job_reference: Option<JobReference>Unique opaque ID of the job.
state: StringRunning state of the job. When the state is DONE, errorResult can be checked to determine whether the job succeeded or failed.
error_result: Option<ErrorProto>A result object that will be present only if the job has failed.
statistics: Option<JobStatistics>Output only. Information about the job, including starting time and ending time of the job.
configuration: Option<JobConfiguration>Required. Describes the job configuration.
status: Option<JobStatus>[Full-projection-only] Describes the status of this job.
user_email: String[Full-projection-only] Email address of the user who ran the job.
principal_subject: String[Full-projection-only] String representation of identity of requesting party. Populated for both first- and third-party identities. Only present for APIs that support third-party identities.
Implementations
Sourceimpl ListFormatJob
impl ListFormatJob
Sourcepub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
pub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
Sets the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = ListFormatJob::new().set_job_reference(JobReference::default()/* use setters */);Sourcepub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
pub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
Sets or clears the value of job_reference.
Example
use google_cloud_bigquery_v2::model::JobReference;
let x = ListFormatJob::new().set_or_clear_job_reference(Some(JobReference::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_job_reference(None::<JobReference>);Sourcepub fn set_error_result<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_error_result<T>(self, v: T) -> Selfwhere
T: Into<ErrorProto>,
Sets the value of error_result.
Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = ListFormatJob::new().set_error_result(ErrorProto::default()/* use setters */);Sourcepub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
pub fn set_or_clear_error_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorProto>,
Sets or clears the value of error_result.
Example
use google_cloud_bigquery_v2::model::ErrorProto;
let x = ListFormatJob::new().set_or_clear_error_result(Some(ErrorProto::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_error_result(None::<ErrorProto>);Sourcepub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
Sets the value of statistics.
Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = ListFormatJob::new().set_statistics(JobStatistics::default()/* use setters */);Sourcepub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
Sets or clears the value of statistics.
Example
use google_cloud_bigquery_v2::model::JobStatistics;
let x = ListFormatJob::new().set_or_clear_statistics(Some(JobStatistics::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_statistics(None::<JobStatistics>);Sourcepub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
Sets the value of configuration.
Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = ListFormatJob::new().set_configuration(JobConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
Sets or clears the value of configuration.
Example
use google_cloud_bigquery_v2::model::JobConfiguration;
let x = ListFormatJob::new().set_or_clear_configuration(Some(JobConfiguration::default()/* use setters */));
let x = ListFormatJob::new().set_or_clear_configuration(None::<JobConfiguration>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sourcepub fn set_user_email<T: Into<String>>(self, v: T) -> Self
pub fn set_user_email<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
pub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
Sets the value of principal_subject.
Example
let x = ListFormatJob::new().set_principal_subject("example");Trait Implementations
Sourceimpl Clone for ListFormatJob
impl Clone for ListFormatJob
Sourcefn clone(&self) -> ListFormatJob
fn clone(&self) -> ListFormatJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListFormatJob
impl Debug for ListFormatJob
Sourceimpl Default for ListFormatJob
impl Default for ListFormatJob
Sourcefn default() -> ListFormatJob
fn default() -> ListFormatJob
Sourceimpl Message for ListFormatJob
impl Message for ListFormatJob
Sourceimpl PartialEq for ListFormatJob
impl PartialEq for ListFormatJob
impl StructuralPartialEq for ListFormatJob