MlStatistics

Struct MlStatistics 

#[non_exhaustive]
pub struct MlStatistics { pub max_iterations: i64, pub iteration_results: Vec<IterationResult>, pub model_type: ModelType, pub training_type: TrainingType, pub hparam_trials: Vec<HparamTuningTrial>, /* private fields */ }
Job statistics specific to a BigQuery ML training job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_iterations: i64

Output only. Maximum number of iterations specified as max_iterations in the ‘CREATE MODEL’ query. The actual number of iterations may be less than this number due to early stop.

iteration_results: Vec<IterationResult>

Results for all completed iterations. Empty for hyperparameter tuning jobs.

model_type: ModelType

Output only. The type of the model that is being trained.

training_type: TrainingType

Output only. Training type of the job.

hparam_trials: Vec<HparamTuningTrial>

Output only. Trials of a hyperparameter tuning job sorted by trial_id.

Implementations

Source

impl MlStatistics

pub fn new() -> Self

Creates a new default instance.

pub fn set_max_iterations<T: Into<i64>>(self, v: T) -> Self

Sets the value of max_iterations.

Example
let x = MlStatistics::new().set_max_iterations(42);
pub fn set_iteration_results<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<IterationResult>,

Sets the value of iteration_results.

Example
use google_cloud_bigquery_v2::model::model::training_run::IterationResult;
let x = MlStatistics::new()
    .set_iteration_results([
        IterationResult::default()/* use setters */,
        IterationResult::default()/* use (different) setters */,
    ]);
pub fn set_model_type<T: Into<ModelType>>(self, v: T) -> Self

Sets the value of model_type.

Example
use google_cloud_bigquery_v2::model::model::ModelType;
let x0 = MlStatistics::new().set_model_type(ModelType::LinearRegression);
let x1 = MlStatistics::new().set_model_type(ModelType::LogisticRegression);
let x2 = MlStatistics::new().set_model_type(ModelType::Kmeans);
pub fn set_training_type<T: Into<TrainingType>>(self, v: T) -> Self

Sets the value of training_type.

Example
use google_cloud_bigquery_v2::model::ml_statistics::TrainingType;
let x0 = MlStatistics::new().set_training_type(TrainingType::SingleTraining);
let x1 = MlStatistics::new().set_training_type(TrainingType::HparamTuning);
pub fn set_hparam_trials<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<HparamTuningTrial>,

Sets the value of hparam_trials.

Example
use google_cloud_bigquery_v2::model::model::HparamTuningTrial;
let x = MlStatistics::new()
    .set_hparam_trials([
        HparamTuningTrial::default()/* use setters */,
        HparamTuningTrial::default()/* use (different) setters */,
    ]);