#[non_exhaustive]pub struct QueryTimelineSample {
pub elapsed_ms: Option<Int64Value>,
pub total_slot_ms: Option<Int64Value>,
pub pending_units: Option<Int64Value>,
pub completed_units: Option<Int64Value>,
pub active_units: Option<Int64Value>,
pub shuffle_ram_usage_ratio: Option<DoubleValue>,
pub estimated_runnable_units: Option<Int64Value>,
/* private fields */
}Expand description
Summary of the state of query execution at a given time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.elapsed_ms: Option<Int64Value>Milliseconds elapsed since the start of query execution.
total_slot_ms: Option<Int64Value>Cumulative slot-ms consumed by the query.
pending_units: Option<Int64Value>Total units of work remaining for the query. This number can be revised (increased or decreased) while the query is running.
completed_units: Option<Int64Value>Total parallel units of work completed by this query.
active_units: Option<Int64Value>Total number of active workers. This does not correspond directly to slot usage. This is the largest value observed since the last sample.
shuffle_ram_usage_ratio: Option<DoubleValue>Total shuffle usage ratio in shuffle RAM per reservation of this query. This will be provided for reservation customers only.
estimated_runnable_units: Option<Int64Value>Units of work that can be scheduled immediately. Providing additional slots for these units of work will accelerate the query, if no other query in the reservation needs additional slots.
Implementations
Sourceimpl QueryTimelineSample
impl QueryTimelineSample
Sourcepub fn set_elapsed_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_elapsed_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of elapsed_ms.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_elapsed_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_elapsed_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_elapsed_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of elapsed_ms.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_elapsed_ms(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_elapsed_ms(None::<Int64Value>);Sourcepub fn set_total_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_slot_ms<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_slot_ms.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_total_slot_ms(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_slot_ms.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_total_slot_ms(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_total_slot_ms(None::<Int64Value>);Sourcepub fn set_pending_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_pending_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of pending_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_pending_units(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_pending_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_pending_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of pending_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_pending_units(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_pending_units(None::<Int64Value>);Sourcepub fn set_completed_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_completed_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of completed_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_completed_units(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_completed_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_completed_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of completed_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_completed_units(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_completed_units(None::<Int64Value>);Sourcepub fn set_active_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_active_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of active_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_active_units(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_active_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_active_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of active_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_active_units(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_active_units(None::<Int64Value>);Sourcepub fn set_shuffle_ram_usage_ratio<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_shuffle_ram_usage_ratio<T>(self, v: T) -> Selfwhere
T: Into<DoubleValue>,
Sets the value of shuffle_ram_usage_ratio.
Example
use wkt::DoubleValue;
let x = QueryTimelineSample::new().set_shuffle_ram_usage_ratio(DoubleValue::default()/* use setters */);Sourcepub fn set_or_clear_shuffle_ram_usage_ratio<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
pub fn set_or_clear_shuffle_ram_usage_ratio<T>(self, v: Option<T>) -> Selfwhere
T: Into<DoubleValue>,
Sets or clears the value of shuffle_ram_usage_ratio.
Example
use wkt::DoubleValue;
let x = QueryTimelineSample::new().set_or_clear_shuffle_ram_usage_ratio(Some(DoubleValue::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_shuffle_ram_usage_ratio(None::<DoubleValue>);Sourcepub fn set_estimated_runnable_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_estimated_runnable_units<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of estimated_runnable_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_estimated_runnable_units(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_estimated_runnable_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_estimated_runnable_units<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of estimated_runnable_units.
Example
use wkt::Int64Value;
let x = QueryTimelineSample::new().set_or_clear_estimated_runnable_units(Some(Int64Value::default()/* use setters */));
let x = QueryTimelineSample::new().set_or_clear_estimated_runnable_units(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for QueryTimelineSample
impl Clone for QueryTimelineSample
Sourcefn clone(&self) -> QueryTimelineSample
fn clone(&self) -> QueryTimelineSample
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for QueryTimelineSample
impl Debug for QueryTimelineSample
Sourceimpl Default for QueryTimelineSample
impl Default for QueryTimelineSample
Sourcefn default() -> QueryTimelineSample
fn default() -> QueryTimelineSample
Sourceimpl Message for QueryTimelineSample
impl Message for QueryTimelineSample
Sourceimpl PartialEq for QueryTimelineSample
impl PartialEq for QueryTimelineSample
impl StructuralPartialEq for QueryTimelineSample