#[non_exhaustive]pub struct SparkOptions {
pub connection: String,
pub runtime_version: String,
pub container_image: String,
pub properties: HashMap<String, String>,
pub main_file_uri: String,
pub py_file_uris: Vec<String>,
pub jar_uris: Vec<String>,
pub file_uris: Vec<String>,
pub archive_uris: Vec<String>,
pub main_class: String,
/* private fields */
}Expand description
Options for a user-defined Spark routine.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection: StringFully qualified name of the user-provided Spark connection object. Format:
"projects/{project_id}/locations/{location_id}/connections/{connection_id}"
runtime_version: StringRuntime version. If not specified, the default runtime version is used.
container_image: StringCustom container image for the runtime environment.
properties: HashMap<String, String>Configuration properties as a set of key/value pairs, which will be passed on to the Spark application. For more information, see Apache Spark and the procedure option list.
main_file_uri: StringThe main file/jar URI of the Spark application. Exactly one of the definition_body field and the main_file_uri field must be set for Python. Exactly one of main_class and main_file_uri field should be set for Java/Scala language type.
py_file_uris: Vec<String>Python files to be placed on the PYTHONPATH for PySpark application.
Supported file types: .py, .egg, and .zip. For more information
about Apache Spark, see
Apache Spark.
jar_uris: Vec<String>JARs to include on the driver and executor CLASSPATH. For more information about Apache Spark, see Apache Spark.
file_uris: Vec<String>Files to be placed in the working directory of each executor. For more information about Apache Spark, see Apache Spark.
archive_uris: Vec<String>Archive files to be extracted into the working directory of each executor. For more information about Apache Spark, see Apache Spark.
main_class: StringThe fully qualified name of a class in jar_uris, for example, com.example.wordcount. Exactly one of main_class and main_jar_uri field should be set for Java/Scala language type.
Implementations
Sourceimpl SparkOptions
impl SparkOptions
Sourcepub fn set_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_connection<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_runtime_version<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_version<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_version.
Example
let x = SparkOptions::new().set_runtime_version("example");Sourcepub fn set_container_image<T: Into<String>>(self, v: T) -> Self
pub fn set_container_image<T: Into<String>>(self, v: T) -> Self
Sets the value of container_image.
Example
let x = SparkOptions::new().set_container_image("example");Sourcepub fn set_properties<T, K, V>(self, v: T) -> Self
pub fn set_properties<T, K, V>(self, v: T) -> Self
Sets the value of properties.
Example
let x = SparkOptions::new().set_properties([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_main_file_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_main_file_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of main_file_uri.
Example
let x = SparkOptions::new().set_main_file_uri("example");Sourcepub fn set_py_file_uris<T, V>(self, v: T) -> Self
pub fn set_py_file_uris<T, V>(self, v: T) -> Self
Sets the value of py_file_uris.
Example
let x = SparkOptions::new().set_py_file_uris(["a", "b", "c"]);Sourcepub fn set_jar_uris<T, V>(self, v: T) -> Self
pub fn set_jar_uris<T, V>(self, v: T) -> Self
Sourcepub fn set_file_uris<T, V>(self, v: T) -> Self
pub fn set_file_uris<T, V>(self, v: T) -> Self
Sourcepub fn set_archive_uris<T, V>(self, v: T) -> Self
pub fn set_archive_uris<T, V>(self, v: T) -> Self
Sets the value of archive_uris.
Example
let x = SparkOptions::new().set_archive_uris(["a", "b", "c"]);Sourcepub fn set_main_class<T: Into<String>>(self, v: T) -> Self
pub fn set_main_class<T: Into<String>>(self, v: T) -> Self