#[non_exhaustive]pub struct Table {Show 51 fields
pub kind: String,
pub etag: String,
pub id: String,
pub self_link: String,
pub table_reference: Option<TableReference>,
pub friendly_name: Option<StringValue>,
pub description: Option<StringValue>,
pub labels: HashMap<String, String>,
pub schema: Option<TableSchema>,
pub time_partitioning: Option<TimePartitioning>,
pub range_partitioning: Option<RangePartitioning>,
pub clustering: Option<Clustering>,
pub require_partition_filter: Option<BoolValue>,
pub partition_definition: Option<PartitioningDefinition>,
pub num_bytes: Option<Int64Value>,
pub num_physical_bytes: Option<Int64Value>,
pub num_long_term_bytes: Option<Int64Value>,
pub num_rows: Option<UInt64Value>,
pub creation_time: i64,
pub expiration_time: Option<Int64Value>,
pub last_modified_time: u64,
pub type: String,
pub view: Option<ViewDefinition>,
pub materialized_view: Option<MaterializedViewDefinition>,
pub materialized_view_status: Option<MaterializedViewStatus>,
pub external_data_configuration: Option<ExternalDataConfiguration>,
pub biglake_configuration: Option<BigLakeConfiguration>,
pub managed_table_type: ManagedTableType,
pub location: String,
pub streaming_buffer: Option<Streamingbuffer>,
pub encryption_configuration: Option<EncryptionConfiguration>,
pub snapshot_definition: Option<SnapshotDefinition>,
pub default_collation: Option<StringValue>,
pub default_rounding_mode: RoundingMode,
pub clone_definition: Option<CloneDefinition>,
pub num_time_travel_physical_bytes: Option<Int64Value>,
pub num_total_logical_bytes: Option<Int64Value>,
pub num_active_logical_bytes: Option<Int64Value>,
pub num_long_term_logical_bytes: Option<Int64Value>,
pub num_current_physical_bytes: Option<Int64Value>,
pub num_total_physical_bytes: Option<Int64Value>,
pub num_active_physical_bytes: Option<Int64Value>,
pub num_long_term_physical_bytes: Option<Int64Value>,
pub num_partitions: Option<Int64Value>,
pub max_staleness: String,
pub restrictions: Option<RestrictionConfig>,
pub table_constraints: Option<TableConstraints>,
pub resource_tags: HashMap<String, String>,
pub table_replication_info: Option<TableReplicationInfo>,
pub replicas: Vec<TableReference>,
pub external_catalog_table_options: Option<ExternalCatalogTableOptions>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringThe type of resource ID.
etag: StringOutput only. A hash of this resource.
id: StringOutput only. An opaque ID uniquely identifying the table.
self_link: StringOutput only. A URL that can be used to access this resource again.
table_reference: Option<TableReference>Required. Reference describing the ID of this table.
friendly_name: Option<StringValue>Optional. A descriptive name for this table.
description: Option<StringValue>Optional. A user-friendly description of this table.
labels: HashMap<String, String>The labels associated with this table. You can use these to organize and group your tables. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter and each label in the list must have a different key.
schema: Option<TableSchema>Optional. Describes the schema of this table.
time_partitioning: Option<TimePartitioning>If specified, configures time-based partitioning for this table.
range_partitioning: Option<RangePartitioning>If specified, configures range partitioning for this table.
clustering: Option<Clustering>Clustering specification for the table. Must be specified with time-based partitioning, data in the table will be first partitioned and subsequently clustered.
require_partition_filter: Option<BoolValue>Optional. If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
partition_definition: Option<PartitioningDefinition>Optional. The partition information for all table formats, including managed partitioned tables, hive partitioned tables, iceberg partitioned, and metastore partitioned tables. This field is only populated for metastore partitioned tables. For other table formats, this is an output only field.
num_bytes: Option<Int64Value>Output only. The size of this table in logical bytes, excluding any data in the streaming buffer.
num_physical_bytes: Option<Int64Value>Output only. The physical size of this table in bytes. This includes storage used for time travel.
num_long_term_bytes: Option<Int64Value>Output only. The number of logical bytes in the table that are considered “long-term storage”.
num_rows: Option<UInt64Value>Output only. The number of rows of data in this table, excluding any data in the streaming buffer.
creation_time: i64Output only. The time when this table was created, in milliseconds since the epoch.
expiration_time: Option<Int64Value>Optional. The time when this table expires, in milliseconds since the epoch. If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed. The defaultTableExpirationMs property of the encapsulating dataset can be used to set a default expirationTime on newly created tables.
last_modified_time: u64Output only. The time when this table was last modified, in milliseconds since the epoch.
type: StringOutput only. Describes the table type. The following values are supported:
TABLE: A normal BigQuery table.VIEW: A virtual table defined by a SQL query.EXTERNAL: A table that references data stored in an external storage system, such as Google Cloud Storage.MATERIALIZED_VIEW: A precomputed view defined by a SQL query.SNAPSHOT: An immutable BigQuery table that preserves the contents of a base table at a particular time. See additional information on table snapshots.
The default value is TABLE.
view: Option<ViewDefinition>Optional. The view definition.
materialized_view: Option<MaterializedViewDefinition>Optional. The materialized view definition.
materialized_view_status: Option<MaterializedViewStatus>Output only. The materialized view status.
external_data_configuration: Option<ExternalDataConfiguration>Optional. Describes the data format, location, and other properties of a table stored outside of BigQuery. By defining these properties, the data source can then be queried as if it were a standard BigQuery table.
biglake_configuration: Option<BigLakeConfiguration>Optional. Specifies the configuration of a BigQuery table for Apache Iceberg.
managed_table_type: ManagedTableTypeOptional. If set, overrides the default managed table type configured in the dataset.
location: StringOutput only. The geographic location where the table resides. This value is inherited from the dataset.
streaming_buffer: Option<Streamingbuffer>Output only. Contains information regarding this table’s streaming buffer, if one is present. This field will be absent if the table is not being streamed to or if there is no data in the streaming buffer.
encryption_configuration: Option<EncryptionConfiguration>Custom encryption configuration (e.g., Cloud KMS keys).
snapshot_definition: Option<SnapshotDefinition>Output only. Contains information about the snapshot. This value is set via snapshot creation.
default_collation: Option<StringValue>Optional. Defines the default collation specification of new STRING fields in the table. During table creation or update, if a STRING field is added to this table without explicit collation specified, then the table inherits the table default collation. A change to this field affects only fields added afterwards, and does not alter the existing fields. The following values are supported:
- ‘und:ci’: undetermined locale, case insensitive.
- ‘’: empty string. Default to case-sensitive behavior.
default_rounding_mode: RoundingModeOptional. Defines the default rounding mode specification of new decimal fields (NUMERIC OR BIGNUMERIC) in the table. During table creation or update, if a decimal field is added to this table without an explicit rounding mode specified, then the field inherits the table default rounding mode. Changing this field doesn’t affect existing fields.
clone_definition: Option<CloneDefinition>Output only. Contains information about the clone. This value is set via the clone operation.
num_time_travel_physical_bytes: Option<Int64Value>Output only. Number of physical bytes used by time travel storage (deleted or changed data). This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
num_total_logical_bytes: Option<Int64Value>Output only. Total number of logical bytes in the table or materialized view.
num_active_logical_bytes: Option<Int64Value>Output only. Number of logical bytes that are less than 90 days old.
num_long_term_logical_bytes: Option<Int64Value>Output only. Number of logical bytes that are more than 90 days old.
num_current_physical_bytes: Option<Int64Value>Output only. Number of physical bytes used by current live data storage. This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
num_total_physical_bytes: Option<Int64Value>Output only. The physical size of this table in bytes. This also includes storage used for time travel. This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
num_active_physical_bytes: Option<Int64Value>Output only. Number of physical bytes less than 90 days old. This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
num_long_term_physical_bytes: Option<Int64Value>Output only. Number of physical bytes more than 90 days old. This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
num_partitions: Option<Int64Value>Output only. The number of partitions present in the table or materialized view. This data is not kept in real time, and might be delayed by a few seconds to a few minutes.
max_staleness: StringOptional. The maximum staleness of data that could be returned when the table (or stale MV) is queried. Staleness encoded as a string encoding of sql IntervalValue type.
restrictions: Option<RestrictionConfig>Optional. Output only. Restriction config for table. If set, restrict certain accesses on the table based on the config. See Data egress for more details.
table_constraints: Option<TableConstraints>Optional. Tables Primary Key and Foreign Key information
Optional. The tags attached to this table. Tag keys are globally unique. Tag key is expected to be in the namespaced format, for example “123456789012/environment” where 123456789012 is the ID of the parent organization or project resource for this tag key. Tag value is expected to be the short name, for example “Production”. See Tag definitions for more details.
table_replication_info: Option<TableReplicationInfo>Optional. Table replication info for table created AS REPLICA DDL like:
CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv
replicas: Vec<TableReference>Optional. Output only. Table references of all replicas currently active on the table.
external_catalog_table_options: Option<ExternalCatalogTableOptions>Optional. Options defining open source compatible table.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn set_self_link<T: Into<String>>(self, v: T) -> Self
pub fn set_self_link<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<TableReference>,
Sets the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = Table::new().set_table_reference(TableReference::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReference>,
Sets or clears the value of table_reference.
Example
use google_cloud_bigquery_v2::model::TableReference;
let x = Table::new().set_or_clear_table_reference(Some(TableReference::default()/* use setters */));
let x = Table::new().set_or_clear_table_reference(None::<TableReference>);Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = Table::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = Table::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = Table::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of description.
Example
use wkt::StringValue;
let x = Table::new().set_description(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of description.
Example
use wkt::StringValue;
let x = Table::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = Table::new().set_or_clear_description(None::<StringValue>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
pub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
Sourcepub fn set_time_partitioning<T>(self, v: T) -> Selfwhere
T: Into<TimePartitioning>,
pub fn set_time_partitioning<T>(self, v: T) -> Selfwhere
T: Into<TimePartitioning>,
Sets the value of time_partitioning.
Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = Table::new().set_time_partitioning(TimePartitioning::default()/* use setters */);Sourcepub fn set_or_clear_time_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimePartitioning>,
pub fn set_or_clear_time_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimePartitioning>,
Sets or clears the value of time_partitioning.
Example
use google_cloud_bigquery_v2::model::TimePartitioning;
let x = Table::new().set_or_clear_time_partitioning(Some(TimePartitioning::default()/* use setters */));
let x = Table::new().set_or_clear_time_partitioning(None::<TimePartitioning>);Sourcepub fn set_range_partitioning<T>(self, v: T) -> Selfwhere
T: Into<RangePartitioning>,
pub fn set_range_partitioning<T>(self, v: T) -> Selfwhere
T: Into<RangePartitioning>,
Sets the value of range_partitioning.
Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = Table::new().set_range_partitioning(RangePartitioning::default()/* use setters */);Sourcepub fn set_or_clear_range_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangePartitioning>,
pub fn set_or_clear_range_partitioning<T>(self, v: Option<T>) -> Selfwhere
T: Into<RangePartitioning>,
Sets or clears the value of range_partitioning.
Example
use google_cloud_bigquery_v2::model::RangePartitioning;
let x = Table::new().set_or_clear_range_partitioning(Some(RangePartitioning::default()/* use setters */));
let x = Table::new().set_or_clear_range_partitioning(None::<RangePartitioning>);Sourcepub fn set_clustering<T>(self, v: T) -> Selfwhere
T: Into<Clustering>,
pub fn set_clustering<T>(self, v: T) -> Selfwhere
T: Into<Clustering>,
Sets the value of clustering.
Example
use google_cloud_bigquery_v2::model::Clustering;
let x = Table::new().set_clustering(Clustering::default()/* use setters */);Sourcepub fn set_or_clear_clustering<T>(self, v: Option<T>) -> Selfwhere
T: Into<Clustering>,
pub fn set_or_clear_clustering<T>(self, v: Option<T>) -> Selfwhere
T: Into<Clustering>,
Sets or clears the value of clustering.
Example
use google_cloud_bigquery_v2::model::Clustering;
let x = Table::new().set_or_clear_clustering(Some(Clustering::default()/* use setters */));
let x = Table::new().set_or_clear_clustering(None::<Clustering>);Sourcepub fn set_require_partition_filter<T>(self, v: T) -> Self
pub fn set_require_partition_filter<T>(self, v: T) -> Self
Sets the value of require_partition_filter.
Example
use wkt::BoolValue;
let x = Table::new().set_require_partition_filter(BoolValue::default()/* use setters */);Sourcepub fn set_or_clear_require_partition_filter<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_require_partition_filter<T>(self, v: Option<T>) -> Self
Sets or clears the value of require_partition_filter.
Example
use wkt::BoolValue;
let x = Table::new().set_or_clear_require_partition_filter(Some(BoolValue::default()/* use setters */));
let x = Table::new().set_or_clear_require_partition_filter(None::<BoolValue>);Sourcepub fn set_partition_definition<T>(self, v: T) -> Selfwhere
T: Into<PartitioningDefinition>,
pub fn set_partition_definition<T>(self, v: T) -> Selfwhere
T: Into<PartitioningDefinition>,
Sets the value of partition_definition.
Example
use google_cloud_bigquery_v2::model::PartitioningDefinition;
let x = Table::new().set_partition_definition(PartitioningDefinition::default()/* use setters */);Sourcepub fn set_or_clear_partition_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<PartitioningDefinition>,
pub fn set_or_clear_partition_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<PartitioningDefinition>,
Sets or clears the value of partition_definition.
Example
use google_cloud_bigquery_v2::model::PartitioningDefinition;
let x = Table::new().set_or_clear_partition_definition(Some(PartitioningDefinition::default()/* use setters */));
let x = Table::new().set_or_clear_partition_definition(None::<PartitioningDefinition>);Sourcepub fn set_num_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_num_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_num_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_long_term_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_long_term_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_long_term_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_long_term_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_long_term_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_long_term_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_long_term_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_long_term_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_long_term_bytes(None::<Int64Value>);Sourcepub fn set_num_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_num_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
Sourcepub fn set_or_clear_num_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_or_clear_num_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
Sourcepub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
pub fn set_creation_time<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_expiration_time<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_expiration_time<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of expiration_time.
Example
use wkt::Int64Value;
let x = Table::new().set_expiration_time(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_expiration_time<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_expiration_time<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of expiration_time.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_expiration_time(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_expiration_time(None::<Int64Value>);Sourcepub fn set_last_modified_time<T: Into<u64>>(self, v: T) -> Self
pub fn set_last_modified_time<T: Into<u64>>(self, v: T) -> Self
Sets the value of last_modified_time.
Example
let x = Table::new().set_last_modified_time(42_u32);Sourcepub fn set_view<T>(self, v: T) -> Selfwhere
T: Into<ViewDefinition>,
pub fn set_view<T>(self, v: T) -> Selfwhere
T: Into<ViewDefinition>,
Sourcepub fn set_or_clear_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<ViewDefinition>,
pub fn set_or_clear_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<ViewDefinition>,
Sourcepub fn set_materialized_view<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewDefinition>,
pub fn set_materialized_view<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewDefinition>,
Sets the value of materialized_view.
Example
use google_cloud_bigquery_v2::model::MaterializedViewDefinition;
let x = Table::new().set_materialized_view(MaterializedViewDefinition::default()/* use setters */);Sourcepub fn set_or_clear_materialized_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewDefinition>,
pub fn set_or_clear_materialized_view<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewDefinition>,
Sets or clears the value of materialized_view.
Example
use google_cloud_bigquery_v2::model::MaterializedViewDefinition;
let x = Table::new().set_or_clear_materialized_view(Some(MaterializedViewDefinition::default()/* use setters */));
let x = Table::new().set_or_clear_materialized_view(None::<MaterializedViewDefinition>);Sourcepub fn set_materialized_view_status<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewStatus>,
pub fn set_materialized_view_status<T>(self, v: T) -> Selfwhere
T: Into<MaterializedViewStatus>,
Sets the value of materialized_view_status.
Example
use google_cloud_bigquery_v2::model::MaterializedViewStatus;
let x = Table::new().set_materialized_view_status(MaterializedViewStatus::default()/* use setters */);Sourcepub fn set_or_clear_materialized_view_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewStatus>,
pub fn set_or_clear_materialized_view_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<MaterializedViewStatus>,
Sets or clears the value of materialized_view_status.
Example
use google_cloud_bigquery_v2::model::MaterializedViewStatus;
let x = Table::new().set_or_clear_materialized_view_status(Some(MaterializedViewStatus::default()/* use setters */));
let x = Table::new().set_or_clear_materialized_view_status(None::<MaterializedViewStatus>);Sourcepub fn set_external_data_configuration<T>(self, v: T) -> Selfwhere
T: Into<ExternalDataConfiguration>,
pub fn set_external_data_configuration<T>(self, v: T) -> Selfwhere
T: Into<ExternalDataConfiguration>,
Sets the value of external_data_configuration.
Example
use google_cloud_bigquery_v2::model::ExternalDataConfiguration;
let x = Table::new().set_external_data_configuration(ExternalDataConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_external_data_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDataConfiguration>,
pub fn set_or_clear_external_data_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalDataConfiguration>,
Sets or clears the value of external_data_configuration.
Example
use google_cloud_bigquery_v2::model::ExternalDataConfiguration;
let x = Table::new().set_or_clear_external_data_configuration(Some(ExternalDataConfiguration::default()/* use setters */));
let x = Table::new().set_or_clear_external_data_configuration(None::<ExternalDataConfiguration>);Sourcepub fn set_biglake_configuration<T>(self, v: T) -> Selfwhere
T: Into<BigLakeConfiguration>,
pub fn set_biglake_configuration<T>(self, v: T) -> Selfwhere
T: Into<BigLakeConfiguration>,
Sets the value of biglake_configuration.
Example
use google_cloud_bigquery_v2::model::BigLakeConfiguration;
let x = Table::new().set_biglake_configuration(BigLakeConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_biglake_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigLakeConfiguration>,
pub fn set_or_clear_biglake_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigLakeConfiguration>,
Sets or clears the value of biglake_configuration.
Example
use google_cloud_bigquery_v2::model::BigLakeConfiguration;
let x = Table::new().set_or_clear_biglake_configuration(Some(BigLakeConfiguration::default()/* use setters */));
let x = Table::new().set_or_clear_biglake_configuration(None::<BigLakeConfiguration>);Sourcepub fn set_managed_table_type<T: Into<ManagedTableType>>(self, v: T) -> Self
pub fn set_managed_table_type<T: Into<ManagedTableType>>(self, v: T) -> Self
Sets the value of managed_table_type.
Example
use google_cloud_bigquery_v2::model::ManagedTableType;
let x0 = Table::new().set_managed_table_type(ManagedTableType::Native);
let x1 = Table::new().set_managed_table_type(ManagedTableType::Biglake);Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_streaming_buffer<T>(self, v: T) -> Selfwhere
T: Into<Streamingbuffer>,
pub fn set_streaming_buffer<T>(self, v: T) -> Selfwhere
T: Into<Streamingbuffer>,
Sets the value of streaming_buffer.
Example
use google_cloud_bigquery_v2::model::Streamingbuffer;
let x = Table::new().set_streaming_buffer(Streamingbuffer::default()/* use setters */);Sourcepub fn set_or_clear_streaming_buffer<T>(self, v: Option<T>) -> Selfwhere
T: Into<Streamingbuffer>,
pub fn set_or_clear_streaming_buffer<T>(self, v: Option<T>) -> Selfwhere
T: Into<Streamingbuffer>,
Sets or clears the value of streaming_buffer.
Example
use google_cloud_bigquery_v2::model::Streamingbuffer;
let x = Table::new().set_or_clear_streaming_buffer(Some(Streamingbuffer::default()/* use setters */));
let x = Table::new().set_or_clear_streaming_buffer(None::<Streamingbuffer>);Sourcepub fn set_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_encryption_configuration<T>(self, v: T) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets the value of encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Table::new().set_encryption_configuration(EncryptionConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_encryption_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionConfiguration>,
pub fn set_or_clear_encryption_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionConfiguration>,
Sets or clears the value of encryption_configuration.
Example
use google_cloud_bigquery_v2::model::EncryptionConfiguration;
let x = Table::new().set_or_clear_encryption_configuration(Some(EncryptionConfiguration::default()/* use setters */));
let x = Table::new().set_or_clear_encryption_configuration(None::<EncryptionConfiguration>);Sourcepub fn set_snapshot_definition<T>(self, v: T) -> Selfwhere
T: Into<SnapshotDefinition>,
pub fn set_snapshot_definition<T>(self, v: T) -> Selfwhere
T: Into<SnapshotDefinition>,
Sets the value of snapshot_definition.
Example
use google_cloud_bigquery_v2::model::SnapshotDefinition;
let x = Table::new().set_snapshot_definition(SnapshotDefinition::default()/* use setters */);Sourcepub fn set_or_clear_snapshot_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotDefinition>,
pub fn set_or_clear_snapshot_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotDefinition>,
Sets or clears the value of snapshot_definition.
Example
use google_cloud_bigquery_v2::model::SnapshotDefinition;
let x = Table::new().set_or_clear_snapshot_definition(Some(SnapshotDefinition::default()/* use setters */));
let x = Table::new().set_or_clear_snapshot_definition(None::<SnapshotDefinition>);Sourcepub fn set_default_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_default_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of default_collation.
Example
use wkt::StringValue;
let x = Table::new().set_default_collation(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_default_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_default_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of default_collation.
Example
use wkt::StringValue;
let x = Table::new().set_or_clear_default_collation(Some(StringValue::default()/* use setters */));
let x = Table::new().set_or_clear_default_collation(None::<StringValue>);Sourcepub fn set_default_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
pub fn set_default_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
Sets the value of default_rounding_mode.
Example
use google_cloud_bigquery_v2::model::table_field_schema::RoundingMode;
let x0 = Table::new().set_default_rounding_mode(RoundingMode::RoundHalfAwayFromZero);
let x1 = Table::new().set_default_rounding_mode(RoundingMode::RoundHalfEven);Sourcepub fn set_clone_definition<T>(self, v: T) -> Selfwhere
T: Into<CloneDefinition>,
pub fn set_clone_definition<T>(self, v: T) -> Selfwhere
T: Into<CloneDefinition>,
Sets the value of clone_definition.
Example
use google_cloud_bigquery_v2::model::CloneDefinition;
let x = Table::new().set_clone_definition(CloneDefinition::default()/* use setters */);Sourcepub fn set_or_clear_clone_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<CloneDefinition>,
pub fn set_or_clear_clone_definition<T>(self, v: Option<T>) -> Selfwhere
T: Into<CloneDefinition>,
Sets or clears the value of clone_definition.
Example
use google_cloud_bigquery_v2::model::CloneDefinition;
let x = Table::new().set_or_clear_clone_definition(Some(CloneDefinition::default()/* use setters */));
let x = Table::new().set_or_clear_clone_definition(None::<CloneDefinition>);Sourcepub fn set_num_time_travel_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_time_travel_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_time_travel_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_time_travel_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_time_travel_physical_bytes<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_time_travel_physical_bytes<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_time_travel_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_time_travel_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_time_travel_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_total_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_total_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_total_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_total_logical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_total_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_total_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_total_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_total_logical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_total_logical_bytes(None::<Int64Value>);Sourcepub fn set_num_active_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_active_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_active_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_active_logical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_active_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_active_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_active_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_active_logical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_active_logical_bytes(None::<Int64Value>);Sourcepub fn set_num_long_term_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_long_term_logical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_long_term_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_long_term_logical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_long_term_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_long_term_logical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_long_term_logical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_long_term_logical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_long_term_logical_bytes(None::<Int64Value>);Sourcepub fn set_num_current_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_current_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_current_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_current_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_current_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_current_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_current_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_current_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_current_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_total_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_total_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_total_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_total_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_total_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_total_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_total_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_total_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_total_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_active_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_active_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_active_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_active_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_active_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_active_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_active_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_active_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_active_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_long_term_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_long_term_physical_bytes<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_long_term_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_num_long_term_physical_bytes(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_long_term_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_long_term_physical_bytes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_long_term_physical_bytes.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_long_term_physical_bytes(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_long_term_physical_bytes(None::<Int64Value>);Sourcepub fn set_num_partitions<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_partitions<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_partitions.
Example
use wkt::Int64Value;
let x = Table::new().set_num_partitions(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_num_partitions<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_partitions<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_partitions.
Example
use wkt::Int64Value;
let x = Table::new().set_or_clear_num_partitions(Some(Int64Value::default()/* use setters */));
let x = Table::new().set_or_clear_num_partitions(None::<Int64Value>);Sourcepub fn set_max_staleness<T: Into<String>>(self, v: T) -> Self
pub fn set_max_staleness<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_restrictions<T>(self, v: T) -> Selfwhere
T: Into<RestrictionConfig>,
pub fn set_restrictions<T>(self, v: T) -> Selfwhere
T: Into<RestrictionConfig>,
Sets the value of restrictions.
Example
use google_cloud_bigquery_v2::model::RestrictionConfig;
let x = Table::new().set_restrictions(RestrictionConfig::default()/* use setters */);Sourcepub fn set_or_clear_restrictions<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictionConfig>,
pub fn set_or_clear_restrictions<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictionConfig>,
Sets or clears the value of restrictions.
Example
use google_cloud_bigquery_v2::model::RestrictionConfig;
let x = Table::new().set_or_clear_restrictions(Some(RestrictionConfig::default()/* use setters */));
let x = Table::new().set_or_clear_restrictions(None::<RestrictionConfig>);Sourcepub fn set_table_constraints<T>(self, v: T) -> Selfwhere
T: Into<TableConstraints>,
pub fn set_table_constraints<T>(self, v: T) -> Selfwhere
T: Into<TableConstraints>,
Sets the value of table_constraints.
Example
use google_cloud_bigquery_v2::model::TableConstraints;
let x = Table::new().set_table_constraints(TableConstraints::default()/* use setters */);Sourcepub fn set_or_clear_table_constraints<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableConstraints>,
pub fn set_or_clear_table_constraints<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableConstraints>,
Sets or clears the value of table_constraints.
Example
use google_cloud_bigquery_v2::model::TableConstraints;
let x = Table::new().set_or_clear_table_constraints(Some(TableConstraints::default()/* use setters */));
let x = Table::new().set_or_clear_table_constraints(None::<TableConstraints>);Sets the value of resource_tags.
Example
let x = Table::new().set_resource_tags([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_table_replication_info<T>(self, v: T) -> Selfwhere
T: Into<TableReplicationInfo>,
pub fn set_table_replication_info<T>(self, v: T) -> Selfwhere
T: Into<TableReplicationInfo>,
Sets the value of table_replication_info.
Example
use google_cloud_bigquery_v2::model::TableReplicationInfo;
let x = Table::new().set_table_replication_info(TableReplicationInfo::default()/* use setters */);Sourcepub fn set_or_clear_table_replication_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReplicationInfo>,
pub fn set_or_clear_table_replication_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableReplicationInfo>,
Sets or clears the value of table_replication_info.
Example
use google_cloud_bigquery_v2::model::TableReplicationInfo;
let x = Table::new().set_or_clear_table_replication_info(Some(TableReplicationInfo::default()/* use setters */));
let x = Table::new().set_or_clear_table_replication_info(None::<TableReplicationInfo>);Sourcepub fn set_replicas<T, V>(self, v: T) -> Self
pub fn set_replicas<T, V>(self, v: T) -> Self
Sourcepub fn set_external_catalog_table_options<T>(self, v: T) -> Selfwhere
T: Into<ExternalCatalogTableOptions>,
pub fn set_external_catalog_table_options<T>(self, v: T) -> Selfwhere
T: Into<ExternalCatalogTableOptions>,
Sets the value of external_catalog_table_options.
Example
use google_cloud_bigquery_v2::model::ExternalCatalogTableOptions;
let x = Table::new().set_external_catalog_table_options(ExternalCatalogTableOptions::default()/* use setters */);Sourcepub fn set_or_clear_external_catalog_table_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExternalCatalogTableOptions>,
pub fn set_or_clear_external_catalog_table_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<ExternalCatalogTableOptions>,
Sets or clears the value of external_catalog_table_options.
Example
use google_cloud_bigquery_v2::model::ExternalCatalogTableOptions;
let x = Table::new().set_or_clear_external_catalog_table_options(Some(ExternalCatalogTableOptions::default()/* use setters */));
let x = Table::new().set_or_clear_external_catalog_table_options(None::<ExternalCatalogTableOptions>);Trait Implementations
impl StructuralPartialEq for Table