#[non_exhaustive]pub struct TableFieldSchema {Show 19 fields
pub name: String,
pub type: String,
pub mode: String,
pub fields: Vec<TableFieldSchema>,
pub description: Option<StringValue>,
pub policy_tags: Option<PolicyTagList>,
pub data_governance_tags_info: Option<DataGovernanceTagsInfo>,
pub data_policies: Vec<DataPolicyOption>,
pub data_policy_list: Option<DataPolicyList>,
pub max_length: i64,
pub precision: i64,
pub scale: i64,
pub timestamp_precision: Option<Int64Value>,
pub rounding_mode: RoundingMode,
pub collation: Option<StringValue>,
pub default_value_expression: Option<StringValue>,
pub range_element_type: Option<FieldElementType>,
pub foreign_type_definition: String,
pub generated_column: Option<GeneratedColumn>,
/* private fields */
}Expand description
A field in TableSchema
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The field name. The name must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_), and must start with a letter or underscore. The maximum length is 300 characters.
type: StringRequired. The field data type. Possible values include:
- STRING
- BYTES
- INTEGER (or INT64)
- FLOAT (or FLOAT64)
- BOOLEAN (or BOOL)
- TIMESTAMP
- DATE
- TIME
- DATETIME
- GEOGRAPHY
- NUMERIC
- BIGNUMERIC
- JSON
- RECORD (or STRUCT)
- RANGE
Use of RECORD/STRUCT indicates that the field contains a nested schema.
mode: StringOptional. The field mode. Possible values include NULLABLE, REQUIRED and REPEATED. The default value is NULLABLE.
fields: Vec<TableFieldSchema>Optional. Describes the nested schema fields if the type property is set to RECORD.
description: Option<StringValue>Optional. The field description. The maximum length is 1,024 characters.
Optional. The policy tags attached to this field, used for field-level access control. If not set, defaults to empty policy_tags.
Optional. Specifies the data governance tags on this field. This field works with other column-level security fields as follows:
- Precedence: If a data governance tag is attached to a column, it takes precedence over the policy tag attached to the column. However, if a data policy is attached to a column, it takes precedence over the data governance tag.
- Patching behavior: Describes how this field behaves during a
Table.patchschema update:- Unset: If the
data_governance_tags_infofield is omitted from the update request, the existing tags on the column are preserved. - Empty Field: To clear data governance tags from a column, send
the
data_governance_tags_infofield as an empty object. This removes all tags from the column. - Updating tags: To replace an existing tag, send the field with the new tag.
- Unset: If the
data_policies: Vec<DataPolicyOption>Optional. Data policies attached to this field, used for field-level access control.
data_policy_list: Option<DataPolicyList>Optional. Specifies data policies attached to this field, used for field-level access control. When set, this will be the source of truth for data policy information.
max_length: i64Optional. Maximum length of values of this field for STRINGS or BYTES.
If max_length is not specified, no maximum length constraint is imposed on this field.
If type = “STRING”, then max_length represents the maximum UTF-8 length of strings in this field.
If type = “BYTES”, then max_length represents the maximum number of bytes in this field.
It is invalid to set this field if type ≠ “STRING” and ≠ “BYTES”.
precision: i64Optional. Precision (maximum number of total digits in base 10) and scale (maximum number of digits in the fractional part in base 10) constraints for values of this field for NUMERIC or BIGNUMERIC.
It is invalid to set precision or scale if type ≠ “NUMERIC” and ≠ “BIGNUMERIC”.
If precision and scale are not specified, no value range constraint is imposed on this field insofar as values are permitted by the type.
Values of this NUMERIC or BIGNUMERIC field must be in this range when:
- Precision (<var>P</var>) and scale (<var>S</var>) are specified: [-10<sup><var>P</var>-<var>S</var></sup> + 10<sup>-<var>S</var></sup>, 10<sup><var>P</var>-<var>S</var></sup> - 10<sup>-<var>S</var></sup>]
- Precision (<var>P</var>) is specified but not scale (and thus scale is interpreted to be equal to zero): [-10<sup><var>P</var></sup> + 1, 10<sup><var>P</var></sup> - 1].
Acceptable values for precision and scale if both are specified:
- If type = “NUMERIC”: 1 ≤ precision - scale ≤ 29 and 0 ≤ scale ≤ 9.
- If type = “BIGNUMERIC”: 1 ≤ precision - scale ≤ 38 and 0 ≤ scale ≤ 38.
Acceptable values for precision if only precision is specified but not scale (and thus scale is interpreted to be equal to zero):
- If type = “NUMERIC”: 1 ≤ precision ≤ 29.
- If type = “BIGNUMERIC”: 1 ≤ precision ≤ 38.
If scale is specified but not precision, then it is invalid.
scale: i64Optional. See documentation for precision.
timestamp_precision: Option<Int64Value>Optional. Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type.
Possible values include:
- 6 (Default, for TIMESTAMP type with microsecond precision)
- 12 (For TIMESTAMP type with picosecond precision)
rounding_mode: RoundingModeOptional. Specifies the rounding mode to be used when storing values of NUMERIC and BIGNUMERIC type.
collation: Option<StringValue>Optional. Field collation can be set only when the type of field is STRING. The following values are supported:
- ‘und:ci’: undetermined locale, case insensitive.
- ‘’: empty string. Default to case-sensitive behavior.
default_value_expression: Option<StringValue>Optional. A SQL expression to specify the [default value] (https://cloud.google.com/bigquery/docs/default-values) for this field.
range_element_type: Option<FieldElementType>Optional. The subtype of the RANGE, if the type of this field is RANGE. If the type is RANGE, this field is required. Values for the field element type can be the following:
- DATE
- DATETIME
- TIMESTAMP
foreign_type_definition: StringOptional. Definition of the foreign data type. Only valid for top-level schema fields (not nested fields). If the type is FOREIGN, this field is required.
generated_column: Option<GeneratedColumn>Optional. Definition of how values are generated for the field. Only valid for top-level schema fields (not nested fields).
Implementations
Sourceimpl TableFieldSchema
impl TableFieldSchema
Sourcepub fn set_fields<T, V>(self, v: T) -> Self
pub fn set_fields<T, V>(self, v: T) -> Self
Sourcepub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of description.
Example
use wkt::StringValue;
let x = TableFieldSchema::new().set_description(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of description.
Example
use wkt::StringValue;
let x = TableFieldSchema::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_description(None::<StringValue>);Sets the value of policy_tags.
Example
use google_cloud_bigquery_v2::model::table_field_schema::PolicyTagList;
let x = TableFieldSchema::new().set_policy_tags(PolicyTagList::default()/* use setters */);Sets or clears the value of policy_tags.
Example
use google_cloud_bigquery_v2::model::table_field_schema::PolicyTagList;
let x = TableFieldSchema::new().set_or_clear_policy_tags(Some(PolicyTagList::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_policy_tags(None::<PolicyTagList>);Sets the value of data_governance_tags_info.
Example
use google_cloud_bigquery_v2::model::table_field_schema::DataGovernanceTagsInfo;
let x = TableFieldSchema::new().set_data_governance_tags_info(DataGovernanceTagsInfo::default()/* use setters */);Sets or clears the value of data_governance_tags_info.
Example
use google_cloud_bigquery_v2::model::table_field_schema::DataGovernanceTagsInfo;
let x = TableFieldSchema::new().set_or_clear_data_governance_tags_info(Some(DataGovernanceTagsInfo::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_data_governance_tags_info(None::<DataGovernanceTagsInfo>);Sourcepub fn set_data_policies<T, V>(self, v: T) -> Self
pub fn set_data_policies<T, V>(self, v: T) -> Self
Sets the value of data_policies.
Example
use google_cloud_bigquery_v2::model::DataPolicyOption;
let x = TableFieldSchema::new()
.set_data_policies([
DataPolicyOption::default()/* use setters */,
DataPolicyOption::default()/* use (different) setters */,
]);Sourcepub fn set_data_policy_list<T>(self, v: T) -> Selfwhere
T: Into<DataPolicyList>,
pub fn set_data_policy_list<T>(self, v: T) -> Selfwhere
T: Into<DataPolicyList>,
Sets the value of data_policy_list.
Example
use google_cloud_bigquery_v2::model::DataPolicyList;
let x = TableFieldSchema::new().set_data_policy_list(DataPolicyList::default()/* use setters */);Sourcepub fn set_or_clear_data_policy_list<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataPolicyList>,
pub fn set_or_clear_data_policy_list<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataPolicyList>,
Sets or clears the value of data_policy_list.
Example
use google_cloud_bigquery_v2::model::DataPolicyList;
let x = TableFieldSchema::new().set_or_clear_data_policy_list(Some(DataPolicyList::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_data_policy_list(None::<DataPolicyList>);Sourcepub fn set_max_length<T: Into<i64>>(self, v: T) -> Self
pub fn set_max_length<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_precision<T: Into<i64>>(self, v: T) -> Self
pub fn set_precision<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_timestamp_precision<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_timestamp_precision<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of timestamp_precision.
Example
use wkt::Int64Value;
let x = TableFieldSchema::new().set_timestamp_precision(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_timestamp_precision<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_timestamp_precision<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of timestamp_precision.
Example
use wkt::Int64Value;
let x = TableFieldSchema::new().set_or_clear_timestamp_precision(Some(Int64Value::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_timestamp_precision(None::<Int64Value>);Sourcepub fn set_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
pub fn set_rounding_mode<T: Into<RoundingMode>>(self, v: T) -> Self
Sets the value of rounding_mode.
Example
use google_cloud_bigquery_v2::model::table_field_schema::RoundingMode;
let x0 = TableFieldSchema::new().set_rounding_mode(RoundingMode::RoundHalfAwayFromZero);
let x1 = TableFieldSchema::new().set_rounding_mode(RoundingMode::RoundHalfEven);Sourcepub fn set_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_collation<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sourcepub fn set_or_clear_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_collation<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sourcepub fn set_default_value_expression<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_default_value_expression<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of default_value_expression.
Example
use wkt::StringValue;
let x = TableFieldSchema::new().set_default_value_expression(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_default_value_expression<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_default_value_expression<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of default_value_expression.
Example
use wkt::StringValue;
let x = TableFieldSchema::new().set_or_clear_default_value_expression(Some(StringValue::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_default_value_expression(None::<StringValue>);Sourcepub fn set_range_element_type<T>(self, v: T) -> Selfwhere
T: Into<FieldElementType>,
pub fn set_range_element_type<T>(self, v: T) -> Selfwhere
T: Into<FieldElementType>,
Sets the value of range_element_type.
Example
use google_cloud_bigquery_v2::model::table_field_schema::FieldElementType;
let x = TableFieldSchema::new().set_range_element_type(FieldElementType::default()/* use setters */);Sourcepub fn set_or_clear_range_element_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<FieldElementType>,
pub fn set_or_clear_range_element_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<FieldElementType>,
Sets or clears the value of range_element_type.
Example
use google_cloud_bigquery_v2::model::table_field_schema::FieldElementType;
let x = TableFieldSchema::new().set_or_clear_range_element_type(Some(FieldElementType::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_range_element_type(None::<FieldElementType>);Sourcepub fn set_foreign_type_definition<T: Into<String>>(self, v: T) -> Self
pub fn set_foreign_type_definition<T: Into<String>>(self, v: T) -> Self
Sets the value of foreign_type_definition.
Example
let x = TableFieldSchema::new().set_foreign_type_definition("example");Sourcepub fn set_generated_column<T>(self, v: T) -> Selfwhere
T: Into<GeneratedColumn>,
pub fn set_generated_column<T>(self, v: T) -> Selfwhere
T: Into<GeneratedColumn>,
Sets the value of generated_column.
Example
use google_cloud_bigquery_v2::model::table_field_schema::GeneratedColumn;
let x = TableFieldSchema::new().set_generated_column(GeneratedColumn::default()/* use setters */);Sourcepub fn set_or_clear_generated_column<T>(self, v: Option<T>) -> Selfwhere
T: Into<GeneratedColumn>,
pub fn set_or_clear_generated_column<T>(self, v: Option<T>) -> Selfwhere
T: Into<GeneratedColumn>,
Sets or clears the value of generated_column.
Example
use google_cloud_bigquery_v2::model::table_field_schema::GeneratedColumn;
let x = TableFieldSchema::new().set_or_clear_generated_column(Some(GeneratedColumn::default()/* use setters */));
let x = TableFieldSchema::new().set_or_clear_generated_column(None::<GeneratedColumn>);Trait Implementations
Sourceimpl Clone for TableFieldSchema
impl Clone for TableFieldSchema
Sourcefn clone(&self) -> TableFieldSchema
fn clone(&self) -> TableFieldSchema
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TableFieldSchema
impl Debug for TableFieldSchema
Sourceimpl Default for TableFieldSchema
impl Default for TableFieldSchema
Sourcefn default() -> TableFieldSchema
fn default() -> TableFieldSchema
Sourceimpl Message for TableFieldSchema
impl Message for TableFieldSchema
Sourceimpl PartialEq for TableFieldSchema
impl PartialEq for TableFieldSchema
impl StructuralPartialEq for TableFieldSchema