pub trait DatasetService:
Debug
+ Send
+ Sync {
// Provided methods
fn get_dataset(
&self,
_req: GetDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send { ... }
fn insert_dataset(
&self,
_req: InsertDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send { ... }
fn patch_dataset(
&self,
_req: UpdateOrPatchDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send { ... }
fn update_dataset(
&self,
_req: UpdateOrPatchDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send { ... }
fn delete_dataset(
&self,
_req: DeleteDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send { ... }
fn list_datasets(
&self,
_req: ListDatasetsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<DatasetList>>> + Send { ... }
fn undelete_dataset(
&self,
_req: UndeleteDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::DatasetService.
Application developers may need to implement this trait to mock
client::DatasetService. In other use-cases, application developers only
use client::DatasetService and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn get_dataset(
&self,
_req: GetDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send
fn get_dataset( &self, _req: GetDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Dataset>>> + Send
Implements super::client::DatasetService::get_dataset.
Sourcefn insert_dataset(
&self,
_req: InsertDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send
fn insert_dataset( &self, _req: InsertDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Dataset>>> + Send
Implements super::client::DatasetService::insert_dataset.
Sourcefn patch_dataset(
&self,
_req: UpdateOrPatchDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send
fn patch_dataset( &self, _req: UpdateOrPatchDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Dataset>>> + Send
Implements super::client::DatasetService::patch_dataset.
Sourcefn update_dataset(
&self,
_req: UpdateOrPatchDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send
fn update_dataset( &self, _req: UpdateOrPatchDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Dataset>>> + Send
Implements super::client::DatasetService::update_dataset.
Sourcefn delete_dataset(
&self,
_req: DeleteDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<()>>> + Send
fn delete_dataset( &self, _req: DeleteDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<()>>> + Send
Implements super::client::DatasetService::delete_dataset.
Sourcefn list_datasets(
&self,
_req: ListDatasetsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<DatasetList>>> + Send
fn list_datasets( &self, _req: ListDatasetsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<DatasetList>>> + Send
Implements super::client::DatasetService::list_datasets.
Sourcefn undelete_dataset(
&self,
_req: UndeleteDatasetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Dataset>>> + Send
fn undelete_dataset( &self, _req: UndeleteDatasetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Dataset>>> + Send
Implements super::client::DatasetService::undelete_dataset.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".